(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    167922,       5734]
NotebookOptionsPosition[    164093,       5619]
NotebookOutlinePosition[    164668,       5645]
CellTagsIndexPosition[    164594,       5640]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[StyleBox["Chapter 1  Complex Numbers",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.532709081703125*^9, 3.5327090825625*^9}},
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Overview",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell["\<\
\tGet ready for a treat.  You're about to begin studying some of the most \
beautiful ideas in mathematics.  They are ideas with surprises.  They evolved \
over several centuries, yet they greatly simplify extremely difficult \
computations, making some as easy as sliding a hot knife through butter.  \
They also have applications in a variety of areas, ranging from fluid flow, \
to electric circuits, to the mysterious quantum world. Generally, they are \
described as belonging to the area of mathematics known as complex analysis.\
\>", "Text",
 CellChangeTimes->{{3.39896788496875*^9, 3.398967892859375*^9}}],

Cell[TextData[StyleBox["Section 1.1  The Origin of Complex Numbers",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tComplex analysis can roughly be thought of as the subject that applies \
the theory of calculus to imaginary numbers.  But what exactly are imaginary \
numbers?  Usually, students learn about them in high school with introductory \
remarks from their teachers along the following lines: \"We can't take the \
square root of a negative number.  But let's pretend we can and begin by \
using the symbol ",
 Cell[BoxData[
  RowBox[{"\[ImaginaryI]", "=", 
   SqrtBox[
    RowBox[{"-", "1"}]]}]]],
 ".\"  Rules are then learned for doing arithmetic with these numbers.  At \
some level the rules make sense.  If ",
 Cell[BoxData[
  RowBox[{"\[ImaginaryI]", "=", 
   SqrtBox[
    RowBox[{"-", "1"}]]}]]],
 ", it stands to reason that ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ImaginaryI]", "2"], "=", 
   RowBox[{"-", "1"}]}]]],
 ". However, it is not uncommon for students to wonder whether they are \
really doing magic rather than mathematics."
}], "Text",
 CellChangeTimes->{{3.398967897234375*^9, 3.398967910390625*^9}}],

Cell["\<\
\tIf you ever felt that way, congratulate yourself!  You're in the company of \
some of the great mathematicians from the sixteenth through the nineteenth \
centuries.  They, too, were perplexed by the notion of roots of negative \
numbers.  Our purpose in this section is to highlight some of the episodes in \
the very colorful history of how thinking about imaginary numbers developed.  \
We intend to show you that, contrary to popular belief, there is really \
nothing imaginary about \"imaginary numbers.\"  They are just as real as \
\"real numbers.\"\
\>", "Text",
 CellChangeTimes->{{3.39896791690625*^9, 3.398967928140625*^9}}],

Cell[TextData[{
 "\tOur story begins in 1545.  In that year the Italian mathematician ",
 StyleBox[ButtonBox["Girolamo Cardano",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cardan.\
html"], None}],
  FontFamily->"Times New Roman",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 " published Ars Magna (The Great Art), a 40-chapter masterpiece in which he \
gave for the first time an algebraic solution to the ",
 StyleBox["general cubic equation",
  FontColor->RGBColor[0, 0, 1]],
 "  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["z", "3"], "+", 
    RowBox[{
     SubscriptBox["a", "2"], " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{
     SubscriptBox["a", "1"], " ", "z"}], " ", "+", " ", 
    SubscriptBox["a", "0"]}], " ", "=", " ", "0"}]]],
 ". "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{3.398967929875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "\tCardano did not have at his disposal the power of today's algebraic \
notation, and he tended to think of cubes or squares as geometric objects \
rather than algebraic quantities.  Essentially, however, his solution began \
with the substiution ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{"x", "-", 
    RowBox[{
     FractionBox["1", "3"], 
     SubscriptBox["a", "2"]}]}]}]]],
 ".  This move transforms  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["z", "3"], "+", 
    RowBox[{
     SubscriptBox["a", "2"], " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{
     SubscriptBox["a", "1"], " ", "z"}], " ", "+", " ", 
    SubscriptBox["a", "0"]}], " ", "=", " ", "0"}]]],
 "  into the cubic equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "3"], "+", 
    RowBox[{"b", " ", "x"}], " ", "+", " ", "c"}], " ", "=", " ", "0"}]]],
 "  without a squared term, which is called a depressed cubic and can be \
written as \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "3"], "+", 
    RowBox[{"b", " ", "x"}], " ", "+", " ", "c"}], " ", "=", " ", "0"}]]],
 ". \n\nYou need not worry about the computational details, but the \
coefficients are  ",
 Cell[BoxData[
  RowBox[{"b", " ", "=", " ", 
   RowBox[{
    SubscriptBox["a", "1"], "-", 
    RowBox[{
     FractionBox["1", "3"], 
     SubsuperscriptBox["a", "2", "2"]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"c", " ", "=", " ", 
   RowBox[{
    SubscriptBox["a", "0"], "-", 
    RowBox[{
     FractionBox["1", "3"], 
     SubscriptBox["a", "1"], " ", 
     SubscriptBox["a", "2"]}], "+", 
    RowBox[{
     FractionBox["1", "27"], "2", " ", 
     SubsuperscriptBox["a", "2", "3"]}]}]}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Exploration", "."}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506701722234375*^9, 3.506701722234375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqn0", " ", "=", 
     RowBox[{
      SuperscriptBox["z", "3"], "+", 
      RowBox[{
       SubscriptBox["a", "2"], " ", 
       SuperscriptBox["z", "2"]}], "+", 
      RowBox[{
       SubscriptBox["a", "1"], " ", "z"}], " ", "+", " ", 
      SubscriptBox["a", "0"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqn1", " ", "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"eqn0", ",", " ", 
       RowBox[{"z", "\[Rule]", " ", 
        RowBox[{"x", "-", 
         RowBox[{
          SubscriptBox["a", "2"], "/", "3"}]}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"eqn2", " ", "=", 
     RowBox[{"ExpandAll", "[", "eqn1", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"eqn3", " ", "=", " ", 
     RowBox[{"Collect", "[", 
      RowBox[{"eqn2", ",", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn0", "\[Equal]", "0"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Substitute  \>\"", ",", 
      RowBox[{"z", "\[Rule]", " ", 
       RowBox[{"x", "-", 
        RowBox[{
         SubscriptBox["a", "2"], "/", "3"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Get\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn1", "\[Equal]", "0"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn2", "\[Equal]", "0"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn3", "\[Equal]", "0"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"A", "=", 
     RowBox[{"CoefficientList", "[", 
      RowBox[{"eqn3", ",", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      SuperscriptBox["x", "3"], ",", "\"\< + (\>\"", ",", 
      SubscriptBox["A", 
       RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], ",", 
      "\"\<)\>\"", ",", "x", ",", "\"\< + (\>\"", ",", 
      SubscriptBox["A", 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<) = 0\>\""}], "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398968590234375*^9, 3.398968591546875*^9}}]
}, Closed]],

Cell[TextData[{
 "\tTo illustrate, begin with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["z", "3"], "+", 
    RowBox[{"9", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{"24", "z"}], "+", "20"}], " ", "=", " ", "0"}]]],
 "  and substitute  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "-", 
     RowBox[{
      FractionBox["1", "3"], 
      SubscriptBox["a", "2"]}]}], " ", "=", "  ", 
    RowBox[{
     RowBox[{"x", "-", 
      FractionBox["9", "3"]}], " ", "=", "  ", 
     RowBox[{"x", "-", "3"}]}]}]}]]],
 ".  The equation then becomes  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "-", "3"}], ")"}], "3"], "+", 
    RowBox[{"9", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "-", "3"}], ")"}], "2"]}], "+", 
    RowBox[{"24", " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", "3"}], ")"}]}], "+", "20"}], " ", "=", " ", "0"}]]],
 ", which simplifies to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "3"], "-", 
    RowBox[{"3", " ", "x"}], "+", "2"}], " ", "=", " ", "0"}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Exploration", "."}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670172621875*^9, 3.50670172621875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqn0", " ", "=", 
     RowBox[{
      SuperscriptBox["z", "3"], "+", 
      RowBox[{"9", 
       SuperscriptBox["z", "2"]}], "+", 
      RowBox[{"24", "z"}], "+", "20"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqn1", " ", "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"eqn0", ",", " ", 
       RowBox[{"z", "\[Rule]", " ", 
        RowBox[{"x", "-", 
         RowBox[{"9", "/", "3"}]}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"eqn2", " ", "=", 
     RowBox[{"ExpandAll", "[", "eqn1", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn0", "\[Equal]", "0"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Substitute  \>\"", ",", 
      RowBox[{"z", "\[Rule]", " ", 
       RowBox[{"x", "-", 
        RowBox[{"9", "/", "3"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Get\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn1", "\[Equal]", "0"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn2", "\[Equal]", "0"}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3989685975*^9, 3.39896859859375*^9}}]
}, Closed]],

Cell[TextData[{
 "\tIf Cardano could get any value of x that solved a depressed cubic, he \
could easily get a corresponding solution to ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["z", "3"], "+", 
    RowBox[{
     SubscriptBox["a", "2"], " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{
     SubscriptBox["a", "1"], " ", "z"}], " ", "+", " ", 
    SubscriptBox["a", "0"]}], " ", "=", " ", "0"}]]],
 " from the identity ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{"x", "-", 
    RowBox[{
     FractionBox["1", "3"], 
     SubscriptBox["a", "2"]}]}]}]]],
 ". Happily, Cardano knew how to solve a depressed cubic.  The technique had \
been communicated to him by Niccolo Fontana who, unfortunately, came to be \
known as ",
 StyleBox[ButtonBox["Tartaglia",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Tartaglia.\
html"], None}],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 " (the stammerer) due to a speaking disorder.  The procedure was also \
independently discovered some 30 years earlier by Scipione del Ferro of \
Bologna.  Ferro and Tartaglia showed that one of the solutions to the \
depressed cubic equation is\n\n\t\t",
 Cell[BoxData[
  RowBox[{"x", " ", "=", " ", 
   RowBox[{
    RadicalBox[
     RowBox[{
      FractionBox[
       RowBox[{"-", "c"}], "2"], " ", "+", " ", 
      SqrtBox[
       RowBox[{
        FractionBox[
         SuperscriptBox["c", "2"], "4"], "+", 
        FractionBox[
         SuperscriptBox["b", "3"], "27"]}]]}], "3"], " ", "+", " ", 
    RadicalBox[
     RowBox[{
      RowBox[{"-", 
       FractionBox["c", "2"]}], " ", "-", " ", 
      SqrtBox[
       RowBox[{
        FractionBox[
         SuperscriptBox["c", "2"], "4"], "+", 
        FractionBox[
         SuperscriptBox["b", "3"], "27"]}]]}], "3"]}]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text",
 CellChangeTimes->{{3.398967950421875*^9, 3.39896795578125*^9}}],

Cell[TextData[{
 "\tAlthough Cardano would not have reasoned in the following way, today we \
can take this value for x and use it to factor the depressed cubic into a \
linear and quadratic term.  The remaining roots can then be found with the \
quadratic formula. \n\n\tFor example, to solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["z", "3"], "+", 
    RowBox[{"9", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{"24", "z"}], "+", "20"}], " ", "=", " ", "0"}]]],
 ",  use the substitution  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"x", "-", "3"}]}]]],
 "  to get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "3"], "-", 
    RowBox[{"3", " ", "x"}], "+", "2"}], " ", "=", " ", "0"}]]],
 ",  which is a depressed cubic equation.  Next, apply the \
\"Ferro-Tartaglia\" formula with ",
 Cell[BoxData[
  RowBox[{"b", "=", 
   RowBox[{"-", "3"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"c", "=", "2"}]]],
 " to get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RadicalBox[
     RowBox[{
      FractionBox[
       RowBox[{"-", "2"}], "2"], " ", "+", " ", 
      SqrtBox[
       RowBox[{
        FractionBox[
         SuperscriptBox["2", "2"], "4"], "+", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "3"}], ")"}], "3"], "27"]}]]}], "3"], " ", "+", " ", 
    RadicalBox[
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "2"]}], " ", "-", " ", 
      SqrtBox[
       RowBox[{
        FractionBox[
         SuperscriptBox["2", "2"], "4"], "+", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "3"}], ")"}], "3"], "27"]}]]}], "3"]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], 
      RowBox[{"1", "/", "3"}]], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], 
      RowBox[{"1", "/", "3"}]]}], " ", "=", " ", 
    RowBox[{"-", "2"}]}]}]]],
 ".  Since  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{"-", "2"}]}]]],
 "  is a root,   ",
 Cell[BoxData[
  RowBox[{"x", "+", "2"}]]],
 "  must be a factor of  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["x", "3"], "-", 
   RowBox[{"3", " ", "x"}], "+", "2"}]]],
 ".  Dividing   ",
 Cell[BoxData[
  RowBox[{"x", "+", "2"}]]],
 "  into  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["x", "3"], "-", 
   RowBox[{"3", " ", "x"}], "+", "2"}]]],
 "  gives  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["x", "2"], "-", 
   RowBox[{"2", " ", "x"}], "+", "1"}]]],
 ",  which yields the remaining (duplicate) roots of   ",
 Cell[BoxData[
  RowBox[{"x", "=", "1"}]]],
 ".  The solutions to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["z", "3"], "+", 
    RowBox[{"9", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{"24", "z"}], "+", "20"}], " ", "=", " ", "0"}]]],
 "  are obtained by recalling  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"x", "-", "3"}]}]]],
 ", which yields the three roots  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], "-", "3"}], "=", 
    RowBox[{"-", "5"}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], " ", "=", " ", 
   RowBox[{
    SubscriptBox["z", "3"], "=", 
    RowBox[{
     RowBox[{"1", "-", "3"}], "=", 
     RowBox[{"-", "2"}]}]}]}]]],
 "."
}], "Text",
 CellChangeTimes->{3.3989679595625*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Exploration", "."}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506701730265625*^9, 3.506701730265625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqn0", " ", "=", 
     RowBox[{
      SuperscriptBox["z", "3"], "+", 
      RowBox[{"9", 
       SuperscriptBox["z", "2"]}], "+", 
      RowBox[{"24", "z"}], "+", "20"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqn1", " ", "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"eqn0", ",", " ", 
       RowBox[{"z", "\[Rule]", " ", 
        RowBox[{"x", "-", 
         RowBox[{"9", "/", "3"}]}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"eqn2", " ", "=", 
     RowBox[{"ExpandAll", "[", "eqn1", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn0", "\[Equal]", "0"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Substitute  \>\"", ",", 
      RowBox[{"z", "\[Rule]", " ", 
       RowBox[{"x", "-", 
        RowBox[{"9", "/", "3"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Get\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn1", "\[Equal]", "0"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn2", "\[Equal]", "0"}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39896860703125*^9, 3.39896862921875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Start with the Ferro-Tartaglia formula\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<x = \!\(\*RadicalBox[\(\*FractionBox[\(-c\), \(2\)]\\\  + \\\ \
\*SqrtBox[\(\*FractionBox[SuperscriptBox[\(c\), \(2\)], \(4\)] + \
\*FractionBox[SuperscriptBox[\(b\), \(3\)], \(27\)]\)]\), \(3\)]\) + \
\!\(\*RadicalBox[\(\(-\*FractionBox[\(c\), \(2\)]\)\\\  - \\\ \
\*SqrtBox[\(\*FractionBox[SuperscriptBox[\(c\), \(2\)], \(4\)] + \
\*FractionBox[SuperscriptBox[\(b\), \(3\)], \(27\)]\)]\), \(3\)]\)\>\"", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Substitute  b\[Rule]-3  and  c\[Rule]2  and  get\>\"", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x = \>\"", ",", 
      RowBox[{"ReplaceAll", "[", " ", 
       RowBox[{
        RowBox[{
         RadicalBox[
          RowBox[{
           FractionBox[
            RowBox[{"-", "c"}], "2"], " ", "+", " ", 
           SqrtBox[
            RowBox[{
             FractionBox[
              SuperscriptBox["c", "2"], "4"], "+", 
             FractionBox[
              SuperscriptBox["b", "3"], "27"]}]]}], "3"], " ", "+", " ", 
         RadicalBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["c", "2"]}], " ", "-", " ", 
           SqrtBox[
            RowBox[{
             FractionBox[
              SuperscriptBox["c", "2"], "4"], "+", 
             FractionBox[
              SuperscriptBox["b", "3"], "27"]}]]}], "3"]}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"b", "\[Rule]", "\"\<-3\>\""}], ",", 
          RowBox[{"c", "\[Rule]", "\"\<2\>\""}]}], "}"}]}], "]"}]}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which simplifies\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x = \>\"", ",", 
      RowBox[{"ReplaceAll", "[", " ", 
       RowBox[{
        RowBox[{
         RadicalBox[
          RowBox[{
           FractionBox[
            RowBox[{"-", "c"}], "2"], " ", "+", " ", 
           SqrtBox[
            RowBox[{
             FractionBox[
              SuperscriptBox["c", "2"], "4"], "+", 
             FractionBox[
              SuperscriptBox["b", "3"], "27"]}]]}], "3"], " ", "+", " ", 
         RadicalBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["c", "2"]}], " ", "-", " ", 
           SqrtBox[
            RowBox[{
             FractionBox[
              SuperscriptBox["c", "2"], "4"], "+", 
             FractionBox[
              SuperscriptBox["b", "3"], "27"]}]]}], "3"]}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"b", "\[Rule]", 
           RowBox[{"-", "3"}]}], ",", 
          RowBox[{"c", "\[Rule]", "2"}]}], "}"}]}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<And an answer is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<x = -2\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398968624*^9, 3.398968637890625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Now divide \!\(\*SuperscriptBox[\(x\), \(3\)]\)-3 x+2 by x+2\>\"", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Q", "[", "x_", "]"}], "=", 
     RowBox[{"PolynomialQuotient", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "3"], "-", 
        RowBox[{"3", " ", "x"}], "+", "2"}], ",", 
       RowBox[{"x", "+", "2"}], ",", "x"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Q[x] = \!\(\*FractionBox[\(\*SuperscriptBox[\(x\), \(3\)] - 3\\\ x \
+ 2\), \(x + 2\)]\) = \>\"", ",", 
      RowBox[{"Q", "[", "x", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Q", "[", "x", "]"}], "\[Equal]", "0"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Get\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", "x", "]"}], "\[Equal]", "0"}], ",", "x"}], " ", 
      "]"}], "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398968640984375*^9, 3.39896864715625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", "\"\<The solutions to\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"eqn0", "\[Equal]", "0"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Are\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<    \!\(\*SubscriptBox[\(z\), \(1\)]\) = x-3 = -2 - 3 = -5\>\"", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \!\(\*SubscriptBox[\(z\), \
\(3\)]\)= x-3 = 1 - 3 = -2\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3989686090625*^9, 3.3989686500625*^9}]
}, Closed]],

Cell[TextData[{
 "\tSo, by using Tartaglia's work and a clever transformation technique, \
Cardano was able to crack what had seemed to be the impossible task of \
solving the general cubic equation.  Surprisingly, this development played a \
significant role in helping to establish the legitimacy of imaginary numbers. \
 Roots of negative numbers, of course, had come up earlier in the simplest of \
quadratic equations, such as  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "2"], "+", "1"}], "=", "0"}]]],
 ".  The solutions we know today as  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{"\[PlusMinus]", 
    SqrtBox[
     RowBox[{"-", "1"}]]}]}]]],
 ", however, were easy for mathematicians to ignore.  In Cardano's time, \
negative numbers were still being treated with some suspicion, as it was \
difficult to conceive of any physical reality corresponding to them. Taking \
square roots of such quantities was surely all the more ludicrous. \
Nevertheless, Cardano made some genuine attempts to deal with ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"-", "1"}]]]],
 ".  Unfortunately, his geometric thinking made it hard to make much headway. \
 At one point he commented that the process of arithmetic that deals with \
quantities such as ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"-", "1"}]]]],
 " \"involves mental tortures and is truly sophisticated.\"  At another point \
he concluded that the process is \"as refined as it is useless.\" Many \
mathematicians held this view, but finally there was a breakthrough."
}], "Text",
 CellChangeTimes->{{3.398967978859375*^9, 3.398967984671875*^9}}],

Cell[TextData[{
 "\tIn his 1572 treatise L'Algebra, ",
 StyleBox[ButtonBox["Rafael Bombelli",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Bombelli.\
html"], None}],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 " showed that roots of negative numbers have great utility indeed. Consider \
the depressed cubic ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "3"], "-", 
    RowBox[{"15", "x"}], "-", "4"}], "=", "0"}]]],
 ".  Using ",
 Cell[BoxData[
  RowBox[{"b", "=", 
   RowBox[{"-", "15"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"c", "=", 
   RowBox[{"-", "4"}]}]]],
 " in the \"Ferro-Tartaglia\" formula for the depressed cubic, we compute ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RadicalBox[
     RowBox[{"2", "+", 
      SqrtBox[
       RowBox[{"-", "121"}]]}], "3"], "+", 
    RadicalBox[
     RowBox[{"2", "-", 
      SqrtBox[
       RowBox[{"-", "121"}]]}], "3"]}]}]]],
 ", or in a somewhat different form, ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RadicalBox[
     RowBox[{"2", "+", 
      RowBox[{"11", 
       SqrtBox[
        RowBox[{"-", "1"}]]}]}], "3"], "+", 
    RadicalBox[
     RowBox[{"2", "-", 
      RowBox[{"11", 
       SqrtBox[
        RowBox[{"-", "1"}]]}]}], "3"]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "\tSimplifying this expression would have been very difficult if Bombelli \
had not come up with what he called a \"wild thought.\"   He suspected that \
if the original depressed cubic had real solutions, then the two parts of x \
in the preceding equation could be written as  ",
 Cell[BoxData[
  RowBox[{"u", "+", 
   RowBox[{"v", 
    SqrtBox[
     RowBox[{"-", "1"}]]}]}]],
  AspectRatioFixed->True],
 "  and  ",
 Cell[BoxData[
  RowBox[{"u", "-", 
   RowBox[{"v", 
    SqrtBox[
     RowBox[{"-", "1"}]]}]}]],
  AspectRatioFixed->True],
 "  for some real numbers u and v.  That is, Bombeli believed  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "+", 
    RowBox[{"v", 
     SqrtBox[
      RowBox[{"-", "1"}]]}]}], "=", 
   RadicalBox[
    RowBox[{"2", "+", 
     RowBox[{"11", 
      SqrtBox[
       RowBox[{"-", "1"}]]}]}], "3"]}]]],
 " and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "-", 
    RowBox[{"v", 
     SqrtBox[
      RowBox[{"-", "1"}]]}]}], "=", 
   RadicalBox[
    RowBox[{"2", "-", 
     RowBox[{"11", 
      SqrtBox[
       RowBox[{"-", "1"}]]}]}], "3"]}]]],
 ",  which would mean  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"u", "+", 
      RowBox[{"v", 
       SqrtBox[
        RowBox[{"-", "1"}]]}]}], ")"}], "3"], "=", 
   RowBox[{"2", "+", 
    RowBox[{"11", 
     SqrtBox[
      RowBox[{"-", "1"}]]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"u", "-", 
      RowBox[{"v", 
       SqrtBox[
        RowBox[{"-", "1"}]]}]}], ")"}], "3"], "=", 
   RowBox[{"2", "-", 
    RowBox[{"11", 
     SqrtBox[
      RowBox[{"-", "1"}]]}]}]}]]],
 ".  Then, using the well-known algebraic identity ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"a", "+", "b"}], ")"}], "3"], "=", 
   RowBox[{
    SuperscriptBox["a", "3"], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "2"], " ", "b"}], "+", 
    RowBox[{"3", " ", "a", " ", 
     SuperscriptBox["b", "2"]}], "+", 
    SuperscriptBox["b", "3"]}]}]]],
 ", and (letting ",
 Cell[BoxData[
  RowBox[{"a", "=", "u"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"b", "=", 
   RowBox[{"v", " ", 
    SqrtBox[
     RowBox[{"-", "1"}]]}]}]]],
 "),  and assuming that roots of negative numbers obey the rules of algebra, \
he obtained  \n\t\n\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"u", "+", 
      RowBox[{"v", 
       SqrtBox[
        RowBox[{"-", "1"}]]}]}], ")"}], "3"], "="}]]],
 "  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["u", "3"], "+", 
   RowBox[{"3", 
    SuperscriptBox["u", "2"], 
    RowBox[{"(", 
     RowBox[{"v", 
      SqrtBox[
       RowBox[{"-", "1"}]]}], ")"}]}], "+", 
   RowBox[{"3", 
    RowBox[{"(", "u", ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"v", 
       SqrtBox[
        RowBox[{"-", "1"}]]}], ")"}], "2"]}], "+", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"v", 
      SqrtBox[
       RowBox[{"-", "1"}]]}], ")"}], "3"]}]]],
 "  \n\t",
 Cell[BoxData["           "]],
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"=", " ", 
    RowBox[{
     SuperscriptBox["u", "3"], "+", 
     RowBox[{"3", 
      RowBox[{"(", "u", ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"v", 
         SqrtBox[
          RowBox[{"-", "1"}]]}], ")"}], "2"]}], "+", 
     RowBox[{"3", 
      SuperscriptBox["u", "2"], 
      RowBox[{"(", 
       RowBox[{"v", 
        SqrtBox[
         RowBox[{"-", "1"}]]}], ")"}]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"v", 
        SqrtBox[
         RowBox[{"-", "1"}]]}], ")"}], "3"]}]}]}]]],
 "   \n\t                          ",
 Cell[BoxData[
  RowBox[{"=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["u", "3"], "-", 
      RowBox[{"3", "u", " ", 
       SuperscriptBox["v", "2"]}]}], ")"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", 
        SuperscriptBox["u", "2"], "v"}], "-", 
       SuperscriptBox["v", "3"]}], ")"}], 
     SqrtBox[
      RowBox[{"-", "1"}]]}]}]}]]],
 "  \n\t                          ",
 Cell[BoxData[
  RowBox[{"=", " ", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["u", "2"], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["v", "2"]}]}], ")"}]}], "+", 
    RowBox[{"v", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", 
        SuperscriptBox["u", "2"]}], "-", 
       SuperscriptBox["v", "2"]}], ")"}], 
     SqrtBox[
      RowBox[{"-", "1"}]]}]}]}]]],
 "  \n\t                          ",
 Cell[BoxData[
  RowBox[{"=", " ", 
   RowBox[{"2", " ", "+", " ", 
    RowBox[{"11", 
     SqrtBox[
      RowBox[{"-", "1"}]]}]}]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.39896762759375*^9, 3.398967636140625*^9}, 
   3.398967990828125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "\tBy equating like parts, Bombelli reasoned that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["u", "2"], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["v", "2"]}]}], ")"}]}], "=", "2"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", 
       SuperscriptBox["u", "2"]}], "-", 
      SuperscriptBox["v", "2"]}], ")"}]}], "=", "11"}]]],
 ".  Perhaps thinking even more wildly, Bombelli then supposed that u and v \
were integers.  The only integer factors of 2 are 2 and 1, so the equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["u", "2"], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["v", "2"]}]}], ")"}]}], "=", "2"}]]],
 "   led Bombelli to conclude that  ",
 Cell[BoxData[
  RowBox[{"u", "=", "2"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["u", "2"], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["v", "2"]}]}], "=", "1"}]]],
 ".  From this conclusion it follows that  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["v", "2"], "=", "1"}]]],
 ", or  ",
 Cell[BoxData[
  RowBox[{"v", "=", 
   RowBox[{"\[PlusMinus]", "1"}]}]]],
 ". Amazingly, ",
 Cell[BoxData[
  RowBox[{"u", "=", "2"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"v", "=", "1"}]]],
 "  solve the second equation ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", 
       SuperscriptBox["u", "2"]}], "-", 
      SuperscriptBox["v", "2"]}], ")"}]}], "=", "11"}]]],
 ", so Bombelli declared the values for ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v",
  FontFamily->"Courier New"],
 " to be  ",
 Cell[BoxData[
  RowBox[{"u", "=", "2"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"v", "=", "1"}]]],
 ",  respectively."
}], "Text",
 CellChangeTimes->{{3.398968012640625*^9, 3.39896804475*^9}}],

Cell[TextData[{
 "\tSince ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"2", "+", 
      SqrtBox[
       RowBox[{"-", "1"}]]}], ")"}], "3"], "=", 
   RowBox[{"2", "+", 
    RowBox[{"11", 
     SqrtBox[
      RowBox[{"-", "1"}]]}]}]}]]],
 ", we clearly have ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"2", "+", 
    SqrtBox[
     RowBox[{"-", "1"}]]}], "=", 
   RadicalBox[
    RowBox[{"2", "+", 
     RowBox[{"11", 
      SqrtBox[
       RowBox[{"-", "1"}]]}]}], "3"]}]]],
 ".  Similarly, Bombelli showed that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"2", "-", 
    SqrtBox[
     RowBox[{"-", "1"}]]}], "=", 
   RadicalBox[
    RowBox[{"2", "-", 
     RowBox[{"11", 
      SqrtBox[
       RowBox[{"-", "1"}]]}]}], "3"]}]]],
 ".  But this means that\n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RadicalBox[
     RowBox[{"2", "+", 
      RowBox[{"11", 
       SqrtBox[
        RowBox[{"-", "1"}]]}]}], "3"], "+", 
    RadicalBox[
     RowBox[{"2", "-", 
      RowBox[{"11", 
       SqrtBox[
        RowBox[{"-", "1"}]]}]}], "3"]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "+", 
       SqrtBox[
        RowBox[{"-", "1"}]]}], ")"}], "+", 
     RowBox[{"(", 
      RowBox[{"2", "-", 
       SqrtBox[
        RowBox[{"-", "1"}]]}], ")"}]}], "=", "4"}]}]]],
 ", "
}], "Text",
 CellChangeTimes->{3.398968090828125*^9}],

Cell[TextData[{
 "which was a proverbial bombshell.  Prior to Bombelli, mathematicians could \
easily scoff at imaginary numbers when they arose as solutions to quadratic \
equations.  With cubic equations, they no longer had this luxury.  That ",
 Cell[BoxData[
  RowBox[{"x", "=", "4"}]]],
 " was a correct solution to the equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "3"], "-", 
    RowBox[{"15", "x"}], "-", "4"}], "=", "0"}]]],
 "  was indisputable, as it could be checked easily.  However, to arrive at \
this very real solution, mathematicians had to take a detour through the \
uncharted territory of \"imaginary numbers.\"  Thus, whatever else might have \
been said about these numbers (which, today, we call complex numbers), their \
utility could no longer be ignored."
}], "Text",
 CellChangeTimes->{3.398968096859375*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Exploration", "."}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506701734296875*^9, 3.506701734296875*^9}},
 AspectRatioFixed->False],

Cell["Enter the cubic equation.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"b", ",", "c", ",", "r", ",", "x", ",", "z"}], "]"}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{"eqn", " ", "=", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["x", "3"], " ", "-", " ", 
       RowBox[{"15", " ", "x"}], " ", "-", " ", "4"}], " ", "\[Equal]", " ", 
      "0"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{"eqn", ",", " ", "x"}], " ", "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", "eqn", "\[IndentingNewLine]", 
   RowBox[{"MapAll", "[", 
    RowBox[{"Factor", ",", "eqn"}], "]"}], "\n", "solset", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39896866034375*^9, 3.398968662453125*^9}}],

Cell["Enter the solution for the cubic equation.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"z", " ", "=", " ", 
    RowBox[{
     RadicalBox[
      RowBox[{
       FractionBox[
        RowBox[{"-", "c"}], "2"], " ", "+", " ", 
       SqrtBox[
        RowBox[{
         FractionBox[
          SuperscriptBox["c", "2"], "4"], "+", 
         FractionBox[
          SuperscriptBox["b", "3"], "27"]}]]}], "3"], " ", "+", " ", 
     RadicalBox[
      RowBox[{
       RowBox[{"-", 
        FractionBox["c", "2"]}], " ", "-", " ", 
       SqrtBox[
        RowBox[{
         FractionBox[
          SuperscriptBox["c", "2"], "4"], "+", 
         FractionBox[
          SuperscriptBox["b", "3"], "27"]}]]}], "3"]}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39896868140625*^9, 3.3989686825*^9}}],

Cell[TextData[{
 "\nUse the Ferro-Tartaglia formula  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RadicalBox[
     RowBox[{
      FractionBox[
       RowBox[{"-", "c"}], "2"], "+", 
      SqrtBox[
       RowBox[{
        FractionBox[
         SuperscriptBox["c", "2"], "4"], "+", 
        FractionBox[
         SuperscriptBox["b", "3"], "27"]}]]}], "3"], "-", 
    RadicalBox[
     RowBox[{
      FractionBox["c", "2"], "+", 
      SqrtBox[
       RowBox[{
        FractionBox[
         SuperscriptBox["c", "2"], "4"], "+", 
        FractionBox[
         SuperscriptBox["b", "3"], "27"]}]]}], "3"]}]}]],
  AspectRatioFixed->True],
 "  and verify that  z  it is a solution."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "z", "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"b", " ", "=", " ", 
     RowBox[{"-", " ", "15"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"c", " ", "=", " ", 
     RowBox[{"-", " ", "4"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Solve  \>\"", ",", "0", ",", "\"\< = \>\"", ",", 
      RowBox[{
       SuperscriptBox["z", "3"], " ", "+", " ", 
       RowBox[{"b", " ", "z"}], " ", "+", " ", "c"}]}], "]"}], ";"}], "  ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Use the `Ferro-Tartaglia formula.`\>\"", "]"}],
     ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<0 = \!\(\*SuperscriptBox[\(z\), \(3\)]\) + b z + c\>\"", "]"}], 
    ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"z", " ", "=", " ", 
     RowBox[{
      RadicalBox[
       RowBox[{
        FractionBox[
         RowBox[{"-", "c"}], "2"], " ", "+", " ", 
        SqrtBox[
         RowBox[{
          FractionBox[
           SuperscriptBox["c", "2"], "4"], "+", 
          FractionBox[
           SuperscriptBox["b", "3"], "27"]}]]}], "3"], " ", "+", " ", 
      RadicalBox[
       RowBox[{
        RowBox[{"-", 
         FractionBox["c", "2"]}], " ", "-", " ", 
        SqrtBox[
         RowBox[{
          FractionBox[
           SuperscriptBox["c", "2"], "4"], "+", 
          FractionBox[
           SuperscriptBox["b", "3"], "27"]}]]}], "3"]}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<z = \!\(\*RadicalBox[\(\*FractionBox[\(-c\), \(2\)] + \\\ \
\*SqrtBox[\(\*FractionBox[SuperscriptBox[\(c\), \(2\)], \(4\)] + \
\*FractionBox[SuperscriptBox[\(b\), \(3\)], \(27\)]\)]\), \(3\)]\) + \
\!\(\*RadicalBox[\(\(-\*FractionBox[\(c\), \(2\)]\) - \\\ \
\*SqrtBox[\(\*FractionBox[SuperscriptBox[\(c\), \(2\)], \(4\)] + \
\*FractionBox[SuperscriptBox[\(b\), \(3\)], \(27\)]\)]\), \(3\)]\)\>\"", 
     "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Substitute  b = \>\"", ",", "b", ",", "\"\<  and  c = \>\"", ",", 
      "c", ",", " ", "\"\<  and get\>\""}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \!\(\*RadicalBox[\(\*FractionBox[\(-c\), \(2\)] + \\\ \
\*SqrtBox[\(\*FractionBox[SuperscriptBox[\(c\), \(2\)], \(4\)] + \
\*FractionBox[SuperscriptBox[\(b\), \(3\)], \(27\)]\)]\), \(3\)]\) = \>\"", 
      ",", " ", 
      RadicalBox[
       RowBox[{
        FractionBox[
         RowBox[{"-", "c"}], "2"], " ", "+", " ", 
        SqrtBox[
         RowBox[{
          FractionBox[
           SuperscriptBox["c", "2"], "4"], "+", 
          FractionBox[
           SuperscriptBox["b", "3"], "27"]}]]}], "3"]}], "]"}], ";"}], "  ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \!\(\*RadicalBox[\(\(-\*FractionBox[\(c\), \(2\)]\) - \\\ \
\*SqrtBox[\(\*FractionBox[SuperscriptBox[\(c\), \(2\)], \(4\)] + \
\*FractionBox[SuperscriptBox[\(b\), \(3\)], \(27\)]\)]\), \(3\)]\) = \>\"", 
      ",", "  ", 
      RadicalBox[
       RowBox[{
        RowBox[{"-", 
         FractionBox["c", "2"]}], " ", "-", " ", 
        SqrtBox[
         RowBox[{
          FractionBox[
           SuperscriptBox["c", "2"], "4"], "+", 
          FractionBox[
           SuperscriptBox["b", "3"], "27"]}]]}], "3"]}], "]"}], ";"}], "  ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The details are\>\"", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<z = \!\(\*RadicalBox[\(2 + \*SqrtBox[\(-121\)]\), \(3\)]\)+ \
\!\(\*RadicalBox[\(2 + \*SqrtBox[\(-121\)]\), \(3\)]\)\>\"", "]"}], ";"}], 
   "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<z = \!\(\*RadicalBox[\(2 + 11 \*SqrtBox[\(-1\)]\), \(3\)]\)+ \
\!\(\*RadicalBox[\(2 + 11 \*SqrtBox[\(-1\)]\), \(3\)]\)\>\"", "]"}], ";"}], 
   "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \!\(\*RadicalBox[\(2 + 11 \*SqrtBox[\(-1\)]\), \(3\)]\) = \>\"",
       ",", 
      RadicalBox[
       RowBox[{"2", "+", 
        RowBox[{"11", 
         SqrtBox[
          RowBox[{"-", "1"}]]}]}], "3"]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \!\(\*RadicalBox[\(2 - 11 \*SqrtBox[\(-1\)]\), \(3\)]\) = \>\"",
       ",", 
      RadicalBox[
       RowBox[{"2", "-", 
        RowBox[{"11", 
         SqrtBox[
          RowBox[{"-", "1"}]]}]}], "3"]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Add these quantities and obtain\>\"", "]"}], 
    ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", " ", 
      RadicalBox[
       RowBox[{"2", "+", 
        RowBox[{"11", 
         SqrtBox[
          RowBox[{"-", "1"}]]}]}], "3"], ",", "\"\< + \>\"", ",", 
      RadicalBox[
       RowBox[{"2", "-", 
        RowBox[{"11", 
         SqrtBox[
          RowBox[{"-", "1"}]]}]}], "3"]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", 
      RowBox[{
       RadicalBox[
        RowBox[{"2", "+", 
         RowBox[{"11", 
          SqrtBox[
           RowBox[{"-", "1"}]]}]}], "3"], "+", 
       RadicalBox[
        RowBox[{"2", "-", 
         RowBox[{"11", 
          SqrtBox[
           RowBox[{"-", "1"}]]}]}], "3"]}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<z = \>\"", " ", ",", " ", "z", ",", " ", 
      "\"\<, using the `Ferro-Tartaglia formula.`\>\""}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39896868565625*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "        Prior to Bombelli, mathematicians could easily scoff at imaginary \
numbers when they arose as solutions to quadratic equations.  With cubic \
equations, they no longer had this cavalier attitude.  That  ",
 Cell[BoxData[
  RowBox[{"x", "=", "4"}]]],
 "  was a correct solution to the equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "3"], "-", 
    RowBox[{"15", "x"}], "-", "4"}], "=", "0"}]]],
 "  was indisputable.  However, to arrive at this very real solution, \
mathematicians had to take a detour through the uncharted territory of \
\"imaginary numbers.\"  Thus, whatever else might have been said about these \
numbers (which, today, we call complex numbers), their utility could no \
longer be ignored.  This was the dawning of a new era in mathematics, the \"",
 StyleBox["Age of complex numbers.",
  FontSlant->"Italic"],
 "\""
}], "Text",
 CellChangeTimes->{{3.50684795725*^9, 3.50684796603125*^9}}],

Cell[TextData[{
 StyleBox["John Wallis leads the way to embed the real numbers in the plane.\n\
\n",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Geometric Progress of John Wallis",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
 StyleBox["        ",
  FontFamily->"Times New Roman",
  FontWeight->"Bold"],
 StyleBox["As significant as Bombelli's work was his results left many issues \
unresolved.  For example, his technique applied only to a few specialized \
cases.  Could it be extended?  Even if it could be extended a larger question \
remained: what possible physical representation could complex numbers have? ",
  FontFamily->"Times New Roman"]
}], "Text",
 CellChangeTimes->{{3.506847972546875*^9, 3.506847972953125*^9}}],

Cell[TextData[{
 StyleBox["        The last question remained unanswered for more than two \
centuries; ",
  FontFamily->"Times New Roman"],
 "University of New Hampshire professor ",
 StyleBox["Paul J. Nahin describes the progress as occurring in several \
stages (see \"\"",
  FontFamily->"Times New Roman"],
 ButtonBox["An Imaginary tale: the Story of ",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.ams.org/notices/199910/rev-blank.pdf"], None}],
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  StyleBox[
   SqrtBox[
    RowBox[{"-", "1"}]],
   FontColor->RGBColor[0, 0, 1]]]],
 StyleBox["\",  by Paul J Nahin, Princeton University Press, 2007, pages \
48-55).  \n\n        A preliminary step came in 1685 when the English \
mathematician ",
  FontFamily->"Times New Roman"],
 " ",
 ButtonBox["John Wallis",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Biographies/Wallis.html"]\
, None}],
 StyleBox[" published \"",
  FontFamily->"Times New Roman"],
 StyleBox["A treatise of Algebra, both Historical and Practical",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox[".\" Among the many contributions in that book two are particularly \
noteworthy for our purposes.  They are displayed in Wallis' analysis of a \
problem from classical geometry that, at first glance, seems completely \
unrelated to complex numbers.",
  FontFamily->"Times New Roman"]
}], "Text",
 CellChangeTimes->{{3.50684797721875*^9, 3.50684799128125*^9}}],

Cell[TextData[{
 StyleBox["\nProblem 1.1.",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["  Construct a triangle determined by two sides and an angle ",
  FontFamily->"Times New Roman"],
 StyleBox["not ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["included between those sides.\n\n",
  FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
 StyleBox["        We will get to Wallis' contributions in a moment.  First, \
observe that Figure 1.1 illustrates the standard solution to Problem 1.1. \
Given side length  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["a"]],
 StyleBox["  ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["(represented by segment  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["AB"]],
 StyleBox["),  angle  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["\[Alpha]"]],
 StyleBox["  ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["(determined by segments  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"AB", "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "BC"}]]],
 StyleBox["),  and side length  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["b"]],
 StyleBox[",  draw an arc of a circle of radius  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["b"]],
 StyleBox["  whose center is at point  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["A"]],
 StyleBox[".  If the arc intersects segment  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["BC"]],
 StyleBox["  ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["at points  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"E", "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "F"}]]],
 StyleBox[",  then the resulting triangles  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"ABE", "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "ABF"}]]],
 StyleBox["  ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["each satisfy the problem requirement.",
  FontFamily->"Times New Roman"]
}], "Text",
 CellChangeTimes->{{3.506847996171875*^9, 3.506848001046875*^9}}],

Cell[TextData[{
 "                    ",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .53883 
%%ImageSize: 480 258.641 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0970874 0.101942 0.0970874 [
[ 0 0 0 0 ]
[ 1 .53883 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .53883 L
0 .53883 L
closepath
clip
newpath
0 1 1 r
.5 Mabswid
[ ] 0 setdash
.01456 .10194 m
.20874 .10194 L
s
.79126 .10194 m
.98544 .10194 L
s
0 0 1 r
.20874 .10194 m
.79126 .10194 L
s
1 .753 .796 r
.01456 .10194 m
.5 .49029 L
s
1 0 1 r
.20874 .10194 m
.5 .49029 L
s
.79126 .10194 m
.5 .49029 L
s
.5 .165 .165 r
newpath
.01456 .10194 .09709 0 38.6598 arc
s
1 .5 0 r
[ .015 .015 ] 0 setdash
newpath
.5 .49029 .48544 -155.89 -32.7042 arc
s
1 0 0 r
.20874 .10194 m
.20874 .10194 .00971 0 365.73 arc
F
.79126 .10194 m
.79126 .10194 .00971 0 365.73 arc
F
0 0 1 r
.01456 .10194 m
.01456 .10194 .00777 0 365.73 arc
F
.98544 .10194 m
.98544 .10194 .00777 0 365.73 arc
F
.5 .49029 m
.5 .49029 .00777 0 365.73 arc
F
0 g
gsave
.5 .52913 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.01456 .08252 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.20874 .08252 -70.1875 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.79126 .08252 -70.1875 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.98544 .08252 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.13107 .15049 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.19903 .29612 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.37864 .29612 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.68447 .29612 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{480, 258.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 479}, {257.625, 0}} -> {-5, -1, 0, 0}}],
 "  "
}], "Text",
 Editable->False],

Cell[TextData[{
 "                                             ",
 StyleBox["Figure 1.1",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 StyleBox["The Standard solution to Wallis' geometrical problem.  ",
  FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
 StyleBox["A Geometric Representation of Real Numbers\n\nThe representation \
of  ",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  SqrtBox[
   RowBox[{
    SuperscriptBox["b", "2"], "-", 
    SuperscriptBox["c", "2"]}]]],
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["  when  ",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  RowBox[{"b", ">", "c"}]],
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[".",
  FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
 StyleBox["        Wallis' first contribution allowed him to associate (real) \
numbers with the points  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"E", "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "F"}]],
  FontFamily->"Times New Roman"],
 StyleBox["  ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["of Figure 1.1.  The association came by way of a construct that \
may sound completely trivial to us, but that is only because we have been \
raised knowing about Wallis' idea: \"",
  FontFamily->"Times New Roman"],
 StyleBox["the real number line",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox[".\"  By choosing an arbitrary point to represent the number zero \
on a given line, Wallis declared that positive numbers could be viewed as \
corresponding distances to the ",
  FontFamily->"Times New Roman"],
 StyleBox["right",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox[" of zero, and negative numbers as corresponding (positive) \
distances to the ",
  FontFamily->"Times New Roman"],
 StyleBox["left",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox[" of zero.",
  FontFamily->"Times New Roman"]
}], "Text",
 CellChangeTimes->{{3.506848004703125*^9, 3.506848009*^9}}],

Cell[TextData[{
 StyleBox["        To complete the association refer to Figure 1.2 (a) and \
think of segment  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["BC"]],
 StyleBox["  ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["as lying on a portion of the  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["x"]],
 "-axis",
 StyleBox[".  Then draw a perpendicular segment  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"AD", "  ", 
   StyleBox["to",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "BC"}]]],
 ",",
 StyleBox["  ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["and designate the origin to be at  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["D"]],
 StyleBox[".  If the length of  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"AD", "  ", 
   StyleBox["is",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "c"}]]],
 StyleBox[" ,",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["  then the Pythagorean theorem gives  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  SqrtBox[
   RowBox[{
    SuperscriptBox["b", "2"], "-", 
    SuperscriptBox["c", "2"]}]]]],
 StyleBox["  for the length of segments  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["ED"]],
 StyleBox["  ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["and  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["DF"]],
 ".",
 StyleBox["  ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["Combining this result with Wallis' number real line results in \
points  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"E", "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "F"}]]],
 StyleBox["  representing the real numbers:   \n\n                    ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"E", " ", "=", " ", 
   RowBox[{"0", "-", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}]]}]}]]],
 StyleBox[",     and     ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"F", " ", "=", " ", 
   RowBox[{"0", "+", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}]]}]}]]],
 StyleBox[".  ",
  FontFamily->"Times New Roman"]
}], "Text",
 CellChangeTimes->{{3.50684801196875*^9, 3.50684801421875*^9}}],

Cell[TextData[{
 "                    ",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .54854 
%%ImageSize: 480 263.301 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0970874 0.11165 0.0970874 [
[ 0 0 0 0 ]
[ 1 .54854 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .54854 L
0 .54854 L
closepath
clip
newpath
0 1 1 r
.5 Mabswid
[ ] 0 setdash
.01456 .11165 m
.20874 .11165 L
s
.79126 .11165 m
.98544 .11165 L
s
0 0 1 r
.20874 .11165 m
.79126 .11165 L
s
0 1 0 r
.5 .11165 m
.5 .5 L
s
1 .753 .796 r
.01456 .11165 m
.5 .5 L
s
1 0 1 r
.20874 .11165 m
.5 .5 L
s
.79126 .11165 m
.5 .5 L
s
.5 .165 .165 r
newpath
.01456 .11165 .09709 0 38.6598 arc
s
1 .5 0 r
[ .015 .015 ] 0 setdash
newpath
.5 .5 .48544 -155.89 -32.7042 arc
s
0 1 0 r
[ .01 .01 ] 0 setdash
.50874 .16505 m
.5534 .16505 L
.5534 .12233 L
s
.49126 .16505 m
.4466 .16505 L
.4466 .12243 L
s
1 0 0 r
.20874 .11165 m
.20874 .11165 .00971 0 365.73 arc
F
.79126 .11165 m
.79126 .11165 .00971 0 365.73 arc
F
0 0 1 r
.01456 .11165 m
.01456 .11165 .00777 0 365.73 arc
F
.5 .11165 m
.5 .11165 .00971 0 365.73 arc
F
.98544 .11165 m
.98544 .11165 .00777 0 365.73 arc
F
.5 .5 m
.5 .5 .00777 0 365.73 arc
F
0 g
gsave
.5 .53883 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.01456 .09223 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.20874 .09223 -70.1875 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .09223 -73.7813 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.79126 .09223 -70.1875 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.20874 .03398 -99.25 -20.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.688 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.188 9.938 moveto
(\\217) show
80.063 9.938 moveto
(!) show
82.750 9.938 moveto
(!) show
85.438 9.938 moveto
(!) show
88.125 9.938 moveto
(!) show
90.813 9.938 moveto
(!) show
93.500 9.938 moveto
(!) show
96.188 9.938 moveto
(!) show
98.875 9.938 moveto
(!) show
101.563 9.938 moveto
(!) show
104.250 9.938 moveto
(!) show
106.938 9.938 moveto
(!) show
109.625 9.938 moveto
(!) show
112.313 9.938 moveto
(!) show
115.000 9.938 moveto
(!) show
117.500 9.938 moveto
(!) show
80.500 16.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
87.688 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
96.188 16.688 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
106.250 16.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
113.438 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
135.500 16.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.79126 .03398 -92.0625 -20.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 16.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.688 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.188 9.938 moveto
(\\217) show
80.063 9.938 moveto
(!) show
82.750 9.938 moveto
(!) show
85.438 9.938 moveto
(!) show
88.125 9.938 moveto
(!) show
90.813 9.938 moveto
(!) show
93.500 9.938 moveto
(!) show
96.188 9.938 moveto
(!) show
98.875 9.938 moveto
(!) show
101.563 9.938 moveto
(!) show
104.250 9.938 moveto
(!) show
106.938 9.938 moveto
(!) show
109.625 9.938 moveto
(!) show
112.313 9.938 moveto
(!) show
115.000 9.938 moveto
(!) show
117.500 9.938 moveto
(!) show
80.500 16.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
87.688 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
96.188 16.688 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
106.250 16.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
113.438 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
121.125 16.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.98544 .09223 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.13107 .16019 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.19903 .30583 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.37864 .30583 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.52427 .30583 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.68447 .30583 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{480, 263.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 479}, {262.25, 0}} -> {-5, -1, 0, 0}}],
 "  "
}], "Text",
 Editable->False],

Cell[TextData[{
 "                                             ",
 StyleBox["Figure 1.2 (a)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 StyleBox["Wallis' ",
  FontFamily->"Times New Roman"],
 StyleBox["geometric ",
  FontFamily->"Times New Roman"],
 StyleBox["depiction of \"real numbers.\"  ",
  FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
 StyleBox["        For example, if  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"b", "=", 
   RowBox[{
    RowBox[{"5", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "c"}], "=", "4"}]}]]],
 StyleBox[", the points  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"E", "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "F"}]]],
 StyleBox["  ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["would represent  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "3"}], "  ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}], "  ", "+", "3"}]]],
 StyleBox[",  respectively,  because \n\n                    ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"E", " ", "=", " ", 
   RowBox[{
    RowBox[{"-", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["5", "2"], "-", 
       SuperscriptBox["4", "2"]}]]}], "=", 
    RowBox[{"-", "3"}]}]}]]],
 StyleBox[",     and     ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"F", " ", "=", " ", 
   RowBox[{
    RowBox[{"+", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["5", "2"], "-", 
       SuperscriptBox["4", "2"]}]]}], "  ", "=", "  ", 
    RowBox[{"+", "3"}]}]}]]],
 ",  ",
 StyleBox["\n\nas shown below in the Figure 1.2 (b).",
  FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
 "                    ",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .53883 
%%ImageSize: 480 258.641 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0970874 0.101942 0.0970874 [
[ 0 0 0 0 ]
[ 1 .53883 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .53883 L
0 .53883 L
closepath
clip
newpath
0 1 1 r
.5 Mabswid
[ ] 0 setdash
.01456 .10194 m
.20874 .10194 L
s
.79126 .10194 m
.98544 .10194 L
s
0 0 1 r
.20874 .10194 m
.79126 .10194 L
s
0 1 0 r
.5 .10194 m
.5 .49029 L
s
1 .753 .796 r
.01456 .10194 m
.5 .49029 L
s
1 0 1 r
.20874 .10194 m
.5 .49029 L
s
.79126 .10194 m
.5 .49029 L
s
.5 .165 .165 r
newpath
.01456 .10194 .09709 0 38.6598 arc
s
1 .5 0 r
[ .015 .015 ] 0 setdash
newpath
.5 .49029 .48544 -155.89 -32.7042 arc
s
0 1 0 r
[ .01 .01 ] 0 setdash
.50874 .15534 m
.5534 .15534 L
.5534 .11262 L
s
.49126 .15534 m
.4466 .15534 L
.4466 .11272 L
s
1 0 0 r
.20874 .10194 m
.20874 .10194 .00971 0 365.73 arc
F
.79126 .10194 m
.79126 .10194 .00971 0 365.73 arc
F
0 0 1 r
.01456 .10194 m
.01456 .10194 .00777 0 365.73 arc
F
.5 .10194 m
.5 .10194 .00971 0 365.73 arc
F
.98544 .10194 m
.98544 .10194 .00777 0 365.73 arc
F
.5 .49029 m
.5 .49029 .00777 0 365.73 arc
F
0 g
gsave
.5 .52913 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.01456 .08252 -67.1875 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
71.375 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.20874 .08252 -84.5625 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 12.813 moveto
(-) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
106.125 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .08252 -73.7813 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.79126 .08252 -84.5625 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
91.750 12.813 moveto
(+) show
98.938 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
106.125 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.98544 .08252 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.13107 .15049 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.19903 .29612 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.38835 .29612 -73.7813 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.52913 .29612 -73.7813 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.68932 .29612 -73.7813 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{480, 258.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 479}, {257.625, 0}} -> {-5, -1, 0, 0}}],
 "  "
}], "Text",
 Editable->False],

Cell[TextData[{
 "                                   ",
 StyleBox["Figure 1.2 (b)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 StyleBox["Wallis' geometric depiction of the \"real numbers,\" ",
  FontFamily->"Times New Roman"],
 "  ",
 Cell[BoxData[
  RowBox[{"E", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "F"}], "=", "3"}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["        From both an algebraic and geometric viewpoint this \
procedure only makes sense if the stipulated length  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["b"]],
 StyleBox["  is greater than or equal to  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["c"]],
 StyleBox[".   If  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["b"],
  FontFamily->"Times New Roman"],
 StyleBox["  were less than  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["c"]],
 StyleBox["  then the algebraic expressions for points  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"E", "=", 
   RowBox[{"-", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}]]}]}]]],
 StyleBox["  and  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"F", "=", 
   RowBox[{"+", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}]]}]}]]],
 StyleBox["  would be meaningless, as the quantity  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["b", "2"], "-", 
   SuperscriptBox["c", "2"]}]]],
 StyleBox["  inside the square root would be negative.  Viewed geometrically, \
 if  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["b"]],
 StyleBox["  were less than  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["c"]],
 StyleBox["  then the arc of radius  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["b"]],
 StyleBox["  that is centered at  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["A"],
  FontFamily->"Times New Roman"],
 StyleBox["  would not be able to intersect the segment  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["BC"],
  FontFamily->"Times New Roman"],
 StyleBox[".  In other words, if  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["b"]],
 StyleBox["  were less than  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["c"]],
 StyleBox["  Problem 1.1 would appear to have no solution.  ",
  FontFamily->"Times New Roman"]
}], "Text",
 CellChangeTimes->{{3.5068480201875*^9, 3.506848036234375*^9}}],

Cell[TextData[{
 StyleBox["A Geometric Representation of Complex Numbers\n\nThe \
representation of  ",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  SqrtBox[
   RowBox[{
    SuperscriptBox["b", "2"], "-", 
    SuperscriptBox["c", "2"]}]]],
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["  when  ",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  RowBox[{"b", "<", "c"}]],
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[".",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n",
 StyleBox["        Appearances, of course,  can be deceiving, and Wallis \
reinforced the truth of that ancient proverb when he came up with his second \
contribution.  It was a solution to Problem 1.1 in the case when  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["b"]],
 StyleBox["  is less than  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["c"]],
 ".",
 StyleBox["  Figure 1.3 (a) illustrates how he did it.  From the midpoint of  \
",
  FontFamily->"Times New Roman"],
 Cell[BoxData["AD"]],
 StyleBox["  Wallis drew a circle with diameter  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["AD"]],
 StyleBox[".  Then, with  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["A"]],
 StyleBox["  as a center he drew an arc of radius  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["b"]],
 StyleBox[".  Because  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["b"]],
 StyleBox["  is less than  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["c"]],
 StyleBox["  the arc will intersect the circle at two points, say  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"E", "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "F"}]]],
 ",  which now lie above the \"",
 StyleBox["real number line",
  FontSlant->"Italic"],
 ".\"  "
}], "Text",
 CellChangeTimes->{{3.50684804028125*^9, 3.5068480436875*^9}}],

Cell[TextData[{
 "                    ",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .53922 
%%ImageSize: 480 258.824 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0980392 0.0980392 0.0980392 [
[ 0 0 0 0 ]
[ 1 .53922 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .53922 L
0 .53922 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.0098 .09804 m
.9902 .09804 L
s
0 1 0 r
.5 .09804 m
.5 .4902 L
s
0 1 1 r
.0098 .09804 m
.31176 .23922 L
s
[ .02 .02 ] 0 setdash
.0098 .09804 m
.68824 .23922 L
s
1 .753 .796 r
[ ] 0 setdash
.0098 .09804 m
.5 .4902 L
s
1 0 1 r
.31176 .23922 m
.5 .4902 L
s
[ .02 .02 ] 0 setdash
.68824 .23922 m
.5 .4902 L
s
.5 .165 .165 r
[ ] 0 setdash
newpath
.0098 .09804 .09804 0 38.6598 arc
s
0 1 0 r
[ .015 .015 ] 0 setdash
newpath
.5 .29412 .19608 0 365.73 arc
s
1 .5 0 r
newpath
.5 .4902 .31373 -155.89 -32.7042 arc
s
1 0 0 r
.31176 .23922 m
.31176 .23922 .0098 0 365.73 arc
F
.68824 .23922 m
.68824 .23922 .0098 0 365.73 arc
F
0 0 1 r
.0098 .09804 m
.0098 .09804 .00784 0 365.73 arc
F
.5 .09804 m
.5 .09804 .0098 0 365.73 arc
F
.9902 .09804 m
.9902 .09804 .00784 0 365.73 arc
F
.5 .4902 m
.5 .4902 .00784 0 365.73 arc
F
0 g
gsave
.5 .52941 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.0098 .07843 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.31373 .22059 -70.1875 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .07843 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.68824 .22059 -70.1875 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.9902 .07843 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.12745 .14902 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.26961 .34804 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.41176 .34804 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.51961 .34804 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.64706 .34804 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{480, 258.813},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 479}, {257.813, 0}} -> {-5, -1, 0, 0}}],
 "  "
}], "Text",
 Editable->False],

Cell[TextData[{
 "                                             ",
 StyleBox["Figure 1.3 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Wallis' ",
 StyleBox["geometric ",
  FontFamily->"Times New Roman"],
 "depiction of the \"complex numbers,\" ",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"E", "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "F"}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["        Again we get two triangles:  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"ABE", "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "ABF"}]]],
 StyleBox[".  Wallis claimed that these triangles each satisfy the \
requirement of Problem 1.1.  You might object to this construction on the \
grounds that angle  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["\[Alpha]"]],
 StyleBox["  ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["is not part of either triangle.  However, if you read the problem \
statement carefully, you will notice that it never states that the angle  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["\[Alpha]"]],
 StyleBox["  ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["had to be part of any triangle, only that it ",
  FontFamily->"Times New Roman"],
 StyleBox["determine",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox[" a triangle.  From this perspective Wallis completely satisfied \
the requirement.",
  FontFamily->"Times New Roman"]
}], "Text",
 CellChangeTimes->{{3.506848047953125*^9, 3.50684805003125*^9}}],

Cell[TextData[{
 StyleBox["        Notice that the points  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"E", "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman"], "  ", "F"}]]],
 StyleBox["  are no longer on the ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["x"]],
 StyleBox["-axis as they were when  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["b"]],
 StyleBox["  ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["was greater than  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["c"]],
 ",",
 StyleBox["  ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["(and  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"\[PlusMinus]", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["c", "2"]}]]}]]],
 StyleBox[" are real numbers). They are now located somewhere above the ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["x"]],
 StyleBox["-axis, and it is not unreasonable to conclude that points  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"E", "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman"], "  ", "F"}]]],
 StyleBox["  give,  respectively,  the geometric representations of the \
expressions  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"E", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}]]}], "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "F"}], "=", 
    RowBox[{"+", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}]]}]}]}]]],
 StyleBox["  when ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"b", "  ", 
   StyleBox["is",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox["less",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox["than",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "c"}]]],
 StyleBox[", ",
  FontFamily->"Times New Roman",
  FontSlant->"Italic"],
 StyleBox["(and  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"\[PlusMinus]", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["c", "2"]}]]}]]],
 StyleBox[" are complex numbers). ",
  FontFamily->"Times New Roman"]
}], "Text",
 CellChangeTimes->{{3.506848054375*^9, 3.506848056921875*^9}}],

Cell[TextData[{
 StyleBox["        Although Wallis only hinted at such a conclusion, he \
nevertheless helped set the stage for thinking of real numbers as being \
embedded in a larger set of complex numbers, and that these numbers could be \
represented geometrically as vertical displacements from the ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["x"]],
 StyleBox["-axis.  Unfortunately, if we tried to apply Wallis' method to \
construct complex numbers we would find it had some ",
  FontFamily->"Times New Roman"],
 "critical",
 StyleBox[" defects. ",
  FontFamily->"Times New Roman"]
}], "Text",
 CellChangeTimes->{{3.506848059421875*^9, 3.506848061171875*^9}}],

Cell[TextData[{
 StyleBox["Wallis' depiction of  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  RowBox[{"\[PlusMinus]", 
   SqrtBox[
    RowBox[{"-", "1"}]]}]],
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 "                    ",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .44118 
%%ImageSize: 480 211.765 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0980392 0.0980392 0.0980392 [
[ 0 0 0 0 ]
[ 1 .44118 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .44118 L
0 .44118 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.20588 .09804 m
.79412 .09804 L
s
0 1 0 r
.5 .09804 m
.5 .39216 L
s
0 1 1 r
.20588 .09804 m
.5 .39216 L
s
[ .02 .02 ] 0 setdash
.20588 .09804 m
.5 .39216 L
s
1 0 1 r
[ ] 0 setdash
.5 .39216 m
.5 .39216 L
s
[ .02 .02 ] 0 setdash
.5 .39216 m
.5 .39216 L
s
0 1 0 r
[ .015 .015 ] 0 setdash
newpath
.5 .2451 .14706 0 365.73 arc
s
1 0 0 r
.5 .39216 m
.5 .39216 .0098 0 365.73 arc
F
.5 .39216 m
.5 .39216 .0098 0 365.73 arc
F
0 0 1 r
.20588 .09804 m
.20588 .09804 .00784 0 365.73 arc
F
.5 .09804 m
.5 .09804 .0098 0 365.73 arc
F
.79412 .09804 m
.79412 .09804 .00784 0 365.73 arc
F
0 g
gsave
.5 .43137 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.20588 .07843 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.50882 .37255 -77.375 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
91.750 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .07843 -73.7813 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.50098 .37255 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.79412 .07843 -66.5938 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.41176 .39216 -73.7813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.50098 .2451 -73.7813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.58824 .39216 -73.7813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
70.188 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{480, 211.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 479}, {210.75, 0}} -> {-5, -1, 0, 0}}],
 "  "
}], "Text",
 Editable->False],

Cell[TextData[{
 "                    ",
 StyleBox["Figure 1.3 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  An interpretation of Wallis' ",
 StyleBox["geometric ",
  FontFamily->"Times New Roman"],
 "depiction of   \"",
 Cell[BoxData[
  RowBox[{"E", "=", 
   RowBox[{"-", 
    SqrtBox[
     RowBox[{"-", "1"}]]}]}]]],
 "\"   and   \"",
 Cell[BoxData[
  RowBox[{"F", "=", 
   RowBox[{"+", 
    SqrtBox[
     RowBox[{"-", "1"}]]}]}]]],
 "\".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Suppose that we choose  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"b", "=", 
   RowBox[{
    RowBox[{"0", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "c"}], "=", "1"}]}]]],
 StyleBox[",  then ",
  FontFamily->"Times New Roman"],
 "Wallis'",
 StyleBox[" expression  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"\[PlusMinus]", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["c", "2"]}]]}]]],
 StyleBox["  becomes  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"\[PlusMinus]", 
   SqrtBox[
    RowBox[{"-", "1"}]]}]]],
 StyleBox[",  and points  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"E", "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman"], "  ", "F"}]]],
 StyleBox["  now coincide at point  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["A"]],
 ",  as shown above in Figure 1.3 (b).",
 StyleBox["  For certain, we can say that the value  ",
  FontFamily->"Times New Roman"],
 "\"",
 Cell[BoxData[
  RowBox[{"F", "=", 
   RowBox[{"+", 
    SqrtBox[
     RowBox[{"-", "1"}]]}]}]]],
 "\"  is the proper choice we use today.  So in some sense, Wallis was the \
first person to place the point  ",
 Cell[BoxData[
  RowBox[{"+", 
   SqrtBox[
    RowBox[{"-", "1"}]]}]]],
 "  in it's proper location in the upper half-plane.  ",
 StyleBox["But we surely would not want to equate the points ",
  FontFamily->"Times New Roman"],
 "\"",
 Cell[BoxData[
  RowBox[{"E", "=", 
   RowBox[{"-", 
    SqrtBox[
     RowBox[{"-", "1"}]]}]}]]],
 "\"   and   \"",
 Cell[BoxData[
  RowBox[{"F", "=", 
   RowBox[{"+", 
    SqrtBox[
     RowBox[{"-", "1"}]]}]}]]],
 ".\"  The reason for this anomaly was that the entire complex plane had not \
yet been invented.",
 StyleBox["  Thus, even with Wallis' work the jigsaw of getting the proper \
picture of complex numbers remained.  It would be another century before \
someone put most of the pieces together. ",
  FontFamily->"Times New Roman"]
}], "Text",
 CellChangeTimes->{{3.5068480654375*^9, 3.50684807325*^9}}],

Cell[TextData[{
 "\tWallis's method has the undesirable consequence that  ",
 Cell[BoxData[
  RowBox[{"-", 
   SqrtBox[
    RowBox[{"-", "1"}]]}]]],
 "  is represented by the same point as is  ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"-", "1"}]]]],
 ".  Nevertheless, this interpretation helped set the stage for thinking of \
complex numbers as \"points on the plane.\" By 1732, the great Swiss \
mathematician  ",
 StyleBox[ButtonBox["Leonhard Euler",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Euler.\
html"], None}],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 "  (pronounced \"oiler\") adopted this view concerning the n solutions to \
the equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "n"], "-", "1"}], "=", "0"}]]],
 ".  You will learn shortly that these solutions can be expressed as  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", 
    RowBox[{"(", "\[Theta]", ")"}]}], "+", 
   RowBox[{
    SqrtBox[
     RowBox[{"-", "1"}]], "sin", 
    RowBox[{"(", "\[Theta]", ")"}]}]}]]],
 "  for various values of  ",
 Cell[BoxData["\[Theta]"]],
 ";  Euler thought of them as being located at the vertices of a regular \
polygon in the plane.  Euler was also the first to use the symbol ",
 Cell[BoxData["\[ImaginaryI]"]],
 " for ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"-", "1"}]]]],
 ".  Today, this notation is still the most popular, although some electrical \
engineers prefer the symbol ",
 Cell[BoxData["j"]],
 " instead so that they can use ",
 Cell[BoxData["\[ImaginaryI]"]],
 " to represent current."
}], "Text",
 CellChangeTimes->{{3.398968163359375*^9, 3.398968173265625*^9}}],

Cell[TextData[{
 "\tIs it possible to modify slightly Wallis's picture of complex numbers so \
that it is consistent with the representation used today?  To help you answer \
this question, refer to the article by Alec Norton and Benjamin Lotto, \"",
 StyleBox[ButtonBox["Complex Roots Made Visible",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://links.jstor.org/sici?sici=0746-8342%28198406%2915%3A3%3C248%\
3ACRMV%3E2.0.CO%3B2-8"], None}],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 ",\" The College Mathematics Journal, 15(3), June 1984, pp. 248--249, Jstor. "
}], "Text"],

Cell[TextData[{
 "\tTwo additional mathematicians deserve mention. The Frenchman ",
 StyleBox[ButtonBox["Augustin-Louis Cauchy",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cauchy.\
html"], None}],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 " (1789-1857) formulated many of the classic theorems that are now part of \
the corpus of complex analysis.  The German ",
 StyleBox[ButtonBox["Carl Friedrich Gauss",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Gauss.\
html"], None}],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 " (1777--1855) reinforced the utility of complex numbers by using them in \
his several proofs of the fundamental theorem of algebra (see Chapter 6).  In \
an 1831 paper, he produced a clear geometric representation of x+iy by \
identifying it with the point (x, y) in the coordinate plane.  He also \
described how to perform arithmetic operations with these new numbers."
}], "Text",
 CellChangeTimes->{{3.39896818575*^9, 3.398968190625*^9}}],

Cell[TextData[{
 "\tIt would be a mistake, however, to conclude that in 1831 complex numbers \
were transformed into legitimacy.  In that same year the prolific logician ",
 StyleBox[ButtonBox["Augustus De Morgan",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/De_Morgan.\
html"], None}],
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 " commented in his book, On the Study and Difficulties of Mathematics, \"We \
have shown the symbol ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"-", "a"}]]]],
 " to be void of meaning, or rather self-contradictory and absurd. \
Nevertheless, by means of such symbols, a part of algebra is established \
which is of great utility.\""
}], "Text",
 CellChangeTimes->{3.398968198859375*^9}],

Cell[TextData[{
 "\tThere are, indeed, genuine logical problems associated with complex \
numbers.  For example, with real numbers  ",
 Cell[BoxData[
  RowBox[{
   SqrtBox["ab"], "=", 
   RowBox[{
    SqrtBox["a"], 
    SqrtBox["b"]}]}]]],
 "  so long as both sides of the equation are defined.  Applying this \
identity to complex numbers leads to  ",
 Cell[BoxData[
  RowBox[{"1", "=", 
   RowBox[{
    SqrtBox["1"], "=", 
    RowBox[{
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}]}]], "=", 
     RowBox[{
      RowBox[{
       SqrtBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]], 
       SqrtBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]]}], "=", 
      RowBox[{
       RowBox[{"\[ImaginaryI]", "*", "\[ImaginaryI]"}], "=", 
       RowBox[{"-", "1"}]}]}]}]}]}]],
  CellChangeTimes->{{3.398967650859375*^9, 3.398967652265625*^9}, {
   3.39896773903125*^9, 3.3989677949375*^9}}],
 ".  Plausible answers to these problems can be given, however, and you will \
learn how to resolve this apparent contradiction in ",
 StyleBox[ButtonBox["Section 2.4",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/ComplexFunBranchMod.html"], 
    None}],
  FontVariations->{"Underline"->True}],
 ".  De Morgan's remark illustrates that many factors are needed to persuade \
mathematicians to adopt new theories.  In this case, as always, a firm \
logical foundation was crucial, but so, too, was a willingness to modify some \
ideas concerning certain well-established properties of numbers."
}], "Text",
 CellChangeTimes->{{3.39896780171875*^9, 3.398967813421875*^9}, {
  3.39896820609375*^9, 3.39896821690625*^9}, {3.398968483515625*^9, 
  3.3989684976875*^9}}],

Cell["\<\
\tAs time passed, mathematicians gradually refined their thinking, and by the \
end of the nineteenth century complex numbers were firmly entrenched.  Thus, \
as it is with many new mathematical or scientific innovations, the theory of \
complex numbers evolved by way of a very intricate process.  But what is the \
theory that Tartaglia, Ferro, Cardano, Bombelli, Wallis, Euler, Cauchy, \
Gauss, and so many others helped produce?  That is, how do we now think of \
complex numbers?  We explore this question in the remainder of this chapter.\
\>", "Text",
 CellChangeTimes->{{3.39896822465625*^9, 3.398968229375*^9}, 
   3.39896850290625*^9}],

Cell[TextData[{
 StyleBox["The solution of the cubic equations.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can construct the solutions to the general cubic equation. However they \
are quite formidable."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Exploration", "."}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506701739796875*^9, 3.506701739796875*^9}},
 AspectRatioFixed->False],

Cell["Enter the depressed cubic equation.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqn", " ", "=", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["z", "3"], "+", 
       RowBox[{"b", " ", "z"}], " ", "+", " ", "c"}], " ", "\[Equal]", " ", 
      "0"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{"eqn", ",", " ", "z"}], " ", "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], "=", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"2", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], "=", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"3", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The depressed cubic equation \>\"", ",", "eqn"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Mathematica can find the roots\>\"", ",", "\"\<\\n\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["z", "3"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input"],

Cell["Enter the general cubic equation.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqn", " ", "=", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["z", "3"], "+", 
       RowBox[{"a", " ", 
        SuperscriptBox["z", "2"]}], "+", 
       RowBox[{"b", " ", "z"}], " ", "+", " ", "c"}], " ", "\[Equal]", " ", 
      "0"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{"eqn", ",", " ", "z"}], " ", "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], "=", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"2", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], "=", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"3", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The general cubic equation \>\"", ",", "eqn"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Mathematica can find the roots\>\"", ",", "\"\<\\n\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["z", "3"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input"],

Cell[TextData[{
 "\nThe formulas for the roots ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   RowBox[{
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", 
    SubscriptBox["z", "3"]}]}]]],
 " are complicated.  Hopefully this text will promote their understanding."
}], "Text"]
}, Closed]]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{921, 636},
WindowMargins->{{24, Automatic}, {Automatic, -3}},
CellLabelAutoDelete->True,
Magnification->1,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[1548, 46, 248, 6, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 164483, 5633}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 248, 6, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[1799, 54, 96, 2, 29, "Text"],
Cell[1898, 58, 624, 9, 83, "Text"],
Cell[2525, 69, 130, 2, 29, "Text"],
Cell[2658, 73, 1047, 25, 107, "Text"],
Cell[3708, 100, 647, 10, 83, "Text"],
Cell[4358, 112, 977, 29, 83, "Text",
 Evaluatable->False],
Cell[5338, 143, 1766, 57, 149, "Text"],
Cell[CellGroupData[{
Cell[7129, 204, 231, 6, 37, "Subsection"],
Cell[7363, 212, 2476, 66, 315, "Input"]
}, Closed]],
Cell[9854, 281, 1147, 42, 50, "Text"],
Cell[CellGroupData[{
Cell[11026, 327, 229, 6, 37, "Subsection"],
Cell[11258, 335, 1376, 39, 212, "Input"]
}, Closed]],
Cell[12649, 377, 1995, 60, 158, "Text"],
Cell[14647, 439, 3447, 128, 190, "Text"],
Cell[CellGroupData[{
Cell[18119, 571, 231, 6, 37, "Subsection"],
Cell[18353, 579, 1380, 39, 212, "Input"],
Cell[19736, 620, 3280, 93, 374, "Input"],
Cell[23019, 715, 1428, 41, 216, "Input"],
Cell[24450, 758, 803, 22, 152, "Input"]
}, Closed]],
Cell[25268, 783, 1623, 35, 161, "Text"],
Cell[26894, 820, 1353, 51, 83, "Text"],
Cell[28250, 873, 4916, 195, 264, "Text",
 Evaluatable->False],
Cell[33169, 1070, 1961, 76, 92, "Text"],
Cell[35133, 1148, 1374, 61, 110, "Text"],
Cell[36510, 1211, 865, 18, 83, "Text"],
Cell[CellGroupData[{
Cell[37400, 1233, 278, 8, 37, "Subsection",
 Evaluatable->False],
Cell[37681, 1243, 41, 0, 29, "Text"],
Cell[37725, 1245, 815, 22, 172, "Input"],
Cell[38543, 1269, 58, 0, 29, "Text"],
Cell[38604, 1271, 785, 26, 126, "Input"],
Cell[39392, 1299, 741, 28, 83, "Text",
 Evaluatable->False],
Cell[40136, 1329, 5828, 174, 757, "Input"]
}, Closed]],
Cell[45979, 1506, 965, 21, 80, "Text"],
Cell[46947, 1529, 301, 9, 65, "Text"],
Cell[47251, 1540, 519, 10, 47, "Text"],
Cell[47773, 1552, 1533, 40, 122, "Text"],
Cell[49309, 1594, 406, 12, 83, "Text"],
Cell[49718, 1608, 2319, 75, 65, "Text"],
Cell[52040, 1685, 12354, 435, 276, "Text"],
Cell[64397, 2122, 265, 8, 29, "Text"],
Cell[64665, 2132, 618, 23, 70, "Text"],
Cell[65286, 2157, 1481, 41, 83, "Text"],
Cell[66770, 2200, 2868, 100, 117, "Text"],
Cell[69641, 2302, 20999, 782, 281, "Text"],
Cell[90643, 3086, 360, 12, 29, "Text"],
Cell[91006, 3100, 1935, 69, 109, "Text"],
Cell[92944, 3171, 17139, 611, 276, "Text"],
Cell[110086, 3784, 631, 23, 29, "Text"],
Cell[110720, 3809, 2095, 66, 91, "Text"],
Cell[112818, 3877, 2143, 69, 160, "Text"],
Cell[114964, 3948, 14818, 521, 276, "Text"],
Cell[129785, 4471, 606, 22, 29, "Text"],
Cell[130394, 4495, 1350, 37, 65, "Text"],
Cell[131747, 4534, 3501, 123, 81, "Text"],
Cell[135251, 4659, 673, 14, 65, "Text"],
Cell[135927, 4675, 261, 11, 34, "Text"],
Cell[136191, 4688, 11882, 448, 229, "Text"],
Cell[148076, 5138, 475, 21, 32, "Text"],
Cell[148554, 5161, 2300, 78, 115, "Text"],
Cell[150857, 5241, 1710, 51, 110, "Text"],
Cell[152570, 5294, 617, 12, 65, "Text"],
Cell[153190, 5308, 1156, 24, 83, "Text"],
Cell[154349, 5334, 808, 19, 68, "Text"],
Cell[155160, 5355, 1816, 50, 107, "Text"],
Cell[156979, 5407, 655, 10, 83, "Text"],
Cell[157637, 5419, 334, 11, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[157996, 5434, 278, 8, 37, "Subsection",
 Evaluatable->False],
Cell[158277, 5444, 51, 0, 29, "Text"],
Cell[158331, 5446, 2289, 63, 312, "Input"],
Cell[160623, 5511, 49, 0, 29, "Text"],
Cell[160675, 5513, 2452, 68, 332, "Input"],
Cell[163130, 5583, 947, 33, 47, "Text"]
}, Closed]]
}
]
*)

(* End of internal cache information *)
