(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    131362,       4356]
NotebookOptionsPosition[    126288,       4191]
NotebookOutlinePosition[    126707,       4209]
CellTagsIndexPosition[    126664,       4206]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[StyleBox["1.2  The Algebra of Complex Numbers",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.532709090375*^9, 3.53270909121875*^9}}],

Cell[TextData[{
 "\tWe have seen that complex numbers came to be viewed as ordered pairs of \
real numbers. That is, a complex number ",
 Cell[BoxData["z"]],
 " is defined to be \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 ", \n\t\t\nwhere x and y are both real numbers."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tThe reason we say ordered pair is because we are thinking of a point in \
the plane.  The point (2, 3), for example, is not the same as (3, 2).  The \
order in which we write ",
 Cell[BoxData["x"]],
 " and ",
 Cell[BoxData["y"]],
 " in the equation makes a difference.  Clearly, then, two complex numbers \
are equal if and only if their x coordinates are and their y coordinates are \
equal. In other words,\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}], "=", 
   RowBox[{"(", 
    RowBox[{"u", ",", "v"}], ")"}]}]]],
 "   iff   ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"u", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "y"}], "=", "v"}]}]]],
 ".\n\t\t\n(Throughout this text, iff means if and only if.)"
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{3.39896940053125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "\tA meaningful number system requires a method for combining ordered pairs. \
 The definition of algebraic operations must be consistent so that the sum, \
difference, product, and quotient of any two ordered pairs will again be an \
ordered pair.  The key to defining how these numbers should be manipulated is \
to follow ",
 StyleBox[ButtonBox["Gauss's",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Gauss.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " lead and equate ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"x", ",", "y"}], ")"}]]],
 " with ",
 Cell[BoxData[
  RowBox[{"x", "+", "\[ImaginaryI]y"}]]],
 ".  Then, if ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["x", "1"], ",", 
     SubscriptBox["y", "1"]}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["x", "2"], ",", 
     SubscriptBox["y", "2"]}], ")"}]}]]],
 " are arbitrary complex numbers, we have"
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "+", 
     SubscriptBox["z", "2"]}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "1"], ",", 
       SubscriptBox["y", "1"]}], ")"}], "+", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "2"], ",", 
       SubscriptBox["y", "2"]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "1"], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["y", "1"]}]}], ")"}], "+", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "2"], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["y", "2"]}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "1"], "+", 
       SubscriptBox["x", "2"]}], ")"}], "+", 
     RowBox[{"\[ImaginaryI]", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["y", "1"], "+", 
        SubscriptBox["y", "2"]}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["x", "1"], "+", 
       SubscriptBox["x", "2"]}], ",", 
      RowBox[{
       SubscriptBox["y", "1"], "+", 
       SubscriptBox["y", "2"]}]}], ")"}]}]}]}]],
 "  \n\n\tThus, the following definitions should make sense."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Definition 1.1, (Addition)\n",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\nFormula (1-8)",
  FontColor->RGBColor[0, 0, 1]],
 "    ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], " ", "+", 
    SubscriptBox["z", "2"]}], " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "1"], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["y", "1"]}]}], ")"}], "+", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "2"], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["y", "2"]}]}], ")"}]}], "=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["x", "1"], "+", 
       SubscriptBox["x", "2"]}], ",", 
      RowBox[{
       SubscriptBox["y", "1"], "+", 
       SubscriptBox["y", "2"]}]}], ")"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Derivation", " ", "of", "  ", "Formula", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "8"}], ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506702921859375*^9, 3.506702921875*^9}},
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", " ", 
     RowBox[{
      SubscriptBox["x", "1"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "1"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], "=", " ", 
     RowBox[{
      SubscriptBox["x", "2"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "2"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) + \!\(\*SubscriptBox[\(z\), \
\(2\)]\) = \>\"", " ", ",", " ", 
      RowBox[{
       SubscriptBox["z", "1"], "+", 
       SubscriptBox["z", "2"]}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) + \!\(\*SubscriptBox[\(z\), \
\(2\)]\) = \>\"", " ", ",", " ", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        SubscriptBox["z", "1"], "+", 
        SubscriptBox["z", "2"]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Definition 1.2, (Subtraction)\n",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\nFormula (1-9)",
  FontColor->RGBColor[0, 0, 1]],
 "    ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], " ", "-", 
    SubscriptBox["z", "2"]}], " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "1"], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["y", "1"]}]}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "2"], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["y", "2"]}]}], ")"}]}], "=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["x", "1"], "-", 
       SubscriptBox["x", "2"]}], ",", 
      RowBox[{
       SubscriptBox["y", "1"], "-", 
       SubscriptBox["y", "2"]}]}], ")"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Derivation", " ", "of", "  ", "Formula", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "9"}], ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.5067029255625*^9, 3.5067029255625*^9}},
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", " ", 
     RowBox[{
      SubscriptBox["x", "1"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "1"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], "=", " ", 
     RowBox[{
      SubscriptBox["x", "2"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "2"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) - \!\(\*SubscriptBox[\(z\), \
\(2\)]\) = \>\"", " ", ",", " ", 
      RowBox[{
       SubscriptBox["z", "1"], "-", 
       SubscriptBox["z", "2"]}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) - \!\(\*SubscriptBox[\(z\), \
\(2\)]\) = \>\"", " ", ",", " ", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        SubscriptBox["z", "1"], "-", 
        SubscriptBox["z", "2"]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39896911946875*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 1.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Given  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{"3", "+", 
     RowBox[{"7", "\[ImaginaryI]", "   ", "and", "   ", 
      SubscriptBox["z", "2"]}]}], "=", 
    RowBox[{"5", "-", 
     RowBox[{"6", "\[ImaginaryI]"}]}]}]}]]],
 ".  ",
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["  ",
  FontWeight->"Bold"],
 "Find  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "+", 
   SubscriptBox["z", "2"]}]]],
 "  and  ",
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["  ",
  FontWeight->"Bold"],
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "-", 
   SubscriptBox["z", "2"]}]]],
 ".  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], " ", "+", 
    SubscriptBox["z", "2"]}], " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"3", ",", "7"}], ")"}], "+", 
     RowBox[{"(", 
      RowBox[{"5", ",", 
       RowBox[{"-", "6"}]}], ")"}]}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", "+", "5"}], ",", 
       RowBox[{"7", "-", "6"}]}], ")"}], "=", 
     RowBox[{"(", 
      RowBox[{"8", ",", "1"}], ")"}]}]}]}]]],
 "  and  \n\t\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], " ", "+", 
    SubscriptBox["z", "2"]}], " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"3", ",", "7"}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{"5", ",", 
       RowBox[{"-", "6"}]}], ")"}]}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", "-", "5"}], ",", 
       RowBox[{"7", "+", "6"}]}], ")"}], "=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "13"}], ")"}]}]}]}]]],
 ".\n\n We can also use the notation ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{"3", "+", 
    RowBox[{"7", "\[ImaginaryI]"}]}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{"5", "-", 
    RowBox[{"6", "\[ImaginaryI]"}]}]}]]],
 ":\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], " ", "+", 
    SubscriptBox["z", "2"]}], " ", "=", 
   RowBox[{
    RowBox[{"3", "+", 
     RowBox[{"7", "\[ImaginaryI]"}], "+", "5", "-", 
     RowBox[{"6", "\[ImaginaryI]"}]}], "=", 
    RowBox[{"8", "+", "\[ImaginaryI]"}]}]}]]],
 "  and  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], " ", "-", 
    SubscriptBox["z", "2"]}], " ", "=", 
   RowBox[{
    RowBox[{"3", "+", 
     RowBox[{"7", "\[ImaginaryI]"}], " ", "-", 
     RowBox[{"(", 
      RowBox[{"5", "-", 
       RowBox[{"6", "\[ImaginaryI]"}]}], ")"}]}], "=", 
    RowBox[{
     RowBox[{"-", "2"}], "+", 
     RowBox[{"13", "\[ImaginaryI]"}]}]}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"1.1", ".", " ", 
    RowBox[{"(", "a", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506702929625*^9, 3.506702929625*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["  ",
  FontWeight->"Bold"],
 "Compute  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "+", 
   SubscriptBox["z", "2"]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"V", ",", "w", ",", "z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", 
     RowBox[{"3", "+", 
      RowBox[{"7", "\[ImaginaryI]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], "=", 
     RowBox[{"5", "-", 
      RowBox[{"6", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "1"], "=", 
     RowBox[{
      SubscriptBox["z", "1"], "+", 
      SubscriptBox["z", "2"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "2"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "1"], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["w", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["w", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "3"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["w", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["w", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{
     SubscriptBox["V", "1"], ",", 
     SubscriptBox["V", "2"], ",", 
     SubscriptBox["V", "3"], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "8"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "7"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "8", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "7", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["7", "8"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Red      \>\"", ",", 
      "\"\<     \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Green    \>\"", ",", 
      "\"\<     \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Blue     \>\"", ",", 
      "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) + \!\(\*SubscriptBox[\(z\), \(2\
\)]\) = \>\"", " ", ",", " ", 
      RowBox[{
       SubscriptBox["z", "1"], " ", "+", " ", 
       SubscriptBox["z", "2"]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398969129578125*^9, 3.398969138359375*^9}, {
   3.399672999375*^9, 3.399672999796875*^9}, {3.39967331546875*^9, 
   3.399673317890625*^9}, {3.399673534359375*^9, 3.39967356275*^9}, 
   3.3996736110625*^9, {3.399673657390625*^9, 3.399673678015625*^9}, {
   3.399674045125*^9, 3.39967414403125*^9}, {3.39967432315625*^9, 
   3.39967432459375*^9}, {3.3997079581875*^9, 3.399708025125*^9}, {
   3.400232531875*^9, 3.4002325329375*^9}},
 AspectRatioFixed->True],

Cell[BoxData[""], "Input",
 CellChangeTimes->{3.3996741685625*^9, 3.39967432596875*^9, 
  3.3997074493125*^9}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{
  3.399673136546875*^9, 3.399673536625*^9, 3.39967358109375*^9, 
   3.3996736140625*^9, 3.39967372065625*^9, 3.399673903140625*^9, {
   3.399674080984375*^9, 3.399674123671875*^9}, 3.39967416346875*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"1.1", ".", " ", 
    RowBox[{"(", "b", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.50670293184375*^9, 3.50670293184375*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 " ",
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox[" ",
  FontWeight->"Bold"],
 "Compute ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "-", 
   SubscriptBox["z", "2"]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"w", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", 
     RowBox[{"3", "+", 
      RowBox[{"7", "\[ImaginaryI]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], "=", 
     RowBox[{"5", "-", 
      RowBox[{"6", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "2"], "=", 
     RowBox[{
      SubscriptBox["z", "1"], "-", 
      SubscriptBox["z", "2"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"v1", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.12"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.012", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"v2", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.12"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.012", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["w", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["w", "2"], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"v3", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.12"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.012", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["w", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["w", "2"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"v1", ",", "v2", ",", "v3", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "13"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "13", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["13", "5"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Red      \>\"", ",", 
      "\"\<     \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Green    \>\"", ",", 
      "\"\<     \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Blue    \>\"", ",", 
      "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) - \!\(\*SubscriptBox[\(z\), \(2\
\)]\) = \>\"", " ", ",", " ", 
      RowBox[{
       SubscriptBox["z", "1"], " ", "-", " ", 
       SubscriptBox["z", "2"]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3989691465*^9, 3.398969149515625*^9}, {
   3.399673005828125*^9, 3.399673006703125*^9}, {3.39970750028125*^9, 
   3.3997075491875*^9}, {3.39970804234375*^9, 3.399708091890625*^9}, 
   3.400232541890625*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tGiven the rationale we devised for addition and subtraction, it is \
tempting to define the product  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], " ", 
   SubscriptBox["z", "2"]}]]],
 "  as  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], " ", 
    SubscriptBox["z", "2"]}], " ", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["x", "2"]}], ",", 
     RowBox[{
      SubscriptBox["y", "1"], " ", 
      SubscriptBox["y", "2"]}]}], ")"}]}]]],
 ".  It turns out, however, that this is not a good definition, and we ask \
you in the exercises for this section to explain why.  How, then, should \
products be defined?  Again, if we equate  ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"x", ",", "y"}], ")"}]]],
 "  with  ",
 Cell[BoxData[
  RowBox[{"x", "+", 
   RowBox[{"\[ImaginaryI]", " ", "y"}]}]]],
 "  and assume, for the moment, that  ",
 Cell[BoxData[
  RowBox[{"\[ImaginaryI]", "=", 
   SqrtBox[
    RowBox[{"-", "1"}]]}]]],
 "  makes sense (so that  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ImaginaryI]", "2"], "=", 
   RowBox[{"-", "1"}]}]]],
 "), we have"
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], " ", 
     SubscriptBox["z", "2"]}], " ", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "1"], ",", " ", 
       SubscriptBox["y", "1"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "2"], ",", 
       SubscriptBox["y", "2"]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"          ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "1"], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["y", "1"]}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "2"], "+", 
       SubscriptBox["\[ImaginaryI]y", "2"]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"          ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["x", "2"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["y", "2"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["x", "2"], " ", 
      SubscriptBox["y", "1"]}], "+", 
     RowBox[{
      SuperscriptBox["\[ImaginaryI]", "2"], " ", 
      SubscriptBox["y", "1"], " ", 
      SubscriptBox["y", 
       RowBox[{"2", "\[IndentingNewLine]"}]]}]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"          ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["x", "2"]}], "-", 
     RowBox[{
      SubscriptBox["y", "1"], " ", 
      SubscriptBox["y", "2"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["x", "1"], " ", 
         SubscriptBox["y", "2"]}], "+", 
        RowBox[{
         SubscriptBox["x", "2"], " ", 
         SubscriptBox["y", "1"]}]}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"          ", 
   RowBox[{"=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["x", "1"], " ", 
        SubscriptBox["x", "2"]}], "-", 
       RowBox[{
        SubscriptBox["y", "1"], " ", 
        SubscriptBox["y", "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["x", "1"], " ", 
        SubscriptBox["y", "2"]}], "+", 
       RowBox[{
        SubscriptBox["x", "2"], " ", 
        SubscriptBox["y", "1"]}]}]}], ")"}]}]}]}]],
 "  \n\n\tThus, it appears we are forced into the following definition."
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 1.3, (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Complex Multiplication",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/ComplexMultiplication.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[")",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n\nFormula (1-10)",
  FontColor->RGBColor[0, 0, 1]],
 "    ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], " ", 
    SubscriptBox["z", "2"]}], " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "1"], ",", " ", 
       SubscriptBox["y", "1"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "2"], ",", 
       SubscriptBox["y", "2"]}], ")"}]}], "="}]}]]],
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["x", "2"]}], "-", 
     RowBox[{
      SubscriptBox["y", "1"], " ", 
      SubscriptBox["y", "2"]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", "1"], " ", 
      SubscriptBox["y", "2"]}], "+", 
     RowBox[{
      SubscriptBox["x", "2"], " ", 
      SubscriptBox["y", "1"]}]}]}], ")"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Derivation", " ", "of", "  ", "Formula", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "10"}], ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506702934953125*^9, 3.506702934953125*^9}},
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", " ", 
     RowBox[{
      SubscriptBox["x", "1"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "1"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], "=", " ", 
     RowBox[{
      SubscriptBox["x", "2"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "2"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) \!\(\*SubscriptBox[\(z\), \(2\)]\
\) = \>\"", " ", ",", " ", 
      RowBox[{
       SubscriptBox["z", "1"], " ", 
       SubscriptBox["z", "2"]}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) \!\(\*SubscriptBox[\(z\), \(2\)]\
\) = \>\"", " ", ",", " ", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        SubscriptBox["z", "2"]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.398969160875*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["\nExample 1.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Given  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{"3", "+", 
     RowBox[{"7", "\[ImaginaryI]", "   ", "and", "   ", 
      SubscriptBox["z", "2"]}]}], "=", 
    RowBox[{"5", "-", 
     RowBox[{"6", "\[ImaginaryI]"}]}]}]}]]],
 ".  Find  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   SubscriptBox["z", "2"]}]]],
 ".  \n\t\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], 
     SubscriptBox["z", "2"]}], " ", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"3", ",", "7"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"5", ",", 
       RowBox[{"-", "6"}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"          ", 
   RowBox[{"=", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"3", "*", "5"}], "-", 
       RowBox[{"7", 
        RowBox[{"(", 
         RowBox[{"-", "6"}], ")"}]}]}], ",", 
      RowBox[{
       RowBox[{"3", 
        RowBox[{"(", 
         RowBox[{"-", "6"}], ")"}]}], "+", 
       RowBox[{"5", "*", "7"}]}]}], ")"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"          ", 
   RowBox[{"=", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"15", "+", "42"}], ",", 
      RowBox[{
       RowBox[{"-", "18"}], "+", "35"}]}], ")"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"          ", 
   RowBox[{"=", " ", 
    RowBox[{"(", 
     RowBox[{"57", ",", "17"}], ")"}]}]}]}]],
 " \n\n We get the same answer by using the notation ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{"3", "+", 
    RowBox[{"7", "\[ImaginaryI]"}]}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{"5", "-", 
    RowBox[{"6", "\[ImaginaryI]"}]}]}]]],
 ":\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], 
     SubscriptBox["z", "2"]}], " ", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", ",", "7"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"5", ",", 
        RowBox[{"-", "6"}]}], ")"}]}], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"7", "\[ImaginaryI]"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"5", "-", 
        RowBox[{"6", "\[ImaginaryI]"}]}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"          ", 
   RowBox[{"=", 
    RowBox[{"15", "-", 
     RowBox[{"18", "\[ImaginaryI]"}], "+", 
     RowBox[{"35", "\[ImaginaryI]"}], "-", 
     RowBox[{"42", " ", 
      SuperscriptBox["\[ImaginaryI]", "2"]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"          ", 
   RowBox[{"=", 
    RowBox[{"15", "-", 
     RowBox[{"42", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "18"}], "+", "35"}], ")"}], "\[ImaginaryI]"}]}]}], 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"          ", 
   RowBox[{"=", " ", 
    RowBox[{"57", "+", 
     RowBox[{"17", "\[ImaginaryI]"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"          ", 
   RowBox[{"=", " ", 
    RowBox[{"(", 
     RowBox[{"57", ",", "17"}], ")"}]}]}]}]],
 " \n\nOf course, it makes sense that the answer came out as we expected \
because we used the notation ",
 Cell[BoxData[
  RowBox[{"x", "+", 
   RowBox[{"\[ImaginaryI]", " ", "y"}]}]],
  CellChangeTimes->{{3.39896942940625*^9, 3.398969440609375*^9}}],
 " as motivation for our definition in the first place."
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.39896944484375*^9, 3.398969450984375*^9}},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"1.2", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.50670293896875*^9, 3.50670293896875*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 "Compute ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   SubscriptBox["z", "2"]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"V", ",", "w", ",", "z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", 
     RowBox[{"3", "+", 
      RowBox[{"7", "\[ImaginaryI]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], "=", 
     RowBox[{"5", "-", 
      RowBox[{"6", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "3"], "=", 
     RowBox[{
      SubscriptBox["z", "1"], 
      SubscriptBox["z", "2"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.05"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "2"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.05"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "2"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "3"], "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.05"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["w", "3"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["w", "3"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{
     SubscriptBox["V", "1"], ",", 
     SubscriptBox["V", "2"], ",", 
     SubscriptBox["V", "3"], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "57"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "17"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "57", ",", "5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "17", ",", "2"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Red      \>\"", ",", 
      "\"\<   \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Green    \>\"", ",", 
      "\"\<   \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Blue     \>\"", ",", 
      "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) \!\(\*SubscriptBox[\(z\), \
\(2\)]\) = \>\"", " ", ",", " ", 
      RowBox[{
       SubscriptBox["z", "1"], 
       SubscriptBox["z", "2"]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398969170546875*^9, 3.39896917403125*^9}, {
   3.399673012375*^9, 3.3996730126875*^9}, {3.399707589125*^9, 
   3.39970762184375*^9}, {3.399708103921875*^9, 3.3997081435*^9}, 
   3.400232554140625*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tTo motivate our definition for division, we will proceed along the same \
lines as we did for multiplication, assuming ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "\[NotEqual]", "0"}]]],
 ":  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    SubscriptBox["z", "1"], 
    SubscriptBox["z", "2"]], "=", 
   RowBox[{
    FractionBox[
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "1"], ",", " ", 
       SubscriptBox["y", "1"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "2"], ",", 
       SubscriptBox["y", "2"]}], ")"}]], "=", 
    FractionBox[
     RowBox[{
      SubscriptBox["x", "1"], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "1"]}]}], 
     RowBox[{
      SubscriptBox["x", "2"], "+", 
      SubscriptBox["\[ImaginaryI]y", "2"]}]]}]}]]],
 "  "
}], "Text"],

Cell[TextData[{
 "\t\nWe need to figure out a way to write the preceding quantity in the form \
 ",
 Cell[BoxData[
  RowBox[{"x", "+", 
   RowBox[{"\[ImaginaryI]", " ", "y"}]}]]],
 ".  To do this, we use a standard trick and multiply the numerator and \
denominator by  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "2"], "+", 
   SubscriptBox["\[ImaginaryI]y", "2"]}]]],
 ",  which gives \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    FractionBox[
     SubscriptBox["z", "1"], 
     SubscriptBox["z", "2"]], "=", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "1"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["y", "1"]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "2"], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["y", "2"]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "2"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["y", "2"]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "2"], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["y", "2"]}]}], ")"}]}]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"=", 
    FractionBox[
     RowBox[{
      RowBox[{
       SubscriptBox["x", "1"], " ", 
       SubscriptBox["x", "2"]}], "+", 
      RowBox[{
       SubscriptBox["y", "1"], " ", 
       SubscriptBox["y", "2"]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["x", "1"]}], " ", 
          SubscriptBox["y", "2"]}], "+", 
         RowBox[{
          SubscriptBox["x", "2"], " ", 
          SubscriptBox["y", "1"]}]}], ")"}]}]}], 
     RowBox[{
      SubsuperscriptBox["x", "2", "2"], "+", 
      SubsuperscriptBox["y", "2", "2"]}]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"=", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        SubscriptBox["x", "1"], " ", 
        SubscriptBox["x", "2"]}], "+", 
       RowBox[{
        SubscriptBox["y", "1"], " ", 
        SubscriptBox["y", "2"]}]}], 
      RowBox[{
       SubsuperscriptBox["x", "2", "2"], "+", 
       SubsuperscriptBox["y", "2", "2"]}]], "+", 
     RowBox[{"\[ImaginaryI]", 
      FractionBox[
       RowBox[{" ", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["x", "1"]}], " ", 
          SubscriptBox["y", "2"]}], "+", 
         RowBox[{
          SubscriptBox["x", "2"], " ", 
          SubscriptBox["y", "1"]}]}]}], 
       RowBox[{
        SubsuperscriptBox["x", "2", "2"], "+", 
        SubsuperscriptBox["y", "2", "2"]}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"=", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{
         SubscriptBox["x", "1"], " ", 
         SubscriptBox["x", "2"]}], "+", 
        RowBox[{
         SubscriptBox["y", "1"], " ", 
         SubscriptBox["y", "2"]}]}], 
       RowBox[{
        SubsuperscriptBox["x", "2", "2"], "+", 
        SubsuperscriptBox["y", "2", "2"]}]], ",", 
      FractionBox[
       RowBox[{" ", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["x", "1"]}], " ", 
          SubscriptBox["y", "2"]}], "+", 
         RowBox[{
          SubscriptBox["x", "2"], " ", 
          SubscriptBox["y", "1"]}]}]}], 
       RowBox[{
        SubsuperscriptBox["x", "2", "2"], "+", 
        SubsuperscriptBox["y", "2", "2"]}]]}], ")"}]}]}]}]],
 "   \n\nThus, we finally arrive at a rather odd definition."
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 1.4, (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Complex Division",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/ComplexDivision.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[")\n",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\nFormula (1-11)",
  FontColor->RGBColor[0, 0, 1]],
 "    ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    SubscriptBox["z", "1"], 
    SubscriptBox["z", "2"]], "=", 
   RowBox[{
    FractionBox[
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "1"], ",", " ", 
       SubscriptBox["y", "1"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "2"], ",", 
       SubscriptBox["y", "2"]}], ")"}]], "=", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{
         SubscriptBox["x", "1"], " ", 
         SubscriptBox["x", "2"]}], "+", 
        RowBox[{
         SubscriptBox["y", "1"], " ", 
         SubscriptBox["y", "2"]}]}], 
       RowBox[{
        SubsuperscriptBox["x", "2", "2"], "+", 
        SubsuperscriptBox["y", "2", "2"]}]], ",", 
      FractionBox[
       RowBox[{" ", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["x", "1"]}], " ", 
          SubscriptBox["y", "2"]}], "+", 
         RowBox[{
          SubscriptBox["x", "2"], " ", 
          SubscriptBox["y", "1"]}]}]}], 
       RowBox[{
        SubsuperscriptBox["x", "2", "2"], "+", 
        SubsuperscriptBox["y", "2", "2"]}]]}], ")"}]}]}]]],
 ",   for   ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "\[NotEqual]", "0"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Derivation", " ", "of", "  ", "Formula", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "11"}], ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506702942578125*^9, 3.506702942578125*^9}},
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", " ", 
     RowBox[{
      SubscriptBox["x", "1"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "1"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], "=", " ", 
     RowBox[{
      SubscriptBox["x", "2"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "2"]}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n", "=", 
     RowBox[{"Expand", "[", 
      RowBox[{
       SubscriptBox["z", "1"], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["x", "2"], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["y", "2"]}]}], ")"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d", "=", 
     RowBox[{"Expand", "[", 
      RowBox[{
       SubscriptBox["z", "2"], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["x", "2"], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["y", "2"]}]}], ")"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[SubscriptBox[\(z\), \(1\)], SubscriptBox[\(z\), \
\(2\)]]\) = \>\"", " ", ",", " ", 
      FractionBox[
       SubscriptBox["z", "1"], 
       SubscriptBox["z", "2"]]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[SubscriptBox[\(z\), \(1\)], SubscriptBox[\(z\), \
\(2\)]]\) = \>\"", " ", ",", 
      FractionBox["n", "d"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[SubscriptBox[\(z\), \(1\)], SubscriptBox[\(z\), \
\(2\)]]\) = \>\"", " ", ",", 
      FractionBox[
       RowBox[{
        RowBox[{"ComplexExpand", "[", 
         RowBox[{"Re", "[", "n", "]"}], "]"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"ComplexExpand", "[", 
          RowBox[{"Im", "[", "n", "]"}], "]"}]}]}], "d"]}], "]"}], ";"}], " ",
    "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.398969182203125*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 1.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Given  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{"3", "+", 
     RowBox[{"7", "\[ImaginaryI]", "   ", "and", "   ", 
      SubscriptBox["z", "2"]}]}], "=", 
    RowBox[{"5", "-", 
     RowBox[{"6", "\[ImaginaryI]"}]}]}]}]]],
 ".  Find  ",
 Cell[BoxData[
  FractionBox[
   SubscriptBox["z", "1"], 
   SubscriptBox["z", "2"]]]],
 ".  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    SubscriptBox["z", "1"], 
    SubscriptBox["z", "2"]], "=", 
   RowBox[{
    FractionBox[
     RowBox[{"(", 
      RowBox[{"3", ",", " ", "7"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"5", ",", 
       RowBox[{"-", "6"}]}], ")"}]], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"15", "-", "42"}], 
        RowBox[{"25", "+", "36"}]], ",", 
       FractionBox[
        RowBox[{" ", 
         RowBox[{"18", "+", "35"}]}], 
        RowBox[{"25", "+", "36"}]]}], ")"}], "=", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["27", "61"]}], ",", 
       FractionBox["53", "61"]}], ")"}]}]}]}]]],
 "\n\t\nAs with the example for multiplication, we also get this answer if we \
use the notation  ",
 Cell[BoxData[
  RowBox[{"x", "+", 
   RowBox[{"\[ImaginaryI]", " ", "y"}]}]]],
 ":\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    FractionBox[
     SubscriptBox["z", "1"], 
     SubscriptBox["z", "2"]], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"(", 
       RowBox[{"3", ",", " ", "7"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"5", ",", 
        RowBox[{"-", "6"}]}], ")"}]], "=", 
     FractionBox[
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"7", "\[ImaginaryI]"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"5", "-", 
        RowBox[{"6", "\[ImaginaryI]"}]}], ")"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"7", "\[ImaginaryI]"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"5", "-", 
         RowBox[{"6", "\[ImaginaryI]"}]}], ")"}]], 
      FractionBox[
       RowBox[{"(", 
        RowBox[{"5", "+", 
         RowBox[{"6", "\[ImaginaryI]"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"5", "+", 
         RowBox[{"6", "\[ImaginaryI]"}]}], ")"}]]}], "=", 
     FractionBox[
      RowBox[{"15", "+", 
       RowBox[{"18", "\[ImaginaryI]"}], "+", 
       RowBox[{"35", "\[ImaginaryI]"}], "+", 
       RowBox[{"42", 
        SuperscriptBox["\[ImaginaryI]", "2"]}]}], 
      RowBox[{"25", "+", 
       RowBox[{"30", "\[ImaginaryI]"}], "-", 
       RowBox[{"30", "\[ImaginaryI]"}], "-", 
       RowBox[{"36", 
        SuperscriptBox["\[ImaginaryI]", "2"]}]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"=", 
    RowBox[{
     FractionBox[
      RowBox[{"15", "-", "42", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"18", "+", "35"}], ")"}], "\[ImaginaryI]"}]}], 
      RowBox[{"(", 
       RowBox[{"25", "+", "3"}], ")"}]], " ", "=", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["27", "61"]}], "+", 
      RowBox[{
       FractionBox["53", "61"], "\[ImaginaryI]"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["27", "61"]}], ",", 
      FractionBox["53", "61"]}], ")"}]}]}]}]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"1.3", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.50670294615625*^9, 3.506702946171875*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 "Compute ",
 Cell[BoxData[
  FractionBox[
   SubscriptBox["z", "1"], 
   SubscriptBox["z", "2"]]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"V", ",", "w", ",", "z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", 
     RowBox[{"3", "+", 
      RowBox[{"7", "\[ImaginaryI]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], "=", 
     RowBox[{"5", "-", 
      RowBox[{"6", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "4"], "=", 
     FractionBox[
      SubscriptBox["z", "1"], 
      SubscriptBox["z", "2"]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "1"], "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.1"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "2"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.1"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "2"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "3"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.1"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["w", "4"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["w", "4"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{
     SubscriptBox["V", "1"], ",", 
     SubscriptBox["V", "2"], ",", 
     SubscriptBox["V", "3"], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "7"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "5", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "7", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["13", "6"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Red      \>\"", ",", 
      "\"\< \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Green    \>\"", ",", 
      "\"\< \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Blue     \>\"", ",", 
      "\"\<\!\(\*FractionBox[SubscriptBox[\(z\), \(1\)], SubscriptBox[\(z\), \
\(2\)]]\) = \>\"", " ", ",", " ", 
      FractionBox[
       SubscriptBox["z", "1"], 
       SubscriptBox["z", "2"]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398969191453125*^9, 3.398969193921875*^9}, {
   3.399673018125*^9, 3.3996730183125*^9}, {3.399707641515625*^9, 
   3.399707671*^9}, 3.4002325631875*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tTo perform operations on complex numbers, most mathematicians would use \
the notation  ",
 Cell[BoxData[
  RowBox[{"x", "+", 
   RowBox[{"\[ImaginaryI]", " ", "y"}]}]]],
 "  and engage in algebraic manipulations, as we did here, rather than apply \
the complicated-looking definitions we gave for those operations on ordered \
pairs.  This procedure is valid because we used the  ",
 Cell[BoxData[
  RowBox[{"x", "+", 
   RowBox[{"\[ImaginaryI]", " ", "y"}]}]]],
 "  notation as a guide for defining the operations in the first place.  \
Remember, though, that the  ",
 Cell[BoxData[
  RowBox[{"x", "+", 
   RowBox[{"\[ImaginaryI]", " ", "y"}]}]]],
 "  notation is nothing more than a convenient bookkeeping device for keeping \
track of how to manipulate ordered pairs.  It is the ordered pair algebraic \
definitions that form the real foundation on which the complex number system \
is based.  In fact, if you were to program a computer to do arithmetic on \
complex numbers, your program would perform calculations on ordered pairs, \
using exactly the definitions that we gave."
}], "Text"],

Cell[TextData[{
 "\tIt turns out that our algebraic definitions give complex numbers all the \
properties we normally ascribe to the real number system.  Taken together, \
they describe what algebraists call a ",
 StyleBox[ButtonBox["field",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/Field.html"], None}],
  FontVariations->{"Underline"->True}],
 ".  In formal terms, a field is a set (in this case, the complex numbers) \
together with two binary operations (in this case, addition and \
multiplication) having the following properties."
}], "Text"],

Cell[TextData[{
 StyleBox["(P1) Commutative Law for Addition.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  \n",
 StyleBox["\n\t\t\t",
  FontColor->RGBColor[1, 0, 1]],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], "+", 
    SubscriptBox["z", "2"]}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["z", "2"], "+", 
    SubscriptBox["z", "1"]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Derivation", " ", "of", "  ", "Property", " ", 
   RowBox[{
    RowBox[{"(", "P1", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.50670294940625*^9, 3.50670294940625*^9}},
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], " ", "=", " ", 
     RowBox[{
      SubscriptBox["x", "1"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "1"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], " ", "=", " ", 
     RowBox[{
      SubscriptBox["x", "2"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "2"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", " ", ",", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) + \!\(\*SubscriptBox[\(z\), \
\(2\)]\) = \>\"", " ", ",", " ", 
      RowBox[{
       SubscriptBox["z", "1"], "+", 
       SubscriptBox["z", "2"]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) + \!\(\*SubscriptBox[\(z\), \
\(1\)]\) = \>\"", " ", ",", " ", 
      RowBox[{
       SubscriptBox["z", "2"], "+", 
       SubscriptBox["z", "1"]}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(z\), \(1\)]\) + \!\(\*SubscriptBox[\(z\), \
\(2\)]\) = \!\(\*SubscriptBox[\(z\), \(2\)]\) + \!\(\*SubscriptBox[\(z\), \(1\
\)]\) ? \>\"", ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["z", "1"], "+", 
        SubscriptBox["z", "2"]}], " ", "\[Equal]", " ", 
       RowBox[{
        SubscriptBox["z", "2"], "+", 
        SubscriptBox["z", "1"]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39896920234375*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["(P2) Associative Law for Addition.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], "+", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "2"], "+", 
      SubscriptBox["z", "3"]}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], "+", 
      SubscriptBox["z", "2"]}], ")"}], "+", " ", 
    SubscriptBox["z", "3"]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["(P3) Additive Identity.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  There is a complex number ",
 Cell[BoxData["\[Omega]"]],
 " such that \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "+", "\[Omega]"}], "=", "z"}]]],
 " for all complex numbers z. \n\t\t\nThe number ",
 Cell[BoxData["\[Omega]"]],
 " is obviously the ordered pair ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"0", ",", "0"}], ")"}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["(P4) Additive Inverses.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Given any complex number ",
 Cell[BoxData["z"]],
 ", there is a complex number ",
 Cell[BoxData["\[Eta]"]],
 " (depending on ",
 Cell[BoxData["z"]],
 ") with the property that \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "+", "\[Eta]"}], "=", 
   RowBox[{"(", 
    RowBox[{"0", ",", "0"}], ")"}]}]]],
 ". \n\nObviously, if ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}], "=", 
    RowBox[{"x", "+", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]}]]],
 ", the number ",
 Cell[BoxData["\[Eta]"]],
 " will be ",
 Cell[BoxData[
  RowBox[{"\[Eta]", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "x"}], ",", 
      RowBox[{"-", "y"}]}], ")"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "x"}], "-", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}], "=", 
     RowBox[{"-", "z"}]}]}]}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["(P5) Commutative Law for Multiplication.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], 
    SubscriptBox["z", "2"]}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["z", "2"], 
    SubscriptBox["z", "1"]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["(P6) Associative Law for Multiplication.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "2"], 
      SubscriptBox["z", "3"]}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "1"], 
      SubscriptBox["z", "2"]}], ")"}], 
    SubscriptBox["z", "3"]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.40290958984375*^9, 3.40290959371875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["(P7) Multiplicative Identity.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  There is a complex number ",
 Cell[BoxData["\[Zeta]"]],
 " such that \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"\[Zeta]z", "=", "z"}]]],
 " for all complex numbers ",
 Cell[BoxData["z"]],
 ". \n\nAs one might expect, it turns out that ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"1", ",", "0"}], ")"}]]],
 " is the unique complex number ",
 Cell[BoxData["\[Zeta]"]],
 " with this property.  We ask you to verify this identity in the exercises \
for this section."
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{3.398969486890625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["(P8) Multiplicative Inverses.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Given any number ",
 Cell[BoxData["z"]],
 " other than the number (0, 0), there is a complex number (depending on ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ") which we shall denote by ",
 Cell[BoxData[
  SuperscriptBox["z", 
   RowBox[{"-", "1"}]]]],
 " with the property that \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", " ", 
    SuperscriptBox["z", 
     RowBox[{"-", "1"}]]}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", ",", "0"}], ")"}], "=", "1"}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Based on our definition for division, it seems reasonable that the number ",
 Cell[BoxData[
  SuperscriptBox["z", 
   RowBox[{"-", "1"}]]]],
 " would be  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SuperscriptBox["z", 
     RowBox[{"-", "1"}]], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}], 
      RowBox[{"z", " "}]], "=", " ", 
     FractionBox["1", 
      RowBox[{"x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}]]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"       ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"x", "-", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"x", "-", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]], " ", "=", " ", 
     FractionBox[
      RowBox[{"x", "-", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"]}]]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"       ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["x", 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"]}]], " ", "+", 
     RowBox[{"\[ImaginaryI]", 
      FractionBox[
       RowBox[{"-", "y"}], 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"]}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"       ", 
   RowBox[{"=", 
    RowBox[{"(", " ", 
     RowBox[{
      FractionBox["x", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"]}]], " ", ",", 
      FractionBox[
       RowBox[{"-", "y"}], 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"]}]]}], ")"}]}]}]}]],
 ".  \n\nWe ask you to confirm this result in the exercises for this section."
}], "Text"],

Cell[TextData[{
 StyleBox["(P9) The Distributive Law.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "2"], "+", 
      SubscriptBox["z", "3"]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], 
     SubscriptBox["z", "2"]}], "+", 
    RowBox[{
     SubscriptBox["z", "1"], 
     SubscriptBox["z", "3"]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.402909600109375*^9, 3.4029096144375*^9}, {
  3.52680896096875*^9, 3.52680896096875*^9}},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Derivation", " ", "of", "  ", "Property", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"P", " ", "9"}], ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506702954984375*^9, 3.506702954984375*^9}},
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", 
     RowBox[{
      SubscriptBox["x", "1"], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "1"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], "=", 
     RowBox[{
      SubscriptBox["x", "2"], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "2"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], "=", 
     RowBox[{
      SubscriptBox["x", "3"], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["y", "3"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<          \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<          \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<          \!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  \!\(\*SubscriptBox[\(z\), \(1\)]\)(\!\(\*SubscriptBox[\(z\), \
\(2\)]\) + \!\(\*SubscriptBox[\(z\), \(3\)]\)) = \>\"", " ", ",", 
      RowBox[{
       SubscriptBox["z", "1"], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["z", "2"], "+", 
         SubscriptBox["z", "3"]}], ")"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) \!\(\*SubscriptBox[\(z\), \(2\)]\
\) + \!\(\*SubscriptBox[\(z\), \(1\)]\) \!\(\*SubscriptBox[\(z\), \(3\)]\) = \
\>\"", " ", ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["z", "1"], 
        SubscriptBox["z", "2"]}], "+", 
       RowBox[{
        SubscriptBox["z", "1"], " ", 
        SubscriptBox["z", "3"]}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  \!\(\*SubscriptBox[\(z\), \(1\)]\)(\!\(\*SubscriptBox[\(z\), \
\(2\)]\) + \!\(\*SubscriptBox[\(z\), \(3\)]\)) = \>\"", " ", ",", " ", 
      RowBox[{"Expand", "[", 
       RowBox[{
        SubscriptBox["z", "1"], 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["z", "2"], "+", 
          SubscriptBox["z", "3"]}], ")"}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) \!\(\*SubscriptBox[\(z\), \(2\)]\
\) + \!\(\*SubscriptBox[\(z\), \(1\)]\) \!\(\*SubscriptBox[\(z\), \(3\)]\) = \
\>\"", " ", ",", " ", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["z", "1"], " ", 
         SubscriptBox["z", "2"]}], "+", 
        RowBox[{
         SubscriptBox["z", "1"], " ", 
         SubscriptBox["z", "3"]}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(z\), \(1\)]\)(\!\(\*SubscriptBox[\(z\), \(2\
\)]\) + \!\(\*SubscriptBox[\(z\), \(3\)]\)) =  \!\(\*SubscriptBox[\(z\), \
\(1\)]\) \!\(\*SubscriptBox[\(z\), \(2\)]\) + \!\(\*SubscriptBox[\(z\), \
\(1\)]\) \!\(\*SubscriptBox[\(z\), \(3\)]\) ?  \>\"", ",", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{
         SubscriptBox["z", "1"], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["z", "2"], "+", 
           SubscriptBox["z", "3"]}], ")"}]}], "]"}], "  ", "\[Equal]", "  ", 
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["z", "1"], " ", 
          SubscriptBox["z", "2"]}], "+", 
         RowBox[{
          SubscriptBox["z", "1"], " ", 
          SubscriptBox["z", "3"]}]}], "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.398969211734375*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tNone of these properties is difficult to prove.  Most of the proofs make \
use of corresponding facts in the real number system.  To illustrate, we give \
a proof of property (P1).\
\>", "Text",
 CellChangeTimes->{3.398969514171875*^9}],

Cell[TextData[{
 "Proof of the commutative law for addition:  Let ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["x", "1"], ",", 
     SubscriptBox["y", "1"]}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["x", "2"], ",", 
     SubscriptBox["y", "2"]}], ")"}]}]]],
 " be arbitrary complex numbers.  Then,\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "+", 
     SubscriptBox["z", "2"]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "1"], ",", 
       SubscriptBox["y", "1"]}], ")"}], "+", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "2"], ",", 
       SubscriptBox["y", "2"]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["x", "1"], "+", 
        SubscriptBox["x", "2"]}], ",", 
       RowBox[{
        SubscriptBox["y", "1"], "+", 
        SubscriptBox["y", "2"]}]}], ")"}], "        ", 
     RowBox[{"(", 
      StyleBox[
       RowBox[{
       "by", " ", "definition", " ", "of", " ", "addition", " ", "of", " ", 
        "complex", " ", "numbers"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["x", "2"], "+", 
        SubscriptBox["x", "1"]}], ",", 
       RowBox[{
        SubscriptBox["y", "2"], "+", 
        SubscriptBox["y", "1"]}]}], ")"}], "        ", 
     RowBox[{"(", 
      StyleBox[
       RowBox[{
       "by", " ", "the", " ", "commutative", " ", "law", " ", "for", " ", 
        "real", " ", "numbers"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "2"], ",", 
       SubscriptBox["y", "2"]}], ")"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "1"], ",", 
        SubscriptBox["y", "1"]}], ")"}], "   ", 
      RowBox[{"(", 
       StyleBox[
        RowBox[{
        "by", " ", "definition", " ", "of", " ", "addition", " ", "of", " ", 
         "complex", " ", "numbers"}],
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", " ", 
    RowBox[{
     SubscriptBox["z", "2"], "+", 
     SubscriptBox["z", "1"]}]}]}]}]]
}], "Text",
 CellChangeTimes->{3.398969517828125*^9}],

Cell[TextData[{
 "\tActually, you can think of the real number system as a subset of the \
complex number system.  To see why, let's agree that, as any complex number \
of the form ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"t", ",", "0"}], ")"}]]],
 " is on the ",
 Cell[BoxData["x"]],
 " axis, we can identify it with the real number ",
 Cell[BoxData["t"]],
 ".  With this correspondence, we can easily verify that our definitions for \
addition, subtraction, multiplication, and division of complex numbers are \
consistent with the corresponding operations on real numbers.  For example, \
if ",
 Cell[BoxData[
  SubscriptBox["x", "1"]]],
 " and ",
 Cell[BoxData[
  SubscriptBox["x", "2"]]],
 " are real numbers, then\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["x", "1"], 
     SubscriptBox["x", "2"]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "1"], ",", "0"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "2"], ",", "0"}], ")"}], "     ", 
     RowBox[{"(", 
      StyleBox[
       RowBox[{"by", " ", "our", " ", "agreed", " ", "correspondence"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["x", "1"], 
         SubscriptBox["x", "2"]}], "-", "0"}], ",", 
       RowBox[{"0", "+", "0"}]}], ")"}], "   ", 
     RowBox[{"(", 
      StyleBox[
       RowBox[{
       "by", " ", "definition", " ", "of", " ", "multiplication", " ", "of", 
        " ", "complex", " ", "numbers"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["x", "1"], 
        SubscriptBox["x", "2"]}], ",", "0"}], ")"}], "                ", 
     RowBox[{"(", 
      StyleBox[
       RowBox[{
       "confirming", " ", "the", " ", "consistence", " ", "of", " ", "our", 
        " ", "correspondence"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], ")"}]}]}]}]}]]
}], "Text"],

Cell[TextData[{
 "\tIt is now time to show specifically how the symbol ",
 Cell[BoxData["\[ImaginaryI]"]],
 " relates to the quantity  ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"-", "1"}]]]],
 ".  Note that \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}], "2"], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0", "-", "1"}], ",", 
       RowBox[{"0", "+", "0"}]}], ")"}], "    ", 
     RowBox[{"(", 
      StyleBox[
       RowBox[{
       "by", " ", "definition", " ", "of", " ", "multiplication", " ", "of", 
        " ", "complex", " ", "numbers"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "0"}], ")"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{"-", "1"}], "                          ", 
     RowBox[{"(", 
      StyleBox[
       RowBox[{"by", " ", "our", " ", "agreed", " ", "correspondence"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], ")"}]}]}]}]}]]
}], "Text"],

Cell[TextData[{
 "\tIf we use the symbol ",
 Cell[BoxData["\[ImaginaryI]"]],
 " for the point ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"0", ",", "1"}], ")"}]]],
 " , the preceding identity gives \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ImaginaryI]", "2"], " ", "=", " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}], "2"], " ", "=", " ", 
    RowBox[{"-", "1"}]}]}]]],
 ", \n\nwhich means  ",
 Cell[BoxData[
  RowBox[{"\[ImaginaryI]", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"0", ",", "1"}], ")"}], "=", 
    SqrtBox[
     RowBox[{"-", "1"}]]}]}]]],
 ".  So, the next time you are having a discussion with your friends and they \
scoff when you claim that ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"-", "1"}]]]],
 " is not imaginary, calmly put your pencil on the point ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"0", ",", "1"}], ")"}]]],
 " of the coordinate plane and ask them if there is anything imaginary about \
it.  When they agree there isn't, you can tell them that this point, in fact, \
represents the mysterious ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"-", "1"}]]]],
 " in the same way that ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"1", ",", "0"}], ")"}]]],
 " represents ",
 Cell[BoxData["1"]],
 " ."
}], "Text"],

Cell[TextData[{
 "\tWe can also see more clearly now how the notation  ",
 Cell[BoxData[
  RowBox[{"x", "+", 
   RowBox[{"\[ImaginaryI]", " ", "y"}]}]]],
 "  equates to ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"x", ",", "y"}], ")"}]]],
 ".  Using the preceding conventions (i.e.,  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{"(", 
    RowBox[{"x", ",", "0"}], ")"}]}]]],
 ", etc.), we have  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"x", "+", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", ",", "0"}], ")"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"y", ",", "0"}], ")"}], "    ", 
      RowBox[{"(", 
       StyleBox[
        RowBox[{
        "by", " ", "our", " ", "previously", " ", "discussed", " ", 
         "conventions"}],
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", ",", "0"}], ")"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"0", ",", "y"}], ")"}], "                   ", 
      RowBox[{"(", 
       StyleBox[
        RowBox[{
        "by", " ", "definition", " ", "of", " ", "multiplication", " ", "of", 
         " ", "complex", " ", "numbers"}],
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}], "                                   ", 
     RowBox[{"(", 
      StyleBox[
       RowBox[{
       "by", " ", "definition", " ", "of", " ", "addition", " ", "of", " ", 
        "complex", " ", "numbers"}],
       FontFamily->"Times New Roman"], ")"}]}]}]}]}]],
 "  "
}], "Text",
 CellChangeTimes->{3.5327053230625*^9}],

Cell[TextData[{
 "\tThus we may move freely between the notations  ",
 Cell[BoxData[
  RowBox[{"x", "+", 
   RowBox[{"\[ImaginaryI]", " ", "y"}]}]]],
 "  and ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"x", ",", "y"}], ")"}]]],
 ", depending on which is more convenient for the context in which we are \
working.  Students sometimes wonder whether it matters where the \"",
 Cell[BoxData["\[ImaginaryI]"]],
 "\" is located in writing a complex number.  It does not.  Generally, most \
texts place terms containing an \"",
 Cell[BoxData["\[ImaginaryI]"]],
 "\" at the end of an expression, and place the \"",
 Cell[BoxData["\[ImaginaryI]"]],
 "\" before a variable, but after a constant.  Thus, we write  ",
 Cell[BoxData[
  RowBox[{"x", "+", 
   RowBox[{"\[ImaginaryI]", " ", "y"}]}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{"u", "+", 
   RowBox[{"\[ImaginaryI]", " ", "v"}]}]]],
 ", etc.,  but  ",
 Cell[BoxData[
  RowBox[{"3", "+", 
   RowBox[{"7", "\[ImaginaryI]", " "}]}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{"5", "-", 
   RowBox[{"6", "\[ImaginaryI]"}]}]]],
 "  and so forth.  Because letters lower in the alphabet generally denote \
constants, you will usually (but not always) see the expression  ",
 Cell[BoxData[
  RowBox[{"a", "+", 
   RowBox[{"b", " ", "\[ImaginaryI]"}]}]]],
 ",  instead of  ",
 Cell[BoxData[
  RowBox[{"a", "+", 
   RowBox[{"\[ImaginaryI]", " ", "b"}]}]]],
 ".  Many authors write quantities like ",
 Cell[BoxData[
  RowBox[{"1", "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SqrtBox["3"]}]}]]],
 "  instead of  ",
 Cell[BoxData[
  RowBox[{"1", "+", 
   RowBox[{
    SqrtBox["3"], "\[ImaginaryI]"}]}]]],
 "  to make sure the \"",
 Cell[BoxData["\[ImaginaryI]"]],
 "\" is not mistakenly thought to be inside the square root symbol.  \
Additionally, if there is concern that the \"",
 Cell[BoxData["\[ImaginaryI]"]],
 "\" might be missed, it is sometimes placed before a lengthy expression, as \
in  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"2", "cos", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["5", "6"]}], "\[Pi]"}], "+", 
      RowBox[{"2", "n", " ", "\[Pi]"}]}], ")"}]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", "2", "sin", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["5", "6"]}], "\[Pi]"}], "+", 
      RowBox[{"2", "n", " ", "\[Pi]"}]}], ")"}]}]}]]],
 "."
}], "Text",
 CellChangeTimes->{{3.53270537153125*^9, 3.53270537153125*^9}}],

Cell["\<\
\tWe close this section with three important definitions and a theorem \
involving them.  We ask you for a proof of the theorem in the excercises.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Definition 1.5, (Real Part of z).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["  ",
  FontColor->RGBColor[0, 0, 1]],
 "The real part of  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"x", "+", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]]],
 ",  denoted by  ",
 Cell[BoxData[
  RowBox[{"Re", 
   RowBox[{"(", "z", ")"}]}]]],
 ",  is the real number  ",
 Cell[BoxData["x"]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Definition 1.6, (Imaginary Part of z).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["  ",
  FontColor->RGBColor[0, 0, 1]],
 "The imaginary part of  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"x", "+", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]]],
 ",  denoted by  ",
 Cell[BoxData[
  RowBox[{"Im", 
   RowBox[{"(", "z", ")"}]}]]],
 ",  is the real number  ",
 Cell[BoxData["y"]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Definition 1.7, (Conjugate of z).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["  ",
  FontColor->RGBColor[0, 0, 1]],
 "The conjugate of  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"x", "+", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]]],
 ",  denoted by  ",
 Cell[BoxData[
  OverscriptBox[
   RowBox[{"z", " "}], "_"]]],
 ",  is the complex number  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"x", ",", 
     RowBox[{"-", "y"}]}], ")"}], "=", 
   RowBox[{"x", "-", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Example 1.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Given  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], "+", 
     RowBox[{"7", "\[ImaginaryI]", "   ", "and", "   ", 
      SubscriptBox["z", "2"]}]}], "=", 
    RowBox[{"9", "+", 
     RowBox[{"4", "\[ImaginaryI]"}]}]}]}]]],
 ".   \n\n",
 StyleBox["1.4",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " ",
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  We have   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", "[", 
    SubscriptBox["z", "1"], "]"}], "=", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{
      RowBox[{"-", "3"}], "+", 
      RowBox[{"7", "\[ImaginaryI]"}]}], "]"}], "=", 
    RowBox[{"-", "3"}], " "}]}]]],
 "    and    ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", "[", 
    SubscriptBox["z", "2"], "]"}], "=", " ", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{"9", "+", 
      RowBox[{"4", "\[ImaginaryI]"}]}], "]"}], "=", "9"}]}]]],
 ".  \n\n",
 StyleBox["1.4",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " ",
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  We have   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", 
    SubscriptBox["z", "1"], "]"}], "=", 
   RowBox[{
    RowBox[{"Im", "[", 
     RowBox[{
      RowBox[{"-", "3"}], "+", 
      RowBox[{"7", "\[ImaginaryI]"}]}], "]"}], "=", "7"}]}]]],
 "    and    ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", 
    SubscriptBox["z", "2"], "]"}], "=", 
   RowBox[{
    RowBox[{"Im", "[", 
     RowBox[{"9", "+", 
      RowBox[{"4", "\[ImaginaryI]"}]}], "]"}], "=", "4"}]}]]],
 ".  \n\n",
 StyleBox["1.4",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " ",
 StyleBox["(c)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  We have   ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox[
    SubscriptBox["z", "1"], "_"], " ", "=", 
   RowBox[{
    OverscriptBox[
     RowBox[{
      RowBox[{"-", "3"}], "+", 
      RowBox[{"7", "\[ImaginaryI]"}]}], "_"], " ", "=", 
    RowBox[{
     RowBox[{"-", "3"}], "-", 
     RowBox[{"7", "\[ImaginaryI]"}]}]}]}]]],
 "    and      ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox[
    SubscriptBox["z", "2"], "_"], "=", 
   RowBox[{
    OverscriptBox[
     RowBox[{"9", "+", 
      RowBox[{"4", "\[ImaginaryI]"}]}], "_"], " ", "=", 
    RowBox[{"9", "-", 
     RowBox[{"4", "\[ImaginaryI]"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", "1.4", " ", 
   RowBox[{
    RowBox[{"(", "a", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506702960921875*^9, 3.5067029609375*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Compute ",
 Cell[BoxData[
  RowBox[{"Re", "[", 
   SubscriptBox["z", "1"], "]"}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"V", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", "3"}], " ", "+", " ", 
      RowBox[{"7", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "1"], "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.12"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.012", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "2"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.12"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.012", "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "1"], "]"}], ",", "0"}], "}"}]}], "}"}], 
         "]"}]}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{
     SubscriptBox["V", "1"], ",", 
     SubscriptBox["V", "2"], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "7"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "0", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "7", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["7", "3"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Red      \>\"", ",", 
      "\"\<    \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Blue     \>\"", ",", 
      "\"\<Re[\!\(\*SubscriptBox[\(z\), \(1\)]\)] = \>\"", " ", ",", " ", 
      RowBox[{"Re", "[", 
       SubscriptBox["z", "1"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39896922278125*^9, 3.398969249578125*^9}, {
  3.399673024578125*^9, 3.399673024921875*^9}, {3.399707704046875*^9, 
  3.39970772359375*^9}, {3.399708168328125*^9, 3.399708177109375*^9}, {
  3.400232490734375*^9, 3.400232492125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Compute ",
 Cell[BoxData[
  RowBox[{"Re", "[", 
   SubscriptBox["z", "2"], "]"}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"V", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], " ", "=", " ", 
     RowBox[{"9", " ", "+", " ", 
      RowBox[{"4", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "2"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "2"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.007", "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "2"], "]"}], ",", "0"}], "}"}]}], "}"}], 
         "]"}]}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{
     SubscriptBox["V", "1"], ",", 
     SubscriptBox["V", "2"], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "9"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "9", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["4", "9"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Red      \>\"", ",", 
      "\"\<    \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Blue     \>\"", ",", 
      "\"\<Re[\!\(\*SubscriptBox[\(z\), \(2\)]\)] = \>\"", " ", ",", " ", 
      RowBox[{"Re", "[", 
       SubscriptBox["z", "2"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39896926025*^9, 3.39896929425*^9}, {
  3.399673026609375*^9, 3.39967302690625*^9}, {3.399707736359375*^9, 
  3.39970775625*^9}, {3.399708183234375*^9, 3.399708222578125*^9}, {
  3.399708482125*^9, 3.399708493375*^9}, {3.4002324986875*^9, 3.4002325*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", "1.4", " ", 
   RowBox[{
    RowBox[{"(", "b", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.50670296425*^9, 3.506702964265625*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Compute ",
 Cell[BoxData[
  RowBox[{"Im", "[", 
   SubscriptBox["z", "1"], "]"}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"V", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", "3"}], " ", "+", " ", 
      RowBox[{"7", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.12"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.012", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "2"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.12"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.02", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{
     SubscriptBox["V", "1"], ",", 
     SubscriptBox["V", "2"], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "7"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "0", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "7", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["7", "3"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Red      \>\"", ",", 
      "\"\<    \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Green    \>\"", ",", 
      "\"\<Im[\!\(\*SubscriptBox[\(z\), \(1\)]\)] = \>\"", " ", ",", " ", 
      RowBox[{"Im", "[", 
       SubscriptBox["z", "1"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398969305921875*^9, 3.39896932484375*^9}, {
  3.39967303259375*^9, 3.399673032828125*^9}, {3.39970777228125*^9, 
  3.399707789671875*^9}, {3.399708242671875*^9, 3.399708316765625*^9}, {
  3.400232506421875*^9, 3.400232507421875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "\n",
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Compute ",
 Cell[BoxData[
  RowBox[{"Im", "[", 
   SubscriptBox["z", "2"], "]"}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"V", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], " ", "=", " ", 
     RowBox[{"9", " ", "+", " ", 
      RowBox[{"4", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "2"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "2"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "2"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{
     SubscriptBox["V", "1"], ",", 
     SubscriptBox["V", "2"], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "9"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "9", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["4", "9"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Red      \>\"", ",", 
      "\"\<    \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Green    \>\"", ",", 
      "\"\<Im[\!\(\*SubscriptBox[\(z\), \(2\)]\)] = \>\"", " ", ",", " ", 
      RowBox[{"Im", "[", 
       SubscriptBox["z", "2"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398969332328125*^9, 3.398969352609375*^9}, {
  3.39967303840625*^9, 3.399673038578125*^9}, {3.399707810015625*^9, 
  3.3997078281875*^9}, {3.399708343828125*^9, 3.399708406203125*^9}, {
  3.400232511625*^9, 3.400232512484375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", "1.4", " ", 
   RowBox[{
    RowBox[{"(", "c", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506702967125*^9, 3.506702967125*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Compute  ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox[
    SubscriptBox["z", "1"], "_"], " "}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"V", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", "3"}], " ", "+", " ", 
      RowBox[{"7", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.1"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "2"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.1"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "1"], "]"}], ",", 
             RowBox[{"-", 
              RowBox[{"Im", "[", 
               SubscriptBox["z", "1"], "]"}]}]}], "}"}]}], "}"}], "]"}]}], 
       "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{
     SubscriptBox["V", "1"], ",", 
     SubscriptBox["V", "2"], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "7"}], ",", "7"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "0", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "7"}], ",", "7", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["7", "3"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Red      \>\"", ",", 
      "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Blue     \>\"", ",", 
      "\"\<\!\(\*OverscriptBox[SubscriptBox[\(z\), \(1\)], \(_\)]\) = \>\"", 
      " ", ",", 
      RowBox[{"Conjugate", "[", 
       SubscriptBox["z", "1"], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39896936165625*^9, 3.39896936415625*^9}, {
  3.399673043296875*^9, 3.399673043671875*^9}, {3.399707853828125*^9, 
  3.399707872140625*^9}, {3.400232516671875*^9, 3.400232517484375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "\n",
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Compute  ",
 Cell[BoxData[
  OverscriptBox[
   SubscriptBox["z", "2"], "_"]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"V", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], " ", "=", " ", 
     RowBox[{"9", " ", "+", " ", 
      RowBox[{"4", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["z", "2"], "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["V", "2"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.006", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["z", "2"], "]"}], ",", 
             RowBox[{"-", 
              RowBox[{"Im", "[", 
               SubscriptBox["z", "2"], "]"}]}]}], "}"}]}], "}"}], "]"}]}], 
       "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{
     SubscriptBox["V", "1"], ",", 
     SubscriptBox["V", "2"], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "9"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "8", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["8", "9"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Red      \>\"", ",", 
      "\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", " ", ",", " ", 
      SubscriptBox["z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Blue     \>\"", ",", 
      "\"\<\!\(\*OverscriptBox[SubscriptBox[\(z\), \(2\)], \(_\)]\) = \>\"", 
      " ", ",", " ", 
      RowBox[{"Conjugate", "[", 
       SubscriptBox["z", "2"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.398969369515625*^9, 3.398969372109375*^9}, {
  3.3996730491875*^9, 3.39967304953125*^9}, {3.3997078856875*^9, 
  3.3997079049375*^9}, {3.399708424203125*^9, 3.39970843709375*^9}, {
  3.40023252075*^9, 3.4002325216875*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tThe following theorem gives some important facts relating to these \
operations.  You will be asked for a proof in the exercises\
\>", "Text",
 CellChangeTimes->{3.398969544765625*^9}],

Cell[TextData[{
 StyleBox["Theorem 1.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], ",", 
   RowBox[{
    SubscriptBox["z", "2"], "  ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", "z"}]}]]],
 "  are arbitrary complex numbers. Then if ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "\[NotEqual]", "0"}]]],
 " \n\n",
 Cell[BoxData[GridBox[{
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "12"}], ")"}],
       FontColor->RGBColor[0, 0, 1]], "    "}], 
     RowBox[{" ", "\[IndentingNewLine]", " "}], 
     RowBox[{
      OverscriptBox[
       RowBox[{
        OverscriptBox[
         RowBox[{"z", " "}], "_"], " "}], "_"], "=", "z", 
      "                        "}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "13"}], ")"}],
       FontColor->RGBColor[0, 0, 1]], "     "}], 
     RowBox[{" ", "\[IndentingNewLine]", " "}], 
     RowBox[{
      OverscriptBox[
       RowBox[{
        SubscriptBox["z", "1"], "+", 
        SubscriptBox["z", "2"]}], "_"], " ", "=", 
      RowBox[{
       OverscriptBox[
        SubscriptBox["z", "1"], "_"], "+", 
       OverscriptBox[
        SubscriptBox["z", "2"], "_"], "    "}]}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "14"}], ")"}],
       FontColor->RGBColor[0, 0, 1]], "     "}], 
     RowBox[{" ", "\[IndentingNewLine]", " "}], 
     RowBox[{
      OverscriptBox[
       RowBox[{
        SubscriptBox["z", "1"], 
        SubscriptBox["z", "2"]}], "_"], " ", "=", 
      RowBox[{
       OverscriptBox[
        SubscriptBox["z", "1"], "_"], "  ", 
       OverscriptBox[
        SubscriptBox["z", "2"], "_"], "          "}]}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "15"}], ")"}],
       FontColor->RGBColor[0, 0, 1]], "     "}], 
     RowBox[{" ", "\[IndentingNewLine]", " "}], 
     RowBox[{
      OverscriptBox[
       RowBox[{"(", 
        FractionBox[
         SubscriptBox["z", "1"], 
         SubscriptBox["z", "2"]], ")"}], "_"], " ", "=", 
      RowBox[{
       RowBox[{
        FractionBox[
         OverscriptBox[
          SubscriptBox["z", "1"], "_"], 
         RowBox[{" ", 
          OverscriptBox[
           RowBox[{
            SubscriptBox["z", "2"], " "}], "_"], " "}]], 
        StyleBox["if",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], " ", 
        SubscriptBox["z", "2"]}], "\[NotEqual]", "0"}]}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "16"}], ")"}],
       FontColor->RGBColor[0, 0, 1]], "     "}], 
     RowBox[{" ", "\[IndentingNewLine]", " "}], 
     RowBox[{
      RowBox[{"Re", "[", "z", "]"}], "=", 
      FractionBox[
       RowBox[{" ", 
        RowBox[{"z", " ", "+", "  ", 
         OverscriptBox[
          RowBox[{"z", " "}], "_"]}]}], "2"], "       "}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "17"}], ")"}],
       FontColor->RGBColor[0, 0, 1]], "     "}], 
     RowBox[{" ", "\[IndentingNewLine]", " "}], 
     RowBox[{
      RowBox[{"Im", "[", "z", "]"}], "=", 
      FractionBox[
       RowBox[{" ", 
        RowBox[{"z", " ", "-", "  ", 
         OverscriptBox[
          RowBox[{"z", " "}], "_"]}]}], 
       RowBox[{"2", "\[ImaginaryI]"}]], "        "}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "18"}], ")"}],
       FontColor->RGBColor[0, 0, 1]], "     "}], 
     RowBox[{" ", "\[IndentingNewLine]", " "}], 
     RowBox[{
      RowBox[{"Re", "[", 
       RowBox[{"\[ImaginaryI]", " ", "z"}], "]"}], "=", 
      RowBox[{"-", " ", 
       RowBox[{"Im", "[", "z", "]"}]}]}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "19"}], ")"}],
       FontColor->RGBColor[0, 0, 1]], "    "}], " ", 
     RowBox[{
      RowBox[{"Im", "[", 
       RowBox[{"\[ImaginaryI]", " ", "z"}], "]"}], "=", 
      RowBox[{"Re", "[", "z", "]"}], "    "}]}
   }]]],
 "  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.532705502296875*^9, 3.532705513484375*^9}, {
  3.532705599578125*^9, 3.532705605328125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "\tBecause of what it erroneously connotes, it is a shame that the term \
imaginary is used in Definition (1.6).  It was coined by the brilliant \
mathematician and philosopher ",
 StyleBox[ButtonBox["Ren\[EAcute] Descartes",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Descartes.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " (1596--1650) during an era when quantities such as ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"-", "1"}]]]],
 " were thought to be just that.  Gauss, who was successful in getting \
mathematicians to adopt the phrase complex number rather than imaginary \
number, also suggested that they use lateral part of z in place of imaginary \
part of z.  Unfortunately, that suggestion never caught on, and it appears we \
are stuck with what history has handed down to us."
}], "Text"]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{949, 644},
WindowMargins->{{5, Automatic}, {Automatic, 2}},
CellLabelAutoDelete->True,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 185, 3, 29, "Text"],
Cell[1736, 51, 391, 12, 101, "Text",
 Evaluatable->False],
Cell[2130, 65, 1095, 33, 119, "Text",
 Evaluatable->False],
Cell[3228, 100, 1121, 36, 65, "Text"],
Cell[4352, 138, 1639, 58, 180, "Text",
 Evaluatable->False],
Cell[5994, 198, 932, 35, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[6951, 237, 338, 10, 37, "Subsection",
 Evaluatable->False],
Cell[7292, 249, 1808, 52, 232, "Input"]
}, Closed]],
Cell[9115, 304, 935, 35, 62, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[10075, 343, 337, 10, 37, "Subsection",
 Evaluatable->False],
Cell[10415, 355, 1849, 53, 232, "Input"]
}, Closed]],
Cell[12279, 411, 2939, 117, 206, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[15243, 532, 312, 9, 37, "Subsection",
 Evaluatable->False],
Cell[15558, 543, 247, 12, 29, "Text"],
Cell[CellGroupData[{
Cell[15830, 559, 5209, 147, 315, "Input"],
Cell[21042, 708, 110, 2, 31, "Input"],
Cell[21155, 712, 249, 4, 31, "Input"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[21453, 722, 316, 9, 29, "Subsection",
 Evaluatable->False],
Cell[21772, 733, 251, 13, 29, "Text"],
Cell[22026, 748, 4880, 139, 315, "Input"]
}, Closed]],
Cell[26921, 890, 1194, 42, 65, "Text"],
Cell[28118, 934, 2546, 86, 225, "Text"],
Cell[30667, 1022, 1345, 51, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[32037, 1077, 342, 10, 37, "Subsection",
 Evaluatable->False],
Cell[32382, 1089, 1843, 53, 232, "Input"]
}, Closed]],
Cell[34240, 1145, 3767, 132, 456, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[38032, 1281, 276, 8, 37, "Subsection",
 Evaluatable->False],
Cell[38311, 1291, 132, 7, 29, "Text"],
Cell[38446, 1300, 4830, 141, 292, "Input"]
}, Closed]],
Cell[43291, 1444, 866, 31, 74, "Text"],
Cell[44160, 1477, 3738, 125, 311, "Text"],
Cell[47901, 1604, 1766, 64, 82, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[49692, 1672, 342, 10, 37, "Subsection",
 Evaluatable->False],
Cell[50037, 1684, 2825, 81, 343, "Input"]
}, Closed]],
Cell[52877, 1768, 3659, 130, 315, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[56561, 1902, 277, 8, 37, "Subsection",
 Evaluatable->False],
Cell[56841, 1912, 135, 7, 38, "Text"],
Cell[56979, 1921, 4875, 143, 347, "Input"]
}, Closed]],
Cell[61869, 2067, 1116, 23, 98, "Text"],
Cell[62988, 2092, 588, 12, 65, "Text"],
Cell[63579, 2106, 445, 18, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[64049, 2128, 315, 9, 37, "Subsection",
 Evaluatable->False],
Cell[64367, 2139, 2280, 64, 252, "Input"]
}, Closed]],
Cell[66662, 2206, 551, 22, 62, "Text",
 Evaluatable->False],
Cell[67216, 2230, 517, 19, 101, "Text",
 Evaluatable->False],
Cell[67736, 2251, 1051, 42, 101, "Text",
 Evaluatable->False],
Cell[68790, 2295, 395, 16, 65, "Text",
 Evaluatable->False],
Cell[69188, 2313, 596, 23, 65, "Text",
 Evaluatable->False],
Cell[69787, 2338, 678, 22, 101, "Text",
 Evaluatable->False],
Cell[70468, 2362, 668, 25, 83, "Text",
 Evaluatable->False],
Cell[71139, 2389, 2069, 68, 259, "Text"],
Cell[73211, 2459, 667, 25, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[73903, 2488, 342, 10, 37, "Subsection",
 Evaluatable->False],
Cell[74248, 2500, 4339, 123, 352, "Input"]
}, Closed]],
Cell[78602, 2626, 248, 5, 44, "Text"],
Cell[78853, 2633, 3361, 113, 218, "Text"],
Cell[82217, 2748, 2792, 88, 178, "Text"],
Cell[85012, 2838, 1823, 60, 183, "Text"],
Cell[86838, 2900, 1305, 46, 143, "Text"],
Cell[88146, 2948, 2328, 75, 142, "Text"],
Cell[90477, 3025, 2448, 77, 133, "Text"],
Cell[92928, 3104, 170, 3, 29, "Text"],
Cell[93101, 3109, 490, 20, 29, "Text",
 Evaluatable->False],
Cell[93594, 3131, 500, 20, 29, "Text",
 Evaluatable->False],
Cell[94097, 3153, 646, 26, 29, "Text",
 Evaluatable->False],
Cell[94746, 3181, 2545, 105, 137, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[97316, 3290, 311, 9, 37, "Subsection",
 Evaluatable->False],
Cell[97630, 3301, 193, 9, 29, "Text"],
Cell[97826, 3312, 3506, 99, 235, "Input"],
Cell[101335, 3413, 193, 9, 29, "Text"],
Cell[101531, 3424, 3460, 96, 235, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[105028, 3525, 309, 9, 29, "Subsection",
 Evaluatable->False],
Cell[105340, 3536, 193, 9, 29, "Text"],
Cell[105536, 3547, 3474, 98, 235, "Input"],
Cell[109013, 3647, 200, 10, 47, "Text"],
Cell[109216, 3659, 3395, 95, 235, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[112648, 3759, 307, 9, 29, "Subsection",
 Evaluatable->False],
Cell[112958, 3770, 208, 10, 29, "Text"],
Cell[113169, 3782, 3606, 103, 235, "Input"],
Cell[116778, 3887, 195, 10, 47, "Text"],
Cell[116976, 3899, 3573, 101, 235, "Input"]
}, Closed]],
Cell[120564, 4003, 196, 4, 26, "Text"],
Cell[120763, 4009, 4619, 159, 344, "Text",
 Evaluatable->False],
Cell[125385, 4170, 899, 19, 86, "Text"]
}
]
*)

(* End of internal cache information *)
