(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    313707,      13523]
NotebookOptionsPosition[    311052,      13441]
NotebookOutlinePosition[    311445,      13458]
CellTagsIndexPosition[    311402,      13455]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[StyleBox["2.4  Branches of Functions",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.532709155578125*^9, 3.53270915609375*^9}}],

Cell["\<\
\tIn Section 2.3 we defined the principal square root function and \
investigated some of its properties.  We left unanswered some questions \
concerning the choices of square roots.  We now look at these questions \
because they are similar to situations involving other elementary functions.\
\>", "Text",
 CellChangeTimes->{3.398978223*^9}],

Cell["\<\
    In our definition of a function in Section 2.1, we specified that each \
value of the independent variable in the domain is mapped onto one and only \
one value in the range.  As a result, we often talk about a single-valued \
function, which emphasizes the \"only one\" part of the definition and allows \
us to distinguish such functions from multiple-valued functions, which we now \
introduce.\
\>", "Text"],

Cell[TextData[{
 "\tLet ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " denote a function whose domain is the set ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " and whose range is the set ",
 StyleBox["R",
  FontFamily->"Courier New"],
 ".  If  w  is a value in the range, then there is an associated inverse \
function ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"g", 
    RowBox[{"(", "w", ")"}]}]}]]],
 " that assigns to each value ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " the value (or values) of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " for which the equation ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", "w"}]]],
 " holds.  But unless ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " takes on the value  w  at most once in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", then the inverse function ",
 StyleBox["g",
  FontFamily->"Courier New"],
 " is necessarily many valued, and se say that ",
 StyleBox["g",
  FontFamily->"Courier New"],
 " is a ",
 StyleBox[ButtonBox["multivalued function",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/MultivaluedFunction.html"], None}],
  FontVariations->{"Underline"->True}],
 ".  For example, the inverse of the function ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox["z", "2"]}]}]]],
 " is the square root function ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      RowBox[{"-", "1"}]], 
     RowBox[{"(", "w", ")"}]}], "=", 
    SuperscriptBox["w", 
     FractionBox["1", "2"]]}]}]]],
 ".  For each value z other than ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 ", then, the two points ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["-z",
  FontFamily->"Courier New"],
 " are mapped onto the same point ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "; hence ",
 StyleBox["g",
  FontFamily->"Courier New"],
 " is in general a two-valued function."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tThe study of limits, continuity, and derivatives loses all meaning if an \
arbitrary or ambiguous assignment of function values is made.  For this \
reason we did not allow multivalued functions to be considered when we \
defined these concepts.  When working with inverse functions, you have to \
specify carefully one of the many possible inverse values when constructing \
an inverse function, as when you determine implicit functions in calculus.  \
If the values of a function f are determined by an equation that they satisfy \
rather than by an explicit formula, then we say that the function is defined \
implicitly or that",
 " ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " ",
 "is an implicit function.  In the theory of complex variables we present a \
similar concept."
}], "Text",
 CellChangeTimes->{3.39897824121875*^9}],

Cell[TextData[{
 "\tLet ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " be a multiple-valued function.  A branch of ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " is any single-valued function ",
 Cell[BoxData[
  SubscriptBox["f", "0"]]],
 " that is continuous in some domain (except, perhaps, on the boundary).  At \
each point ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " in the domain, assigns one of the values of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 ".  Associated with the branch of a function is the ",
 StyleBox[ButtonBox["branch cut",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/BranchCut.html"], None}],
  FontVariations->{"Underline"->True}],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tWe now investigate the branches of the ",
 StyleBox[ButtonBox["square root",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/SquareRoot.html"], None}],
  FontVariations->{"Underline"->True}],
 " function."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Example 2.20.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  We consider some branches of the two-valued square root function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", "  ", 
   SuperscriptBox["z", 
    FractionBox["1", "2"]]}]]],
 ",  (where ",
 Cell[BoxData[
  RowBox[{"z", "\[NotEqual]", "0"}]]],
 ").  Define the principal square root function as  \n\n",
 StyleBox["(2-28)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["f", "1"], 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{"|", "z", 
     SuperscriptBox["|", 
      FractionBox["1", "2"]]}]}]}]]],
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      FractionBox[
       RowBox[{"Arg", 
        RowBox[{"(", "z", ")"}]}], "2"]}]], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["r", 
      FractionBox["1", "2"]], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{" ", 
       RowBox[{"\[ImaginaryI]", 
        FractionBox["\[Theta]", "2"]}]}]]}]}]}]]],
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"=", " ", 
    RowBox[{
     SuperscriptBox["r", 
      FractionBox["1", "2"]], 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"cos", 
        RowBox[{"(", 
         FractionBox["\[Theta]", "2"], ")"}]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "sin", 
        RowBox[{"(", 
         FractionBox["\[Theta]", "2"], ")"}]}]}], " ", ")"}]}]}]}]]],
 ",  \n\nwhere  ",
 Cell[BoxData[
  RowBox[{"r", "=", 
   RowBox[{"|", "z", 
    SuperscriptBox["|", 
     FractionBox["1", "2"]]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "=", 
   RowBox[{"Arg", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " so that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Pi]"}], "<", "\[Theta]", "\[LessEqual]", "\[Pi]"}]]],
 ".  The function ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "1"], 
   RowBox[{"(", "z", ")"}]}]]],
 " is a branch of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 ".  Using the same notation, we can find other branches of the square root \
function.  For example, if we let\n\n",
 StyleBox["(2-29)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["f", "2"], 
     RowBox[{"(", "z", ")"}]}], "=", " ", 
    RowBox[{"|", "z", 
     SuperscriptBox["|", 
      FractionBox["1", "2"]]}]}]}]]],
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      FractionBox[
       RowBox[{
        RowBox[{"Arg", 
         RowBox[{"(", "z", ")"}]}], "+", 
        RowBox[{"2", "\[Pi]"}]}], "2"]}]], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["r", 
      FractionBox["1", "2"]], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{" ", 
       RowBox[{"\[ImaginaryI]", 
        FractionBox[
         RowBox[{"\[Theta]", "+", 
          RowBox[{"2", "\[Pi]"}]}], "2"]}]}]]}]}]}]]],
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"=", " ", 
    RowBox[{
     SuperscriptBox["r", 
      RowBox[{"1", "/", "2"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", 
        FractionBox[
         RowBox[{"\[Theta]", "+", 
          RowBox[{"2", "\[Pi]"}]}], "2"]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "sin", 
        FractionBox[
         RowBox[{"\[Theta]", "+", 
          RowBox[{"2", "\[Pi]"}]}], "2"]}]}], ")"}]}]}]}]]],
 ",    \n\n\tthen\n \t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["f", "2"], 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["r", 
      FractionBox["1", "2"]], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{" ", 
       RowBox[{"\[ImaginaryI]", 
        FractionBox[
         RowBox[{"\[Theta]", "+", 
          RowBox[{"2", "\[Pi]"}]}], "2"]}]}]]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", " ", 
    RowBox[{
     SuperscriptBox["r", 
      RowBox[{"1", "/", "2"}]], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{" ", 
       RowBox[{"\[ImaginaryI]", 
        FractionBox["\[Theta]", "2"]}]}]], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{" ", 
       RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]}]]}]}], "\[IndentingNewLine]", 
   " "}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"-", " ", 
      SuperscriptBox["r", 
       RowBox[{"1", "/", "2"}]]}], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{" ", 
       RowBox[{"\[ImaginaryI]", 
        FractionBox["\[Theta]", "2"]}]}]]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"-", " ", 
      SubscriptBox["f", "1"]}], 
     RowBox[{"(", "z", ")"}]}]}]}]}]],
 "\n\nso ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "1"], 
   RowBox[{"(", "z", ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SubscriptBox["f", "2"], 
   RowBox[{"(", "z", ")"}]}]]],
 " can be thought of as \"plus\" and \"minus\" square root functions.  The \
negative real axis is called a branch cut for the functions ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "1"], 
   RowBox[{"(", "z", ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SubscriptBox["f", "2"], 
   RowBox[{"(", "z", ")"}]}]]],
 ".  Each point on the branch cut is a point of discontinuity for both \
functions ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "1"], 
   RowBox[{"(", "z", ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SubscriptBox["f", "2"], 
   RowBox[{"(", "z", ")"}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"2.20", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506703578515625*^9, 3.506703578515625*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["f", "1"], 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{
     SuperscriptBox["z", 
      RowBox[{"1", "/", "2"}]], "=", " "}]}]}]]],
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["r", 
    RowBox[{"1", "/", "2"}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"cos", 
      RowBox[{"(", 
       FractionBox["\[Theta]", "2"], ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "sin", 
      RowBox[{"(", 
       FractionBox["\[Theta]", "2"], ")"}]}]}], ")"}]}]]],
 " where ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Pi]"}], "<", "\[Theta]", "<", "\[Pi]"}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["z", 
      RowBox[{"1", "/", "2"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"zplane", " ", "=", 
    RowBox[{"PolarMap", "[", 
     RowBox[{"Iden", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "4", ",", "0.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3.14"}], ",", " ", "3.14", ",", " ", 
        FractionBox["3.14", "12"]}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "4"}], ",", "4.4"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "4"}], ",", "4.4"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "4"}], ",", "4", ",", "2"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "4"}], ",", "4", ",", "2"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The rays r > 0, \[Theta] = \[Alpha], and circles r = c.\>\"", "]"}],
     ";"}], " ", "\n", 
   RowBox[{"wplane", " ", "=", " ", 
    RowBox[{"PolarMap", "[", 
     RowBox[{"f", " ", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "4", ",", "0.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3.14"}], ",", " ", "3.14", ",", " ", 
        FractionBox["3.14", "12"]}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.2"}], ",", "2.2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "2"}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "2", ",", "1"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image rays r>0, \[Theta]=\!\(\*FractionBox[\(\[Alpha]\), \(2\)]\
\), and circles r=\!\(\*SqrtBox[\(c\)]\),\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<under the mapping  w = \!\(\*SubscriptBox[\(f\), \(1\)]\)(z) = \
\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<.\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<w = \!\(\*SubscriptBox[\(f\), \(1\)]\)(z) = \
\!\(\*SuperscriptBox[\(r\), \(1/2\)]\)(cos(\!\(\*FractionBox[\(\[Theta]\), \
\(2\)]\))+\[ImaginaryI] sin(\!\(\*FractionBox[\(\[Theta]\), \(2\)]\))) where \
-\[Pi]<\[Theta]<\[Pi]\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399191858265625*^9, 3.399191884015625*^9}, 
   3.399192085703125*^9, {3.399794862203125*^9, 3.39979486253125*^9}, 
   3.40025101634375*^9},
 AspectRatioFixed->True],

Cell["\<\

We can compare the above polar mapping with the cartesian coordinate mapping.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4.4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4.4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "2"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Vertical lines x=a, and horizontal lines y=b.\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.2"}], ",", "2.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "2"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image hyperbolas \!\(\*SuperscriptBox[\(u\), \
\(2\)]\)-\!\(\*SuperscriptBox[\(v\), \(2\)]\) = a and 2uv = b,\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<under the mapping  w = \!\(\*SubscriptBox[\(f\), \(1\)]\)(z) = \
\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<.\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<w = \!\(\*SubscriptBox[\(f\), \(1\)]\)(z) = \
\!\(\*SuperscriptBox[\(r\), \(1/2\)]\)(cos(\!\(\*FractionBox[\(\[Theta]\), \
\(2\)]\))+\[ImaginaryI] sin(\!\(\*FractionBox[\(\[Theta]\), \(2\)]\))) where \
-\[Pi]<\[Theta]<\[Pi]\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399191981578125*^9, 3.3991920054375*^9}, {
  3.399794869921875*^9, 3.399794870640625*^9}, {3.40025102965625*^9, 
  3.400251031234375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "\nUse ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["f", "2"], 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{
     RowBox[{"-", " ", 
      SuperscriptBox["z", 
       RowBox[{"1", "/", "2"}]]}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["r", 
         RowBox[{"1", "/", "2"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"cos", 
           RowBox[{"(", 
            FractionBox[
             RowBox[{"\[Theta]", "+", 
              RowBox[{"2", "\[Pi]"}]}], "2"], ")"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "sin", 
           RowBox[{"(", 
            FractionBox[
             RowBox[{"\[Theta]", "+", 
              RowBox[{"2", "\[Pi]"}]}], "2"], ")"}]}]}], ")"}], "  ", 
        StyleBox["where",
         FontFamily->"Times New Roman"]}], "  ", "-", "\[Pi]"}], "<", 
      "\[Theta]", "<", "\[Pi]", " "}]}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{"-", " ", 
      SuperscriptBox["z", 
       RowBox[{"1", "/", "2"}]]}]}], ";"}], " ", "\n", 
   RowBox[{"zplane", " ", "=", " ", 
    RowBox[{"PolarMap", "[", 
     RowBox[{"Iden", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "4", ",", "0.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3.14"}], ",", " ", "3.14", ",", " ", 
        FractionBox["3.14", "12"]}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "4"}], ",", "4.4"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "4"}], ",", "4.4"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "4"}], ",", "4", ",", "2"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "4"}], ",", "4", ",", "2"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The rays r>0, \[Theta]=\[Alpha], and circles r=c.\>\"",
      "]"}], ";"}], " ", "\n", 
   RowBox[{"wplane", " ", "=", " ", 
    RowBox[{"PolarMap", "[", 
     RowBox[{"f", " ", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "4", ",", "0.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3.14"}], ",", " ", "3.14", ",", " ", 
        FractionBox["3.14", "12"]}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2.2"}], ",", "0.2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "2"}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "2"}], ",", "0", ",", "1"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image rays r>0, \[Theta] = \!\(\*FractionBox[\(\[Alpha] + 4  \
\[Pi]\), \(2\)]\), and circles r=\!\(\*SqrtBox[\(c\)]\),\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<under the mapping  w = \!\(\*SubscriptBox[\(f\), \(2\)]\)(z) = \
\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<.\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<w = \!\(\*SubscriptBox[\(f\), \(2\)]\)(z) = \
\!\(\*SuperscriptBox[\(r\), \(1/2\)]\)(cos(\!\(\*FractionBox[\(\[Theta] + 4  \
\[Pi]\), \(2\)]\))+\[ImaginaryI] sin(\!\(\*FractionBox[\(\[Theta] + 4  \
\[Pi]\), \(2\)]\))) where -\[Pi] < \[Theta] < \[Pi]\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39919201209375*^9, 3.39919203609375*^9}, {
  3.400251037359375*^9, 3.400251052015625*^9}},
 AspectRatioFixed->True],

Cell["\<\

We can compare the above polar mapping with the cartesian coordinate mapping.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4.4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4.4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "2"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Vertical lines x=a, and horizontal lines y=b.\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "0.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "2"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image hyperbolas \!\(\*SuperscriptBox[\(u\), \
\(2\)]\)-\!\(\*SuperscriptBox[\(v\), \(2\)]\) = a and 2uv = b,\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<under the mapping  w = \!\(\*SubscriptBox[\(f\), \(2\)]\)(z) = \
\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<.\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<w = \!\(\*SubscriptBox[\(f\), \(2\)]\)(z) = \
\!\(\*SuperscriptBox[\(r\), \(1/2\)]\)(cos(\!\(\*FractionBox[\(\[Theta] + 4  \
\[Pi]\), \(2\)]\))+\[ImaginaryI] sin(\!\(\*FractionBox[\(\[Theta] + 4  \
\[Pi]\), \(2\)]\))) where -\[Pi]<\[Theta]<\[Pi]\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399192042296875*^9, 3.399192064296875*^9}, {
  3.400251059828125*^9, 3.400251061828125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "\nWe have illustrated the two branches of the square root  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["f", "1"], 
     RowBox[{"(", "z", ")"}]}], "=", "  ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["z", 
       RowBox[{"1", "/", "2"}]], "   ", 
      StyleBox["and",
       FontFamily->"Times New Roman"], "  ", "w"}], "=", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", "2"], 
       RowBox[{"(", "z", ")"}]}], "=", 
      RowBox[{"-", " ", 
       SuperscriptBox["z", 
        RowBox[{"1", "/", "2"}]]}]}]}]}]}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 2.21.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "1"], 
    RowBox[{"(", "z", ")"}]}], "=", " ", 
   RowBox[{
    SuperscriptBox["r", 
     FractionBox["1", "2"]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cos", 
       FractionBox["\[Theta]", "2"]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "sin", 
       FractionBox["\[Theta]", "2"]}]}], ")"}]}]}]]],
 "  is discontinuous along the negative real axis.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  Let  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], " ", "=", " ", 
   RowBox[{
    SubscriptBox["r", "0"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{" ", 
      RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]}]]}]}]]],
 "  denote a negative real number.  We compute the limit as ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " approaches ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " through the upper half-plane ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"z", ":", 
    RowBox[{
     RowBox[{"Im", 
      RowBox[{"(", "z", ")"}]}], ">", "0"}]}], "}"}]]],
 " and the limit as ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " approaches ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " through the lower half-plane ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"z", ":", 
    RowBox[{
     RowBox[{"Im", 
      RowBox[{"(", "z", ")"}]}], "<", "0"}]}], "}"}]]],
 " .  In polar coordinates these limits are given by    \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["lim", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"r", ",", "\[Theta]"}], ")"}], "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["r", "0"], ",", "\[Pi]"}], ")"}]}]], " ", 
    RowBox[{
     SubscriptBox["f", "1"], 
     RowBox[{"(", 
      RowBox[{"r", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{" ", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]}]]}], ")"}]}]}], " ", "=",
    " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["lim", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"r", ",", "\[Theta]"}], ")"}], "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["r", "0"], ",", "\[Pi]"}], ")"}]}]], " ", 
     RowBox[{
      SuperscriptBox["r", 
       FractionBox["1", "2"]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"cos", 
         FractionBox["\[Theta]", "2"]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "sin", 
         FractionBox["\[Theta]", "2"]}]}], ")"}]}]}], " ", "=", " ", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["r", "0", 
      RowBox[{"1", "/", "2"}]]}]}]}]]],
 ",  and  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["lim", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"r", ",", "\[Theta]"}], ")"}], "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["r", "0"], ",", 
        RowBox[{"-", "\[Pi]"}]}], ")"}]}]], 
    RowBox[{
     SubscriptBox["f", "1"], 
     RowBox[{"(", 
      RowBox[{"r", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{" ", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]}]]}], ")"}]}]}], " ", "=",
    " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["lim", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"r", ",", "\[Theta]"}], ")"}], "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["r", "0"], ",", 
         RowBox[{"-", "\[Pi]"}]}], ")"}]}]], 
     RowBox[{
      SuperscriptBox["r", 
       FractionBox["1", "2"]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"cos", 
         FractionBox["\[Theta]", "2"]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "sin", 
         FractionBox["\[Theta]", "2"]}]}], ")"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"-", " ", "\[ImaginaryI]"}], " ", 
     SubsuperscriptBox["r", "0", 
      RowBox[{"1", "/", "2"}]]}]}]}]]],
 ".  \n\nAs the two limits are distinct, the function ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "1"], 
   RowBox[{"(", "z", ")"}]}]]],
 " is discontinuous at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["Remark 2.4",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Likewise,  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "1"], 
   RowBox[{"(", "z", ")"}]}]]],
 " is discontinuous at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  The mappings  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    SubscriptBox["f", "1"], 
    RowBox[{"(", "z", ")"}]}]}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    SubscriptBox["f", "2"], 
    RowBox[{"(", "z", ")"}]}]}]]],
 ",  and the branch cut are illustrated in Figure 2.18."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"2.21", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506703582234375*^9, 3.506703582234375*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"r", ",", "\[Theta]"}], "]"}], "=", 
    RowBox[{
     SuperscriptBox["z", 
      RowBox[{"1", "/", "2"}]], "=", " "}]}]}]]],
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["r", 
    RowBox[{"1", "/", "2"}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"cos", 
      RowBox[{"(", 
       FractionBox["\[Theta]", "2"], ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "sin", 
      RowBox[{"(", 
       FractionBox["\[Theta]", "2"], ")"}]}]}], ")"}]}]]],
 "  and find the limits as z approaches a point on the negative x-axis."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "r", ",", "\[Theta]"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"r_", ",", "\[Theta]_"}], "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["r", 
       RowBox[{"1", "/", "2"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Cos", "[", 
         FractionBox["\[Theta]", "2"], "]"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Sin", "[", 
          FractionBox["\[Theta]", "2"], "]"}]}]}], ")"}]}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"lim1", " ", "=", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"r", ",", "\[Theta]"}], "]"}], ",", 
        RowBox[{"\[Theta]", "\[Rule]", "\[Pi]"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"lim2", " ", "=", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"r", ",", "\[Theta]"}], "]"}], ",", 
        RowBox[{"\[Theta]", "\[Rule]", 
         RowBox[{"-", "\[Pi]"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Let z approach the point z = r \!\(\*SuperscriptBox[\(\
\[ExponentialE]\), \(\[ImaginaryI]\[Pi]\)]\) on negative x-axis.\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<  z = r \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\
\[Pi]\)]\)\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"r", ",", "\[Theta]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Approach from the upper half-plane\>\"", "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[Theta] \[Rule] \[Pi]\)]\)   r \
\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\[Pi]\)]\)  = \>\"", 
      ",", 
      RowBox[{"r", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[Theta] \[Rule] \[Pi]\)]\) f[r \
\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\[Pi]\)]\)] = \>\"", 
      ",", "lim1"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Approach from the lower half-plane\>\"", "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[Theta] \[Rule] \(-\[Pi]\)\)]\)   \
r \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\[Pi]\)]\)  = \
\>\"", ",", 
      RowBox[{"r", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Pi]"}]]}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[Theta] \[Rule] \(-\[Pi]\)\)]\) \
f[r \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\[Pi]\)]\)] = \>\
\"", ",", "lim2"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.398978284875*^9}],

Cell[TextData[{
 "Since the two limits are different,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "1"], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", 
     RowBox[{"1", "/", "2"}]], "=", " "}]}]]],
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["r", 
    RowBox[{"1", "/", "2"}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"cos", 
      RowBox[{"(", 
       FractionBox["\[Theta]", "2"], ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "sin", 
      RowBox[{"(", 
       FractionBox["\[Theta]", "2"], ")"}]}]}], ")"}]}]]],
 "  is discontinuous at all points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "=", 
    RowBox[{
     RowBox[{"-", "r"}], "+", 
     RowBox[{"0", "\[ImaginaryI]"}]}]}], ",", "  ", 
   RowBox[{"r", ">", "0"}]}]]],
 "  along the negative real axis."
}], "Text"]
}, Closed]],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.941 1 .941 r
0 .5 m
0 0 L
1 0 L
1 1 L
0 1 L
0 .5 L
F
1 1 1 r
0 .5 m
0 .49 L
.5 .49 L
.5 .51 L
0 .51 L
0 .5 L
F
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.25 .5 m
.25 .49957 L
.24999 .49917 L
.24998 .49872 L
.24997 .49829 L
.24995 .4979 L
.24992 .49753 L
.24985 .4967 L
.24976 .49586 L
.24962 .49494 L
.24925 .49308 L
.24875 .49125 L
.24806 .48928 L
.24644 .4857 L
.2411 .4773 L
.23499 .46939 L
.22881 .4611 L
.2263 .45704 L
.22453 .45336 L
.22386 .45152 L
.22358 .45055 L
.22333 .44954 L
.22317 .44865 L
.2231 .44818 L
.22304 .44768 L
.223 .44722 L
.22297 .4468 L
.22296 .44638 L
.22296 .44599 L
.22297 .44554 L
.22299 .44506 L
.22304 .44455 L
.2231 .44408 L
.22325 .44323 L
.22347 .44233 L
.22379 .44134 L
.22421 .44031 L
.22519 .43849 L
.22649 .43667 L
.22795 .43506 L
.23217 .43159 L
.23723 .42858 L
.24298 .42593 L
.25022 .42327 L
.25884 .42073 L
.27606 .41682 L
.31277 .41083 L
.32209 .40932 L
.32996 .40781 L
.33603 .40633 L
Mistroke
.33902 .4054 L
.3414 .40448 L
.34355 .40344 L
.34522 .40237 L
.34661 .40114 L
.3472 .40039 L
.34764 .39967 L
.34778 .39936 L
.34792 .39902 L
.34802 .39872 L
.3481 .39839 L
.34818 .398 L
.34822 .39761 L
.34824 .39723 L
.34823 .39687 L
.3482 .39648 L
.34815 .39612 L
.34808 .3957 L
.34796 .39525 L
.34764 .3943 L
.34723 .39338 L
.34608 .39144 L
.34437 .38919 L
.33998 .38467 L
.32354 .37206 L
.26391 .33707 L
.18407 .2952 L
.14853 .27591 L
.13101 .26559 L
.11732 .25663 L
.10629 .248 L
.10282 .2446 L
.10006 .24117 L
.09902 .23943 L
.09867 .2387 L
.09836 .23791 L
.09815 .23719 L
.09801 .23653 L
.09794 .23585 L
.09794 .23515 L
.09803 .23448 L
.09812 .2341 L
.09823 .23376 L
.09852 .2331 L
.09894 .23243 L
.09944 .23183 L
.1 .23129 L
.10129 .23036 L
.10282 .22956 L
.10451 .22889 L
Mistroke
.10666 .22825 L
.10931 .22768 L
.11076 .22744 L
.11244 .22721 L
.11401 .22703 L
.11577 .22688 L
.1176 .22675 L
.11934 .22667 L
.12115 .22661 L
.12292 .22658 L
.12463 .22657 L
.12657 .22659 L
.12867 .22663 L
.13068 .22669 L
.13262 .22677 L
.13444 .22686 L
.13867 .22712 L
.1489 .22803 L
.15948 .22928 L
.18391 .2331 L
.21286 .23888 L
.26966 .25334 L
.38438 .29425 L
.43223 .3169 L
.47132 .33851 L
.49599 .35309 L
.50452 .35752 L
.50642 .3583 L
.50727 .3586 L
.50799 .35882 L
.5086 .35898 L
.50922 .35911 L
.50953 .35915 L
.5098 .35918 L
.51007 .3592 L
.51036 .35921 L
.5106 .3592 L
.51085 .35918 L
.51125 .35911 L
.51148 .35904 L
.51168 .35896 L
.51185 .35887 L
.51202 .35876 L
.51229 .35852 L
.51241 .35838 L
.51253 .35821 L
.51271 .35787 L
.51283 .3575 L
.51291 .35707 L
.51295 .35661 L
Mistroke
.51294 .35616 L
.5129 .35563 L
.51282 .355 L
.51275 .35466 L
.51267 .35428 L
.51228 .35283 L
.51099 .34946 L
.50883 .345 L
.5027 .33473 L
.4764 .30068 L
.43245 .2556 L
.29253 .14522 L
.09456 .01981 L
Mfstroke
.09456 .01981 m
.06318 0 L
s
1 0 0 r
.25 .5 m
.25 .50043 L
.24999 .50083 L
.24998 .50128 L
.24997 .50171 L
.24995 .5021 L
.24992 .50247 L
.24985 .5033 L
.24976 .50414 L
.24962 .50506 L
.24925 .50692 L
.24875 .50875 L
.24806 .51072 L
.24644 .5143 L
.2411 .5227 L
.23499 .53061 L
.22881 .5389 L
.2263 .54296 L
.22453 .54664 L
.22386 .54848 L
.22358 .54945 L
.22333 .55046 L
.22317 .55135 L
.2231 .55182 L
.22304 .55232 L
.223 .55278 L
.22297 .5532 L
.22296 .55362 L
.22296 .55401 L
.22297 .55446 L
.22299 .55494 L
.22304 .55545 L
.2231 .55592 L
.22325 .55677 L
.22347 .55767 L
.22379 .55866 L
.22421 .55969 L
.22519 .56151 L
.22649 .56333 L
.22795 .56494 L
.23217 .56841 L
.23723 .57142 L
.24298 .57407 L
.25022 .57673 L
.25884 .57927 L
.27606 .58318 L
.31277 .58917 L
.32209 .59068 L
.32996 .59219 L
.33603 .59367 L
Mistroke
.33902 .5946 L
.3414 .59552 L
.34355 .59656 L
.34522 .59763 L
.34661 .59886 L
.3472 .59961 L
.34764 .60033 L
.34778 .60064 L
.34792 .60098 L
.34802 .60128 L
.3481 .60161 L
.34818 .602 L
.34822 .60239 L
.34824 .60277 L
.34823 .60313 L
.3482 .60352 L
.34815 .60388 L
.34808 .6043 L
.34796 .60475 L
.34764 .6057 L
.34723 .60662 L
.34608 .60856 L
.34437 .61081 L
.33998 .61533 L
.32354 .62794 L
.26391 .66293 L
.18407 .7048 L
.14853 .72409 L
.13101 .73441 L
.11732 .74337 L
.10629 .752 L
.10282 .7554 L
.10006 .75883 L
.09902 .76057 L
.09867 .7613 L
.09836 .76209 L
.09815 .76281 L
.09801 .76347 L
.09794 .76415 L
.09794 .76485 L
.09803 .76552 L
.09812 .7659 L
.09823 .76624 L
.09852 .7669 L
.09894 .76757 L
.09944 .76817 L
.1 .76871 L
.10129 .76964 L
.10282 .77044 L
.10451 .77111 L
Mistroke
.10666 .77175 L
.10931 .77232 L
.11076 .77256 L
.11244 .77279 L
.11401 .77297 L
.11577 .77312 L
.1176 .77325 L
.11934 .77333 L
.12115 .77339 L
.12292 .77342 L
.12463 .77343 L
.12657 .77341 L
.12867 .77337 L
.13068 .77331 L
.13262 .77323 L
.13444 .77314 L
.13867 .77288 L
.1489 .77197 L
.15948 .77072 L
.18391 .7669 L
.21286 .76112 L
.26966 .74666 L
.38438 .70575 L
.43223 .6831 L
.47132 .66149 L
.49599 .64691 L
.50452 .64248 L
.50642 .6417 L
.50727 .6414 L
.50799 .64118 L
.5086 .64102 L
.50922 .64089 L
.50953 .64085 L
.5098 .64082 L
.51007 .6408 L
.51036 .64079 L
.5106 .6408 L
.51085 .64082 L
.51125 .64089 L
.51148 .64096 L
.51168 .64104 L
.51185 .64113 L
.51202 .64124 L
.51229 .64148 L
.51241 .64162 L
.51253 .64179 L
.51271 .64213 L
.51283 .6425 L
.51291 .64293 L
.51295 .64339 L
Mistroke
.51294 .64384 L
.5129 .64437 L
.51282 .645 L
.51275 .64534 L
.51267 .64572 L
.51228 .64717 L
.51099 .65054 L
.50883 .655 L
.5027 .66527 L
.4764 .69932 L
.43245 .7444 L
.29253 .85478 L
.09456 .98019 L
Mfstroke
.09456 .98019 m
.06318 1 L
s
0 g
.5 .5 m
1 .5 L
s
.5 0 m
.5 1 L
s
0 .51 m
.5 .51 L
s
[ .02 .02 ] 0 setdash
0 .49 m
.5 .49 L
s
0 1 0 r
.03 w
.25 .5 Mdot
0 g
gsave
.98 .525 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5375 .98 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.28 .525 -70.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{199, 199},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzVmutOG0cYhhdjm5BwBifGMY4BcwpnQkIJgZCAIIi0UtVUStI/ddNKyY+q
VZp77O1wB65n7H1ndnjrd7tVqtSSzbLzPc/Ozo53vhnv181P73/5tfnpw7tm
/fxj8/f3H979UT/77WN7V39fFEV/mnc9Mtut9mb3YyhqtVpRv/3fbJn3K+yL
sK9pP6Ph6Kp1lTP7X5mtbpDZMu8fzWdfJ3IU5S2UfyuYMdhV5ASxfyOYSdhV
ZInYLwVzG3YVWUbkhYiskHqcCeYu7CpyhthPBFODXUXWif1YMLOwq8h5Yj8U
TAN2FbmIyAMRuUzq8ZVgVmBXkavE/lAwa7CryA1i3xHMJuwqcpvYNwWzA7uK
3EXkuoh8ROpxXzB7sKvIfWJfEsxjwiwK5gA1UpGHxD4vmCPCzAnmKWFmBXOM
s1CRz4m9JpgTwswI5hQ1UpFnxF4RzDlhpgXzgjBlwVzgLFTkJbGXBPOSMFOC
saNh0SDsPjApaFtukSI87r6Wig6OOGQ+C2bXCikdy2Ach3GBlI4K4xRh7HXI
m11zOFflYZlKGR42Bg+luXL22FVchRrx3BKeMmGcsUpKbwrjNGFqMLJcaVAY
KzjXWXhYvW8ITxUed+XuEM+A8NSSHguzK1wUnjo88/CwPlwQHnc2DXjGiScv
PA3COCObKfQL4wJqtoStEeLJCc8S8Qx328b3mLd5/eSxK4S9lZJdJezNblv6
bICtE2wwOO2Q2Uwyf9slW2ikpkdvg3ZJsWIeEEZ12YeEUd1qjzD+BY/PUyVs
rjN5BzP/XcvagmaMuk2QjHyCyAUReZT8nqrMKah2XTDPCHNPMP9p3sVGhy+A
se1mEdVatk8MRPH9WnXvIP/oMW+yN4ENEbmBeqq52DpphQeCST+PXCP23f8x
k6W1ssylM8+/A2b7MzBbuPoq0nTVznBd+MdbdqDEnTEeTrLa7FZy5Gv/KRit
3fq5Yw/29my49stGboXqre53r9XZStH6La+8iOqy2fzruO072Yvb6mFkGSpz
v7Gf+cS+uP2CbunrbV3ZcMyO8Ra1zgsty8/TG9eJkc0hMrbDGtGzSU+WS/hv
3Oz2dq0J7BGXM9Cpbqi5KB7SUtxGfXuq26hFUi0v5qPEbbTn0Bsn7Go4L0aJ
5eUe6Zg9ukoRTkkrpE1aPjdzQhiVuD0njEoQnxFGtdsxYVTCe4S+qa7fE0T6
KXo8BPmRB6QeitmHfRFbXmXC8D0SngsOQTt1wKjp0i45lQZoNUHbSR7x2gDh
9sUGf0q4Rep7QzAbhBkMjm1e/ri8Rph4Xu3XN8DuEyyeyvsYO+QyYYdTsouE
HQlO0bzVMoa7jLZvWniUeNSyyhw8DXjGiUd1tXrym2jhSeJRC1A1eObgKRGP
6rwzhHF1vENK1VLdXdB11KxMPGrpcBqee/BUiEctZbJjV2GsklK13MpapQJj
jZSqJeESztWedR6tF3jUEvUUYUowuj6sFs9Zj5yAZ4GUZjHas7FZxTIpHUtj
tIjtkfaWwjKrceGxy/oDUeJWrH7EeUmOo5hLwqgfmC5QI/Xz1QtiV8w5YdSP
cGeEUT/2neIsVA71JeddT3EWaknriNgVc0gYlasdoEZqNvSY2BWzTxj1A75L
2NTjAY+IXTG7sKtHG1xKph6X2Cb1UMwm7GkXsny7YtLPI1eJXTErsKtHbNg9
WTEuV1OPB7m8TD1yNE/qoZhZ2I9FJBtlFeNyL/WoF8uuFOPyJ/WYGsuGFFOG
vfOIXXKh56qzwB794BG3QbDH91je/NajWU6axTOJWrBHFPs7pUHNJ8ixGR3O
IULPGI7NHr7MkXZsv/zKj0DwnS0uhI1u/2dN8NqzDMHyPW0C88rD1n298QRR
319PgYIr\
\>"],
  ImageRangeCache->{{{0, 198}, {198, 0}} -> {-2, -2, 0, 0}}],
 StyleBox["          ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.941 1 .941 r
.5 .5 m
.5 0 L
1 0 L
1 1 L
.5 1 L
.5 .5 L
F
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.5 .75 m
.50031 .75 L
.50059 .75001 L
.50091 .75002 L
.50122 .75004 L
.5015 .75006 L
.50176 .75009 L
.50236 .75017 L
.50295 .75028 L
.50361 .75044 L
.50494 .75087 L
.50623 .75142 L
.50762 .75217 L
.51014 .75387 L
.51581 .75868 L
.51861 .76103 L
.51997 .76204 L
.5212 .76284 L
.52241 .76349 L
.52304 .76377 L
.52371 .76402 L
.52405 .76413 L
.52442 .76423 L
.52477 .7643 L
.52508 .76436 L
.5254 .7644 L
.52575 .76443 L
.52607 .76444 L
.52638 .76443 L
.5267 .76442 L
.52688 .7644 L
.52706 .76438 L
.52741 .76432 L
.52778 .76423 L
.52846 .76402 L
.52908 .76376 L
.53051 .76291 L
.53124 .76235 L
.53202 .76163 L
.53472 .75833 L
.53717 .75424 L
.54267 .74195 L
.54813 .72746 L
.55053 .72124 L
.55317 .71503 L
.55553 .71039 L
.55683 .70832 L
.55807 .70673 L
.55874 .70603 L
.55947 .70542 L
Mistroke
.55979 .7052 L
.56014 .70499 L
.56046 .70484 L
.56075 .70472 L
.56108 .70462 L
.56125 .70458 L
.56143 .70455 L
.56174 .70452 L
.56207 .70452 L
.56237 .70456 L
.56269 .70462 L
.56299 .70472 L
.56326 .70483 L
.56387 .70517 L
.56453 .70568 L
.56522 .70638 L
.56587 .70719 L
.56703 .709 L
.56828 .71147 L
.57113 .71909 L
.57374 .72835 L
.58415 .77938 L
.5894 .80559 L
.59169 .81516 L
.59417 .82352 L
.59555 .8271 L
.59616 .8284 L
.59682 .82962 L
.59741 .83052 L
.59804 .8313 L
.59839 .83164 L
.59871 .83189 L
.59902 .83209 L
.59933 .83223 L
.59964 .83233 L
.59982 .83236 L
.59999 .83237 L
.60033 .83235 L
.60052 .83231 L
.60069 .83225 L
.60099 .83212 L
.60131 .83192 L
.60165 .83165 L
.60196 .83134 L
.60269 .83041 L
.60335 .8293 L
.60483 .82591 L
.6061 .82201 L
.60745 .81691 L
.60986 .80536 L
Mistroke
.61532 .76957 L
.62525 .68881 L
.63035 .6535 L
.63182 .64556 L
.63322 .6392 L
.63459 .63418 L
.63583 .63076 L
.63646 .62948 L
.63679 .62892 L
.63713 .62843 L
.63744 .62806 L
.63777 .62775 L
.63807 .62754 L
.63835 .62741 L
.63852 .62736 L
.6387 .62734 L
.63903 .62736 L
.63935 .62746 L
.63965 .62763 L
.63997 .62789 L
.64032 .62828 L
.64104 .62938 L
.64166 .63068 L
.64224 .63216 L
.64353 .63646 L
.64467 .64137 L
.64587 .64764 L
.64837 .66424 L
.65105 .68666 L
.65587 .73634 L
.6611 .79669 L
.66677 .85766 L
.66943 .88085 L
.67088 .89141 L
.67224 .89972 L
.67349 .90593 L
.67464 .9103 L
.67529 .91221 L
.67591 .91362 L
.67622 .91419 L
.67656 .91468 L
.67675 .91491 L
.67693 .91509 L
.67727 .91533 L
.67759 .91544 L
.67789 .91545 L
.67821 .91535 L
.67839 .91525 L
.67856 .91512 L
.67889 .91478 L
Mistroke
.67925 .91427 L
.67991 .91297 L
.68053 .91134 L
.68117 .90918 L
.68234 .90415 L
.68368 .89656 L
.68494 .88775 L
.68781 .86197 L
.69312 .79684 L
.69798 .72537 L
.70339 .64585 L
.70602 .61154 L
.7084 .58488 L
.7096 .57346 L
.7109 .56278 L
.71202 .55507 L
.71325 .54833 L
.71389 .5456 L
.71456 .54324 L
.71494 .54219 L
.71528 .5414 L
.71563 .54075 L
.71595 .54029 L
.71624 .53999 L
.71656 .5398 L
.71687 .53974 L
.71705 .53977 L
.71722 .53983 L
.71752 .54005 L
.7178 .54036 L
.71811 .54081 L
.71843 .54144 L
.7191 .5432 L
.71974 .54544 L
.72093 .55112 L
.72221 .55936 L
.72361 .57073 L
.72611 .59725 L
.72843 .62791 L
.73877 .80893 L
.74356 .89375 L
.74871 .96516 L
.75 .97824 L
Mfstroke
1 0 0 r
.5 .25 m
.50031 .25 L
.50059 .24999 L
.50091 .24998 L
.50122 .24996 L
.5015 .24994 L
.50176 .24991 L
.50236 .24983 L
.50295 .24972 L
.50361 .24956 L
.50494 .24913 L
.50623 .24858 L
.50762 .24783 L
.51014 .24613 L
.51581 .24132 L
.51861 .23897 L
.51997 .23796 L
.5212 .23716 L
.52241 .23651 L
.52304 .23623 L
.52371 .23598 L
.52405 .23587 L
.52442 .23577 L
.52477 .2357 L
.52508 .23564 L
.5254 .2356 L
.52575 .23557 L
.52607 .23556 L
.52638 .23557 L
.5267 .23558 L
.52688 .2356 L
.52706 .23562 L
.52741 .23568 L
.52778 .23577 L
.52846 .23598 L
.52908 .23624 L
.53051 .23709 L
.53124 .23765 L
.53202 .23837 L
.53472 .24167 L
.53717 .24576 L
.54267 .25805 L
.54813 .27254 L
.55053 .27876 L
.55317 .28497 L
.55553 .28961 L
.55683 .29168 L
.55807 .29327 L
.55874 .29397 L
.55947 .29458 L
Mistroke
.55979 .2948 L
.56014 .29501 L
.56046 .29516 L
.56075 .29528 L
.56108 .29538 L
.56125 .29542 L
.56143 .29545 L
.56174 .29548 L
.56207 .29548 L
.56237 .29544 L
.56269 .29538 L
.56299 .29528 L
.56326 .29517 L
.56387 .29483 L
.56453 .29432 L
.56522 .29362 L
.56587 .29281 L
.56703 .291 L
.56828 .28853 L
.57113 .28091 L
.57374 .27165 L
.58415 .22062 L
.5894 .19441 L
.59169 .18484 L
.59417 .17648 L
.59555 .1729 L
.59616 .1716 L
.59682 .17038 L
.59741 .16948 L
.59804 .1687 L
.59839 .16836 L
.59871 .16811 L
.59902 .16791 L
.59933 .16777 L
.59964 .16767 L
.59982 .16764 L
.59999 .16763 L
.60033 .16765 L
.60052 .16769 L
.60069 .16775 L
.60099 .16788 L
.60131 .16808 L
.60165 .16835 L
.60196 .16866 L
.60269 .16959 L
.60335 .1707 L
.60483 .17409 L
.6061 .17799 L
.60745 .18309 L
.60986 .19464 L
Mistroke
.61532 .23043 L
.62525 .31119 L
.63035 .3465 L
.63182 .35444 L
.63322 .3608 L
.63459 .36582 L
.63583 .36924 L
.63646 .37052 L
.63679 .37108 L
.63713 .37157 L
.63744 .37194 L
.63777 .37225 L
.63807 .37246 L
.63835 .37259 L
.63852 .37264 L
.6387 .37266 L
.63903 .37264 L
.63935 .37254 L
.63965 .37237 L
.63997 .37211 L
.64032 .37172 L
.64104 .37062 L
.64166 .36932 L
.64224 .36784 L
.64353 .36354 L
.64467 .35863 L
.64587 .35236 L
.64837 .33576 L
.65105 .31334 L
.65587 .26366 L
.6611 .20331 L
.66677 .14234 L
.66943 .11915 L
.67088 .10859 L
.67224 .10028 L
.67349 .09407 L
.67464 .0897 L
.67529 .08779 L
.67591 .08638 L
.67622 .08581 L
.67656 .08532 L
.67675 .08509 L
.67693 .08491 L
.67727 .08467 L
.67759 .08456 L
.67789 .08455 L
.67821 .08465 L
.67839 .08475 L
.67856 .08488 L
.67889 .08522 L
Mistroke
.67925 .08573 L
.67991 .08703 L
.68053 .08866 L
.68117 .09082 L
.68234 .09585 L
.68368 .10344 L
.68494 .11225 L
.68781 .13803 L
.69312 .20316 L
.69798 .27463 L
.70339 .35415 L
.70602 .38846 L
.7084 .41512 L
.7096 .42654 L
.7109 .43722 L
.71202 .44493 L
.71325 .45167 L
.71389 .4544 L
.71456 .45676 L
.71494 .45781 L
.71528 .4586 L
.71563 .45925 L
.71595 .45971 L
.71624 .46001 L
.71656 .4602 L
.71687 .46026 L
.71705 .46023 L
.71722 .46017 L
.71752 .45995 L
.7178 .45964 L
.71811 .45919 L
.71843 .45856 L
.7191 .4568 L
.71974 .45456 L
.72093 .44888 L
.72221 .44064 L
.72361 .42927 L
.72611 .40275 L
.72843 .37209 L
.73877 .19107 L
.74356 .10625 L
.74871 .03484 L
.75 .02176 L
Mfstroke
0 g
0 .5 m
1 .5 L
s
.5 .5 m
.5 1 L
s
[ .02 .02 ] 0 setdash
.5 0 m
.5 .5 L
s
0 0 1 r
.03 w
.5 .75 Mdot
1 0 0 r
.5 .25 Mdot
0 g
gsave
.98 .525 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5375 .98 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47 .25 -77.375 -10.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.188 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
91.750 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47 .75 -77.375 -10.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
91.750 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{199, 199},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztW91umzAUdiBA+relk9p1k7amF1vbi7bpKnVvsF1Nu6va7aZRNKm9mDZ1
fce+Tt+AcRybgHMIJ2AbSECKIQd/3/mwj08MJt9Gj3e/fo8e78ejwdeH0d+7
+/G/wZc/D5HJ7TDGnuAzYHAcRoeiGLMwDJnL+JfoCD4jXrLkqefwmX9uoexY
PH/OzS5XKyudmaukyDldRYy+1hwilYY5Ek8KYPahdACyWQ06gYH9hk2eA27u
piqFNccq1/6+xlReCiN7Zn0Z+A5MEqwhBOfaCZQmeYdgHMQWFODeRjCYRl3+
+lA6WcGry8tLBZOVdlzE5hf2NzM+sXAr7PKVBR/bC0Zut/aOlI56sWJ+t0oM
MpMaqBHaaA39lXHKgbxOj0jrlbB9Sri/gl0AXd2FI17REV6VTGlb2rVyEwqb
B0c+QKieqfWo/ZlU+B12Xtx4mFaesqhXb1JrZmtyhVRGqmpdCv04KLEMq3tc
5im8ivu7B0fYgLAtiacP6oTTpJAb5JFRUBdx2E9aIAIam1JQU51eLTMZt8zM
prAMfnMh4liCqZFOnQblCenFQsrc5RTxvGPa317rwFCXUIPUpD+s3kWOv11e
0h+4rJSPNyJslMxITQvG+d4qlWBfmExp0NdN5nZLNavC+KFqnqM5sX1przJ6
OcWwH/GB0EzYsZF66dHxmaTVPOYQSj43slJzvLhBIb/VeP6Jn6lkEfrHpI1g
m8xi5DYfdiO6OGnjLA4J6KVs0q1J7KG8TrFQW5blLG43J31EQlNHELy5MNEW
kkedHUw3xggcNem1sLiK/KFLwmQvLC/WTWEdxJY339lDMOuauMUsL4Js6GRU
xtiqc+/iA6ZR9PgY0BWHy+Jjh8jTq4E/F7FRH6vk+QsQW7f1V7k/8Ux2geyg
y3MQexaBJ8HU0NQqZDZbrhHpfa0y8GyENYlJLRgPFgtUf8uuy0MwWMia1DWz
5h9VxIaIbV1zlqgjA5URa2E7CjHPVDVYPa0KfTCUaS+TCv04DuW7J0qKpaY1
ahdgtjkr/VxQ6iGIW4UqLKFsIRjdAzf5vlLmOn/FuurQNk3SUGbCVkSDfIMT
m7SUmUC1fuvhV77CrSRu7O6YGv61dTnFwB67HdLlrw9l6Zsu6h8kmsYt/+tC
jfU68WFROmz5ED7S08mWSh/VvoLJSnJWeXgS3LSOPrGEOUUw1P/tthjzmOkP
+tR2VIDHUXhgO9bE83MGg6/dY9dyrRWrth1s6ZcmGJu8pCBgrPMfqpOmZQ==
\
\>"],
  ImageRangeCache->{{{0, 198}, {198, 0}} -> {-2, -2, 0, 0}}],
 StyleBox["   \n\t\t\t\t(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The branch  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["f", "1"], 
     RowBox[{"(", "z", ")"}]}], "=", 
    SqrtBox["z"]}]}]]],
 "    (where   ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   SuperscriptBox["w", "2"]}]]],
 ").   "
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.941 1 .941 r
0 .5 m
0 0 L
1 0 L
1 1 L
0 1 L
0 .5 L
F
1 1 1 r
0 .5 m
0 .49 L
.5 .49 L
.5 .51 L
0 .51 L
0 .5 L
F
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.25 .5 m
.25 .49957 L
.24999 .49917 L
.24998 .49872 L
.24997 .49829 L
.24995 .4979 L
.24992 .49753 L
.24985 .4967 L
.24976 .49586 L
.24962 .49494 L
.24925 .49308 L
.24875 .49125 L
.24806 .48928 L
.24644 .4857 L
.2411 .4773 L
.23499 .46939 L
.22881 .4611 L
.2263 .45704 L
.22453 .45336 L
.22386 .45152 L
.22358 .45055 L
.22333 .44954 L
.22317 .44865 L
.2231 .44818 L
.22304 .44768 L
.223 .44722 L
.22297 .4468 L
.22296 .44638 L
.22296 .44599 L
.22297 .44554 L
.22299 .44506 L
.22304 .44455 L
.2231 .44408 L
.22325 .44323 L
.22347 .44233 L
.22379 .44134 L
.22421 .44031 L
.22519 .43849 L
.22649 .43667 L
.22795 .43506 L
.23217 .43159 L
.23723 .42858 L
.24298 .42593 L
.25022 .42327 L
.25884 .42073 L
.27606 .41682 L
.31277 .41083 L
.32209 .40932 L
.32996 .40781 L
.33603 .40633 L
Mistroke
.33902 .4054 L
.3414 .40448 L
.34355 .40344 L
.34522 .40237 L
.34661 .40114 L
.3472 .40039 L
.34764 .39967 L
.34778 .39936 L
.34792 .39902 L
.34802 .39872 L
.3481 .39839 L
.34818 .398 L
.34822 .39761 L
.34824 .39723 L
.34823 .39687 L
.3482 .39648 L
.34815 .39612 L
.34808 .3957 L
.34796 .39525 L
.34764 .3943 L
.34723 .39338 L
.34608 .39144 L
.34437 .38919 L
.33998 .38467 L
.32354 .37206 L
.26391 .33707 L
.18407 .2952 L
.14853 .27591 L
.13101 .26559 L
.11732 .25663 L
.10629 .248 L
.10282 .2446 L
.10006 .24117 L
.09902 .23943 L
.09867 .2387 L
.09836 .23791 L
.09815 .23719 L
.09801 .23653 L
.09794 .23585 L
.09794 .23515 L
.09803 .23448 L
.09812 .2341 L
.09823 .23376 L
.09852 .2331 L
.09894 .23243 L
.09944 .23183 L
.1 .23129 L
.10129 .23036 L
.10282 .22956 L
.10451 .22889 L
Mistroke
.10666 .22825 L
.10931 .22768 L
.11076 .22744 L
.11244 .22721 L
.11401 .22703 L
.11577 .22688 L
.1176 .22675 L
.11934 .22667 L
.12115 .22661 L
.12292 .22658 L
.12463 .22657 L
.12657 .22659 L
.12867 .22663 L
.13068 .22669 L
.13262 .22677 L
.13444 .22686 L
.13867 .22712 L
.1489 .22803 L
.15948 .22928 L
.18391 .2331 L
.21286 .23888 L
.26966 .25334 L
.38438 .29425 L
.43223 .3169 L
.47132 .33851 L
.49599 .35309 L
.50452 .35752 L
.50642 .3583 L
.50727 .3586 L
.50799 .35882 L
.5086 .35898 L
.50922 .35911 L
.50953 .35915 L
.5098 .35918 L
.51007 .3592 L
.51036 .35921 L
.5106 .3592 L
.51085 .35918 L
.51125 .35911 L
.51148 .35904 L
.51168 .35896 L
.51185 .35887 L
.51202 .35876 L
.51229 .35852 L
.51241 .35838 L
.51253 .35821 L
.51271 .35787 L
.51283 .3575 L
.51291 .35707 L
.51295 .35661 L
Mistroke
.51294 .35616 L
.5129 .35563 L
.51282 .355 L
.51275 .35466 L
.51267 .35428 L
.51228 .35283 L
.51099 .34946 L
.50883 .345 L
.5027 .33473 L
.4764 .30068 L
.43245 .2556 L
.29253 .14522 L
.09456 .01981 L
Mfstroke
.09456 .01981 m
.06318 0 L
s
1 0 0 r
.25 .5 m
.25 .50043 L
.24999 .50083 L
.24998 .50128 L
.24997 .50171 L
.24995 .5021 L
.24992 .50247 L
.24985 .5033 L
.24976 .50414 L
.24962 .50506 L
.24925 .50692 L
.24875 .50875 L
.24806 .51072 L
.24644 .5143 L
.2411 .5227 L
.23499 .53061 L
.22881 .5389 L
.2263 .54296 L
.22453 .54664 L
.22386 .54848 L
.22358 .54945 L
.22333 .55046 L
.22317 .55135 L
.2231 .55182 L
.22304 .55232 L
.223 .55278 L
.22297 .5532 L
.22296 .55362 L
.22296 .55401 L
.22297 .55446 L
.22299 .55494 L
.22304 .55545 L
.2231 .55592 L
.22325 .55677 L
.22347 .55767 L
.22379 .55866 L
.22421 .55969 L
.22519 .56151 L
.22649 .56333 L
.22795 .56494 L
.23217 .56841 L
.23723 .57142 L
.24298 .57407 L
.25022 .57673 L
.25884 .57927 L
.27606 .58318 L
.31277 .58917 L
.32209 .59068 L
.32996 .59219 L
.33603 .59367 L
Mistroke
.33902 .5946 L
.3414 .59552 L
.34355 .59656 L
.34522 .59763 L
.34661 .59886 L
.3472 .59961 L
.34764 .60033 L
.34778 .60064 L
.34792 .60098 L
.34802 .60128 L
.3481 .60161 L
.34818 .602 L
.34822 .60239 L
.34824 .60277 L
.34823 .60313 L
.3482 .60352 L
.34815 .60388 L
.34808 .6043 L
.34796 .60475 L
.34764 .6057 L
.34723 .60662 L
.34608 .60856 L
.34437 .61081 L
.33998 .61533 L
.32354 .62794 L
.26391 .66293 L
.18407 .7048 L
.14853 .72409 L
.13101 .73441 L
.11732 .74337 L
.10629 .752 L
.10282 .7554 L
.10006 .75883 L
.09902 .76057 L
.09867 .7613 L
.09836 .76209 L
.09815 .76281 L
.09801 .76347 L
.09794 .76415 L
.09794 .76485 L
.09803 .76552 L
.09812 .7659 L
.09823 .76624 L
.09852 .7669 L
.09894 .76757 L
.09944 .76817 L
.1 .76871 L
.10129 .76964 L
.10282 .77044 L
.10451 .77111 L
Mistroke
.10666 .77175 L
.10931 .77232 L
.11076 .77256 L
.11244 .77279 L
.11401 .77297 L
.11577 .77312 L
.1176 .77325 L
.11934 .77333 L
.12115 .77339 L
.12292 .77342 L
.12463 .77343 L
.12657 .77341 L
.12867 .77337 L
.13068 .77331 L
.13262 .77323 L
.13444 .77314 L
.13867 .77288 L
.1489 .77197 L
.15948 .77072 L
.18391 .7669 L
.21286 .76112 L
.26966 .74666 L
.38438 .70575 L
.43223 .6831 L
.47132 .66149 L
.49599 .64691 L
.50452 .64248 L
.50642 .6417 L
.50727 .6414 L
.50799 .64118 L
.5086 .64102 L
.50922 .64089 L
.50953 .64085 L
.5098 .64082 L
.51007 .6408 L
.51036 .64079 L
.5106 .6408 L
.51085 .64082 L
.51125 .64089 L
.51148 .64096 L
.51168 .64104 L
.51185 .64113 L
.51202 .64124 L
.51229 .64148 L
.51241 .64162 L
.51253 .64179 L
.51271 .64213 L
.51283 .6425 L
.51291 .64293 L
.51295 .64339 L
Mistroke
.51294 .64384 L
.5129 .64437 L
.51282 .645 L
.51275 .64534 L
.51267 .64572 L
.51228 .64717 L
.51099 .65054 L
.50883 .655 L
.5027 .66527 L
.4764 .69932 L
.43245 .7444 L
.29253 .85478 L
.09456 .98019 L
Mfstroke
.09456 .98019 m
.06318 1 L
s
0 g
.5 .5 m
1 .5 L
s
.5 0 m
.5 1 L
s
0 .51 m
.5 .51 L
s
[ .02 .02 ] 0 setdash
0 .49 m
.5 .49 L
s
0 1 0 r
.03 w
.25 .5 Mdot
0 g
gsave
.98 .525 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5375 .98 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.28 .525 -70.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
77.375 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{199, 199},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzVmutOG0cYhhdjm5BwBifGMY4BcwpnQkIJgZCAIIi0UtVUStI/ddNKyY+q
VZp77O1wB65n7H1ndnjrd7tVqtSSzbLzPc/Ozo53vhnv181P73/5tfnpw7tm
/fxj8/f3H979UT/77WN7V39fFEV/mnc9Mtut9mb3YyhqtVpRv/3fbJn3K+yL
sK9pP6Ph6Kp1lTP7X5mtbpDZMu8fzWdfJ3IU5S2UfyuYMdhV5ASxfyOYSdhV
ZInYLwVzG3YVWUbkhYiskHqcCeYu7CpyhthPBFODXUXWif1YMLOwq8h5Yj8U
TAN2FbmIyAMRuUzq8ZVgVmBXkavE/lAwa7CryA1i3xHMJuwqcpvYNwWzA7uK
3EXkuoh8ROpxXzB7sKvIfWJfEsxjwiwK5gA1UpGHxD4vmCPCzAnmKWFmBXOM
s1CRz4m9JpgTwswI5hQ1UpFnxF4RzDlhpgXzgjBlwVzgLFTkJbGXBPOSMFOC
saNh0SDsPjApaFtukSI87r6Wig6OOGQ+C2bXCikdy2Ach3GBlI4K4xRh7HXI
m11zOFflYZlKGR42Bg+luXL22FVchRrx3BKeMmGcsUpKbwrjNGFqMLJcaVAY
KzjXWXhYvW8ITxUed+XuEM+A8NSSHguzK1wUnjo88/CwPlwQHnc2DXjGiScv
PA3COCObKfQL4wJqtoStEeLJCc8S8Qx328b3mLd5/eSxK4S9lZJdJezNblv6
bICtE2wwOO2Q2Uwyf9slW2ikpkdvg3ZJsWIeEEZ12YeEUd1qjzD+BY/PUyVs
rjN5BzP/XcvagmaMuk2QjHyCyAUReZT8nqrMKah2XTDPCHNPMP9p3sVGhy+A
se1mEdVatk8MRPH9WnXvIP/oMW+yN4ENEbmBeqq52DpphQeCST+PXCP23f8x
k6W1ssylM8+/A2b7MzBbuPoq0nTVznBd+MdbdqDEnTEeTrLa7FZy5Gv/KRit
3fq5Yw/29my49stGboXqre53r9XZStH6La+8iOqy2fzruO072Yvb6mFkGSpz
v7Gf+cS+uP2CbunrbV3ZcMyO8Ra1zgsty8/TG9eJkc0hMrbDGtGzSU+WS/hv
3Oz2dq0J7BGXM9Cpbqi5KB7SUtxGfXuq26hFUi0v5qPEbbTn0Bsn7Go4L0aJ
5eUe6Zg9ukoRTkkrpE1aPjdzQhiVuD0njEoQnxFGtdsxYVTCe4S+qa7fE0T6
KXo8BPmRB6QeitmHfRFbXmXC8D0SngsOQTt1wKjp0i45lQZoNUHbSR7x2gDh
9sUGf0q4Rep7QzAbhBkMjm1e/ri8Rph4Xu3XN8DuEyyeyvsYO+QyYYdTsouE
HQlO0bzVMoa7jLZvWniUeNSyyhw8DXjGiUd1tXrym2jhSeJRC1A1eObgKRGP
6rwzhHF1vENK1VLdXdB11KxMPGrpcBqee/BUiEctZbJjV2GsklK13MpapQJj
jZSqJeESztWedR6tF3jUEvUUYUowuj6sFs9Zj5yAZ4GUZjHas7FZxTIpHUtj
tIjtkfaWwjKrceGxy/oDUeJWrH7EeUmOo5hLwqgfmC5QI/Xz1QtiV8w5YdSP
cGeEUT/2neIsVA71JeddT3EWaknriNgVc0gYlasdoEZqNvSY2BWzTxj1A75L
2NTjAY+IXTG7sKtHG1xKph6X2Cb1UMwm7GkXsny7YtLPI1eJXTErsKtHbNg9
WTEuV1OPB7m8TD1yNE/qoZhZ2I9FJBtlFeNyL/WoF8uuFOPyJ/WYGsuGFFOG
vfOIXXKh56qzwB794BG3QbDH91je/NajWU6axTOJWrBHFPs7pUHNJ8ixGR3O
IULPGI7NHr7MkXZsv/zKj0DwnS0uhI1u/2dN8NqzDMHyPW0C88rD1n298QRR
319PgYIr\
\>"],
  ImageRangeCache->{{{0, 198}, {198, 0}} -> {-2, -2, 0, 0}}],
 StyleBox["          ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.941 1 .941 r
.5 .5 m
.5 0 L
0 0 L
0 1 L
.5 1 L
.5 .5 L
F
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.5 .75 m
.49969 .75 L
.49941 .75001 L
.49909 .75002 L
.49878 .75004 L
.4985 .75006 L
.49824 .75009 L
.49764 .75017 L
.49705 .75028 L
.49639 .75044 L
.49506 .75087 L
.49377 .75142 L
.49238 .75217 L
.48986 .75387 L
.48419 .75868 L
.48139 .76103 L
.48003 .76204 L
.4788 .76284 L
.47759 .76349 L
.47696 .76377 L
.47629 .76402 L
.47595 .76413 L
.47558 .76423 L
.47523 .7643 L
.47492 .76436 L
.4746 .7644 L
.47425 .76443 L
.47393 .76444 L
.47362 .76443 L
.4733 .76442 L
.47312 .7644 L
.47294 .76438 L
.47259 .76432 L
.47222 .76423 L
.47154 .76402 L
.47092 .76376 L
.46949 .76291 L
.46876 .76235 L
.46798 .76163 L
.46528 .75833 L
.46283 .75424 L
.45733 .74195 L
.45187 .72746 L
.44947 .72124 L
.44683 .71503 L
.44447 .71039 L
.44317 .70832 L
.44193 .70673 L
.44126 .70603 L
.44053 .70542 L
Mistroke
.44021 .7052 L
.43986 .70499 L
.43954 .70484 L
.43925 .70472 L
.43892 .70462 L
.43875 .70458 L
.43857 .70455 L
.43826 .70452 L
.43793 .70452 L
.43763 .70456 L
.43731 .70462 L
.43701 .70472 L
.43674 .70483 L
.43613 .70517 L
.43547 .70568 L
.43478 .70638 L
.43413 .70719 L
.43297 .709 L
.43172 .71147 L
.42887 .71909 L
.42626 .72835 L
.41585 .77938 L
.4106 .80559 L
.40831 .81516 L
.40583 .82352 L
.40445 .8271 L
.40384 .8284 L
.40318 .82962 L
.40259 .83052 L
.40196 .8313 L
.40161 .83164 L
.40129 .83189 L
.40098 .83209 L
.40067 .83223 L
.40036 .83233 L
.40018 .83236 L
.40001 .83237 L
.39967 .83235 L
.39948 .83231 L
.39931 .83225 L
.39901 .83212 L
.39869 .83192 L
.39835 .83165 L
.39804 .83134 L
.39731 .83041 L
.39665 .8293 L
.39517 .82591 L
.3939 .82201 L
.39255 .81691 L
.39014 .80536 L
Mistroke
.38468 .76957 L
.37475 .68881 L
.36965 .6535 L
.36818 .64556 L
.36678 .6392 L
.36541 .63418 L
.36417 .63076 L
.36354 .62948 L
.36321 .62892 L
.36287 .62843 L
.36256 .62806 L
.36223 .62775 L
.36193 .62754 L
.36165 .62741 L
.36148 .62736 L
.3613 .62734 L
.36097 .62736 L
.36065 .62746 L
.36035 .62763 L
.36003 .62789 L
.35968 .62828 L
.35896 .62938 L
.35834 .63068 L
.35776 .63216 L
.35647 .63646 L
.35533 .64137 L
.35413 .64764 L
.35163 .66424 L
.34895 .68666 L
.34413 .73634 L
.3389 .79669 L
.33323 .85766 L
.33057 .88085 L
.32912 .89141 L
.32776 .89972 L
.32651 .90593 L
.32536 .9103 L
.32471 .91221 L
.32409 .91362 L
.32378 .91419 L
.32344 .91468 L
.32325 .91491 L
.32307 .91509 L
.32273 .91533 L
.32241 .91544 L
.32211 .91545 L
.32179 .91535 L
.32161 .91525 L
.32144 .91512 L
.32111 .91478 L
Mistroke
.32075 .91427 L
.32009 .91297 L
.31947 .91134 L
.31883 .90918 L
.31766 .90415 L
.31632 .89656 L
.31506 .88775 L
.31219 .86197 L
.30688 .79684 L
.30202 .72537 L
.29661 .64585 L
.29398 .61154 L
.2916 .58488 L
.2904 .57346 L
.2891 .56278 L
.28798 .55507 L
.28675 .54833 L
.28611 .5456 L
.28544 .54324 L
.28506 .54219 L
.28472 .5414 L
.28437 .54075 L
.28405 .54029 L
.28376 .53999 L
.28344 .5398 L
.28313 .53974 L
.28295 .53977 L
.28278 .53983 L
.28248 .54005 L
.2822 .54036 L
.28189 .54081 L
.28157 .54144 L
.2809 .5432 L
.28026 .54544 L
.27907 .55112 L
.27779 .55936 L
.27639 .57073 L
.27389 .59725 L
.27157 .62791 L
.26123 .80893 L
.25644 .89375 L
.25129 .96516 L
.25 .97824 L
Mfstroke
1 0 0 r
.5 .25 m
.49969 .25 L
.49941 .24999 L
.49909 .24998 L
.49878 .24996 L
.4985 .24994 L
.49824 .24991 L
.49764 .24983 L
.49705 .24972 L
.49639 .24956 L
.49506 .24913 L
.49377 .24858 L
.49238 .24783 L
.48986 .24613 L
.48419 .24132 L
.48139 .23897 L
.48003 .23796 L
.4788 .23716 L
.47759 .23651 L
.47696 .23623 L
.47629 .23598 L
.47595 .23587 L
.47558 .23577 L
.47523 .2357 L
.47492 .23564 L
.4746 .2356 L
.47425 .23557 L
.47393 .23556 L
.47362 .23557 L
.4733 .23558 L
.47312 .2356 L
.47294 .23562 L
.47259 .23568 L
.47222 .23577 L
.47154 .23598 L
.47092 .23624 L
.46949 .23709 L
.46876 .23765 L
.46798 .23837 L
.46528 .24167 L
.46283 .24576 L
.45733 .25805 L
.45187 .27254 L
.44947 .27876 L
.44683 .28497 L
.44447 .28961 L
.44317 .29168 L
.44193 .29327 L
.44126 .29397 L
.44053 .29458 L
Mistroke
.44021 .2948 L
.43986 .29501 L
.43954 .29516 L
.43925 .29528 L
.43892 .29538 L
.43875 .29542 L
.43857 .29545 L
.43826 .29548 L
.43793 .29548 L
.43763 .29544 L
.43731 .29538 L
.43701 .29528 L
.43674 .29517 L
.43613 .29483 L
.43547 .29432 L
.43478 .29362 L
.43413 .29281 L
.43297 .291 L
.43172 .28853 L
.42887 .28091 L
.42626 .27165 L
.41585 .22062 L
.4106 .19441 L
.40831 .18484 L
.40583 .17648 L
.40445 .1729 L
.40384 .1716 L
.40318 .17038 L
.40259 .16948 L
.40196 .1687 L
.40161 .16836 L
.40129 .16811 L
.40098 .16791 L
.40067 .16777 L
.40036 .16767 L
.40018 .16764 L
.40001 .16763 L
.39967 .16765 L
.39948 .16769 L
.39931 .16775 L
.39901 .16788 L
.39869 .16808 L
.39835 .16835 L
.39804 .16866 L
.39731 .16959 L
.39665 .1707 L
.39517 .17409 L
.3939 .17799 L
.39255 .18309 L
.39014 .19464 L
Mistroke
.38468 .23043 L
.37475 .31119 L
.36965 .3465 L
.36818 .35444 L
.36678 .3608 L
.36541 .36582 L
.36417 .36924 L
.36354 .37052 L
.36321 .37108 L
.36287 .37157 L
.36256 .37194 L
.36223 .37225 L
.36193 .37246 L
.36165 .37259 L
.36148 .37264 L
.3613 .37266 L
.36097 .37264 L
.36065 .37254 L
.36035 .37237 L
.36003 .37211 L
.35968 .37172 L
.35896 .37062 L
.35834 .36932 L
.35776 .36784 L
.35647 .36354 L
.35533 .35863 L
.35413 .35236 L
.35163 .33576 L
.34895 .31334 L
.34413 .26366 L
.3389 .20331 L
.33323 .14234 L
.33057 .11915 L
.32912 .10859 L
.32776 .10028 L
.32651 .09407 L
.32536 .0897 L
.32471 .08779 L
.32409 .08638 L
.32378 .08581 L
.32344 .08532 L
.32325 .08509 L
.32307 .08491 L
.32273 .08467 L
.32241 .08456 L
.32211 .08455 L
.32179 .08465 L
.32161 .08475 L
.32144 .08488 L
.32111 .08522 L
Mistroke
.32075 .08573 L
.32009 .08703 L
.31947 .08866 L
.31883 .09082 L
.31766 .09585 L
.31632 .10344 L
.31506 .11225 L
.31219 .13803 L
.30688 .20316 L
.30202 .27463 L
.29661 .35415 L
.29398 .38846 L
.2916 .41512 L
.2904 .42654 L
.2891 .43722 L
.28798 .44493 L
.28675 .45167 L
.28611 .4544 L
.28544 .45676 L
.28506 .45781 L
.28472 .4586 L
.28437 .45925 L
.28405 .45971 L
.28376 .46001 L
.28344 .4602 L
.28313 .46026 L
.28295 .46023 L
.28278 .46017 L
.28248 .45995 L
.2822 .45964 L
.28189 .45919 L
.28157 .45856 L
.2809 .4568 L
.28026 .45456 L
.27907 .44888 L
.27779 .44064 L
.27639 .42927 L
.27389 .40275 L
.27157 .37209 L
.26123 .19107 L
.25644 .10625 L
.25129 .03484 L
.25 .02176 L
Mfstroke
0 g
0 .5 m
1 .5 L
s
.5 .5 m
.5 1 L
s
[ .02 .02 ] 0 setdash
.5 0 m
.5 .5 L
s
0 0 1 r
.03 w
.5 .75 Mdot
1 0 0 r
.5 .25 Mdot
0 g
gsave
.98 .525 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5375 .98 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.555 .25 -70.1875 -10.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.188 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
77.375 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.555 .75 -70.1875 -10.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.938 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.188 12.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
77.375 12.938 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{199, 199},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztW81u1DAQTp2ku91FlQoSUjmghQMqHED9gzeAExfaAy1cooDUHhCo9B37
OvsGIeM6ySYdO+PEdsKuIyXxjme++daecRwn+ZzcXv38ldxep8ni003y5+o6
/bv4+PsmF4VbQRDcwb4IoJzlRXFIgyzLgjDgP/IS7Ak/BmmwzJaOqg5FFZCC
Euzv4PjDcr0mnf9ZndhUR0j9W0o9TgdTn8GRgeilI8OdhgzOI4JQNO29TVST
5eUX7s10/2dflCk/xjVZ0WqbAaXoKKrtMWI7sWmL/305VF3GZEnfkO3ZcbVT
ji9P9BxsI7KQOAI8tuNqiifhAN4U4TQAfKQZ1XuufPTrlFG5bM+0XTvuqfHk
3ZsI6TH4k+pxUbTi+aSHl1jLtp5xRZlrzoDLBPr9iztWmB5PSk503rgFhO28
PzkqETU5BkRioBQNSxPTC4doQ2rSRWUSPBqWHDb888vEvOzbMbAxMEpQR4Sl
GBX4zHYXWYE5G4gLfklaAxqUOSWcMyMM9G835u6cPnXsSjOvTGHLe3wE2PTm
t+TqlAihWmbY33R4yTLX/kr06EFVMjg/GyOOiRazA8tFBsBejQdCdNp7RRgf
dNZ7ELev5aw3wYLQOELlAxLFpHqcVBd1Pml440IpXfljyrLCXLvqjgvdPIG8
hCPjorC8PYKNyW0ukDk7W0GQ28Q1WeGun5nox7we68feAF/LBmJliWTYiG+Y
XUMJzoR0sKNepHehLky8hUGLuGZRdMqBcbPTsqoyY4iMcDl2ADFDZIRJaBus
mPvkIsLchwTWSCYPaxL2QTYZCIHiNgdLn7WFP0GgQil8Ow3Cffn6u4oQ2cS7
cuNKrAbmIsJqYJvTbUQmD6RqVAr47UdGWATtwkCuh+e/pzEojfaYnXhKhCQT
j+J4XmX4419TlGKinnh0yQcbIFK1F2zn7shhMmabHLWVRk0OGyqKMtdUPPc9
JnLpnR1cVNVWKTmFY2yREpaIhPduXLtvBhHsZxvdIgbcU6dcVt3jF3HCe3fe
pSxcmrNV4Y7wTqv3VpdhixyarvTvawgvVXdx8LwLLB63hFfYDUAdIVCqZRAP
ZQ1KsirnUZDxgfC10/ggZuXo48qQ8DEcUf0QUSd8+efVHamHyNz9mx4Ea0DA
9v2+hD0NblVXPeetQ10YMGs2B2xRaS62SyHY+gfPdGCe\
\>"],
  ImageRangeCache->{{{0, 198}, {198, 0}} -> {-2, -2, 0, 0}}],
 "  ",
 StyleBox["\n\t\t\t\t(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The branch  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["f", "2"], 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{"-", 
     SqrtBox["z"]}]}]}]]],
 "   (where   ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   SuperscriptBox["w", "2"]}]]],
 ").  "
}], "Text"],

Cell[TextData[{
 StyleBox["\t\t\tFigure 2.18",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The branches  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "1"], 
   RowBox[{"(", "z", ")"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "2"], 
   RowBox[{"(", "z", ")"}]}]]],
 "  of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", 
    FractionBox["1", "2"]]}]]],
 ".   "
}], "Text"],

Cell[TextData[{
 "\tWe can construct other branches of the square root function by specifying \
that an argument of z given by  ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "=", 
   RowBox[{"arg", " ", "z"}]}]]],
 "  is to lie in the interval  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "<", "\[Theta]", "\[LessEqual]", 
   RowBox[{"\[Alpha]", "+", 
    RowBox[{"2", "\[Pi]"}]}]}]]],
 ".  The corresponding branch, denoted ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "\[Alpha]"], 
   RowBox[{"(", "z", ")"}]}]]],
 ", is  \n\n",
 StyleBox["(2-30)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "\[Alpha]"], 
    RowBox[{"(", "z", ")"}]}], "=", " ", 
   RowBox[{
    SuperscriptBox["r", 
     FractionBox["1", "2"]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cos", 
       FractionBox["\[Theta]", "2"]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "sin", 
       FractionBox["\[Theta]", "2"]}]}], ")"}]}]}]]],
 ",\n\nwhere  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"r", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{" ", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]}]]}], "\[NotEqual]", 
    "0"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "<", "\[Theta]", "\[LessEqual]", 
   RowBox[{"\[Alpha]", "+", 
    RowBox[{"2", "\[Pi]"}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "    The branch cut for  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "\[Alpha]"], 
   RowBox[{"(", "z", ")"}]}]]],
 "  is the ray  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"r", "\[GreaterEqual]", "0"}], ",", 
   RowBox[{"\[Theta]", "=", "\[Alpha]"}]}]]],
 ",  which includes the origin.  The point ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 ", common to all branch cuts for the multivalued square root function, is \
called a branch point.  The mapping ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    SubscriptBox["f", "\[Alpha]"], 
    RowBox[{"(", "z", ")"}]}]}]]],
 " and its branch cut are illustrated in Figure 2.19."
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.941 1 .941 r
0 .5 m
0 0 L
1 0 L
1 1 L
0 1 L
0 .5 L
F
1 1 1 r
.85 1.10622 m
.83788 1.11322 L
.48788 .507 L
.51212 .493 L
.86212 1.09922 L
.85 1.10622 L
F
0 g
.5 Mabswid
[ ] 0 setdash
0 .5 m
1 .5 L
s
.5 0 m
.5 1 L
s
.79676 1 m
.51306 .50862 L
s
[ .02 .02 ] 0 setdash
.78059 1 m
.50006 .51411 L
s
0 1 0 r
[ ] 0 setdash
newpath
.5 .5 .35 0 57.7082 arc
s
0 g
gsave
.8375 .6875 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
70.188 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.98 .525 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5375 .98 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{199, 199},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztmNtS01AUhkNTighaBQoqpS090APlJAJycvRGr3wHa8cZuHB0kIfyTXwd
3iBmJ2lI0n/vf7nlMpnJoV1Z3/r3Wis7h8+j26tv30e31+NR49PN6OfV9fhX
4+OPG/8vd8ZxnD9qbTjq2PMPo83Y8TzPcZ3gh3+k1lGwdcbOnXcXmdSRWr+o
7Uxuz+25Pbfn9tye23N7bs/tuT23p+2/A4sbvWmESzXcfY1cg/Oc8M2joLYf
JkzvnrmeYAb80K8Ye0Z75jtSx0EUZzb2TSp4TwCh6lLKJ3GM3JfDmP5SSB+l
kCARiVcydcY7wF4JtsVU/oOEZ0uUHu0kVBDmEnBXY6VFTbVTiIzSi38klmAp
JnBEq0jHfX9KEpnRe67LrKFqybRO8KacnIEYVXIlFR+IMws4pyJOOsP+mpWk
VkuU6TKUIdOjLDDoCYBuEKhrvt6tkSadxxbQIiqOMhzZwlDTHAJYjTafpm2s
YYK58gCw64RdErL3LdhzYJ5LxLGROyeUu2fBfqTrpl0Aa0hgqJt2LGDziQkt
e+0Eox8C6KYIylO5bcF+LGT3AbtJ2AvmrhpYI7ncLmC3CHtR11XWMNRVHQBr
E9gT1lX2UJ7KFmB3CPupkN0E7MzzTIbM7rJlc89pA07drP2FTUNl4Sgb2qCz
KZ5aJXGf6Rq1DgK5/xsINXHtgQM9F2ayCuIG99zwNDcOqPbsMUIadB0E7RP2
kpD9ErAHhL1sbnGE3BYhudw1C/YK6la1VqIL3Qtv2wyB+nAZ6GGwinCsSxbs
1ag0aKL29wi5J0JyuWXA3ifsNbNchDyQIFGpFgHsNYG90LXOAoAdSmBI2TyA
vSGwyUXGqlKKe/yEEF+Za1ECImVILtIF7LeEvW6WW4jHfS4BZcuilFwSx6qu
OUSOqBEuiOOGMJ9syDVz7piMmlDGGeHUzTLYKOq6NJ4Sx4bOkfWcteOmMGPs
gmqaM8ZkNIUyjgmnZZbBRtHSpfGIOLZ1jmy2bIezgbLjT0osckeYOXYP2DJn
jo1jSyiD3de6ZhlsFF1dHdjNuadzZA8KPVZAFrkvzBx7GhqYM8fGMRDKYM95
4ZcWwwu5CKD96GRwHOoch8Rxx5w5FndHmDn2NrBrljE9CvCJ31+k/cTepVzw
n5TN3gG1bFQ+ESz4KqFtnR5BZL9zqGVoLgdTVQAlmkg0TRfTUvF3A5RCMgWw
LIS/inGIaKGSuwmuM/MXPoLgCQ==\
\>"],
  ImageRangeCache->{{{0, 198}, {198, 0}} -> {-2, -2, 0, 0}}],
 StyleBox["          ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.941 1 .941 r
.5 .5 m
1.10622 .85 L
.75622 1.45622 L
-0.45622 .75622 L
-0.10622 .15 L
.5 .5 L
F
0 g
.5 Mabswid
[ ] 0 setdash
0 .5 m
1 .5 L
s
.5 0 m
.5 1 L
s
.5 .5 m
0 0 rlineto s
.5 .5 m
0 .21132 L
s
[ .02 .02 ] 0 setdash
1 .78868 m
.5 .5 L
s
0 1 0 r
[ ] 0 setdash
newpath
.5 .5 .35 0 30 arc
s
0 g
gsave
.8875 .6125 -73.7813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.188 12.813 moveto
(\\220) show
77.375 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
84.563 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.98 .525 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5375 .98 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{199, 199},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztl9tSE0EQhpcNAcIZCaABQsJJUChEI4KAHAVRUdRCBfGQSlkFF5YW8lC+
ia/DG8Sd2d2eZNN/Lwm5sWqnKpNk+uu/e2Zn57Cfvzj9/iN/cVbIZ3bP879O
zwq/Mzs/z52mWINlWX/VJ2Op30Xnp1cVrGKxaMUs/cf5pT55XVuRKTJFpshU
R1Og9ZtIXhYvLb8IpAZtZfiCoThBJxhq1iHLTUcYbyFNAWol6AOG2gk6xFAn
k91bjHeRpgD1EHSAoV4m8D7Gk6QpQP0EvcDQTYL2MJRistvB+CBpCtAwQdsY
GiFoE0NZJrs1jI+SpgCNE7SKoUmCljE0xWS3iPFp0hSguwQtYGiWoByG5pjs
5jF+jzQF6D5BcxjKMYFnMP6QNAXoEUF3MLRE0BSGlpnsJjC+QpoC9ISgMQyt
E5TF0CaTXRrjW6QpQE8JGsLQLkEpDO0x2Q1g/DlpCtBLgvow9IqgXgwdMNl1
Y/wNaQrQO4I6MXTIBG7D+HvSFKCPBCUwdExQM4ZOmOwaMf6ZNAXoK0E2hvIK
0hb3SGP90VTMuzu5Zcj9KpDgli9YNILuvHUhJy1V/NON870R5hEjD/efU6/V
4BPo5Qojoaew7XVTq3nFxtqN1HVOMcmMr12izyk2BdoUuIiydc52pdp+0oJ8
QtV11GtlBjdXP/m2ys0yOL5mJocNbQcztPOM7DCW6FZ1lT49zBDNVidxo3Kb
LXFMY8ckE3u6OokBVdfiExjpyeokzAHYe4F9n1FGZwTrpCq396s5plWdrcEn
0O80I9HELAz9WNYct9PlM75ibals0++Dfu86cYAsBRhESxaXsi281EK0CVXf
Eny5WDGmrSskRuBJ0BnFW9rRkHF7J9cmdNFcQa4aNH7FoB046FTlQcubc+6E
cd8l/z8KyrW146Azqu5h5nir8IC5hxkWgx2H8pDt3qgFQmpHYa6YGxknOood
55hJlmAkxrDEA1W31OCDpkqJxDiWyFGXq3Rc8I49pV12XG9jjyW/rSTABMYf
M50T8lmmjgjQKvOcshhfNys/a99gUhQ2701KUYC2Gc0UxvWNL8we6PEAxp+h
zTaJfcwFsQ9D+u7XG2IP5NmN8dcUU4DM3VBYoPW1T1hyDpnEEhg310IBMtfC
ZgzpG188xM7uwyxuboQCZG6EvF1fBiNTZIpM/4cpxrR9wrgdaFPl5Bp4vAz3
ES6pozq4BbuuSiO5e+XYa2j4BwSQNbk=\
\>"],
  ImageRangeCache->{{{0, 198}, {198, 0}} -> {-2, -2, 0, 0}}],
 StyleBox["   \n\t\t\t\tFigure 2.19",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The branch  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "\[Alpha]"], 
   RowBox[{"(", "z", ")"}]}]]],
 "  of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", 
    FractionBox["1", "2"]]}]]],
 ".   "
}], "Text"],

Cell[TextData[{
 StyleBox["The Riemann Surface for",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   SuperscriptBox["z", 
    FractionBox["1", "2"]]}]],
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
 "\tA ",
 StyleBox[ButtonBox["Riemann surface",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/RiemannSurface.html"], None}],
  FontVariations->{"Underline"->True}],
 " is a construct useful for visualizing a multivalued function.  It was \
introduced by ",
 StyleBox[ButtonBox["Georg Friedrich Bernhard Riemann",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Riemann.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " (1826-1866) in 1851.  The idea is ingenious - a geometric construction \
that permits surfaces to be the domain or range of a multivalued function.  \
Riemann surfaces depend on the function being investigated.  We now give a \
nontechnical formulation of the Riemann surface for the multivalued square \
root function. "
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 StyleBox["    ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.08151 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0538949 1.17484 5.10117e-017 1.17484 [
[ 0 0 0 0 ]
[ 1 1.08151 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.08151 L
0 1.08151 L
closepath
clip
newpath
.58664 .53899 m .59263 .54434 L .51103 .57603 L .146 .945 0 r
F
.65652 .50304 m .59263 .54434 L .58664 .53899 L .341 .936 0 r
F
.65652 .50304 m .67041 .50595 L .59263 .54434 L F
.51326 .56907 m .51103 .57603 L .42972 .60092 L 0 .941 .041 r
F
.58664 .53899 m .51103 .57603 L .51326 .56907 L .146 .945 0 r
F
.71911 .46176 m .67041 .50595 L .65652 .50304 L .548 .92 0 r
F
.71911 .46176 m .74029 .46137 L .67041 .50595 L F
.58052 .53418 m .58664 .53899 L .51326 .56907 L .145 .953 0 r
F
.64234 .50082 m .58664 .53899 L .58052 .53418 L .341 .946 0 r
F
.64234 .50082 m .65652 .50304 L .58664 .53899 L F
.77069 .41614 m .74029 .46137 L .71911 .46176 L .759 .899 0 r
F
.77069 .41614 m .79822 .41161 L .74029 .46137 L F
.44021 .59314 m .42972 .60092 L .35293 .61926 L 0 .92 .279 r
F
.51326 .56907 m .42972 .60092 L .44021 .59314 L 0 .941 .041 r
F
.69753 .46299 m .65652 .50304 L .64234 .50082 L .551 .93 0 r
F
.69753 .46299 m .71911 .46176 L .65652 .50304 L F
.51554 .56251 m .51326 .56907 L .44021 .59314 L 0 .943 .04 r
F
.58052 .53418 m .51326 .56907 L .51554 .56251 L .145 .953 0 r
F
.74274 .42167 m .71911 .46176 L .69753 .46299 L .765 .908 0 r
F
.74274 .42167 m .77069 .41614 L .71911 .46176 L F
.57426 .53007 m .58052 .53418 L .51554 .56251 L .143 .96 0 r
F
.62785 .49949 m .58052 .53418 L .57426 .53007 L .341 .957 0 r
F
.62785 .49949 m .64234 .50082 L .58052 .53418 L F
.44021 .59314 m .35293 .61926 L .37143 .61141 L 0 .92 .279 r
F
.45092 .58564 m .44021 .59314 L .37143 .61141 L 0 .913 .272 r
F
.51554 .56251 m .44021 .59314 L .45092 .58564 L 0 .943 .04 r
F
.67553 .4653 m .64234 .50082 L .62785 .49949 L .554 .942 0 r
F
.67553 .4653 m .69753 .46299 L .64234 .50082 L F
.51787 .55648 m .51554 .56251 L .45092 .58564 L 0 .942 .039 r
F
.57426 .53007 m .51554 .56251 L .51787 .55648 L .143 .96 0 r
F
.80773 .36774 m .79822 .41161 L .77069 .41614 L .786 .671 0 r
F
.80773 .36774 m .84025 .35826 L .79822 .41161 L F
.37143 .61141 m .35293 .61926 L .285 .63166 L 0 .877 .496 r
F
.71436 .42843 m .69753 .46299 L .67553 .4653 L .773 .919 0 r
F
.71436 .42843 m .74274 .42167 L .69753 .46299 L F
.45092 .58564 m .37143 .61141 L .39028 .60371 L 0 .913 .272 r
F
.46187 .57851 m .45092 .58564 L .39028 .60371 L 0 .899 .261 r
F
.51787 .55648 m .45092 .58564 L .46187 .57851 L 0 .942 .039 r
F
.56784 .52691 m .57426 .53007 L .51787 .55648 L .139 .964 0 r
F
.61302 .49934 m .57426 .53007 L .56784 .52691 L .34 .969 0 r
F
.61302 .49934 m .62785 .49949 L .57426 .53007 L F
.77487 .37831 m .77069 .41614 L .74274 .42167 L .793 .677 0 r
F
.77487 .37831 m .80773 .36774 L .77069 .41614 L F
.65309 .469 m .62785 .49949 L .61302 .49934 L .558 .956 0 r
F
.65309 .469 m .67553 .4653 L .62785 .49949 L F
.52026 .55118 m .51787 .55648 L .46187 .57851 L 0 .934 .038 r
F
.56784 .52691 m .51787 .55648 L .52026 .55118 L .139 .964 0 r
F
.37143 .61141 m .285 .63166 L .31094 .62439 L 0 .877 .496 r
F
.39028 .60371 m .37143 .61141 L .31094 .62439 L 0 .858 .476 r
F
.68551 .43677 m .67553 .4653 L .65309 .469 L .782 .932 0 r
F
.68551 .43677 m .71436 .42843 L .67553 .4653 L F
.74164 .39022 m .74274 .42167 L .71436 .42843 L .802 .683 0 r
F
.74164 .39022 m .77487 .37831 L .74274 .42167 L F
.46187 .57851 m .39028 .60371 L .40949 .59626 L 0 .899 .261 r
F
.47306 .57191 m .46187 .57851 L .40949 .59626 L 0 .871 .245 r
F
.52026 .55118 m .46187 .57851 L .47306 .57191 L 0 .934 .038 r
F
.56127 .52507 m .56784 .52691 L .52026 .55118 L .134 .961 0 r
F
.59785 .50079 m .56784 .52691 L .56127 .52507 L .336 .979 0 r
F
.59785 .50079 m .61302 .49934 L .56784 .52691 L F
.63018 .47457 m .61302 .49934 L .59785 .50079 L .561 .971 0 r
F
.63018 .47457 m .65309 .469 L .61302 .49934 L F
.82707 .31869 m .84025 .35826 L .80773 .36774 L .79 .435 0 r
F
.82707 .31869 m .86275 .30364 L .84025 .35826 L F
.39028 .60371 m .31094 .62439 L .33726 .61719 L 0 .858 .476 r
F
.40949 .59626 m .39028 .60371 L .33726 .61719 L 0 .828 .448 r
F
.52271 .54693 m .52026 .55118 L .47306 .57191 L 0 .909 .035 r
F
.56127 .52507 m .52026 .55118 L .52271 .54693 L .134 .961 0 r
F
.47393 .84602 m .46714 .86728 L .38553 .82008 L 0 .628 .145 r
F
.55106 .88051 m .46714 .86728 L .47393 .84602 L .049 .624 0 r
F
.55106 .88051 m .55311 .90373 L .46714 .86728 L F
.70805 .40383 m .71436 .42843 L .68551 .43677 L .813 .691 0 r
F
.70805 .40383 m .74164 .39022 L .71436 .42843 L F
.31094 .62439 m .285 .63166 L .23043 .63903 L 0 .813 .681 r
F
.65619 .44719 m .65309 .469 L .63018 .47457 L .793 .947 0 r
F
.65619 .44719 m .68551 .43677 L .65309 .469 L F
.7912 .33487 m .80773 .36774 L .77487 .37831 L .798 .438 0 r
F
.7912 .33487 m .82707 .31869 L .80773 .36774 L F
.40079 .80165 m .38553 .82008 L .3127 .7626 L 0 .632 .36 r
F
.47393 .84602 m .38553 .82008 L .40079 .80165 L 0 .628 .145 r
F
.62799 .90487 m .55311 .90373 L .55106 .88051 L .187 .62 0 r
F
.62799 .90487 m .63895 .92924 L .55311 .90373 L F
.47306 .57191 m .40949 .59626 L .42907 .58916 L 0 .871 .245 r
F
.48451 .5661 m .47306 .57191 L .42907 .58916 L 0 .819 .219 r
F
.47242 .57211 m .48451 .5661 L .44904 .58258 L 0 0 0 r
F
.49487 .56094 m .47306 .57191 L .48451 .5661 L 0 .909 .035 r
F
.49622 .56147 m .48451 .5661 L .47242 .57211 L 0 0 0 r
F
.52271 .54693 m .49487 .56094 L .48451 .5661 L 0 .909 .035 r
F
.40949 .59626 m .33726 .61719 L .36397 .61011 L 0 .828 .448 r
F
.42907 .58916 m .40949 .59626 L .36397 .61011 L 0 .779 .406 r
F
.55453 .5252 m .56127 .52507 L .52271 .54693 L .122 .938 0 r
F
.58231 .50457 m .56127 .52507 L .55453 .5252 L .326 .982 0 r
F
.58231 .50457 m .59785 .50079 L .56127 .52507 L F
.75514 .35243 m .77487 .37831 L .74164 .39022 L .807 .441 0 r
F
.75514 .35243 m .7912 .33487 L .77487 .37831 L F
.31094 .62439 m .23043 .63903 L .2628 .63294 L 0 .813 .681 r
F
.33726 .61719 m .31094 .62439 L .2628 .63294 L 0 .781 .641 r
F
.60679 .48281 m .59785 .50079 L .58231 .50457 L .562 .987 0 r
F
.60679 .48281 m .63018 .47457 L .59785 .50079 L F
.48085 .82382 m .47393 .84602 L .40079 .80165 L 0 .621 .144 r
F
.54896 .85617 m .47393 .84602 L .48085 .82382 L .049 .617 0 r
F
.54896 .85617 m .55106 .88051 L .47393 .84602 L F
.67405 .41969 m .68551 .43677 L .65619 .44719 L .826 .701 0 r
F
.67405 .41969 m .70805 .40383 L .68551 .43677 L F
.33574 .74794 m .3127 .7626 L .25301 .69572 L 0 .637 .57 r
F
.40079 .80165 m .3127 .7626 L .33574 .74794 L 0 .632 .36 r
F
.52522 .54424 m .52271 .54693 L .48451 .5661 L 0 .848 .03 r
F
.50704 .55554 m .52522 .54424 L .49622 .56147 L 0 0 0 r
F
.54093 .53448 m .52271 .54693 L .52522 .54424 L .122 .938 0 r
F
.52779 .54416 m .52522 .54424 L .50704 .55554 L 0 0 0 r
F
.55453 .5252 m .54093 .53448 L .52522 .54424 L .122 .938 0 r
F
.41634 .7825 m .40079 .80165 L .33574 .74794 L 0 .626 .357 r
F
.48085 .82382 m .40079 .80165 L .41634 .7825 L 0 .621 .144 r
F
.61683 .87928 m .55106 .88051 L .54896 .85617 L .186 .613 0 r
F
.61683 .87928 m .62799 .90487 L .55106 .88051 L F
.62635 .46058 m .63018 .47457 L .60679 .48281 L .805 .966 0 r
F
.62635 .46058 m .65619 .44719 L .63018 .47457 L F
.70046 .91909 m .63895 .92924 L .62799 .90487 L .311 .617 0 r
F
.70046 .91909 m .72007 .94382 L .63895 .92924 L F
.71886 .37174 m .74164 .39022 L .70805 .40383 L .817 .445 0 r
F
.71886 .37174 m .75514 .35243 L .74164 .39022 L F
.33726 .61719 m .2628 .63294 L .29547 .62684 L 0 .781 .641 r
F
.36397 .61011 m .33726 .61719 L .29547 .62684 L 0 .733 .586 r
F
.42907 .58916 m .36397 .61011 L .39109 .60321 L 0 .779 .406 r
F
.44904 .58258 m .42907 .58916 L .39109 .60321 L 0 0 0 r
F
.48451 .5661 m .42907 .58916 L .44904 .58258 L 0 .819 .219 r
F
.52522 .54424 m .48451 .5661 L .49622 .56147 L 0 .848 .03 r
F
.48791 .80053 m .48085 .82382 L .41634 .7825 L 0 .614 .143 r
F
.54683 .83055 m .48085 .82382 L .48791 .80053 L .048 .609 0 r
F
.54683 .83055 m .54896 .85617 L .48085 .82382 L F
.33574 .74794 m .25301 .69572 L .28274 .68581 L 0 .637 .57 r
F
.35913 .7328 m .33574 .74794 L .28274 .68581 L 0 .631 .567 r
F
.41634 .7825 m .33574 .74794 L .35913 .7328 L 0 .626 .357 r
F
.63963 .4387 m .65619 .44719 L .62635 .46058 L .843 .714 0 r
F
.63963 .4387 m .67405 .41969 L .65619 .44719 L F
.43216 .76252 m .41634 .7825 L .35913 .7328 L 0 .619 .355 r
F
.48791 .80053 m .41634 .7825 L .43216 .76252 L 0 .614 .143 r
F
.82622 .27178 m .86275 .30364 L .82707 .31869 L .79 .211 0 r
F
.82622 .27178 m .86274 .2508 L .86275 .30364 L F
.68236 .39334 m .70805 .40383 L .67405 .41969 L .831 .45 0 r
F
.68236 .39334 m .71886 .37174 L .70805 .40383 L F
.60547 .85227 m .54896 .85617 L .54683 .83055 L .185 .604 0 r
F
.60547 .85227 m .61683 .87928 L .54896 .85617 L F
.68055 .89309 m .62799 .90487 L .61683 .87928 L .309 .608 0 r
F
.68055 .89309 m .70046 .91909 L .62799 .90487 L F
.54761 .52851 m .55453 .5252 L .52522 .54424 L .098 .855 0 r
F
.56639 .5121 m .55453 .5252 L .54761 .52851 L .297 .955 0 r
F
.56639 .5121 m .58231 .50457 L .55453 .5252 L F
.58287 .4953 m .58231 .50457 L .56639 .5121 L .551 .996 0 r
F
.58287 .4953 m .60679 .48281 L .58231 .50457 L F
.36397 .61011 m .29547 .62684 L .32845 .62071 L 0 .733 .586 r
F
.39109 .60321 m .36397 .61011 L .32845 .62071 L 0 0 0 r
F
.78972 .29383 m .82707 .31869 L .7912 .33487 L .797 .212 0 r
F
.78972 .29383 m .82622 .27178 L .82707 .31869 L F
.54761 .52851 m .52522 .54424 L .52779 .54416 L .098 .855 0 r
F
.59596 .47861 m .60679 .48281 L .58287 .4953 L .816 .988 0 r
F
.59596 .47861 m .62635 .46058 L .60679 .48281 L F
.2628 .63294 m .23043 .63903 L .22218 .63985 L 0 .686 .776 r
F
.2628 .63294 m .22218 .63985 L .22488 .63934 L F
.2628 .63294 m .22143 .63992 L .23001 .63831 L F
.2468 .6352 m .21065 .62088 L .2547 .63373 L 0 .642 .778 r
F
.23001 .63831 m .22886 .63728 L .2468 .6352 L F
.22886 .63728 m .21065 .62088 L .2468 .6352 L F
.2468 .6352 m .23001 .63831 L .24585 .63533 L 0 .686 .776 r
F
.2628 .63294 m .23001 .63831 L .2468 .6352 L F
.2628 .63294 m .24725 .63513 L .25498 .63424 L F
.24725 .63513 m .2468 .6352 L .25498 .63424 L F
.31281 .67567 m .28274 .68581 L .25498 .63424 L 0 .637 .773 r
F
.29547 .62684 m .2628 .63294 L .25571 .63412 L 0 .644 .714 r
F
.29547 .62684 m .25571 .63412 L .25877 .63355 L F
.29547 .62684 m .25498 .63424 L .26369 .63261 L F
.28062 .62946 m .24552 .61669 L .28852 .62799 L 0 .637 .773 r
F
.26369 .63261 m .26248 .63155 L .28062 .62946 L F
.26248 .63155 m .24552 .61669 L .28062 .62946 L F
.29547 .62684 m .26369 .63261 L .28062 .62946 L 0 .644 .714 r
F
.29547 .62684 m .28109 .62938 L .28879 .62852 L F
.28109 .62938 m .28062 .62946 L .28879 .62852 L F
.34322 .66528 m .31281 .67567 L .28879 .62852 L 0 .631 .768 r
F
.34322 .66528 m .28879 .62852 L .28923 .62847 L F
.31281 .67567 m .26369 .63261 L .28852 .62799 L 0 .637 .773 r
F
.28928 .62948 m .26833 .63368 L .29003 .63095 L 0 0 0 r
F
.32845 .62071 m .29547 .62684 L .2895 .62834 L F
.29302 .62769 m .2895 .62834 L .28879 .62852 L F
.32845 .62071 m .2895 .62834 L .29302 .62769 L F
.32845 .62071 m .28879 .62852 L .29767 .62687 L F
.32845 .62071 m .31522 .62357 L .32287 .62275 L F
.34322 .66528 m .29829 .62739 L .31509 .62422 L 0 .631 .768 r
F
.34322 .66528 m .31472 .62368 L .32287 .62275 L F
.37399 .65459 m .34322 .66528 L .32287 .62275 L 0 .624 .761 r
F
.37399 .65459 m .32287 .62275 L .32339 .6227 L F
.36175 .61459 m .32845 .62071 L .32356 .6225 L 0 0 0 r
F
.3277 .62174 m .32356 .6225 L .32287 .62275 L F
.36175 .61459 m .32356 .6225 L .3277 .62174 L F
.34975 .61768 m .32287 .62275 L .33195 .62108 L F
.36175 .61459 m .34967 .6177 L .35722 .61694 L F
.37399 .65459 m .33263 .62162 L .34952 .6184 L 0 .624 .761 r
F
.37399 .65459 m .34913 .61784 L .35722 .61694 L F
.4051 .64355 m .37399 .65459 L .35722 .61694 L 0 .615 .754 r
F
.4051 .64355 m .35722 .61694 L .35787 .61687 L F
.39537 .60849 m .36175 .61459 L .35789 .61659 L 0 0 0 r
F
.36287 .61568 m .35789 .61659 L .35722 .61694 L F
.39537 .60849 m .35789 .61659 L .36287 .61568 L F
.38456 .61173 m .35722 .61694 L .36657 .61524 L F
.39537 .60849 m .38445 .61176 L .39184 .61107 L F
.4051 .64355 m .36733 .61579 L .38427 .61253 L 0 .615 .754 r
F
.4051 .64355 m .38387 .61194 L .39184 .61107 L F
.43658 .63206 m .4051 .64355 L .39184 .61107 L 0 .605 .744 r
F
.43658 .63206 m .39184 .61107 L .3927 .61099 L F
.42931 .60244 m .39537 .60849 L .39248 .6106 L 0 0 0 r
F
.39871 .60949 m .39248 .6106 L .39184 .61107 L F
.42931 .60244 m .39248 .6106 L .39871 .60949 L F
.4198 .60569 m .39184 .61107 L .40157 .60933 L F
.42931 .60244 m .41964 .60574 L .42675 .60516 L F
.46359 .5965 m .42931 .60244 L .42675 .60516 L F
.43658 .63206 m .40247 .60991 L .41941 .6066 L 0 .605 .744 r
F
.43658 .63206 m .41898 .60597 L .42675 .60516 L F
.46841 .61992 m .43658 .63206 L .42675 .60516 L 0 .592 .732 r
F
.45563 .59951 m .42675 .60516 L .43711 .60335 L 0 0 0 r
F
.4982 .59083 m .46359 .5965 L .46193 .5992 L 0 .011 .141 r
F
.46841 .61992 m .43825 .60395 L .45506 .60058 L 0 .592 .732 r
F
.46841 .61992 m .45459 .5999 L .46193 .5992 L F
.50061 .60664 m .46841 .61992 L .46193 .5992 L 0 .574 .715 r
F
.49264 .59305 m .46193 .5992 L .4738 .59719 L 0 .011 .141 r
F
.50061 .60664 m .4746 .59748 L .49157 .59429 L 0 .574 .715 r
F
.50061 .60664 m .49111 .59367 L .4974 .5932 L F
.53316 .58713 m .50061 .60664 L .4974 .5932 L 0 .553 .685 r
F
.53316 .58713 m .52524 .58797 L .52312 .58884 L 0 .186 .346 r
F
.52524 .58797 m .4982 .59083 L .4974 .5932 L F
.52524 .58797 m .4974 .5932 L .49501 .6003 L F
.4982 .59083 m .49111 .59367 L .4974 .5932 L 0 .011 .141 r
F
.4982 .59083 m .46193 .5992 L .49264 .59305 L F
.50381 .58101 m .46359 .5965 L .4982 .59083 L 0 0 .069 r
F
.53316 .58713 m .50381 .58101 L .4982 .59083 L 0 .203 .284 r
F
.53316 .58713 m .4974 .5932 L .49633 .58869 L 0 .553 .685 r
F
.53316 .58713 m .52312 .58884 L .49501 .6003 L 0 .186 .346 r
F
.49157 .59429 m .4738 .59719 L .49111 .59367 L 0 .574 .715 r
F
.4746 .59748 m .4738 .59719 L .49157 .59429 L F
.4974 .5932 m .49111 .59367 L .49722 .59242 L F
.50061 .60664 m .46193 .5992 L .4738 .59719 L F
.4974 .5932 m .45695 .60736 L .49501 .6003 L 0 .011 .141 r
F
.49111 .59367 m .45695 .60736 L .4974 .5932 L F
.49111 .59367 m .4738 .59719 L .48855 .5947 L F
.49264 .59305 m .4738 .59719 L .49111 .59367 L F
.47496 .58491 m .42931 .60244 L .46359 .5965 L 0 0 0 r
F
.50381 .58101 m .47496 .58491 L .46359 .5965 L 0 0 .069 r
F
.49722 .59242 m .45975 .59224 L .49633 .58869 L 0 .574 .715 r
F
.4738 .59719 m .45975 .59224 L .49722 .59242 L F
.46359 .5965 m .45459 .5999 L .46193 .5992 L 0 0 0 r
F
.46359 .5965 m .42675 .60516 L .45563 .59951 L F
.4738 .59719 m .46193 .5992 L .45975 .59224 L 0 .574 .715 r
F
.48855 .5947 m .46193 .5992 L .45695 .60736 L 0 .011 .141 r
F
.45506 .60058 m .43711 .60335 L .45459 .5999 L 0 .592 .732 r
F
.43825 .60395 m .43711 .60335 L .45506 .60058 L F
.46193 .5992 m .45459 .5999 L .46171 .5985 L F
.46841 .61992 m .42675 .60516 L .428 .60506 L F
.46841 .61992 m .42651 .60451 L .43608 .6028 L F
.46193 .5992 m .419 .6134 L .45695 .60736 L 0 0 0 r
F
.45459 .5999 m .419 .6134 L .46193 .5992 L F
.45459 .5999 m .43711 .60335 L .45273 .60061 L F
.45563 .59951 m .43711 .60335 L .45459 .5999 L F
.44657 .59037 m .41861 .59657 L .39537 .60849 L F
.44657 .59037 m .39537 .60849 L .42931 .60244 L F
.47496 .58491 m .44657 .59037 L .42931 .60244 L F
.46171 .5985 m .42343 .5961 L .45975 .59224 L 0 .592 .732 r
F
.43711 .60335 m .42343 .5961 L .46171 .5985 L F
.42778 .60498 m .42675 .60516 L .42651 .60451 L F
.428 .60506 m .42675 .60516 L .42778 .60498 L F
.45273 .60061 m .42675 .60516 L .419 .6134 L 0 0 0 r
F
.41941 .6066 m .40157 .60933 L .41898 .60597 L 0 .605 .744 r
F
.40247 .60991 m .40157 .60933 L .41941 .6066 L F
.41964 .60574 m .41898 .60597 L .42675 .60516 L 0 0 0 r
F
.42675 .60516 m .41898 .60597 L .42651 .60451 L 0 .605 .744 r
F
.43658 .63206 m .39258 .61094 L .40157 .60933 L F
.41898 .60597 m .38116 .6189 L .42675 .60516 L 0 0 0 r
F
.41898 .60597 m .40157 .60933 L .41748 .60648 L F
.4198 .60569 m .40157 .60933 L .41898 .60597 L F
.42931 .60244 m .39184 .61107 L .4198 .60569 L F
.44904 .58258 m .39109 .60321 L .41861 .59657 L F
.41861 .59657 m .39109 .60321 L .36175 .61459 L F
.41861 .59657 m .36175 .61459 L .39537 .60849 L F
.42651 .60451 m .38737 .60011 L .42343 .5961 L 0 .605 .744 r
F
.40157 .60933 m .38737 .60011 L .42651 .60451 L F
.40157 .60933 m .39159 .61046 L .40075 .6088 L F
.39258 .61094 m .39159 .61046 L .40157 .60933 L F
.3927 .61099 m .39184 .61107 L .39159 .61046 L F
.41748 .60648 m .39184 .61107 L .38116 .6189 L 0 0 0 r
F
.42675 .60516 m .38116 .6189 L .419 .6134 L F
.43608 .6028 m .42651 .60451 L .42343 .5961 L 0 .592 .732 r
F
.38427 .61253 m .36657 .61524 L .38387 .61194 L 0 .615 .754 r
F
.36733 .61579 m .36657 .61524 L .38427 .61253 L F
.38445 .61176 m .38387 .61194 L .39184 .61107 L 0 0 0 r
F
.39184 .61107 m .38387 .61194 L .39159 .61046 L 0 .615 .754 r
F
.4051 .64355 m .3578 .61683 L .36657 .61524 L F
.38387 .61194 m .34343 .62406 L .39184 .61107 L 0 0 0 r
F
.38387 .61194 m .36657 .61524 L .38257 .61233 L F
.38456 .61173 m .36657 .61524 L .38387 .61194 L F
.39537 .60849 m .35722 .61694 L .38456 .61173 L F
.39109 .60321 m .32845 .62071 L .36175 .61459 L F
.39159 .61046 m .35154 .6042 L .38737 .60011 L 0 .615 .754 r
F
.36657 .61524 m .35154 .6042 L .39159 .61046 L F
.36657 .61524 m .35696 .61636 L .36586 .61472 L F
.3578 .61683 m .35696 .61636 L .36657 .61524 L F
.35787 .61687 m .35722 .61694 L .35696 .61636 L F
.38257 .61233 m .35722 .61694 L .34343 .62406 L 0 0 0 r
F
.39184 .61107 m .34343 .62406 L .38116 .6189 L F
.40075 .6088 m .39159 .61046 L .38737 .60011 L 0 .605 .744 r
F
.34952 .6184 m .33195 .62108 L .34913 .61784 L 0 .624 .761 r
F
.33263 .62162 m .33195 .62108 L .34952 .6184 L F
.34967 .6177 m .34913 .61784 L .35722 .61694 L 0 0 0 r
F
.35722 .61694 m .34913 .61784 L .35696 .61636 L 0 .624 .761 r
F
.37399 .65459 m .32334 .62266 L .33195 .62108 L F
.34913 .61784 m .30582 .62897 L .35722 .61694 L 0 0 0 r
F
.34913 .61784 m .33195 .62108 L .34797 .61813 L F
.34975 .61768 m .33195 .62108 L .34913 .61784 L F
.36175 .61459 m .32287 .62275 L .34975 .61768 L F
.35696 .61636 m .31597 .60834 L .35154 .6042 L 0 .624 .761 r
F
.33195 .62108 m .31597 .60834 L .35696 .61636 L F
.33195 .62108 m .3226 .6222 L .33132 .62058 L F
.32334 .62266 m .3226 .6222 L .33195 .62108 L F
.32339 .6227 m .32287 .62275 L .3226 .6222 L F
.34797 .61813 m .32287 .62275 L .30582 .62897 L 0 0 0 r
F
.35722 .61694 m .30582 .62897 L .34343 .62406 L F
.36586 .61472 m .35696 .61636 L .35154 .6042 L 0 .615 .754 r
F
.31509 .62422 m .29767 .62687 L .31472 .62368 L 0 .631 .768 r
F
.29829 .62739 m .29767 .62687 L .31509 .62422 L F
.31522 .62357 m .31472 .62368 L .32287 .62275 L 0 0 0 r
F
.32287 .62275 m .31472 .62368 L .3226 .6222 L 0 .631 .768 r
F
.34322 .66528 m .28852 .62799 L .29709 .62639 L F
.31472 .62368 m .31365 .62391 L .32287 .62275 L 0 0 0 r
F
.31365 .62391 m .26833 .63368 L .32107 .62311 L F
.31365 .62391 m .32107 .62311 L .32287 .62275 L F
.31472 .62368 m .29767 .62687 L .31365 .62391 L F
.32845 .62071 m .29767 .62687 L .31472 .62368 L F
.3226 .6222 m .28063 .6125 L .31597 .60834 L 0 .631 .768 r
F
.29767 .62687 m .28063 .6125 L .3226 .6222 L F
.28928 .62948 m .29003 .63095 L .30582 .62897 L 0 0 0 r
F
.32287 .62275 m .28928 .62948 L .30582 .62897 L F
.33132 .62058 m .3226 .6222 L .31597 .60834 L 0 .624 .761 r
F
.28923 .62847 m .28879 .62852 L .28919 .62845 L 0 .631 .768 r
F
.31365 .62391 m .28879 .62852 L .26833 .63368 L 0 0 0 r
F
.28919 .62845 m .28879 .62852 L .28852 .62799 L 0 .631 .768 r
F
.25877 .63355 m .25571 .63412 L .25498 .63424 L 0 .644 .714 r
F
.25532 .63418 m .25498 .63424 L .2547 .63373 L 0 .637 .773 r
F
.25498 .63424 m .23001 .63831 L .2547 .63373 L 0 .642 .778 r
F
.28274 .68581 m .23055 .6388 L .25498 .63424 L F
.23055 .6388 m .23001 .63831 L .25498 .63424 L F
.23001 .63831 m .22143 .63992 L .22048 .63825 L F
.23001 .63831 m .22048 .63825 L .22886 .63728 L F
.24585 .63533 m .24217 .63602 L .19371 .64267 L 0 .686 .776 r
F
.22938 .63843 m .22143 .63992 L .19371 .64267 L F
.22488 .63934 m .22218 .63985 L .22143 .63992 L F
.28274 .68581 m .22143 .63992 L .23001 .63831 L 0 .642 .778 r
F
.24159 .6361 m .19371 .64267 L .23096 .63824 L 0 .686 .776 r
F
.25339 .63446 m .19371 .64267 L .25428 .63436 L F
.2468 .6352 m .19371 .64267 L .25498 .63424 L F
.28274 .68581 m .25301 .69572 L .22143 .63992 L 0 .642 .778 r
F
.23096 .63824 m .19371 .64267 L .17903 .64424 L 0 .439 .707 r
F
.23096 .63824 m .17903 .64424 L .21095 .64227 L F
.23096 .63824 m .21095 .64227 L .21899 .64177 L F
.25428 .63436 m .24159 .6361 L .23096 .63824 L 0 .686 .776 r
F
.25498 .63424 m .25339 .63446 L .25428 .63436 L F
.22886 .63728 m .22048 .63825 L .21065 .62088 L 0 .642 .778 r
F
.31281 .67567 m .2547 .63373 L .26315 .63214 L 0 .637 .773 r
F
.27961 .62964 m .25498 .63424 L .23096 .63824 L 0 .644 .714 r
F
.25535 .6342 m .25498 .63424 L .25532 .63418 L 0 .637 .773 r
F
.31281 .67567 m .25498 .63424 L .25535 .6342 L F
.28879 .62852 m .23096 .63824 L .26833 .63368 L 0 .644 .714 r
F
.28062 .62946 m .26369 .63261 L .27961 .62964 L F
.28062 .62946 m .23096 .63824 L .28879 .62852 L F
.28852 .62799 m .24552 .61669 L .28063 .6125 L 0 .637 .773 r
F
.29709 .62639 m .28852 .62799 L .28063 .6125 L 0 .631 .768 r
F
.2547 .63373 m .21065 .62088 L .24552 .61669 L 0 .642 .778 r
F
.26315 .63214 m .2547 .63373 L .24552 .61669 L 0 .637 .773 r
F
.35913 .7328 m .28274 .68581 L .31281 .67567 L 0 .631 .567 r
F
.38289 .71712 m .35913 .7328 L .31281 .67567 L 0 .625 .563 r
F
.43216 .76252 m .35913 .7328 L .38289 .71712 L 0 .619 .355 r
F
.46941 .5768 m .44904 .58258 L .41861 .59657 L 0 0 0 r
F
.49622 .56147 m .44904 .58258 L .46941 .5768 L F
.75324 .31722 m .7912 .33487 L .75514 .35243 L .805 .213 0 r
F
.75324 .31722 m .78972 .29383 L .7912 .33487 L F
.49511 .77596 m .48791 .80053 L .43216 .76252 L 0 .605 .142 r
F
.54465 .8034 m .48791 .80053 L .49511 .77596 L .048 .599 0 r
F
.54465 .8034 m .54683 .83055 L .48791 .80053 L F
.64561 .41819 m .67405 .41969 L .63963 .4387 L .848 .456 0 r
F
.64561 .41819 m .68236 .39334 L .67405 .41969 L F
.44826 .74155 m .43216 .76252 L .38289 .71712 L 0 .611 .352 r
F
.49511 .77596 m .43216 .76252 L .44826 .74155 L 0 .605 .142 r
F
.60474 .46265 m .62635 .46058 L .59596 .47861 L .866 .73 0 r
F
.60474 .46265 m .63963 .4387 L .62635 .46058 L F
.76411 .92334 m .72007 .94382 L .70046 .91909 L .416 .613 0 r
F
.76411 .92334 m .79172 .94765 L .72007 .94382 L F
.50822 .55882 m .49622 .56147 L .46941 .5768 L 0 0 0 r
F
.52779 .54416 m .49622 .56147 L .50822 .55882 L F
.66035 .8656 m .61683 .87928 L .60547 .85227 L .306 .598 0 r
F
.66035 .8656 m .68055 .89309 L .61683 .87928 L F
.71675 .3423 m .75514 .35243 L .71886 .37174 L .815 .215 0 r
F
.71675 .3423 m .75324 .31722 L .75514 .35243 L F
.59391 .82355 m .54683 .83055 L .54465 .8034 L .184 .593 0 r
F
.59391 .82355 m .60547 .85227 L .54683 .83055 L F
.38289 .71712 m .31281 .67567 L .34322 .66528 L 0 .625 .563 r
F
.407 .70079 m .38289 .71712 L .34322 .66528 L 0 .617 .558 r
F
.44826 .74155 m .38289 .71712 L .407 .70079 L 0 .611 .352 r
F
.68024 .36964 m .71886 .37174 L .68236 .39334 L .827 .216 0 r
F
.68024 .36964 m .71675 .3423 L .71886 .37174 L F
.55003 .52701 m .56639 .5121 L .54761 .52851 L 0 0 0 r
F
.55837 .51607 m .56639 .5121 L .55189 .52531 L .478 .935 0 r
F
.55837 .51607 m .58287 .4953 L .56639 .5121 L F
.56495 .50565 m .58287 .4953 L .56108 .51378 L .803 .996 0 r
F
.56495 .50565 m .56108 .51378 L .55837 .51607 L F
.56495 .50565 m .59596 .47861 L .58287 .4953 L F
.56931 .49611 m .59596 .47861 L .56829 .50274 L .893 .751 0 r
F
.56931 .49611 m .56829 .50274 L .56495 .50565 L F
.53316 .58713 m .56837 .49848 L .56495 .50565 L 0 0 0 r
F
.56837 .49848 m .56931 .49611 L .56495 .50565 L F
.53316 .58713 m .56405 .50797 L .55837 .51607 L F
.56405 .50797 m .56495 .50565 L .55837 .51607 L F
.53316 .58713 m .57022 .49023 L .56931 .49611 L .909 .461 0 r
F
.57022 .49023 m .57114 .48784 L .56931 .49611 L F
.55837 .51607 m .55189 .52531 L .55003 .52701 L .478 .935 0 r
F
.60855 .44812 m .63963 .4387 L .60474 .46265 L .872 .464 0 r
F
.60855 .44812 m .64561 .41819 L .63963 .4387 L F
.5405 .53817 m .54761 .52851 L .52779 .54416 L 0 0 0 r
F
.55003 .52701 m .54761 .52851 L .5405 .53817 L F
.7362 .89776 m .70046 .91909 L .68055 .89309 L .411 .604 0 r
F
.7362 .89776 m .76411 .92334 L .70046 .91909 L F
.50244 .7498 m .49511 .77596 L .44826 .74155 L 0 .594 .141 r
F
.54244 .77436 m .49511 .77596 L .50244 .7498 L .048 .587 0 r
F
.54244 .77436 m .54465 .8034 L .49511 .77596 L F
.46466 .71938 m .44826 .74155 L .407 .70079 L 0 .601 .348 r
F
.50244 .7498 m .44826 .74155 L .46466 .71938 L 0 .594 .141 r
F
.46941 .5768 m .41861 .59657 L .44657 .59037 L 0 0 0 r
F
.4902 .5724 m .46941 .5768 L .44657 .59037 L F
.50822 .55882 m .46941 .5768 L .4902 .5724 L F
.53044 .5493 m .52779 .54416 L .50822 .55882 L F
.5405 .53817 m .52779 .54416 L .53044 .5493 L F
.63984 .8363 m .60547 .85227 L .59391 .82355 L .302 .586 0 r
F
.63984 .8363 m .66035 .8656 L .60547 .85227 L F
.64369 .40018 m .68236 .39334 L .64561 .41819 L .843 .218 0 r
F
.64369 .40018 m .68024 .36964 L .68236 .39334 L F
.58214 .79271 m .54465 .8034 L .54244 .77436 L .182 .58 0 r
F
.58214 .79271 m .59391 .82355 L .54465 .8034 L F
.56931 .49611 m .60474 .46265 L .59596 .47861 L .893 .751 0 r
F
.407 .70079 m .34322 .66528 L .37399 .65459 L 0 .617 .558 r
F
.43149 .68368 m .407 .70079 L .37399 .65459 L 0 .608 .552 r
F
.46466 .71938 m .407 .70079 L .43149 .68368 L 0 .601 .348 r
F
.52052 .56022 m .50822 .55882 L .4902 .5724 L 0 0 0 r
F
.53044 .5493 m .50822 .55882 L .52052 .56022 L F
.24552 .61669 m .21065 .62088 L .18936 .54025 L 0 .524 .826 r
F
.70798 .87068 m .68055 .89309 L .66035 .8656 L .406 .592 0 r
F
.70798 .87068 m .7362 .89776 L .68055 .89309 L F
.60706 .43579 m .64561 .41819 L .60855 .44812 L .865 .22 0 r
F
.60706 .43579 m .64369 .40018 L .64561 .41819 L F
.57114 .48784 m .60474 .46265 L .56931 .49611 L .91 .475 0 r
F
.57114 .48784 m .60855 .44812 L .60474 .46265 L F
.48135 .69564 m .46466 .71938 L .43149 .68368 L 0 .589 .343 r
F
.50991 .72157 m .46466 .71938 L .48135 .69564 L 0 .581 .139 r
F
.50991 .72157 m .50244 .7498 L .46466 .71938 L F
.54018 .74281 m .50244 .7498 L .50991 .72157 L .048 .572 0 r
F
.54018 .74281 m .54244 .77436 L .50244 .7498 L F
.24552 .61669 m .18936 .54025 L .22731 .54267 L 0 .524 .826 r
F
.28063 .6125 m .24552 .61669 L .22731 .54267 L 0 .52 .821 r
F
.80386 .23029 m .86274 .2508 L .82622 .27178 L .787 0 0 r
F
.80386 .23029 m .83846 .20347 L .86274 .2508 L F
.76947 .25806 m .82622 .27178 L .78972 .29383 L .793 0 0 r
F
.76947 .25806 m .80386 .23029 L .82622 .27178 L F
.61904 .80473 m .59391 .82355 L .58214 .79271 L .298 .571 0 r
F
.61904 .80473 m .63984 .8363 L .59391 .82355 L F
.73529 .28702 m .78972 .29383 L .75324 .31722 L .8 0 0 r
F
.73529 .28702 m .76947 .25806 L .78972 .29383 L F
.4902 .5724 m .44657 .59037 L .47496 .58491 L 0 0 0 r
F
.43149 .68368 m .37399 .65459 L .4051 .64355 L 0 .608 .552 r
F
.7013 .31753 m .75324 .31722 L .71675 .3423 L .809 0 0 r
F
.7013 .31753 m .73529 .28702 L .75324 .31722 L F
.51144 .57081 m .4902 .5724 L .47496 .58491 L 0 0 .01 r
F
.52052 .56022 m .4902 .5724 L .51144 .57081 L 0 0 0 r
F
.45635 .66556 m .43149 .68368 L .4051 .64355 L 0 .597 .545 r
F
.48135 .69564 m .43149 .68368 L .45635 .66556 L 0 .589 .343 r
F
.57018 .75903 m .54244 .77436 L .54018 .74281 L .18 .563 0 r
F
.57018 .75903 m .58214 .79271 L .54244 .77436 L F
.66748 .35017 m .71675 .3423 L .68024 .36964 L .819 0 0 r
F
.66748 .35017 m .7013 .31753 L .71675 .3423 L F
.28063 .6125 m .22731 .54267 L .26532 .54527 L 0 .52 .821 r
F
.31597 .60834 m .28063 .6125 L .26532 .54527 L 0 .516 .815 r
F
.57028 .48123 m .60855 .44812 L .57114 .48784 L .899 .223 0 r
F
.57028 .48123 m .60706 .43579 L .60855 .44812 L F
.67947 .84176 m .66035 .8656 L .63984 .8363 L .399 .579 0 r
F
.67947 .84176 m .70798 .87068 L .66035 .8656 L F
.63382 .38585 m .68024 .36964 L .64369 .40018 L .833 0 0 r
F
.63382 .38585 m .66748 .35017 L .68024 .36964 L F
.53316 .58713 m .55003 .52701 L .5405 .53817 L .171 .102 0 r
F
.53316 .58713 m .55837 .51607 L .55003 .52701 L .159 0 0 r
F
.81458 .91802 m .79172 .94765 L .76411 .92334 L .448 .544 0 r
F
.81458 .91802 m .84907 .94112 L .79172 .94765 L F
.53316 .58713 m .5405 .53817 L .53044 .5493 L .096 .173 0 r
F
.60027 .42643 m .64369 .40018 L .60706 .43579 L .851 0 0 r
F
.60027 .42643 m .63382 .38585 L .64369 .40018 L F
.31597 .60834 m .26532 .54527 L .30338 .54811 L 0 .516 .815 r
F
.35154 .6042 m .31597 .60834 L .30338 .54811 L 0 .51 .808 r
F
.45635 .66556 m .4051 .64355 L .43658 .63206 L 0 .597 .545 r
F
.53316 .58713 m .53044 .5493 L .52052 .56022 L 0 .209 .017 r
F
.49834 .66963 m .48135 .69564 L .45635 .66556 L 0 .574 .337 r
F
.51753 .69033 m .48135 .69564 L .49834 .66963 L 0 .564 .136 r
F
.51753 .69033 m .50991 .72157 L .48135 .69564 L F
.59795 .77009 m .58214 .79271 L .57018 .75903 L .293 .552 0 r
F
.59795 .77009 m .61904 .80473 L .58214 .79271 L F
.53788 .70761 m .50991 .72157 L .51753 .69033 L .047 .553 0 r
F
.53788 .70761 m .54018 .74281 L .50991 .72157 L F
.56677 .47668 m .60706 .43579 L .57028 .48123 L .878 0 0 r
F
.56677 .47668 m .60027 .42643 L .60706 .43579 L F
.51144 .57081 m .47496 .58491 L .50381 .58101 L 0 0 .01 r
F
.48158 .64596 m .45635 .66556 L .43658 .63206 L 0 .583 .536 r
F
.49834 .66963 m .45635 .66556 L .48158 .64596 L 0 .574 .337 r
F
.53316 .58713 m .52052 .56022 L .51144 .57081 L 0 .221 .116 r
F
.35154 .6042 m .30338 .54811 L .3415 .55125 L 0 .51 .808 r
F
.38737 .60011 m .35154 .6042 L .3415 .55125 L 0 .504 .8 r
F
.7799 .8937 m .76411 .92334 L .7362 .89776 L .44 .534 0 r
F
.7799 .8937 m .81458 .91802 L .76411 .92334 L F
.65068 .8105 m .63984 .8363 L .61904 .80473 L .39 .562 0 r
F
.65068 .8105 m .67947 .84176 L .63984 .8363 L F
.53316 .58713 m .57028 .48123 L .57114 .48784 L .985 .227 0 r
F
.55801 .72117 m .54018 .74281 L .53788 .70761 L .178 .541 0 r
F
.55801 .72117 m .57018 .75903 L .54018 .74281 L F
.48158 .64596 m .43658 .63206 L .46841 .61992 L 0 .583 .536 r
F
.53316 .58713 m .56677 .47668 L .57028 .48123 L .944 0 0 r
F
.53316 .58713 m .51144 .57081 L .50381 .58101 L 0 .216 .205 r
F
.38737 .60011 m .3415 .55125 L .37968 .55478 L 0 .504 .8 r
F
.42343 .5961 m .38737 .60011 L .37968 .55478 L 0 .496 .79 r
F
.58858 .42078 m .63382 .38585 L .60027 .42643 L .834 0 .205 r
F
.56085 .47452 m .60027 .42643 L .56677 .47668 L .854 0 .198 r
F
.56085 .47452 m .58858 .42078 L .60027 .42643 L F
.61651 .37634 m .66748 .35017 L .63382 .38585 L .819 0 .209 r
F
.58858 .42078 m .61651 .37634 L .63382 .38585 L .834 0 .205 r
F
.74504 .86791 m .7362 .89776 L .70798 .87068 L .431 .523 0 r
F
.74504 .86791 m .7799 .8937 L .7362 .89776 L F
.64467 .33651 m .7013 .31753 L .66748 .35017 L .808 0 .212 r
F
.61651 .37634 m .64467 .33651 L .66748 .35017 L .819 0 .209 r
F
.57658 .73088 m .57018 .75903 L .55801 .72117 L .287 .527 0 r
F
.57658 .73088 m .59795 .77009 L .57018 .75903 L F
.51561 .63958 m .49834 .66963 L .48158 .64596 L 0 .553 .328 r
F
.52528 .6537 m .49834 .66963 L .51561 .63958 L 0 .541 .132 r
F
.52528 .6537 m .51753 .69033 L .49834 .66963 L F
.53316 .58713 m .56085 .47452 L .56677 .47668 L .893 0 .175 r
F
.22731 .54267 m .18936 .54025 L .19199 .45687 L 0 .363 .822 r
F
.5072 .62376 m .48158 .64596 L .46841 .61992 L 0 .564 .522 r
F
.51561 .63958 m .48158 .64596 L .5072 .62376 L 0 .553 .328 r
F
.62161 .77603 m .61904 .80473 L .59795 .77009 L .379 .539 0 r
F
.62161 .77603 m .65068 .8105 L .61904 .80473 L F
.42343 .5961 m .37968 .55478 L .41792 .55886 L 0 .496 .79 r
F
.45975 .59224 m .42343 .5961 L .41792 .55886 L 0 .486 .777 r
F
.6731 .29949 m .73529 .28702 L .7013 .31753 L .799 0 .214 r
F
.64467 .33651 m .6731 .29949 L .7013 .31753 L .808 0 .212 r
F
.53553 .66582 m .51753 .69033 L .52528 .6537 L .047 .527 0 r
F
.53553 .66582 m .53788 .70761 L .51753 .69033 L F
.22731 .54267 m .19199 .45687 L .23047 .46655 L 0 .363 .822 r
F
.26532 .54527 m .22731 .54267 L .23047 .46655 L 0 .36 .817 r
F
.26833 .63368 m .23096 .63824 L .21899 .64177 L 0 0 0 r
F
.5072 .62376 m .46841 .61992 L .50061 .60664 L 0 .564 .522 r
F
.26532 .54527 m .23047 .46655 L .26878 .47653 L 0 .36 .817 r
F
.30338 .54811 m .26532 .54527 L .26878 .47653 L 0 .357 .811 r
F
.70183 .26437 m .76947 .25806 L .73529 .28702 L .792 0 .216 r
F
.6731 .29949 m .70183 .26437 L .73529 .28702 L .799 0 .214 r
F
.30338 .54811 m .26878 .47653 L .30695 .48689 L 0 .357 .811 r
F
.3415 .55125 m .30338 .54811 L .30695 .48689 L 0 .354 .804 r
F
.55291 .47502 m .58858 .42078 L .56085 .47452 L .83 0 .392 r
F
.53316 .58713 m .55291 .47502 L .56085 .47452 L .847 0 .352 r
F
.70999 .84029 m .70798 .87068 L .67947 .84176 L .419 .509 0 r
F
.70999 .84029 m .74504 .86791 L .70798 .87068 L F
.54566 .67571 m .53788 .70761 L .53553 .66582 L .176 .511 0 r
F
.54566 .67571 m .55801 .72117 L .53788 .70761 L F
.26833 .63368 m .21899 .64177 L .25881 .63903 L 0 0 0 r
F
.30582 .62897 m .26833 .63368 L .25881 .63903 L F
.3415 .55125 m .30695 .48689 L .34496 .49773 L 0 .354 .804 r
F
.37968 .55478 m .3415 .55125 L .34496 .49773 L 0 .35 .796 r
F
.57279 .41944 m .61651 .37634 L .58858 .42078 L .815 0 .405 r
F
.55291 .47502 m .57279 .41944 L .58858 .42078 L .83 0 .392 r
F
.45975 .59224 m .41792 .55886 L .45624 .5638 L 0 .486 .777 r
F
.49633 .58869 m .45975 .59224 L .45624 .5638 L 0 .472 .759 r
F
.73087 .2306 m .80386 .23029 L .76947 .25806 L .786 0 .217 r
F
.70183 .26437 m .73087 .2306 L .76947 .25806 L .792 0 .216 r
F
.37968 .55478 m .34496 .49773 L .38283 .50922 L 0 .35 .796 r
F
.41792 .55886 m .37968 .55478 L .38283 .50922 L 0 .345 .787 r
F
.30582 .62897 m .25881 .63903 L .29848 .63598 L 0 0 0 r
F
.34343 .62406 m .30582 .62897 L .29848 .63598 L F
.54353 .47836 m .57279 .41944 L .55291 .47502 L .807 0 .582 r
F
.53316 .58713 m .54353 .47836 L .55291 .47502 L .809 0 .528 r
F
.41792 .55886 m .38283 .50922 L .42057 .52165 L 0 .345 .787 r
F
.45624 .5638 m .41792 .55886 L .42057 .52165 L 0 .338 .774 r
F
.34343 .62406 m .29848 .63598 L .33801 .63251 L 0 0 0 r
F
.38116 .6189 m .34343 .62406 L .33801 .63251 L F
.59288 .37262 m .64467 .33651 L .61651 .37634 L .804 0 .413 r
F
.57279 .41944 m .59288 .37262 L .61651 .37634 L .815 0 .405 r
F
.59229 .73673 m .59795 .77009 L .57658 .73088 L .364 .509 0 r
F
.59229 .73673 m .62161 .77603 L .59795 .77009 L F
.55495 .68324 m .55801 .72117 L .54566 .67571 L .28 .49 0 r
F
.55495 .68324 m .57658 .73088 L .55801 .72117 L F
.76023 .19783 m .83846 .20347 L .80386 .23029 L .78 0 .218 r
F
.73087 .2306 m .76023 .19783 L .80386 .23029 L .786 0 .217 r
F
.45624 .5638 m .42057 .52165 L .45818 .53556 L 0 .338 .774 r
F
.49464 .57041 m .45624 .5638 L .45818 .53556 L 0 .328 .756 r
F
.49633 .58869 m .45624 .5638 L .49464 .57041 L 0 .472 .759 r
F
.53316 .58713 m .5072 .62376 L .50061 .60664 L 0 .549 .496 r
F
.53316 .58713 m .51561 .63958 L .5072 .62376 L 0 .539 .308 r
F
.54353 .47836 m .554 .42284 L .57279 .41944 L .807 0 .582 r
F
.53337 .4846 m .554 .42284 L .54353 .47836 L .769 0 .754 r
F
.53316 .58713 m .53337 .4846 L .54353 .47836 L .759 0 .69 r
F
.67479 .81032 m .67947 .84176 L .65068 .8105 L .404 .491 0 r
F
.67479 .81032 m .70999 .84029 L .67947 .84176 L F
.53316 .58713 m .52528 .6537 L .51561 .63958 L 0 .523 .122 r
F
.38116 .6189 m .33801 .63251 L .37738 .6285 L 0 0 0 r
F
.419 .6134 m .38116 .6189 L .37738 .6285 L F
.53316 .58713 m .49633 .58869 L .49464 .57041 L 0 .447 .73 r
F
.554 .42284 m .59288 .37262 L .57279 .41944 L .797 0 .6 r
F
.49464 .57041 m .45818 .53556 L .4957 .55238 L 0 .328 .756 r
F
.53316 .58713 m .49464 .57041 L .4957 .55238 L 0 .304 .725 r
F
.53316 .58713 m .53553 .66582 L .52528 .6537 L .051 .5 0 r
F
.53337 .4846 m .53358 .43116 L .554 .42284 L .769 0 .754 r
F
.52317 .49366 m .53358 .43116 L .53337 .4846 L .553 0 .751 r
F
.53316 .58713 m .52317 .49366 L .53337 .4846 L .54 0 .692 r
F
.419 .6134 m .37738 .6285 L .4166 .62373 L 0 0 0 r
F
.45695 .60736 m .419 .6134 L .4166 .62373 L 0 0 .009 r
F
.4957 .55238 m .4655 .50854 L .49942 .53516 L 0 .18 .753 r
F
.4957 .55238 m .45818 .53556 L .4655 .50854 L F
.53316 .58713 m .4957 .55238 L .49942 .53516 L 0 .164 .717 r
F
.76023 .19783 m .78994 .16579 L .83846 .20347 L .78 0 .218 r
F
.61323 .33007 m .6731 .29949 L .64467 .33651 L .795 0 .418 r
F
.59288 .37262 m .61323 .33007 L .64467 .33651 L .804 0 .413 r
F
.45818 .53556 m .43133 .48592 L .4655 .50854 L 0 .185 .771 r
F
.45818 .53556 m .42057 .52165 L .43133 .48592 L F
.49942 .53516 m .47771 .48373 L .50555 .51931 L 0 .026 .751 r
F
.49942 .53516 m .4655 .50854 L .47771 .48373 L F
.53316 .58713 m .49942 .53516 L .50555 .51931 L 0 .024 .709 r
F
.52317 .49366 m .51305 .44435 L .53358 .43116 L .553 0 .751 r
F
.51366 .50534 m .51305 .44435 L .52317 .49366 L .349 0 .75 r
F
.53316 .58713 m .51366 .50534 L .52317 .49366 L .337 0 .696 r
F
.53316 .58713 m .54566 .67571 L .53553 .66582 L .192 .471 0 r
F
.45695 .60736 m .4166 .62373 L .45565 .61776 L 0 0 .009 r
F
.49501 .6003 m .45695 .60736 L .45565 .61776 L 0 .055 .185 r
F
.50555 .51931 m .49395 .46207 L .51366 .50534 L .155 0 .75 r
F
.50555 .51931 m .47771 .48373 L .49395 .46207 L F
.53316 .58713 m .50555 .51931 L .51366 .50534 L .148 0 .702 r
F
.51366 .50534 m .49395 .46207 L .51305 .44435 L .349 0 .75 r
F
.42057 .52165 m .39688 .46531 L .43133 .48592 L 0 .189 .784 r
F
.42057 .52165 m .38283 .50922 L .39688 .46531 L F
.63945 .77709 m .65068 .8105 L .62161 .77603 L .383 .467 0 r
F
.63945 .77709 m .67479 .81032 L .65068 .8105 L F
.49501 .6003 m .45565 .61776 L .49452 .60949 L 0 .055 .185 r
F
.53316 .58713 m .49501 .6003 L .49452 .60949 L 0 .147 .362 r
F
.53316 .58713 m .56852 .69116 L .56276 .68838 L .303 .266 0 r
F
.53316 .58713 m .57181 .69172 L .56852 .69116 L .063 .093 0 r
F
.57105 .68966 m .57235 .69022 L .57181 .69172 L 0 0 0 r
F
.53316 .58713 m .57235 .69022 L .57105 .68966 L F
.57158 .68818 m .57009 .68692 L .57235 .69022 L .838 .06 0 r
F
.53316 .58713 m .57009 .68692 L .57158 .68818 L F
.56516 .68209 m .56869 .68573 L .57009 .68692 L .592 0 0 r
F
.57009 .68692 m .57358 .69075 L .57235 .69022 L 0 .014 0 r
F
.57358 .69075 m .61221 .73316 L .57235 .69022 L F
.60496 .7252 m .60789 .72619 L .61221 .73316 L F
.57009 .68692 m .60789 .72619 L .60496 .7252 L F
.56869 .68573 m .60789 .72619 L .57009 .68692 L .592 0 0 r
F
.60051 .71858 m .59809 .71717 L .60789 .72619 L F
.56516 .68209 m .59809 .71717 L .60051 .71858 L F
.57181 .69172 m .61085 .73755 L .60401 .73886 L .178 .232 0 r
F
.57235 .69022 m .61085 .73755 L .57181 .69172 L 0 .101 0 r
F
.57235 .69022 m .61221 .73316 L .61085 .73755 L F
.58348 .70667 m .5959 .71589 L .59809 .71717 L .526 0 0 r
F
.59809 .71717 m .61054 .72709 L .60789 .72619 L 0 0 .083 r
F
.62969 .74234 m .63182 .74256 L .64637 .75563 L F
.59809 .71717 m .63182 .74256 L .62969 .74234 L F
.5959 .71589 m .63182 .74256 L .59809 .71717 L .526 0 0 r
F
.61054 .72709 m .64637 .75563 L .60789 .72619 L 0 0 .083 r
F
.60789 .72619 m .64637 .75563 L .65254 .76626 L 0 .039 0 r
F
.60789 .72619 m .65254 .76626 L .61221 .73316 L F
.61507 .73012 m .60979 .72789 L .63182 .74256 L .526 0 0 r
F
.58348 .70667 m .60979 .72789 L .61507 .73012 L F
.56852 .69116 m .60401 .73886 L .59229 .73673 L .316 .378 0 r
F
.57181 .69172 m .60401 .73886 L .56852 .69116 L .178 .232 0 r
F
.58188 .71249 m .60508 .7259 L .60979 .72789 L .484 0 0 r
F
.60979 .72789 m .63372 .74275 L .63182 .74256 L 0 0 .24 r
F
.63817 .74551 m .63682 .74426 L .6663 .76298 L F
.60979 .72789 m .63682 .74426 L .63817 .74551 L F
.60508 .7259 m .63682 .74426 L .60979 .72789 L .484 0 0 r
F
.58188 .71249 m .59917 .72503 L .63682 .74426 L F
.59917 .72503 m .63561 .74314 L .63682 .74426 L .351 0 0 r
F
.63561 .74314 m .66457 .75753 L .63682 .74426 L F
.63372 .74275 m .6663 .76298 L .63182 .74256 L 0 0 .24 r
F
.53316 .58713 m .56516 .68209 L .57009 .68692 L .938 0 .033 r
F
.53316 .58713 m .56276 .68838 L .55495 .68324 L .369 .38 0 r
F
.53316 .58713 m .55791 .67601 L .56516 .68209 L .9 0 .151 r
F
.53316 .58713 m .55495 .68324 L .54566 .67571 L .305 .433 0 r
F
.53316 .58713 m .54885 .66899 L .55791 .67601 L .848 0 .29 r
F
.53316 .58713 m .53865 .66127 L .54885 .66899 L .8 0 .43 r
F
.53316 .58713 m .52808 .6531 L .53865 .66127 L .645 0 .491 r
F
.53316 .58713 m .51791 .64465 L .52808 .6531 L .428 0 .49 r
F
.53316 .58713 m .50889 .63603 L .51791 .64465 L .231 0 .479 r
F
.53316 .58713 m .50168 .6273 L .50889 .63603 L .054 0 .458 r
F
.53316 .58713 m .49678 .61847 L .50168 .6273 L 0 .051 .429 r
F
.53316 .58713 m .49452 .60949 L .49678 .61847 L 0 .107 .394 r
F
.56276 .68838 m .57658 .73088 L .55495 .68324 L .346 .462 0 r
F
.56276 .68838 m .59229 .73673 L .57658 .73088 L F
.554 .42284 m .56461 .37544 L .59288 .37262 L .797 0 .6 r
F
.53358 .43116 m .56461 .37544 L .554 .42284 L .762 0 .777 r
F
.38283 .50922 m .36214 .44592 L .39688 .46531 L 0 .191 .794 r
F
.38283 .50922 m .34496 .49773 L .36214 .44592 L F
.4655 .50854 m .44955 .45314 L .47771 .48373 L 0 .027 .77 r
F
.4655 .50854 m .43133 .48592 L .44955 .45314 L F
.56461 .37544 m .61323 .33007 L .59288 .37262 L .789 0 .612 r
F
.63386 .29005 m .70183 .26437 L .6731 .29949 L .788 0 .423 r
F
.61323 .33007 m .63386 .29005 L .6731 .29949 L .795 0 .418 r
F
.34496 .49773 m .32709 .42736 L .36214 .44592 L 0 .193 .802 r
F
.34496 .49773 m .30695 .48689 L .32709 .42736 L F
.53358 .43116 m .53378 .38516 L .56461 .37544 L .762 0 .777 r
F
.51305 .44435 m .53378 .38516 L .53358 .43116 L .551 0 .773 r
F
.47771 .48373 m .47396 .42468 L .49395 .46207 L .155 0 .769 r
F
.47771 .48373 m .44955 .45314 L .47396 .42468 L F
.60401 .73886 m .62161 .77603 L .59229 .73673 L .356 .433 0 r
F
.60401 .73886 m .63945 .77709 L .62161 .77603 L F
.84767 .90382 m .84907 .94112 L .81458 .91802 L .399 .385 0 r
F
.84767 .90382 m .88731 .92491 L .84907 .94112 L F
.30695 .48689 m .29172 .40938 L .32709 .42736 L 0 .195 .808 r
F
.30695 .48689 m .26878 .47653 L .29172 .40938 L F
.49395 .46207 m .50277 .40173 L .51305 .44435 L .348 0 .77 r
F
.49395 .46207 m .47396 .42468 L .50277 .40173 L F
.51305 .44435 m .50277 .40173 L .53378 .38516 L .551 0 .773 r
F
.43133 .48592 m .42105 .42498 L .44955 .45314 L 0 .027 .783 r
F
.43133 .48592 m .39688 .46531 L .42105 .42498 L F
.49452 .60949 m .45989 .628 L .49678 .61847 L 0 .059 .219 r
F
.49452 .60949 m .45565 .61776 L .45989 .628 L F
.26878 .47653 m .25602 .39184 L .29172 .40938 L 0 .196 .814 r
F
.26878 .47653 m .23047 .46655 L .25602 .39184 L F
.80805 .88157 m .81458 .91802 L .7799 .8937 L .387 .377 0 r
F
.80805 .88157 m .84767 .90382 L .81458 .91802 L F
.56852 .69116 m .59229 .73673 L .56276 .68838 L .316 .378 0 r
F
.65479 .25167 m .73087 .2306 L .70183 .26437 L .782 0 .426 r
F
.63386 .29005 m .65479 .25167 L .70183 .26437 L .788 0 .423 r
F
.56461 .37544 m .57538 .33193 L .61323 .33007 L .789 0 .612 r
F
.53378 .38516 m .57538 .33193 L .56461 .37544 L .756 0 .792 r
F
.57538 .33193 m .63386 .29005 L .61323 .33007 L .782 0 .62 r
F
.23047 .46655 m .21998 .37462 L .25602 .39184 L 0 .198 .819 r
F
.23047 .46655 m .19199 .45687 L .21998 .37462 L F
.76847 .8579 m .7799 .8937 L .74504 .86791 L .373 .368 0 r
F
.76847 .8579 m .80805 .88157 L .7799 .8937 L F
.39688 .46531 m .39218 .39825 L .42105 .42498 L 0 .028 .793 r
F
.39688 .46531 m .36214 .44592 L .39218 .39825 L F
.45565 .61776 m .42257 .63396 L .45989 .628 L 0 .003 .056 r
F
.45565 .61776 m .4166 .62373 L .42257 .63396 L F
.44955 .45314 m .45367 .39009 L .47396 .42468 L .154 0 .783 r
F
.44955 .45314 m .42105 .42498 L .45367 .39009 L F
.72893 .83245 m .74504 .86791 L .70999 .84029 L .355 .356 0 r
F
.72893 .83245 m .76847 .8579 L .74504 .86791 L F
.53378 .38516 m .534 .34266 L .57538 .33193 L .756 0 .792 r
F
.50277 .40173 m .534 .34266 L .53378 .38516 L .548 0 .787 r
F
.49678 .61847 m .46953 .63834 L .50168 .6273 L 0 .032 .243 r
F
.49678 .61847 m .45989 .628 L .46953 .63834 L F
.47396 .42468 m .49233 .36225 L .50277 .40173 L .347 0 .784 r
F
.47396 .42468 m .45367 .39009 L .49233 .36225 L F
.4166 .62373 m .38481 .63806 L .42257 .63396 L 0 0 0 r
F
.4166 .62373 m .37738 .6285 L .38481 .63806 L F
.68946 .80468 m .70999 .84029 L .67479 .81032 L .332 .34 0 r
F
.68946 .80468 m .72893 .83245 L .70999 .84029 L F
.67604 .2144 m .76023 .19783 L .73087 .2306 L .777 0 .429 r
F
.65479 .25167 m .67604 .2144 L .73087 .2306 L .782 0 .426 r
F
.50277 .40173 m .49233 .36225 L .534 .34266 L .548 0 .787 r
F
.36214 .44592 m .36292 .37246 L .39218 .39825 L 0 .028 .8 r
F
.36214 .44592 m .32709 .42736 L .36292 .37246 L F
.65009 .77365 m .67479 .81032 L .63945 .77709 L .3 .319 0 r
F
.65009 .77365 m .68946 .80468 L .67479 .81032 L F
.61085 .73755 m .63945 .77709 L .60401 .73886 L .253 .287 0 r
F
.61085 .73755 m .65009 .77365 L .63945 .77709 L F
.37738 .6285 m .34663 .64096 L .38481 .63806 L 0 0 0 r
F
.37738 .6285 m .33801 .63251 L .34663 .64096 L F
.58634 .29066 m .65479 .25167 L .63386 .29005 L .776 0 .627 r
F
.57538 .33193 m .58634 .29066 L .63386 .29005 L .782 0 .62 r
F
.534 .34266 m .58634 .29066 L .57538 .33193 L .751 0 .803 r
F
.42105 .42498 m .43305 .35711 L .45367 .39009 L .154 0 .793 r
F
.42105 .42498 m .39218 .39825 L .43305 .35711 L F
.33801 .63251 m .30803 .64301 L .34663 .64096 L 0 0 0 r
F
.33801 .63251 m .29848 .63598 L .30803 .64301 L F
.50168 .6273 m .48395 .649 L .50889 .63603 L .054 0 .256 r
F
.50168 .6273 m .46953 .63834 L .48395 .649 L F
.32709 .42736 m .33326 .34729 L .36292 .37246 L 0 .028 .807 r
F
.32709 .42736 m .29172 .40938 L .33326 .34729 L F
.69761 .1779 m .78994 .16579 L .76023 .19783 L .772 0 .431 r
F
.67604 .2144 m .69761 .1779 L .76023 .19783 L .777 0 .429 r
F
.29848 .63598 m .26902 .64441 L .30803 .64301 L 0 0 0 r
F
.29848 .63598 m .25881 .63903 L .26902 .64441 L F
.45989 .628 m .43677 .64459 L .46953 .63834 L 0 .011 .085 r
F
.45989 .628 m .42257 .63396 L .43677 .64459 L F
.45367 .39009 m .48169 .32456 L .49233 .36225 L .346 0 .794 r
F
.45367 .39009 m .43305 .35711 L .48169 .32456 L F
.534 .34266 m .53421 .30215 L .58634 .29066 L .751 0 .803 r
F
.49233 .36225 m .53421 .30215 L .534 .34266 L .545 0 .798 r
F
.49233 .36225 m .48169 .32456 L .53421 .30215 L F
.25881 .63903 m .22958 .64528 L .26902 .64441 L 0 0 0 r
F
.25881 .63903 m .21899 .64177 L .22958 .64528 L F
.50889 .63603 m .50216 .6601 L .51791 .64465 L .23 0 .256 r
F
.50889 .63603 m .48395 .649 L .50216 .6601 L F
.59749 .25079 m .67604 .2144 L .65479 .25167 L .771 0 .632 r
F
.58634 .29066 m .59749 .25079 L .65479 .25167 L .776 0 .627 r
F
.39218 .39825 m .41208 .32512 L .43305 .35711 L .154 0 .801 r
F
.39218 .39825 m .36292 .37246 L .41208 .32512 L F
.61221 .73316 m .65009 .77365 L .61085 .73755 L .106 .15 0 r
F
.29172 .40938 m .30319 .32254 L .33326 .34729 L 0 .028 .813 r
F
.29172 .40938 m .25602 .39184 L .30319 .32254 L F
.69761 .1779 m .71954 .14192 L .78994 .16579 L .772 0 .431 r
F
.21899 .64177 m .18973 .64572 L .22958 .64528 L 0 0 0 r
F
.21899 .64177 m .17903 .64424 L .18973 .64572 L F
.53421 .30215 m .59749 .25079 L .58634 .29066 L .747 0 .811 r
F
.51791 .64465 m .52282 .67162 L .52808 .6531 L .424 0 .242 r
F
.51791 .64465 m .50216 .6601 L .52282 .67162 L F
.65254 .76626 m .68946 .80468 L .65009 .77365 L .185 .177 0 r
F
.61221 .73316 m .65254 .76626 L .65009 .77365 L .106 .15 0 r
F
.42257 .63396 m .40341 .64833 L .43677 .64459 L 0 0 0 r
F
.42257 .63396 m .38481 .63806 L .40341 .64833 L F
.55791 .67601 m .59809 .71717 L .56516 .68209 L .737 0 0 r
F
.25602 .39184 m .27269 .29809 L .30319 .32254 L 0 .029 .817 r
F
.25602 .39184 m .21998 .37462 L .27269 .29809 L F
.43305 .35711 m .47085 .28795 L .48169 .32456 L .344 0 .802 r
F
.43305 .35711 m .41208 .32512 L .47085 .28795 L F
.52808 .6531 m .54435 .68344 L .53865 .66127 L .633 0 .208 r
F
.52808 .6531 m .52282 .67162 L .54435 .68344 L F
.69327 .79429 m .72893 .83245 L .68946 .80468 L .236 .194 0 r
F
.65254 .76626 m .69327 .79429 L .68946 .80468 L .185 .177 0 r
F
.46953 .63834 m .45839 .65604 L .48395 .649 L .05 0 .097 r
F
.46953 .63834 m .43677 .64459 L .45839 .65604 L F
.36292 .37246 m .39076 .29378 L .41208 .32512 L .153 0 .807 r
F
.36292 .37246 m .33326 .34729 L .39076 .29378 L F
.55791 .67601 m .58348 .70667 L .59809 .71717 L .737 0 0 r
F
.54885 .66899 m .58348 .70667 L .55791 .67601 L .777 0 .022 r
F
.53421 .30215 m .53443 .26285 L .59749 .25079 L .747 0 .811 r
F
.48169 .32456 m .53443 .26285 L .53421 .30215 L .542 0 .806 r
F
.60884 .21182 m .69761 .1779 L .67604 .2144 L .767 0 .636 r
F
.59749 .25079 m .60884 .21182 L .67604 .2144 L .771 0 .632 r
F
.53865 .66127 m .56511 .69526 L .54885 .66899 L .769 0 .129 r
F
.53865 .66127 m .54435 .68344 L .56511 .69526 L F
.54885 .66899 m .56511 .69526 L .58348 .70667 L .777 0 .022 r
F
.48169 .32456 m .47085 .28795 L .53443 .26285 L .542 0 .806 r
F
.73438 .81908 m .76847 .8579 L .72893 .83245 L .272 .206 0 r
F
.69327 .79429 m .73438 .81908 L .72893 .83245 L .236 .194 0 r
F
.53443 .26285 m .60884 .21182 L .59749 .25079 L .743 0 .818 r
F
.77583 .84159 m .80805 .88157 L .76847 .8579 L .299 .215 0 r
F
.73438 .81908 m .77583 .84159 L .76847 .8579 L .272 .206 0 r
F
.38481 .63806 m .36945 .65044 L .40341 .64833 L 0 0 0 r
F
.38481 .63806 m .34663 .64096 L .36945 .65044 L F
.81761 .86237 m .84767 .90382 L .80805 .88157 L .32 .222 0 r
F
.77583 .84159 m .81761 .86237 L .80805 .88157 L .299 .215 0 r
F
.8597 .8818 m .88731 .92491 L .84767 .90382 L .337 .228 0 r
F
.81761 .86237 m .8597 .8818 L .84767 .90382 L .32 .222 0 r
F
.33326 .34729 m .36906 .26282 L .39076 .29378 L .153 0 .813 r
F
.33326 .34729 m .30319 .32254 L .36906 .26282 L F
.8597 .8818 m .9021 .90012 L .88731 .92491 L .337 .228 0 r
F
.41208 .32512 m .45981 .252 L .47085 .28795 L .343 0 .809 r
F
.41208 .32512 m .39076 .29378 L .45981 .252 L F
.48395 .649 m .48595 .6686 L .50216 .6601 L .212 0 .09 r
F
.48395 .649 m .45839 .65604 L .48595 .6686 L F
.64637 .75563 m .69327 .79429 L .65254 .76626 L .029 .052 0 r
F
.6204 .17342 m .71954 .14192 L .69761 .1779 L .763 0 .639 r
F
.60884 .21182 m .6204 .17342 L .69761 .1779 L .767 0 .636 r
F
.53443 .26285 m .53466 .2243 L .60884 .21182 L .743 0 .818 r
F
.47085 .28795 m .53466 .2243 L .53443 .26285 L .54 0 .812 r
F
.34663 .64096 m .3349 .65138 L .36945 .65044 L 0 0 0 r
F
.34663 .64096 m .30803 .64301 L .3349 .65138 L F
.43677 .64459 m .43221 .65998 L .45839 .65604 L .044 0 0 r
F
.43677 .64459 m .40341 .64833 L .43221 .65998 L F
.47085 .28795 m .45981 .252 L .53466 .2243 L .54 0 .812 r
F
.53466 .2243 m .6204 .17342 L .60884 .21182 L .739 0 .823 r
F
.30319 .32254 m .34697 .23208 L .36906 .26282 L .153 0 .818 r
F
.30319 .32254 m .27269 .29809 L .34697 .23208 L F
.50216 .6601 m .51738 .68234 L .52282 .67162 L .389 0 .061 r
F
.50216 .6601 m .48595 .6686 L .51738 .68234 L F
.6855 .78004 m .73438 .81908 L .69327 .79429 L .109 .06 0 r
F
.64637 .75563 m .6855 .78004 L .69327 .79429 L .029 .052 0 r
F
.6204 .17342 m .63219 .13535 L .71954 .14192 L .763 0 .639 r
F
.39076 .29378 m .44855 .21643 L .45981 .252 L .342 0 .814 r
F
.39076 .29378 m .36906 .26282 L .44855 .21643 L F
.30803 .64301 m .29973 .6514 L .3349 .65138 L 0 0 0 r
F
.30803 .64301 m .26902 .64441 L .29973 .6514 L F
.56511 .69526 m .60979 .72789 L .58348 .70667 L .634 0 0 r
F
.52282 .67162 m .55024 .6971 L .54435 .68344 L .572 0 .003 r
F
.52282 .67162 m .51738 .68234 L .55024 .6971 L F
.63182 .74256 m .6855 .78004 L .64637 .75563 L 0 0 .099 r
F
.53466 .2243 m .53489 .18618 L .6204 .17342 L .739 0 .823 r
F
.45981 .252 m .53489 .18618 L .53466 .2243 L .538 0 .818 r
F
.56511 .69526 m .58188 .71249 L .60979 .72789 L .634 0 0 r
F
.54435 .68344 m .58188 .71249 L .56511 .69526 L .672 0 0 r
F
.72524 .80125 m .77583 .84159 L .73438 .81908 L .165 .065 0 r
F
.6855 .78004 m .72524 .80125 L .73438 .81908 L .109 .06 0 r
F
.54435 .68344 m .55024 .6971 L .58188 .71249 L .672 0 0 r
F
.45981 .252 m .44855 .21643 L .53489 .18618 L .538 0 .818 r
F
.40341 .64833 m .40541 .66187 L .43221 .65998 L .038 0 0 r
F
.40341 .64833 m .36945 .65044 L .40541 .66187 L F
.45839 .65604 m .46927 .67346 L .48595 .6686 L .188 0 0 r
F
.45839 .65604 m .43221 .65998 L .46927 .67346 L F
.53489 .18618 m .63219 .13535 L .6204 .17342 L .736 0 .828 r
F
.26902 .64441 m .26394 .65069 L .29973 .6514 L 0 0 0 r
F
.26902 .64441 m .22958 .64528 L .26394 .65069 L F
.36906 .26282 m .43706 .18104 L .44855 .21643 L .341 0 .819 r
F
.36906 .26282 m .34697 .23208 L .43706 .18104 L F
.76558 .82021 m .81761 .86237 L .77583 .84159 L .206 .069 0 r
F
.72524 .80125 m .76558 .82021 L .77583 .84159 L .165 .065 0 r
F
.63182 .74256 m .6663 .76298 L .6855 .78004 L 0 0 .099 r
F
.6663 .76298 m .72524 .80125 L .6855 .78004 L 0 0 .107 r
F
.22958 .64528 m .22753 .64934 L .26394 .65069 L 0 0 0 r
F
.22958 .64528 m .18973 .64572 L .22753 .64934 L F
.53489 .18618 m .53512 .14826 L .63219 .13535 L .736 0 .828 r
F
.44855 .21643 m .53512 .14826 L .53489 .18618 L .536 0 .823 r
F
.48595 .6686 m .51179 .68897 L .51738 .68234 L .344 0 0 r
F
.48595 .6686 m .46927 .67346 L .51179 .68897 L F
.44855 .21643 m .43706 .18104 L .53512 .14826 L .536 0 .823 r
F
.80652 .83749 m .8597 .8818 L .81761 .86237 L .237 .072 0 r
F
.76558 .82021 m .80652 .83749 L .81761 .86237 L .206 .069 0 r
F
.36945 .65044 m .37798 .66228 L .40541 .66187 L .031 0 0 r
F
.36945 .65044 m .3349 .65138 L .37798 .66228 L F
.43221 .65998 m .45213 .67593 L .46927 .67346 L .162 0 0 r
F
.43221 .65998 m .40541 .66187 L .45213 .67593 L F
.84804 .85345 m .9021 .90012 L .8597 .8818 L .261 .074 0 r
F
.80652 .83749 m .84804 .85345 L .8597 .8818 L .237 .072 0 r
F
.51738 .68234 m .55631 .70633 L .55024 .6971 L .496 0 0 r
F
.51738 .68234 m .51179 .68897 L .55631 .70633 L F
.70154 .78025 m .76558 .82021 L .72524 .80125 L .034 0 .112 r
F
.6663 .76298 m .70154 .78025 L .72524 .80125 L 0 0 .107 r
F
.55024 .6971 m .59917 .72503 L .58188 .71249 L .557 0 0 r
F
.55024 .6971 m .55631 .70633 L .59917 .72503 L F
.84804 .85345 m .89014 .86834 L .9021 .90012 L .261 .074 0 r
F
.63682 .74426 m .70154 .78025 L .6663 .76298 L 0 0 .282 r
F
.3349 .65138 m .34991 .66153 L .37798 .66228 L .025 0 0 r
F
.3349 .65138 m .29973 .6514 L .34991 .66153 L F
.46927 .67346 m .50601 .69291 L .51179 .68897 L .294 0 0 r
F
.46927 .67346 m .45213 .67593 L .50601 .69291 L F
.73752 .7953 m .80652 .83749 L .76558 .82021 L .092 0 .115 r
F
.70154 .78025 m .73752 .7953 L .76558 .82021 L .034 0 .112 r
F
.40541 .66187 m .43451 .67664 L .45213 .67593 L .136 0 0 r
F
.40541 .66187 m .37798 .66228 L .43451 .67664 L F
.63682 .74426 m .66457 .75753 L .70154 .78025 L 0 0 .282 r
F
.29973 .6514 m .32117 .65981 L .34991 .66153 L .019 0 0 r
F
.29973 .6514 m .26394 .65069 L .32117 .65981 L F
.66457 .75753 m .73752 .7953 L .70154 .78025 L 0 0 .308 r
F
.51179 .68897 m .56258 .71267 L .55631 .70633 L .414 0 0 r
F
.51179 .68897 m .50601 .69291 L .56258 .71267 L F
.55631 .70633 m .56258 .71267 L .61697 .73455 L .443 0 0 r
F
.56258 .71267 m .61036 .73188 L .61697 .73455 L .339 0 0 r
F
.59917 .72503 m .61697 .73455 L .62431 .73753 L .351 0 0 r
F
.55631 .70633 m .61697 .73455 L .59917 .72503 L .443 0 0 r
F
.61036 .73188 m .6353 .74191 L .61697 .73455 L .339 0 0 r
F
.62431 .73753 m .61697 .73455 L .66457 .75753 L .351 0 0 r
F
.77425 .80868 m .84804 .85345 L .80652 .83749 L .137 0 .117 r
F
.73752 .7953 m .77425 .80868 L .80652 .83749 L .092 0 .115 r
F
.26394 .65069 m .29175 .65727 L .32117 .65981 L .013 0 0 r
F
.26394 .65069 m .22753 .64934 L .29175 .65727 L F
.37798 .66228 m .41639 .67596 L .43451 .67664 L .11 0 0 r
F
.37798 .66228 m .34991 .66153 L .41639 .67596 L F
.45213 .67593 m .50006 .69489 L .50601 .69291 L .244 0 0 r
F
.45213 .67593 m .43451 .67664 L .50006 .69489 L F
.81175 .82075 m .89014 .86834 L .84804 .85345 L .172 0 .119 r
F
.77425 .80868 m .81175 .82075 L .84804 .85345 L .137 0 .117 r
F
.66457 .75753 m .69304 .7686 L .73752 .7953 L 0 0 .308 r
F
.61697 .73455 m .69304 .7686 L .66457 .75753 L 0 0 .441 r
F
.69304 .7686 m .77425 .80868 L .73752 .7953 L 0 0 .325 r
F
.50601 .69291 m .56904 .71691 L .56258 .71267 L .335 0 0 r
F
.50601 .69291 m .50006 .69489 L .56904 .71691 L F
.61697 .73455 m .6353 .74191 L .63971 .74473 L 0 0 .441 r
F
.56258 .71267 m .56904 .71691 L .6353 .74191 L .339 0 0 r
F
.56904 .71691 m .6313 .73935 L .6353 .74191 L .249 0 0 r
F
.6313 .73935 m .65418 .74759 L .6353 .74191 L F
.63971 .74473 m .6353 .74191 L .69304 .7686 L 0 0 .441 r
F
.81175 .82075 m .85002 .83174 L .89014 .86834 L .172 0 .119 r
F
.34991 .66153 m .39776 .67414 L .41639 .67596 L .086 0 0 r
F
.34991 .66153 m .32117 .65981 L .39776 .67414 L F
.72226 .77799 m .81175 .82075 L .77425 .80868 L .025 0 .336 r
F
.69304 .7686 m .72226 .77799 L .77425 .80868 L 0 0 .325 r
F
.43451 .67664 m .49393 .69533 L .50006 .69489 L .197 0 0 r
F
.43451 .67664 m .41639 .67596 L .49393 .69533 L F
.6353 .74191 m .72226 .77799 L .69304 .7686 L 0 0 .485 r
F
.32117 .65981 m .3786 .67132 L .39776 .67414 L .064 0 0 r
F
.32117 .65981 m .29175 .65727 L .3786 .67132 L F
.50006 .69489 m .49393 .69533 L .5757 .71951 L .262 0 0 r
F
.52965 .70434 m .5757 .71951 L .56904 .71691 L F
.5339 .7059 m .5757 .71951 L .52965 .70434 L F
.49393 .69533 m .56346 .71528 L .5757 .71951 L .198 0 0 r
F
.56904 .71691 m .5757 .71951 L .58905 .72412 L .249 0 0 r
F
.56346 .71528 m .58258 .72077 L .5757 .71951 L .198 0 0 r
F
.58905 .72412 m .5757 .71951 L .65418 .74759 L .249 0 0 r
F
.49393 .69533 m .48761 .69449 L .54893 .71146 L .198 0 0 r
F
.54476 .70992 m .54893 .71146 L .58258 .72077 L F
.49393 .69533 m .54893 .71146 L .54476 .70992 L F
.50006 .69489 m .5339 .7059 L .52965 .70434 L .262 0 0 r
F
.6353 .74191 m .65418 .74759 L .72226 .77799 L 0 0 .485 r
F
.75224 .78605 m .85002 .83174 L .81175 .82075 L .072 0 .345 r
F
.72226 .77799 m .75224 .78605 L .81175 .82075 L .025 0 .336 r
F
.39776 .67414 m .3786 .67132 L .45602 .68735 L .115 0 0 r
F
.4376 .68126 m .48761 .69449 L .49393 .69533 L .154 0 0 r
F
.4407 .68229 m .48761 .69449 L .4376 .68126 L F
.41639 .67596 m .39776 .67414 L .48761 .69449 L F
.39776 .67414 m .48109 .69254 L .48761 .69449 L .115 0 0 r
F
.45286 .68631 m .45602 .68735 L .48109 .69254 L F
.39776 .67414 m .45602 .68735 L .45286 .68631 L F
.41639 .67596 m .4407 .68229 L .4376 .68126 L .154 0 0 r
F
.65418 .74759 m .75224 .78605 L .72226 .77799 L 0 0 .516 r
F
.75224 .78605 m .783 .79302 L .85002 .83174 L .072 0 .345 r
F
.65418 .74759 m .67362 .75192 L .75224 .78605 L 0 0 .516 r
F
.5757 .71951 m .67362 .75192 L .65418 .74759 L 0 0 .644 r
F
.67362 .75192 m .783 .79302 L .75224 .78605 L 0 0 .538 r
F
.5757 .71951 m .58258 .72077 L .67362 .75192 L 0 0 .644 r
F
.67362 .75192 m .69364 .75512 L .783 .79302 L 0 0 .538 r
F
.58258 .72077 m .69364 .75512 L .67362 .75192 L 0 0 .688 r
F
.48761 .69449 m .58967 .72088 L .58258 .72077 L 0 0 .696 r
F
.48761 .69449 m .48109 .69254 L .58967 .72088 L F
.58258 .72077 m .58967 .72088 L .69364 .75512 L 0 0 .688 r
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{221.938, 239.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 220.938}, {238.938, 0}} -> {0, 0, 0, 0}}],
 StyleBox["\n\t\tFigure 2.A",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  A graphical view of the Riemann surface for  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["z", 
    FractionBox["1", "2"]]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "\tConsider ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox["z", 
     FractionBox["1", "2"]]}]}]]],
 ", which has two values for any ",
 Cell[BoxData[
  RowBox[{"z", "\[NotEqual]", "0"}]]],
 ".  Each function ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "1"], 
   RowBox[{"(", "z", ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SubscriptBox["f", "2"], 
   RowBox[{"(", "z", ")"}]}]]],
 " in Figure 2.18 is single-valued on the domain formed by cutting the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane along the negative ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " axis.  Let ",
 Cell[BoxData[
  SubscriptBox["D", "1"]]],
 " and ",
 Cell[BoxData[
  SubscriptBox["D", "2"]]],
 " be the domains of ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "1"], 
   RowBox[{"(", "z", ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SubscriptBox["f", "2"], 
   RowBox[{"(", "z", ")"}]}]]],
 ", respectively.  The range set for ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "1"], 
   RowBox[{"(", "z", ")"}]}]]],
 " is the set ",
 Cell[BoxData[
  SubscriptBox["H", "1"]]],
 " consisting of the right half-plane, and the positive ",
 StyleBox["v",
  FontFamily->"Courier New"],
 " axis; the range set for ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["f", "2"], 
   RowBox[{"(", "z", ")"}]}]]],
 " is the set ",
 Cell[BoxData[
  SubscriptBox["H", "2"]]],
 " consisting of the left half-plane and the negative ",
 StyleBox["v",
  FontFamily->"Courier New"],
 " axis.  The sets ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["H", "1"], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SubscriptBox["H", "2"]}]]],
 " are \"glued together\" along the positive v axis and the negative ",
 StyleBox["v",
  FontFamily->"Courier New"],
 " axis to form the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " plane with the origin deleted."
}], "Text"],

Cell[TextData[{
 "\tWe stack ",
 Cell[BoxData[
  SubscriptBox["D", "1"]]],
 " directly above ",
 Cell[BoxData[
  SubscriptBox["D", "2"]]],
 ".  The edge of ",
 Cell[BoxData[
  SubscriptBox["D", "1"]]],
 " in the upper half-plane is joined to the edge of ",
 Cell[BoxData[
  SubscriptBox["D", "2"]]],
 " in the lower half-plane, and the edge of ",
 Cell[BoxData[
  SubscriptBox["D", "1"]]],
 " in the lower half-plane is joined to the edge of ",
 Cell[BoxData[
  SubscriptBox["D", "2"]]],
 " in the upper half-plane.  When these domains are glued together in this \
manner, they form ",
 StyleBox["R",
  FontFamily->"Courier New"],
 ", which is a Riemann surface domain for the mapping ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox["z", 
     FractionBox["1", "2"]]}]}]]],
 ".  The portions of ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["D", "2"], " ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", "R"}]}]]],
 " that lie in ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"z", ":", 
    RowBox[{"|", "z", "|", 
     RowBox[{"<", "1"}]}]}], "}"}]]],
 " are shown in Figure 2.20."
}], "Text"],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .6193 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-017 1 -0.147002 1 [
[ 0 0 0 0 ]
[ 1 .6193 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .6193 L
0 .6193 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.46506 .54239 m
.46616 .59988 L
s
.46429 .50194 m .46506 .54239 L .3297 .54623 L p 1 1 1 r
F P
0 g
s
.46506 .54239 m .46429 .50194 L .57405 .48079 L p 1 1 1 r
F P
0 g
s
.57405 .48079 m .59948 .51679 L .46506 .54239 L p 1 1 1 r
F P
0 g
s
.59948 .51679 m .57405 .48079 L .67053 .44188 L p 1 1 1 r
F P
0 g
s
.67053 .44188 m .71877 .46979 L .59948 .51679 L p 1 1 1 r
F P
0 g
s
.35381 .50475 m .3297 .54623 L .20766 .52883 L p 1 1 1 r
F P
0 g
s
.3297 .54623 m .35381 .50475 L .46429 .50194 L p 1 1 1 r
F P
0 g
s
.46349 .45966 m .46429 .50194 L .35381 .50475 L p 1 1 1 r
F P
0 g
s
.46429 .50194 m .46349 .45966 L .54754 .44327 L p 1 1 1 r
F P
0 g
s
.54754 .44327 m .57405 .48079 L .46429 .50194 L p 1 1 1 r
F P
0 g
s
.57405 .48079 m .54754 .44327 L .6207 .41305 L p 1 1 1 r
F P
0 g
s
.6207 .41305 m .67053 .44188 L .57405 .48079 L p 1 1 1 r
F P
0 g
s
.20766 .52883 m .25521 .48972 L .35381 .50475 L p 1 1 1 r
F P
0 g
s
.37891 .46155 m .35381 .50475 L .25521 .48972 L p 1 1 1 r
F P
0 g
s
.35381 .50475 m .37891 .46155 L .46349 .45966 L p 1 1 1 r
F P
0 g
s
.71877 .46979 m .67053 .44188 L .7412 .38715 L p 1 1 1 r
F P
0 g
s
.7412 .38715 m .80814 .40305 L .71877 .46979 L p 1 1 1 r
F P
0 g
s
.25521 .48972 m .20766 .52883 L .11409 .49173 L p 1 1 1 r
F P
0 g
s
.46265 .41544 m .46349 .45966 L .37891 .46155 L p 1 1 1 r
F P
0 g
s
.46349 .45966 m .46265 .41544 L .51989 .40414 L p 1 1 1 r
F P
0 g
s
.51989 .40414 m .54754 .44327 L .46349 .45966 L p 1 1 1 r
F P
0 g
s
.67053 .44188 m .6207 .41305 L .67303 .37096 L p 1 1 1 r
F P
0 g
s
.67303 .37096 m .7412 .38715 L .67053 .44188 L p 1 1 1 r
F P
0 g
s
.54754 .44327 m .51989 .40414 L .5692 .38326 L p 1 1 1 r
F P
0 g
s
.5692 .38326 m .6207 .41305 L .54754 .44327 L p 1 1 1 r
F P
0 g
s
.25521 .48972 m .30423 .4494 L .37891 .46155 L p 1 1 1 r
F P
0 g
s
.40507 .41653 m .37891 .46155 L .30423 .4494 L p 1 1 1 r
F P
0 g
s
.37891 .46155 m .40507 .41653 L .46265 .41544 L p 1 1 1 r
F P
0 g
s
.11409 .49173 m .18134 .45853 L .25521 .48972 L p 1 1 1 r
F P
0 g
s
.30423 .4494 m .25521 .48972 L .18134 .45853 L p 1 1 1 r
F P
0 g
s
.6207 .41305 m .5692 .38326 L .60361 .35447 L p 1 1 1 r
F P
0 g
s
.60361 .35447 m .67303 .37096 L .6207 .41305 L p 1 1 1 r
F P
0 g
s
.18134 .45853 m .24962 .42483 L .30423 .4494 L p 1 1 1 r
F P
0 g
s
.35479 .4078 m .30423 .4494 L .24962 .42483 L p 1 1 1 r
F P
0 g
s
.30423 .4494 m .35479 .4078 L .40507 .41653 L p 1 1 1 r
F P
0 g
s
.46176 .36912 m .46265 .41544 L .40507 .41653 L p 1 1 1 r
F P
0 g
s
.46265 .41544 m .46176 .36912 L .49101 .36327 L p 1 1 1 r
F P
0 g
s
.49101 .36327 m .51989 .40414 L .46265 .41544 L p 1 1 1 r
F P
0 g
s
.80814 .40305 m .7412 .38715 L .77413 .32056 L p 1 1 1 r
F P
0 g
s
.77413 .32056 m .85245 .32056 L .80814 .40305 L p 1 1 1 r
F P
0 g
s
.51989 .40414 m .49101 .36327 L .51594 .35244 L p 1 1 1 r
F P
0 g
s
.51594 .35244 m .5692 .38326 L .51989 .40414 L p 1 1 1 r
F P
0 g
s
.43235 .36958 m .40507 .41653 L .35479 .4078 L p 1 1 1 r
F P
0 g
s
.40507 .41653 m .43235 .36958 L .46176 .36912 L p 1 1 1 r
F P
0 g
s
.18134 .45853 m .11409 .49173 L .06477 .4382 L p 1 1 1 r
F P
0 g
s
.7412 .38715 m .67303 .37096 L .6958 .32056 L p 1 1 1 r
F P
0 g
s
.6958 .32056 m .77413 .32056 L .7412 .38715 L p 1 1 1 r
F P
0 g
s
.5692 .38326 m .51594 .35244 L .53289 .33768 L p 1 1 1 r
F P
0 g
s
.53289 .33768 m .60361 .35447 L .5692 .38326 L p 1 1 1 r
F P
0 g
s
.24962 .42483 m .31894 .39061 L .35479 .4078 L p 1 1 1 r
F P
0 g
s
.40697 .36488 m .35479 .4078 L .31894 .39061 L p 1 1 1 r
F P
0 g
s
.35479 .4078 m .40697 .36488 L .43235 .36958 L p 1 1 1 r
F P
0 g
s
.06477 .4382 m .14464 .41448 L .18134 .45853 L p 1 1 1 r
F P
0 g
s
.24962 .42483 m .18134 .45853 L .14464 .41448 L p 1 1 1 r
F P
0 g
s
.67303 .37096 m .60361 .35447 L .61748 .32056 L p 1 1 1 r
F P
0 g
s
.61748 .32056 m .6958 .32056 L .67303 .37096 L p 1 1 1 r
F P
0 g
s
.46084 .32056 m .46176 .36912 L .43235 .36958 L closepath p 1 1 1 r
F P
0 g
s
.46084 .32056 m .49101 .36327 L .46176 .36912 L closepath p 1 1 1 r
F P
0 g
s
.14464 .41448 m .22418 .39085 L .24962 .42483 L p 1 1 1 r
F P
0 g
s
.31894 .39061 m .24962 .42483 L .22418 .39085 L p 1 1 1 r
F P
0 g
s
.46084 .32056 m .51594 .35244 L .49101 .36327 L closepath p 1 1 1 r
F P
0 g
s
.46084 .32056 m .43235 .36958 L .40697 .36488 L closepath p 1 1 1 r
F P
0 g
s
.60361 .35447 m .53289 .33768 L .53916 .32056 L p 1 1 1 r
F P
0 g
s
.53916 .32056 m .61748 .32056 L .60361 .35447 L p 1 1 1 r
F P
0 g
s
.46084 .32056 m .53289 .33768 L .51594 .35244 L closepath p 1 1 1 r
F P
0 g
s
.31894 .39061 m .38934 .35586 L .40697 .36488 L p 1 1 1 r
F P
0 g
s
.46084 .32056 m .40697 .36488 L .38934 .35586 L closepath p 1 1 1 r
F P
0 g
s
.22418 .39085 m .30339 .36733 L .31894 .39061 L p 1 1 1 r
F P
0 g
s
.38934 .35586 m .31894 .39061 L .30339 .36733 L p 1 1 1 r
F P
0 g
s
.15042 .22818 m .0736 .20532 L .08277 .13551 L p .872 .872 .872 r
F P
0 g
s
.46084 .32056 m .53916 .32056 L .53289 .33768 L closepath p 1 1 1 r
F P
0 g
s
.08277 .13551 m .16082 .17371 L .15042 .22818 L p .872 .872 .872 r
F P
0 g
s
.22755 .25114 m .15042 .22818 L .16082 .17371 L p .872 .872 .872 r
F P
0 g
s
.30339 .36733 m .38228 .3439 L .38934 .35586 L p 1 1 1 r
F P
0 g
s
.46084 .32056 m .38934 .35586 L .38228 .3439 L closepath p 1 1 1 r
F P
0 g
s
.16082 .17371 m .23762 .2113 L .22755 .25114 L p .872 .872 .872 r
F P
0 g
s
.305 .27418 m .22755 .25114 L .23762 .2113 L p .872 .872 .872 r
F P
0 g
s
.23762 .2113 m .31321 .2483 L .305 .27418 L p .872 .872 .872 r
F P
0 g
s
.38276 .29733 m .305 .27418 L .31321 .2483 L p .872 .872 .872 r
F P
0 g
s
.31321 .2483 m .3876 .28472 L .38276 .29733 L p .872 .872 .872 r
F P
0 g
s
.46084 .32056 m .38276 .29733 L .3876 .28472 L closepath p .872 .872 .872 r
F P
0 g
s
.85245 .32056 m .77413 .32056 L .76007 .24877 L p 1 1 1 r
F P
0 g
s
.76007 .24877 m .83857 .22994 L .85245 .32056 L p 1 1 1 r
F P
0 g
s
.85245 .32056 m
.9014 .32056 L
s
.77413 .32056 m .6958 .32056 L .68309 .26724 L p 1 1 1 r
F P
0 g
s
.68309 .26724 m .76007 .24877 L .77413 .32056 L p 1 1 1 r
F P
0 g
s
.6958 .32056 m .61748 .32056 L .60758 .28536 L p 1 1 1 r
F P
0 g
s
.60758 .28536 m .68309 .26724 L .6958 .32056 L p 1 1 1 r
F P
0 g
s
.61748 .32056 m .53916 .32056 L .53351 .30313 L p 1 1 1 r
F P
0 g
s
.53351 .30313 m .60758 .28536 L .61748 .32056 L p 1 1 1 r
F P
0 g
s
.46084 .32056 m .53351 .30313 L .53916 .32056 L closepath p 1 1 1 r
F P
0 g
s
.46084 .32056 m .51651 .28756 L .53351 .30313 L closepath p .996 .996 .996 r
F P
0 g
s
.46084 .32056 m .4906 .27589 L .51651 .28756 L closepath p .984 .984 .984 r
F P
0 g
s
.46084 .32056 m .45987 .2696 L .4906 .27589 L closepath p .965 .965 .965 r
F P
0 g
s
.46084 .32056 m .42931 .26934 L .45987 .2696 L closepath p .941 .941 .941 r
F P
0 g
s
.46084 .32056 m .4039 .27479 L .42931 .26934 L closepath p .916 .916 .916 r
F P
0 g
s
.46084 .32056 m .3876 .28472 L .4039 .27479 L closepath p .892 .892 .892 r
F P
0 g
s
.34504 .22747 m .4039 .27479 L .3876 .28472 L p .892 .892 .892 r
F P
0 g
s
.3876 .28472 m .31321 .2483 L .34504 .22747 L p .892 .892 .892 r
F P
0 g
s
.60758 .28536 m .53351 .30313 L .51651 .28756 L p .996 .996 .996 r
F P
0 g
s
.28418 .17854 m .34504 .22747 L .31321 .2483 L p .892 .892 .892 r
F P
0 g
s
.31321 .2483 m .23762 .2113 L .28418 .17854 L p .892 .892 .892 r
F P
0 g
s
.39634 .21577 m .42931 .26934 L .4039 .27479 L p .916 .916 .916 r
F P
0 g
s
.4039 .27479 m .34504 .22747 L .39634 .21577 L p .916 .916 .916 r
F P
0 g
s
.51651 .28756 m .57418 .25337 L .60758 .28536 L p .996 .996 .996 r
F P
0 g
s
.57418 .25337 m .51651 .28756 L .4906 .27589 L p .984 .984 .984 r
F P
0 g
s
.68309 .26724 m .60758 .28536 L .57418 .25337 L p .996 .996 .996 r
F P
0 g
s
.45885 .21605 m .45987 .2696 L .42931 .26934 L p .941 .941 .941 r
F P
0 g
s
.42931 .26934 m .39634 .21577 L .45885 .21605 L p .941 .941 .941 r
F P
0 g
s
.4906 .27589 m .52177 .2291 L .57418 .25337 L p .984 .984 .984 r
F P
0 g
s
.52177 .2291 m .4906 .27589 L .45987 .2696 L p .965 .965 .965 r
F P
0 g
s
.22121 .12791 m .28418 .17854 L .23762 .2113 L p .892 .892 .892 r
F P
0 g
s
.23762 .2113 m .16082 .17371 L .22121 .12791 L p .892 .892 .892 r
F P
0 g
s
.45987 .2696 m .45885 .21605 L .52177 .2291 L p .965 .965 .965 r
F P
0 g
s
.76007 .24877 m .68309 .26724 L .63396 .21792 L p .996 .996 .996 r
F P
0 g
s
.57418 .25337 m .63396 .21792 L .68309 .26724 L p .996 .996 .996 r
F P
0 g
s
.15601 .07549 m .22121 .12791 L .16082 .17371 L p .892 .892 .892 r
F P
0 g
s
.16082 .17371 m .08277 .13551 L .15601 .07549 L p .892 .892 .892 r
F P
0 g
s
.36181 .15967 m .39634 .21577 L .34504 .22747 L p .916 .916 .916 r
F P
0 g
s
.34504 .22747 m .28418 .17854 L .36181 .15967 L p .916 .916 .916 r
F P
0 g
s
.63396 .21792 m .57418 .25337 L .52177 .2291 L p .984 .984 .984 r
F P
0 g
s
.83857 .22994 m .76007 .24877 L .69596 .18116 L p .996 .996 .996 r
F P
0 g
s
.63396 .21792 m .69596 .18116 L .76007 .24877 L p .996 .996 .996 r
F P
0 g
s
.45777 .1597 m .45885 .21605 L .39634 .21577 L p .941 .941 .941 r
F P
0 g
s
.39634 .21577 m .36181 .15967 L .45777 .1597 L p .941 .941 .941 r
F P
0 g
s
.52177 .2291 m .55444 .18005 L .63396 .21792 L p .984 .984 .984 r
F P
0 g
s
.55444 .18005 m .52177 .2291 L .45885 .21605 L p .965 .965 .965 r
F P
0 g
s
.69596 .18116 m .76033 .143 L .83857 .22994 L p .996 .996 .996 r
F P
0 g
s
.45885 .21605 m .45777 .1597 L .55444 .18005 L p .965 .965 .965 r
F P
0 g
s
.32562 .10087 m .36181 .15967 L .28418 .17854 L p .916 .916 .916 r
F P
0 g
s
.28418 .17854 m .22121 .12791 L .32562 .10087 L p .916 .916 .916 r
F P
0 g
s
.69596 .18116 m .63396 .21792 L .55444 .18005 L p .984 .984 .984 r
F P
0 g
s
.28763 .03916 m .32562 .10087 L .22121 .12791 L p .916 .916 .916 r
F P
0 g
s
.22121 .12791 m .15601 .07549 L .28763 .03916 L p .916 .916 .916 r
F P
0 g
s
.45664 .10033 m .45777 .1597 L .36181 .15967 L p .941 .941 .941 r
F P
0 g
s
.36181 .15967 m .32562 .10087 L .45664 .10033 L p .941 .941 .941 r
F P
0 g
s
.55444 .18005 m .58873 .12857 L .69596 .18116 L p .984 .984 .984 r
F P
0 g
s
.58873 .12857 m .55444 .18005 L .45777 .1597 L p .965 .965 .965 r
F P
0 g
s
.76033 .143 m .69596 .18116 L .58873 .12857 L p .984 .984 .984 r
F P
0 g
s
.45777 .1597 m .45664 .10033 L .58873 .12857 L p .965 .965 .965 r
F P
0 g
s
.58873 .12857 m .62477 .07447 L .76033 .143 L p .984 .984 .984 r
F P
0 g
s
.45545 .0377 m .45664 .10033 L .32562 .10087 L p .941 .941 .941 r
F P
0 g
s
.32562 .10087 m .28763 .03916 L .45545 .0377 L p .941 .941 .941 r
F P
0 g
s
.62477 .07447 m .58873 .12857 L .45664 .10033 L p .965 .965 .965 r
F P
0 g
s
.45664 .10033 m .45545 .0377 L .62477 .07447 L p .965 .965 .965 r
F P
0 g
s
gsave
.89289 .34183 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.49311 .59115 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 178.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 287}, {177.313, 0}} -> {0, 0, 0, 0}}],
 StyleBox["     ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% PlotRegion
.1 .9 .1 .9 MPlotRegion
% Scaling calculations
0.5 0.434783 0.5 0.434783 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
1 .5 L
s
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
.5 .49565 m
.50002 .49565 L
.50003 .49565 L
.50005 .49565 L
.50007 .49565 L
.5001 .49565 L
.50013 .49565 L
.50017 .49566 L
.5002 .49566 L
.50027 .49566 L
.50034 .49567 L
.50041 .49567 L
.50055 .49569 L
.5007 .49571 L
.50084 .49573 L
.50115 .49581 L
.50141 .49589 L
.50168 .49599 L
.5022 .49625 L
.50267 .49657 L
.50311 .49696 L
.50349 .4974 L
.50379 .49786 L
.50392 .49811 L
.50404 .49839 L
.50414 .49867 L
.50421 .49893 L
.50427 .49921 L
.5043 .49936 L
.50432 .4995 L
.50433 .49964 L
.50434 .49971 L
.50434 .49979 L
.50435 .49985 L
.50435 .49989 L
.50435 .49991 L
.50435 .49992 L
.50435 .49994 L
.50435 .49995 L
.50435 .49997 L
.50435 .49998 L
.50435 .5 L
.50435 .50002 L
.50435 .50004 L
.50435 .50005 L
.50435 .50007 L
.50435 .50009 L
.50435 .50012 L
.50435 .50015 L
.50434 .50019 L
Mistroke
.50434 .50026 L
.50434 .50032 L
.50432 .50046 L
.5043 .50061 L
.50428 .50076 L
.50425 .50092 L
.50418 .5012 L
.50409 .50147 L
.50398 .50175 L
.50373 .50223 L
.5034 .50271 L
.50302 .50312 L
.50257 .50351 L
.50209 .50381 L
.50159 .50405 L
.50132 .50414 L
.50103 .50422 L
.5009 .50425 L
.50076 .50428 L
.50064 .5043 L
.5005 .50432 L
.50037 .50433 L
.50026 .50434 L
.50019 .50434 L
.50013 .50435 L
.5001 .50435 L
.50008 .50435 L
.50007 .50435 L
.50005 .50435 L
.50003 .50435 L
.50002 .50435 L
.5 .50435 L
Mfstroke
.5001 .30551 m
.50085 .30551 L
.50154 .30552 L
.50233 .30552 L
.50308 .30554 L
.50441 .30556 L
.50585 .3056 L
.50744 .30565 L
.50913 .30573 L
.51215 .30589 L
.51527 .30611 L
.51818 .30636 L
.52481 .3071 L
.53153 .30808 L
.53766 .30919 L
.55129 .31239 L
.56292 .31597 L
.57534 .3207 L
.59863 .33237 L
.61938 .34646 L
.63924 .36422 L
.65592 .38374 L
.6694 .40445 L
.6752 .41556 L
.68073 .42816 L
.6852 .44063 L
.68853 .45223 L
.69121 .46445 L
.69235 .47125 L
.69321 .47772 L
.69382 .48388 L
.69405 .48699 L
.69425 .49044 L
.69438 .49337 L
.69443 .49502 L
.69444 .4958 L
.69446 .49653 L
.69447 .49723 L
.69448 .49786 L
.69448 .49856 L
.69449 .49932 L
.69449 .50004 L
.69449 .50082 L
.69448 .50157 L
.69448 .50225 L
.69447 .50305 L
.69445 .50382 L
.69442 .50525 L
.69437 .50679 L
.69431 .50846 L
Mistroke
.69415 .51148 L
.69397 .51427 L
.69339 .52066 L
.69255 .52743 L
.6915 .53396 L
.69013 .54097 L
.68698 .55352 L
.68305 .56572 L
.67804 .57827 L
.66686 .59992 L
.65208 .62124 L
.63529 .63972 L
.61501 .65684 L
.59344 .67057 L
.57116 .681 L
.55919 .68526 L
.54621 .68892 L
.54034 .69026 L
.53397 .6915 L
.52844 .6924 L
.52237 .6932 L
.51676 .69377 L
.51153 .69415 L
.50863 .6943 L
.506 .6944 L
.50454 .69444 L
.50377 .69445 L
.50296 .69447 L
.50225 .69448 L
.50147 .69448 L
.50076 .69449 L
.5001 .69449 L
Mfstroke
.50014 .22498 m
.5012 .22499 L
.50217 .22499 L
.50329 .225 L
.50435 .22502 L
.50623 .22506 L
.50828 .22511 L
.51053 .22519 L
.51291 .22529 L
.51718 .22552 L
.52159 .22583 L
.52571 .22619 L
.53508 .22723 L
.54459 .22862 L
.55325 .23019 L
.57252 .23472 L
.58898 .23978 L
.60654 .24646 L
.63946 .26297 L
.6688 .28289 L
.6969 .308 L
.72048 .33561 L
.73954 .36489 L
.74774 .3806 L
.75556 .39841 L
.76189 .41604 L
.76659 .43246 L
.77038 .44974 L
.77199 .45934 L
.7732 .46849 L
.77407 .4772 L
.7744 .48161 L
.77468 .48648 L
.77486 .49062 L
.77492 .49295 L
.77495 .49406 L
.77497 .49509 L
.77499 .49608 L
.775 .49697 L
.77501 .49797 L
.77501 .49903 L
.77502 .50006 L
.77501 .50117 L
.77501 .50221 L
.775 .50318 L
.77498 .50432 L
.77496 .5054 L
.77491 .50742 L
.77485 .5096 L
.77475 .51197 L
Mistroke
.77454 .51623 L
.77427 .52018 L
.77346 .52921 L
.77227 .53879 L
.77079 .54802 L
.76884 .55793 L
.7644 .57568 L
.75884 .59293 L
.75176 .61068 L
.73594 .64129 L
.71504 .67144 L
.6913 .69758 L
.66262 .72178 L
.63212 .7412 L
.60062 .75595 L
.5837 .76197 L
.56535 .76714 L
.55704 .76903 L
.54804 .77079 L
.54021 .77206 L
.53163 .77319 L
.52369 .77399 L
.5163 .77453 L
.51221 .77474 L
.50849 .77488 L
.50642 .77494 L
.50534 .77496 L
.50419 .77498 L
.50318 .775 L
.50208 .77501 L
.50108 .77501 L
.50014 .77502 L
Mfstroke
.50017 .16319 m
.50147 .16319 L
.50266 .1632 L
.50403 .16321 L
.50533 .16323 L
.50763 .16328 L
.51014 .16334 L
.51289 .16344 L
.51581 .16356 L
.52104 .16385 L
.52644 .16423 L
.53149 .16467 L
.54296 .16594 L
.55461 .16765 L
.56521 .16956 L
.58881 .17511 L
.60897 .1813 L
.63048 .18949 L
.6708 .20971 L
.70673 .2341 L
.74114 .26486 L
.77001 .29867 L
.79336 .33453 L
.80341 .35377 L
.81299 .37559 L
.82073 .39718 L
.82649 .41728 L
.83114 .43844 L
.83311 .45021 L
.83459 .46141 L
.83565 .47208 L
.83606 .47748 L
.8364 .48344 L
.83661 .48852 L
.8367 .49137 L
.83673 .49273 L
.83676 .49399 L
.83677 .4952 L
.83679 .49629 L
.8368 .49751 L
.83681 .49881 L
.83681 .50007 L
.83681 .50143 L
.8368 .50271 L
.83679 .5039 L
.83677 .50529 L
.83674 .50661 L
.83669 .50909 L
.8366 .51175 L
.83649 .51466 L
Mistroke
.83622 .51988 L
.8359 .52471 L
.8349 .53577 L
.83344 .5475 L
.83164 .55881 L
.82925 .57095 L
.8238 .59269 L
.817 .61381 L
.80833 .63555 L
.78896 .67304 L
.76336 .70996 L
.73429 .74197 L
.69917 .77161 L
.66181 .79539 L
.62323 .81346 L
.6025 .82083 L
.58003 .82716 L
.56986 .82948 L
.55883 .83163 L
.54925 .83319 L
.53873 .83457 L
.52902 .83556 L
.51997 .83622 L
.51495 .83648 L
.51039 .83665 L
.50787 .83672 L
.50654 .83675 L
.50513 .83677 L
.5039 .83679 L
.50255 .8368 L
.50132 .83681 L
.50017 .83681 L
Mfstroke
.50019 .11109 m
.5017 .1111 L
.50307 .11111 L
.50466 .11112 L
.50615 .11114 L
.50882 .11119 L
.5117 .11127 L
.51488 .11138 L
.51826 .11152 L
.5243 .11185 L
.53053 .11229 L
.53636 .1128 L
.54961 .11427 L
.56306 .11624 L
.5753 .11845 L
.60255 .12486 L
.62582 .13201 L
.65066 .14146 L
.69722 .16481 L
.73871 .19297 L
.77844 .22849 L
.81178 .26753 L
.83874 .30894 L
.85034 .33115 L
.8614 .35634 L
.87034 .38127 L
.87699 .40449 L
.88236 .42892 L
.88463 .44251 L
.88634 .45544 L
.88757 .46776 L
.88804 .47399 L
.88844 .48088 L
.88868 .48674 L
.88878 .49004 L
.88882 .4916 L
.88884 .49306 L
.88887 .49445 L
.88888 .49572 L
.8889 .49713 L
.8889 .49863 L
.88891 .50008 L
.8889 .50165 L
.88889 .50313 L
.88888 .5045 L
.88886 .5061 L
.88883 .50763 L
.88876 .51049 L
.88867 .51357 L
.88854 .51693 L
Mistroke
.88823 .52295 L
.88786 .52854 L
.88671 .5413 L
.88502 .55485 L
.88293 .56791 L
.88018 .58192 L
.87389 .60703 L
.86603 .63141 L
.85602 .65651 L
.83365 .69981 L
.8041 .74243 L
.77053 .7794 L
.72997 .81363 L
.68684 .84108 L
.64229 .86194 L
.61836 .87046 L
.59241 .87777 L
.58066 .88045 L
.56793 .88293 L
.55687 .88473 L
.54472 .88633 L
.5335 .88746 L
.52305 .88822 L
.51726 .88852 L
.512 .88872 L
.50908 .8888 L
.50755 .88883 L
.50592 .88886 L
.5045 .88888 L
.50294 .88889 L
.50152 .8889 L
.50019 .88891 L
Mfstroke
.5 .49565 m
.50004 .41233 L
.50006 .37331 L
.50008 .34539 L
.50009 .32264 L
.5001 .30127 L
.50011 .28267 L
.50012 .2645 L
.50013 .24824 L
.50013 .23353 L
.50014 .21872 L
.50015 .20516 L
.50015 .19269 L
.50016 .17995 L
.50017 .16814 L
.50017 .15604 L
.50018 .14477 L
.50018 .13425 L
.50019 .12339 L
.50019 .11321 L
.5002 .10269 L
.5002 .0928 L
.50021 .08351 L
.50021 .07386 L
.50022 .06522 L
s
.50085 .49574 m
.51714 .41402 L
.52476 .37576 L
.53022 .34838 L
.53467 .32606 L
.53884 .3051 L
.54248 .28686 L
.54603 .26904 L
.54921 .25309 L
.55208 .23866 L
.55498 .22414 L
.55763 .21085 L
.56007 .19862 L
.56256 .18612 L
.56486 .17454 L
.56723 .16267 L
.56943 .15162 L
.57149 .14131 L
.57361 .13065 L
.5756 .12067 L
.57766 .11035 L
.57959 .10066 L
.58141 .09155 L
.58329 .08208 L
.58498 .0736 L
s
.50167 .49598 m
.53357 .41901 L
.54851 .38297 L
.5592 .35718 L
.56791 .33616 L
.5761 .31641 L
.58322 .29923 L
.59018 .28245 L
.5964 .26742 L
.60204 .25383 L
.60771 .24016 L
.6129 .22763 L
.61767 .21611 L
.62255 .20434 L
.62707 .19344 L
.63171 .18225 L
.63602 .17184 L
.64005 .16213 L
.64421 .15209 L
.64811 .14269 L
.65214 .13297 L
.65592 .12384 L
.65948 .11526 L
.66318 .10634 L
.66648 .09835 L
s
.50242 .49638 m
.54872 .42711 L
.5704 .39467 L
.58591 .37146 L
.59855 .35254 L
.61043 .33477 L
.62077 .31931 L
.63086 .30421 L
.6399 .29068 L
.64807 .27845 L
.6563 .26614 L
.66383 .25487 L
.67076 .2445 L
.67785 .23391 L
.6844 .22409 L
.69113 .21403 L
.69739 .20466 L
.70324 .19592 L
.70928 .18688 L
.71493 .17842 L
.72078 .16967 L
.72627 .16146 L
.73143 .15373 L
.7368 .1457 L
.7416 .13852 L
s
.50308 .49692 m
.56199 .43801 L
.58958 .41042 L
.60932 .39068 L
.62541 .37459 L
.64053 .35947 L
.65368 .34632 L
.66652 .33348 L
.67802 .32198 L
.68843 .31157 L
.6989 .3011 L
.70848 .29152 L
.7173 .2827 L
.72631 .27369 L
.73466 .26534 L
.74322 .25678 L
.75119 .24881 L
.75862 .24138 L
.76631 .23369 L
.7735 .2265 L
.78094 .21906 L
.78793 .21207 L
.7945 .2055 L
.80133 .19867 L
.80744 .19256 L
s
.50362 .49758 m
.57289 .45128 L
.60533 .4296 L
.62854 .41409 L
.64746 .40145 L
.66523 .38957 L
.68069 .37923 L
.69579 .36914 L
.70932 .3601 L
.72155 .35193 L
.73386 .3437 L
.74513 .33617 L
.7555 .32924 L
.76609 .32215 L
.77591 .3156 L
.78597 .30887 L
.79534 .30261 L
.80408 .29676 L
.81312 .29072 L
.82158 .28507 L
.83033 .27922 L
.83854 .27373 L
.84627 .26857 L
.8543 .2632 L
.86148 .2584 L
s
.50402 .49833 m
.58099 .46643 L
.61703 .45149 L
.64282 .4408 L
.66384 .43209 L
.68359 .4239 L
.70077 .41678 L
.71755 .40982 L
.73258 .4036 L
.74617 .39796 L
.75984 .39229 L
.77237 .3871 L
.78389 .38233 L
.79566 .37745 L
.80656 .37293 L
.81775 .36829 L
.82816 .36398 L
.83787 .35995 L
.84791 .35579 L
.85731 .35189 L
.86703 .34786 L
.87616 .34408 L
.88474 .34052 L
.89366 .33682 L
.90165 .33352 L
s
.50426 .49915 m
.58598 .48286 L
.62424 .47524 L
.65162 .46978 L
.67394 .46533 L
.6949 .46116 L
.71314 .45752 L
.73096 .45397 L
.74691 .45079 L
.76134 .44792 L
.77586 .44502 L
.78915 .44237 L
.80138 .43993 L
.81388 .43744 L
.82546 .43514 L
.83733 .43277 L
.84838 .43057 L
.85869 .42851 L
.86935 .42639 L
.87933 .4244 L
.88965 .42234 L
.89934 .42041 L
.90845 .41859 L
.91792 .41671 L
.9264 .41502 L
s
.50435 .5 m
.58767 .49996 L
.62669 .49994 L
.65461 .49992 L
.67736 .49991 L
.69873 .4999 L
.71733 .49989 L
.7355 .49988 L
.75176 .49987 L
.76647 .49987 L
.78128 .49986 L
.79484 .49985 L
.80731 .49985 L
.82005 .49984 L
.83186 .49983 L
.84396 .49983 L
.85523 .49982 L
.86575 .49982 L
.87661 .49981 L
.88679 .49981 L
.89731 .4998 L
.9072 .4998 L
.91649 .49979 L
.92614 .49979 L
.93478 .49978 L
s
.50427 .50085 m
.586 .51705 L
.62427 .52464 L
.65165 .53007 L
.67397 .53449 L
.69494 .53865 L
.71319 .54227 L
.731 .5458 L
.74696 .54896 L
.76139 .55182 L
.77591 .5547 L
.78921 .55734 L
.80144 .55976 L
.81394 .56224 L
.82552 .56454 L
.8374 .56689 L
.84845 .56909 L
.85877 .57113 L
.86942 .57324 L
.8794 .57522 L
.88973 .57727 L
.89942 .57919 L
.90853 .581 L
.91801 .58288 L
.92648 .58456 L
s
.50402 .50166 m
.58103 .53349 L
.61708 .54839 L
.64288 .55906 L
.66391 .56775 L
.68366 .57591 L
.70085 .58302 L
.71764 .58996 L
.73267 .59617 L
.74627 .60179 L
.75995 .60745 L
.77248 .61263 L
.784 .61739 L
.79578 .62226 L
.80669 .62677 L
.81788 .63139 L
.8283 .6357 L
.83801 .63971 L
.84805 .64386 L
.85746 .64775 L
.86718 .65177 L
.87632 .65555 L
.8849 .65909 L
.89383 .66278 L
.90181 .66608 L
s
.50362 .50241 m
.57294 .54865 L
.6054 .57029 L
.62863 .58578 L
.64755 .59841 L
.66534 .61027 L
.68081 .62059 L
.69593 .63067 L
.70946 .63969 L
.7217 .64785 L
.73401 .65607 L
.74529 .66359 L
.75567 .67051 L
.76627 .67758 L
.77609 .68413 L
.78616 .69085 L
.79554 .6971 L
.80429 .70293 L
.81333 .70896 L
.82179 .71461 L
.83055 .72045 L
.83877 .72593 L
.8465 .73108 L
.85453 .73644 L
.86172 .74124 L
s
.50308 .50307 m
.56206 .56193 L
.58967 .58949 L
.60943 .60921 L
.62554 .62529 L
.64067 .64039 L
.65383 .65353 L
.66669 .66636 L
.6782 .67785 L
.68861 .68824 L
.6991 .6987 L
.70869 .70827 L
.71752 .71708 L
.72654 .72609 L
.73489 .73442 L
.74346 .74298 L
.75144 .75094 L
.75888 .75836 L
.76657 .76604 L
.77377 .77323 L
.78122 .78066 L
.78822 .78764 L
.79479 .79421 L
.80163 .80103 L
.80775 .80713 L
s
.50242 .50361 m
.54879 .57284 L
.5705 .60526 L
.58604 .62845 L
.5987 .64736 L
.6106 .66512 L
.62095 .68057 L
.63106 .69566 L
.64011 .70918 L
.64829 .7214 L
.65653 .7337 L
.66408 .74496 L
.67102 .75533 L
.67811 .76591 L
.68468 .77572 L
.69142 .78578 L
.69769 .79514 L
.70354 .80388 L
.70959 .81291 L
.71525 .82136 L
.72111 .8301 L
.72661 .83832 L
.73178 .84603 L
.73715 .85406 L
.74196 .86124 L
s
.50167 .50402 m
.53365 .58096 L
.54863 .61698 L
.55934 .64276 L
.56808 .66377 L
.57628 .68351 L
.58342 .70069 L
.59039 .71746 L
.59664 .73248 L
.60228 .74606 L
.60797 .75974 L
.61317 .77225 L
.61796 .78377 L
.62285 .79554 L
.62738 .80644 L
.63203 .81762 L
.63635 .82802 L
.64039 .83773 L
.64456 .84777 L
.64846 .85716 L
.6525 .86688 L
.6563 .87601 L
.65986 .88458 L
.66357 .8935 L
.66689 .90148 L
s
.50085 .50426 m
.51722 .58597 L
.52489 .62422 L
.53037 .65159 L
.53484 .6739 L
.53904 .69486 L
.54269 .7131 L
.54626 .73091 L
.54946 .74686 L
.55235 .76128 L
.55525 .7758 L
.55792 .78909 L
.56037 .80132 L
.56287 .81382 L
.56519 .82539 L
.56757 .83726 L
.56978 .84831 L
.57185 .85862 L
.57398 .86928 L
.57598 .87925 L
.57805 .88957 L
.57999 .89926 L
.58181 .90837 L
.58371 .91784 L
.58541 .92631 L
s
.50001 .50435 m
.50013 .58767 L
.50019 .62669 L
.50023 .65461 L
.50027 .67736 L
.5003 .69873 L
.50033 .71733 L
.50035 .7355 L
.50038 .75176 L
.5004 .76647 L
.50042 .78128 L
.50044 .79484 L
.50046 .80731 L
.50048 .82005 L
.5005 .83186 L
.50052 .84396 L
.50053 .85523 L
.50055 .86575 L
.50056 .87661 L
.50058 .88679 L
.5006 .89731 L
.50061 .9072 L
.50062 .91649 L
.50064 .92614 L
.50065 .93478 L
s
gsave
.97826 .54348 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.54348 .97826 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97826 .5 m
1 .5 L
s
% Start of user PostScript
1.1 0 1.15 0 MAarrowhead1
% End of user PostScript
.5 .97826 m
.5 1 L
s
% Start of user PostScript
0 1.1 0 1.15 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{178.313, 178.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{17.6875, 159.563}, {159.625, 17.75}} -> {-1, -1, 0, 0}}],
 "  ",
 StyleBox["\n\t\t\t(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  A portion of  ",
 Cell[BoxData[
  SubscriptBox["D", "1"]]],
 "  and its image under  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["z", 
    FractionBox["1", "2"]]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .6193 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-017 1 -0.147002 1 [
[ 0 0 0 0 ]
[ 1 .6193 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .6193 L
0 .6193 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.46467 .38119 m .46551 .39454 L .33227 .37102 L p .893 .893 .893 r
F P
0 g
s
.46551 .39454 m .46467 .38119 L .57344 .38532 L p .932 .932 .932 r
F P
0 g
s
.57344 .38532 m .59848 .39972 L .46551 .39454 L p .932 .932 .932 r
F P
0 g
s
.46551 .39454 m
.46631 .40728 L
s
.35562 .36186 m .33227 .37102 L .2127 .3297 L p .865 .865 .865 r
F P
0 g
s
.33227 .37102 m .35562 .36186 L .46467 .38119 L p .893 .893 .893 r
F P
0 g
s
.59848 .39972 m .57344 .38532 L .66954 .3749 L p .967 .967 .967 r
F P
0 g
s
.66954 .3749 m .7172 .38731 L .59848 .39972 L p .967 .967 .967 r
F P
0 g
s
.46378 .36718 m .46467 .38119 L .35562 .36186 L p .893 .893 .893 r
F P
0 g
s
.46467 .38119 m .46378 .36718 L .54724 .37025 L p .932 .932 .932 r
F P
0 g
s
.54724 .37025 m .57344 .38532 L .46467 .38119 L p .932 .932 .932 r
F P
0 g
s
.2127 .3297 m .25865 .328 L .35562 .36186 L p .865 .865 .865 r
F P
0 g
s
.38006 .35227 m .35562 .36186 L .25865 .328 L p .865 .865 .865 r
F P
0 g
s
.35562 .36186 m .38006 .35227 L .46378 .36718 L p .893 .893 .893 r
F P
0 g
s
.25865 .328 m .2127 .3297 L .12142 .27285 L p .854 .854 .854 r
F P
0 g
s
.57344 .38532 m .54724 .37025 L .62017 .36204 L p .967 .967 .967 r
F P
0 g
s
.62017 .36204 m .66954 .3749 L .57344 .38532 L p .967 .967 .967 r
F P
0 g
s
.7172 .38731 m .66954 .3749 L .74046 .35203 L p .99 .99 .99 r
F P
0 g
s
.74046 .35203 m .80696 .35951 L .7172 .38731 L p .99 .99 .99 r
F P
0 g
s
.46285 .35244 m .46378 .36718 L .38006 .35227 L p .893 .893 .893 r
F P
0 g
s
.46378 .36718 m .46285 .35244 L .5198 .35447 L p .932 .932 .932 r
F P
0 g
s
.5198 .35447 m .54724 .37025 L .46378 .36718 L p .932 .932 .932 r
F P
0 g
s
.12142 .27285 m .18624 .28196 L .25865 .328 L p .854 .854 .854 r
F P
0 g
s
.30633 .32625 m .25865 .328 L .18624 .28196 L p .854 .854 .854 r
F P
0 g
s
.25865 .328 m .30633 .32625 L .38006 .35227 L p .865 .865 .865 r
F P
0 g
s
.40568 .34221 m .38006 .35227 L .30633 .32625 L p .865 .865 .865 r
F P
0 g
s
.38006 .35227 m .40568 .34221 L .46285 .35244 L p .893 .893 .893 r
F P
0 g
s
.66954 .3749 m .62017 .36204 L .67263 .3444 L p .99 .99 .99 r
F P
0 g
s
.67263 .3444 m .74046 .35203 L .66954 .3749 L p .99 .99 .99 r
F P
0 g
s
.54724 .37025 m .5198 .35447 L .56899 .34872 L p .967 .967 .967 r
F P
0 g
s
.56899 .34872 m .62017 .36204 L .54724 .37025 L p .967 .967 .967 r
F P
0 g
s
.18624 .28196 m .25254 .29128 L .30633 .32625 L p .854 .854 .854 r
F P
0 g
s
.35585 .32443 m .30633 .32625 L .25254 .29128 L p .854 .854 .854 r
F P
0 g
s
.30633 .32625 m .35585 .32443 L .40568 .34221 L p .865 .865 .865 r
F P
0 g
s
.18624 .28196 m .12142 .27285 L .0736 .20532 L p .858 .858 .858 r
F P
0 g
s
.62017 .36204 m .56899 .34872 L .60345 .33661 L p .99 .99 .99 r
F P
0 g
s
.60345 .33661 m .67263 .3444 L .62017 .36204 L p .99 .99 .99 r
F P
0 g
s
.46187 .33692 m .46285 .35244 L .40568 .34221 L p .893 .893 .893 r
F P
0 g
s
.46285 .35244 m .46187 .33692 L .49103 .33793 L p .932 .932 .932 r
F P
0 g
s
.49103 .33793 m .5198 .35447 L .46285 .35244 L p .932 .932 .932 r
F P
0 g
s
.80696 .35951 m .74046 .35203 L .77413 .32056 L p .999 .999 .999 r
F P
0 g
s
.77413 .32056 m .85245 .32056 L .80696 .35951 L p .999 .999 .999 r
F P
0 g
s
.43258 .33165 m .40568 .34221 L .35585 .32443 L p .865 .865 .865 r
F P
0 g
s
.40568 .34221 m .43258 .33165 L .46187 .33692 L p .893 .893 .893 r
F P
0 g
s
.5198 .35447 m .49103 .33793 L .51592 .3349 L p .967 .967 .967 r
F P
0 g
s
.51592 .3349 m .56899 .34872 L .5198 .35447 L p .967 .967 .967 r
F P
0 g
s
.0736 .20532 m .15042 .22818 L .18624 .28196 L p .858 .858 .858 r
F P
0 g
s
.25254 .29128 m .18624 .28196 L .15042 .22818 L p .858 .858 .858 r
F P
0 g
s
.74046 .35203 m .67263 .3444 L .6958 .32056 L p .999 .999 .999 r
F P
0 g
s
.6958 .32056 m .77413 .32056 L .74046 .35203 L p .999 .999 .999 r
F P
0 g
s
.25254 .29128 m .32037 .30082 L .35585 .32443 L p .854 .854 .854 r
F P
0 g
s
.40731 .32253 m .35585 .32443 L .32037 .30082 L p .854 .854 .854 r
F P
0 g
s
.35585 .32443 m .40731 .32253 L .43258 .33165 L p .865 .865 .865 r
F P
0 g
s
.56899 .34872 m .51592 .3349 L .53286 .32867 L p .99 .99 .99 r
F P
0 g
s
.53286 .32867 m .60345 .33661 L .56899 .34872 L p .99 .99 .99 r
F P
0 g
s
.15042 .22818 m .22755 .25114 L .25254 .29128 L p .858 .858 .858 r
F P
0 g
s
.32037 .30082 m .25254 .29128 L .22755 .25114 L p .858 .858 .858 r
F P
0 g
s
.67263 .3444 m .60345 .33661 L .61748 .32056 L p .999 .999 .999 r
F P
0 g
s
.61748 .32056 m .6958 .32056 L .67263 .3444 L p .999 .999 .999 r
F P
0 g
s
.46084 .32056 m .46187 .33692 L .43258 .33165 L closepath p .893 .893 .893 r
F P
0 g
s
.46084 .32056 m .49103 .33793 L .46187 .33692 L closepath p .932 .932 .932 r
F P
0 g
s
.46084 .32056 m .43258 .33165 L .40731 .32253 L closepath p .865 .865 .865 r
F P
0 g
s
.46084 .32056 m .51592 .3349 L .49103 .33793 L closepath p .967 .967 .967 r
F P
0 g
s
.22755 .25114 m .305 .27418 L .32037 .30082 L p .858 .858 .858 r
F P
0 g
s
.38978 .31057 m .32037 .30082 L .305 .27418 L p .858 .858 .858 r
F P
0 g
s
.32037 .30082 m .38978 .31057 L .40731 .32253 L p .854 .854 .854 r
F P
0 g
s
.60345 .33661 m .53286 .32867 L .53916 .32056 L p .999 .999 .999 r
F P
0 g
s
.53916 .32056 m .61748 .32056 L .60345 .33661 L p .999 .999 .999 r
F P
0 g
s
.46084 .32056 m .40731 .32253 L .38978 .31057 L closepath p .854 .854 .854 r
F P
0 g
s
.46084 .32056 m .53286 .32867 L .51592 .3349 L closepath p .99 .99 .99 r
F P
0 g
s
.305 .27418 m .38276 .29733 L .38978 .31057 L p .858 .858 .858 r
F P
0 g
s
.46084 .32056 m .38978 .31057 L .38276 .29733 L closepath p .858 .858 .858 r
F P
0 g
s
.46084 .32056 m .53916 .32056 L .53286 .32867 L closepath p .999 .999 .999 r
F P
0 g
s
.85245 .32056 m .77413 .32056 L .76094 .28642 L p .999 .999 .999 r
F P
0 g
s
.76094 .28642 m .84 .27743 L .85245 .32056 L p .999 .999 .999 r
F P
0 g
s
.85245 .32056 m
.9014 .32056 L
s
.77413 .32056 m .6958 .32056 L .68354 .29523 L p .999 .999 .999 r
F P
0 g
s
.68354 .29523 m .76094 .28642 L .77413 .32056 L p .999 .999 .999 r
F P
0 g
s
.6958 .32056 m .61748 .32056 L .60776 .30385 L p .999 .999 .999 r
F P
0 g
s
.60776 .30385 m .68354 .29523 L .6958 .32056 L p .999 .999 .999 r
F P
0 g
s
.61748 .32056 m .53916 .32056 L .53354 .31229 L p .999 .999 .999 r
F P
0 g
s
.53354 .31229 m .60776 .30385 L .61748 .32056 L p .999 .999 .999 r
F P
0 g
s
.46084 .32056 m .53354 .31229 L .53916 .32056 L closepath p .999 .999 .999 r
F P
0 g
s
.46084 .32056 m .51653 .30567 L .53354 .31229 L closepath p .997 .997 .997 r
F P
0 g
s
.46084 .32056 m .49058 .30232 L .51653 .30567 L closepath p 1 1 1 r
F P
0 g
s
.46084 .32056 m .45975 .3033 L .49058 .30232 L closepath p 1 1 1 r
F P
0 g
s
.46084 .32056 m .42907 .3089 L .45975 .3033 L closepath p 1 1 1 r
F P
0 g
s
.46084 .32056 m .40353 .31851 L .42907 .3089 L closepath p 1 1 1 r
F P
0 g
s
.46084 .32056 m .38714 .33079 L .40353 .31851 L closepath p 1 1 1 r
F P
0 g
s
.46084 .32056 m .38228 .3439 L .38714 .33079 L closepath p 1 1 1 r
F P
0 g
s
.31167 .34127 m .38714 .33079 L .38228 .3439 L p 1 1 1 r
F P
0 g
s
.38228 .3439 m .30339 .36733 L .31167 .34127 L p 1 1 1 r
F P
0 g
s
.23434 .352 m .31167 .34127 L .30339 .36733 L p 1 1 1 r
F P
0 g
s
.30339 .36733 m .22418 .39085 L .23434 .352 L p 1 1 1 r
F P
0 g
s
.15509 .363 m .23434 .352 L .22418 .39085 L p 1 1 1 r
F P
0 g
s
.22418 .39085 m .14464 .41448 L .15509 .363 L p 1 1 1 r
F P
0 g
s
.07385 .37428 m .15509 .363 L .14464 .41448 L p 1 1 1 r
F P
0 g
s
.14464 .41448 m .06477 .4382 L .07385 .37428 L p 1 1 1 r
F P
0 g
s
.60776 .30385 m .53354 .31229 L .51653 .30567 L p .997 .997 .997 r
F P
0 g
s
.34382 .31638 m .40353 .31851 L .38714 .33079 L p 1 1 1 r
F P
0 g
s
.38714 .33079 m .31167 .34127 L .34382 .31638 L p 1 1 1 r
F P
0 g
s
.51653 .30567 m .57442 .29019 L .60776 .30385 L p .997 .997 .997 r
F P
0 g
s
.57442 .29019 m .51653 .30567 L .49058 .30232 L p 1 1 1 r
F P
0 g
s
.39559 .2966 m .42907 .3089 L .40353 .31851 L p 1 1 1 r
F P
0 g
s
.40353 .31851 m .34382 .31638 L .39559 .2966 L p 1 1 1 r
F P
0 g
s
.68354 .29523 m .60776 .30385 L .57442 .29019 L p .997 .997 .997 r
F P
0 g
s
.28157 .31415 m .34382 .31638 L .31167 .34127 L p 1 1 1 r
F P
0 g
s
.31167 .34127 m .23434 .352 L .28157 .31415 L p 1 1 1 r
F P
0 g
s
.49058 .30232 m .52187 .28311 L .57442 .29019 L p 1 1 1 r
F P
0 g
s
.52187 .28311 m .49058 .30232 L .45975 .3033 L p 1 1 1 r
F P
0 g
s
.4586 .28504 m .45975 .3033 L .42907 .3089 L p 1 1 1 r
F P
0 g
s
.42907 .3089 m .39559 .2966 L .4586 .28504 L p 1 1 1 r
F P
0 g
s
.45975 .3033 m .4586 .28504 L .52187 .28311 L p 1 1 1 r
F P
0 g
s
.76094 .28642 m .68354 .29523 L .63462 .27409 L p .997 .997 .997 r
F P
0 g
s
.57442 .29019 m .63462 .27409 L .68354 .29523 L p .997 .997 .997 r
F P
0 g
s
.21661 .31183 m .28157 .31415 L .23434 .352 L p 1 1 1 r
F P
0 g
s
.23434 .352 m .15509 .363 L .21661 .31183 L p 1 1 1 r
F P
0 g
s
.63462 .27409 m .57442 .29019 L .52187 .28311 L p 1 1 1 r
F P
0 g
s
.36028 .28364 m .39559 .2966 L .34382 .31638 L p 1 1 1 r
F P
0 g
s
.34382 .31638 m .28157 .31415 L .36028 .28364 L p 1 1 1 r
F P
0 g
s
.84 .27743 m .76094 .28642 L .69729 .25734 L p .997 .997 .997 r
F P
0 g
s
.63462 .27409 m .69729 .25734 L .76094 .28642 L p .997 .997 .997 r
F P
0 g
s
.14876 .3094 m .21661 .31183 L .15509 .363 L p 1 1 1 r
F P
0 g
s
.15509 .363 m .07385 .37428 L .14876 .3094 L p 1 1 1 r
F P
0 g
s
.52187 .28311 m .55484 .26288 L .63462 .27409 L p 1 1 1 r
F P
0 g
s
.55484 .26288 m .52187 .28311 L .4586 .28504 L p 1 1 1 r
F P
0 g
s
.45737 .26571 m .4586 .28504 L .39559 .2966 L p 1 1 1 r
F P
0 g
s
.39559 .2966 m .36028 .28364 L .45737 .26571 L p 1 1 1 r
F P
0 g
s
.69729 .25734 m .76258 .23988 L .84 .27743 L p .997 .997 .997 r
F P
0 g
s
.4586 .28504 m .45737 .26571 L .55484 .26288 L p 1 1 1 r
F P
0 g
s
.69729 .25734 m .63462 .27409 L .55484 .26288 L p 1 1 1 r
F P
0 g
s
.32297 .26993 m .36028 .28364 L .28157 .31415 L p 1 1 1 r
F P
0 g
s
.28157 .31415 m .21661 .31183 L .32297 .26993 L p 1 1 1 r
F P
0 g
s
.55484 .26288 m .58963 .24153 L .69729 .25734 L p 1 1 1 r
F P
0 g
s
.58963 .24153 m .55484 .26288 L .45737 .26571 L p 1 1 1 r
F P
0 g
s
.76258 .23988 m .69729 .25734 L .58963 .24153 L p 1 1 1 r
F P
0 g
s
.45608 .2452 m .45737 .26571 L .36028 .28364 L p 1 1 1 r
F P
0 g
s
.36028 .28364 m .32297 .26993 L .45608 .2452 L p 1 1 1 r
F P
0 g
s
.28349 .25544 m .32297 .26993 L .21661 .31183 L p 1 1 1 r
F P
0 g
s
.21661 .31183 m .14876 .3094 L .28349 .25544 L p 1 1 1 r
F P
0 g
s
.45737 .26571 m .45608 .2452 L .58963 .24153 L p 1 1 1 r
F P
0 g
s
.58963 .24153 m .62639 .21897 L .76258 .23988 L p 1 1 1 r
F P
0 g
s
.62639 .21897 m .58963 .24153 L .45608 .2452 L p 1 1 1 r
F P
0 g
s
.4547 .2234 m .45608 .2452 L .32297 .26993 L p 1 1 1 r
F P
0 g
s
.32297 .26993 m .28349 .25544 L .4547 .2234 L p 1 1 1 r
F P
0 g
s
.45608 .2452 m .4547 .2234 L .62639 .21897 L p 1 1 1 r
F P
0 g
s
gsave
.89289 .34183 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4668 .51799 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 178.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 287}, {177.313, 0}} -> {0, 0, 0, 0}}],
 StyleBox["     ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% PlotRegion
.1 .9 .1 .9 MPlotRegion
% Scaling calculations
0.5 0.434783 0.5 0.434783 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
1 .5 L
s
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
.5 .50435 m
.49998 .50435 L
.49997 .50435 L
.49995 .50435 L
.49993 .50435 L
.4999 .50435 L
.49987 .50435 L
.49983 .50434 L
.4998 .50434 L
.49973 .50434 L
.49966 .50433 L
.49959 .50433 L
.49945 .50431 L
.4993 .50429 L
.49916 .50427 L
.49885 .50419 L
.49859 .50411 L
.49832 .50401 L
.4978 .50375 L
.49733 .50343 L
.49689 .50304 L
.49651 .5026 L
.49621 .50214 L
.49608 .50189 L
.49596 .50161 L
.49586 .50133 L
.49579 .50107 L
.49573 .50079 L
.4957 .50064 L
.49568 .5005 L
.49567 .50036 L
.49566 .50029 L
.49566 .50021 L
.49565 .50015 L
.49565 .50011 L
.49565 .50009 L
.49565 .50008 L
.49565 .50006 L
.49565 .50005 L
.49565 .50003 L
.49565 .50002 L
.49565 .5 L
.49565 .49998 L
.49565 .49996 L
.49565 .49995 L
.49565 .49993 L
.49565 .49991 L
.49565 .49988 L
.49565 .49985 L
.49566 .49981 L
Mistroke
.49566 .49974 L
.49566 .49968 L
.49568 .49954 L
.4957 .49939 L
.49572 .49924 L
.49575 .49908 L
.49582 .4988 L
.49591 .49853 L
.49602 .49825 L
.49627 .49777 L
.4966 .49729 L
.49698 .49688 L
.49743 .49649 L
.49791 .49619 L
.49841 .49595 L
.49868 .49586 L
.49897 .49578 L
.4991 .49575 L
.49924 .49572 L
.49936 .4957 L
.4995 .49568 L
.49963 .49567 L
.49974 .49566 L
.49981 .49566 L
.49987 .49565 L
.4999 .49565 L
.49992 .49565 L
.49993 .49565 L
.49995 .49565 L
.49997 .49565 L
.49998 .49565 L
.5 .49565 L
Mfstroke
.4999 .69449 m
.49915 .69449 L
.49846 .69448 L
.49767 .69448 L
.49692 .69446 L
.49559 .69444 L
.49415 .6944 L
.49256 .69435 L
.49087 .69427 L
.48785 .69411 L
.48473 .69389 L
.48182 .69364 L
.47519 .6929 L
.46847 .69192 L
.46234 .69081 L
.44871 .68761 L
.43708 .68403 L
.42466 .6793 L
.40137 .66763 L
.38062 .65354 L
.36076 .63578 L
.34408 .61626 L
.3306 .59555 L
.3248 .58444 L
.31927 .57184 L
.3148 .55937 L
.31147 .54777 L
.30879 .53555 L
.30765 .52875 L
.30679 .52228 L
.30618 .51612 L
.30595 .51301 L
.30575 .50956 L
.30562 .50663 L
.30557 .50498 L
.30556 .5042 L
.30554 .50347 L
.30553 .50277 L
.30552 .50214 L
.30552 .50144 L
.30551 .50068 L
.30551 .49996 L
.30551 .49918 L
.30552 .49843 L
.30552 .49775 L
.30553 .49695 L
.30555 .49618 L
.30558 .49475 L
.30563 .49321 L
.30569 .49154 L
Mistroke
.30585 .48852 L
.30603 .48573 L
.30661 .47934 L
.30745 .47257 L
.3085 .46604 L
.30987 .45903 L
.31302 .44648 L
.31695 .43428 L
.32196 .42173 L
.33314 .40008 L
.34792 .37876 L
.36471 .36028 L
.38499 .34316 L
.40656 .32943 L
.42884 .319 L
.44081 .31474 L
.45379 .31108 L
.45966 .30974 L
.46603 .3085 L
.47156 .3076 L
.47763 .3068 L
.48324 .30623 L
.48847 .30585 L
.49137 .3057 L
.494 .3056 L
.49546 .30556 L
.49623 .30555 L
.49704 .30553 L
.49775 .30552 L
.49853 .30552 L
.49924 .30551 L
.4999 .30551 L
Mfstroke
.49986 .77502 m
.4988 .77501 L
.49783 .77501 L
.49671 .775 L
.49565 .77498 L
.49377 .77494 L
.49172 .77489 L
.48947 .77481 L
.48709 .77471 L
.48282 .77448 L
.47841 .77417 L
.47429 .77381 L
.46492 .77277 L
.45541 .77138 L
.44675 .76981 L
.42748 .76528 L
.41102 .76022 L
.39346 .75354 L
.36054 .73703 L
.3312 .71711 L
.3031 .692 L
.27952 .66439 L
.26046 .63511 L
.25226 .6194 L
.24444 .60159 L
.23811 .58396 L
.23341 .56754 L
.22962 .55026 L
.22801 .54066 L
.2268 .53151 L
.22593 .5228 L
.2256 .51839 L
.22532 .51352 L
.22514 .50938 L
.22508 .50705 L
.22505 .50594 L
.22503 .50491 L
.22501 .50392 L
.225 .50303 L
.22499 .50203 L
.22499 .50097 L
.22498 .49994 L
.22499 .49883 L
.22499 .49779 L
.225 .49682 L
.22502 .49568 L
.22504 .4946 L
.22509 .49258 L
.22515 .4904 L
.22525 .48803 L
Mistroke
.22546 .48377 L
.22573 .47982 L
.22654 .47079 L
.22773 .46121 L
.22921 .45198 L
.23116 .44207 L
.2356 .42432 L
.24116 .40707 L
.24824 .38932 L
.26406 .35871 L
.28496 .32856 L
.3087 .30242 L
.33738 .27822 L
.36788 .2588 L
.39938 .24405 L
.4163 .23803 L
.43465 .23286 L
.44296 .23097 L
.45196 .22921 L
.45979 .22794 L
.46837 .22681 L
.47631 .22601 L
.4837 .22547 L
.48779 .22526 L
.49151 .22512 L
.49358 .22506 L
.49466 .22504 L
.49581 .22502 L
.49682 .225 L
.49792 .22499 L
.49892 .22499 L
.49986 .22498 L
Mfstroke
.49983 .83681 m
.49853 .83681 L
.49734 .8368 L
.49597 .83679 L
.49467 .83677 L
.49237 .83672 L
.48986 .83666 L
.48711 .83656 L
.48419 .83644 L
.47896 .83615 L
.47356 .83577 L
.46851 .83533 L
.45704 .83406 L
.44539 .83235 L
.43479 .83044 L
.41119 .82489 L
.39103 .8187 L
.36952 .81051 L
.3292 .79029 L
.29327 .7659 L
.25886 .73514 L
.22999 .70133 L
.20664 .66547 L
.19659 .64623 L
.18701 .62441 L
.17927 .60282 L
.17351 .58272 L
.16886 .56156 L
.16689 .54979 L
.16541 .53859 L
.16435 .52792 L
.16394 .52252 L
.1636 .51656 L
.16339 .51148 L
.1633 .50863 L
.16327 .50727 L
.16324 .50601 L
.16323 .5048 L
.16321 .50371 L
.1632 .50249 L
.16319 .50119 L
.16319 .49993 L
.16319 .49857 L
.1632 .49729 L
.16321 .4961 L
.16323 .49471 L
.16326 .49339 L
.16331 .49091 L
.1634 .48825 L
.16351 .48534 L
Mistroke
.16378 .48012 L
.1641 .47529 L
.1651 .46423 L
.16656 .4525 L
.16836 .44119 L
.17075 .42905 L
.1762 .40731 L
.183 .38619 L
.19167 .36445 L
.21104 .32696 L
.23664 .29004 L
.26571 .25803 L
.30083 .22839 L
.33819 .20461 L
.37677 .18654 L
.3975 .17917 L
.41997 .17284 L
.43014 .17052 L
.44117 .16837 L
.45075 .16681 L
.46127 .16543 L
.47098 .16444 L
.48003 .16378 L
.48505 .16352 L
.48961 .16335 L
.49213 .16328 L
.49346 .16325 L
.49487 .16323 L
.4961 .16321 L
.49745 .1632 L
.49868 .16319 L
.49983 .16319 L
Mfstroke
.49981 .88891 m
.4983 .8889 L
.49693 .88889 L
.49534 .88888 L
.49385 .88886 L
.49118 .88881 L
.4883 .88873 L
.48512 .88862 L
.48174 .88848 L
.4757 .88815 L
.46947 .88771 L
.46364 .8872 L
.45039 .88573 L
.43694 .88376 L
.4247 .88155 L
.39745 .87514 L
.37418 .86799 L
.34934 .85854 L
.30278 .83519 L
.26129 .80703 L
.22156 .77151 L
.18822 .73247 L
.16126 .69106 L
.14966 .66885 L
.1386 .64366 L
.12966 .61873 L
.12301 .59551 L
.11764 .57108 L
.11537 .55749 L
.11366 .54456 L
.11243 .53224 L
.11196 .52601 L
.11156 .51912 L
.11132 .51326 L
.11122 .50996 L
.11118 .5084 L
.11116 .50694 L
.11113 .50555 L
.11112 .50428 L
.1111 .50287 L
.1111 .50137 L
.11109 .49992 L
.1111 .49835 L
.11111 .49687 L
.11112 .4955 L
.11114 .4939 L
.11117 .49237 L
.11124 .48951 L
.11133 .48643 L
.11146 .48307 L
Mistroke
.11177 .47705 L
.11214 .47146 L
.11329 .4587 L
.11498 .44515 L
.11707 .43209 L
.11982 .41808 L
.12611 .39297 L
.13397 .36859 L
.14398 .34349 L
.16635 .30019 L
.1959 .25757 L
.22947 .2206 L
.27003 .18637 L
.31316 .15892 L
.35771 .13806 L
.38164 .12954 L
.40759 .12223 L
.41934 .11955 L
.43207 .11707 L
.44313 .11527 L
.45528 .11367 L
.4665 .11254 L
.47695 .11178 L
.48274 .11148 L
.488 .11128 L
.49092 .1112 L
.49245 .11117 L
.49408 .11114 L
.4955 .11112 L
.49706 .11111 L
.49848 .1111 L
.49981 .11109 L
Mfstroke
.5 .50435 m
.49996 .58767 L
.49994 .62669 L
.49992 .65461 L
.49991 .67736 L
.4999 .69873 L
.49989 .71733 L
.49988 .7355 L
.49987 .75176 L
.49987 .76647 L
.49986 .78128 L
.49985 .79484 L
.49985 .80731 L
.49984 .82005 L
.49983 .83186 L
.49983 .84396 L
.49982 .85523 L
.49982 .86575 L
.49981 .87661 L
.49981 .88679 L
.4998 .89731 L
.4998 .9072 L
.49979 .91649 L
.49979 .92614 L
.49978 .93478 L
s
.49915 .50426 m
.48286 .58598 L
.47524 .62424 L
.46978 .65162 L
.46533 .67394 L
.46116 .6949 L
.45752 .71314 L
.45397 .73096 L
.45079 .74691 L
.44792 .76134 L
.44502 .77586 L
.44237 .78915 L
.43993 .80138 L
.43744 .81388 L
.43514 .82546 L
.43277 .83733 L
.43057 .84838 L
.42851 .85869 L
.42639 .86935 L
.4244 .87933 L
.42234 .88965 L
.42041 .89934 L
.41859 .90845 L
.41671 .91792 L
.41502 .9264 L
s
.49833 .50402 m
.46643 .58099 L
.45149 .61703 L
.4408 .64282 L
.43209 .66384 L
.4239 .68359 L
.41678 .70077 L
.40982 .71755 L
.4036 .73258 L
.39796 .74617 L
.39229 .75984 L
.3871 .77237 L
.38233 .78389 L
.37745 .79566 L
.37293 .80656 L
.36829 .81775 L
.36398 .82816 L
.35995 .83787 L
.35579 .84791 L
.35189 .85731 L
.34786 .86703 L
.34408 .87616 L
.34052 .88474 L
.33682 .89366 L
.33352 .90165 L
s
.49758 .50362 m
.45128 .57289 L
.4296 .60533 L
.41409 .62854 L
.40145 .64746 L
.38957 .66523 L
.37923 .68069 L
.36914 .69579 L
.3601 .70932 L
.35193 .72155 L
.3437 .73386 L
.33617 .74513 L
.32924 .7555 L
.32215 .76609 L
.3156 .77591 L
.30887 .78597 L
.30261 .79534 L
.29676 .80408 L
.29072 .81312 L
.28507 .82158 L
.27922 .83033 L
.27373 .83854 L
.26857 .84627 L
.2632 .8543 L
.2584 .86148 L
s
.49692 .50308 m
.43801 .56199 L
.41042 .58958 L
.39068 .60932 L
.37459 .62541 L
.35947 .64053 L
.34632 .65368 L
.33348 .66652 L
.32198 .67802 L
.31157 .68843 L
.3011 .6989 L
.29152 .70848 L
.2827 .7173 L
.27369 .72631 L
.26534 .73466 L
.25678 .74322 L
.24881 .75119 L
.24138 .75862 L
.23369 .76631 L
.2265 .7735 L
.21906 .78094 L
.21207 .78793 L
.2055 .7945 L
.19867 .80133 L
.19256 .80744 L
s
.49638 .50242 m
.42711 .54872 L
.39467 .5704 L
.37146 .58591 L
.35254 .59855 L
.33477 .61043 L
.31931 .62077 L
.30421 .63086 L
.29068 .6399 L
.27845 .64807 L
.26614 .6563 L
.25487 .66383 L
.2445 .67076 L
.23391 .67785 L
.22409 .6844 L
.21403 .69113 L
.20466 .69739 L
.19592 .70324 L
.18688 .70928 L
.17842 .71493 L
.16967 .72078 L
.16146 .72627 L
.15373 .73143 L
.1457 .7368 L
.13852 .7416 L
s
.49598 .50167 m
.41901 .53357 L
.38297 .54851 L
.35718 .5592 L
.33616 .56791 L
.31641 .5761 L
.29923 .58322 L
.28245 .59018 L
.26742 .5964 L
.25383 .60204 L
.24016 .60771 L
.22763 .6129 L
.21611 .61767 L
.20434 .62255 L
.19344 .62707 L
.18225 .63171 L
.17184 .63602 L
.16213 .64005 L
.15209 .64421 L
.14269 .64811 L
.13297 .65214 L
.12384 .65592 L
.11526 .65948 L
.10634 .66318 L
.09835 .66648 L
s
.49574 .50085 m
.41402 .51714 L
.37576 .52476 L
.34838 .53022 L
.32606 .53467 L
.3051 .53884 L
.28686 .54248 L
.26904 .54603 L
.25309 .54921 L
.23866 .55208 L
.22414 .55498 L
.21085 .55763 L
.19862 .56007 L
.18612 .56256 L
.17454 .56486 L
.16267 .56723 L
.15162 .56943 L
.14131 .57149 L
.13065 .57361 L
.12067 .5756 L
.11035 .57766 L
.10066 .57959 L
.09155 .58141 L
.08208 .58329 L
.0736 .58498 L
s
.49565 .5 m
.41233 .50004 L
.37331 .50006 L
.34539 .50008 L
.32264 .50009 L
.30127 .5001 L
.28267 .50011 L
.2645 .50012 L
.24824 .50013 L
.23353 .50013 L
.21872 .50014 L
.20516 .50015 L
.19269 .50015 L
.17995 .50016 L
.16814 .50017 L
.15604 .50017 L
.14477 .50018 L
.13425 .50018 L
.12339 .50019 L
.11321 .50019 L
.10269 .5002 L
.0928 .5002 L
.08351 .50021 L
.07386 .50021 L
.06522 .50022 L
s
.49573 .49915 m
.414 .48295 L
.37573 .47536 L
.34835 .46993 L
.32603 .46551 L
.30506 .46135 L
.28681 .45773 L
.269 .4542 L
.25304 .45104 L
.23861 .44818 L
.22409 .4453 L
.21079 .44266 L
.19856 .44024 L
.18606 .43776 L
.17448 .43546 L
.1626 .43311 L
.15155 .43091 L
.14123 .42887 L
.13058 .42676 L
.1206 .42478 L
.11027 .42273 L
.10058 .42081 L
.09147 .419 L
.08199 .41712 L
.07352 .41544 L
s
.49598 .49834 m
.41897 .46651 L
.38292 .45161 L
.35712 .44094 L
.33609 .43225 L
.31634 .42409 L
.29915 .41698 L
.28236 .41004 L
.26733 .40383 L
.25373 .39821 L
.24005 .39255 L
.22752 .38737 L
.216 .38261 L
.20422 .37774 L
.19331 .37323 L
.18212 .36861 L
.1717 .3643 L
.16199 .36029 L
.15195 .35614 L
.14254 .35225 L
.13282 .34823 L
.12368 .34445 L
.1151 .34091 L
.10617 .33722 L
.09819 .33392 L
s
.49638 .49759 m
.42706 .45135 L
.3946 .42971 L
.37137 .41422 L
.35245 .40159 L
.33466 .38973 L
.31919 .37941 L
.30407 .36933 L
.29054 .36031 L
.2783 .35215 L
.26599 .34393 L
.25471 .33641 L
.24433 .32949 L
.23373 .32242 L
.22391 .31587 L
.21384 .30915 L
.20446 .3029 L
.19571 .29707 L
.18667 .29104 L
.17821 .28539 L
.16945 .27955 L
.16123 .27407 L
.1535 .26892 L
.14547 .26356 L
.13828 .25876 L
s
.49692 .49693 m
.43794 .43807 L
.41033 .41051 L
.39057 .39079 L
.37446 .37471 L
.35933 .35961 L
.34617 .34647 L
.33331 .33364 L
.3218 .32215 L
.31139 .31176 L
.3009 .3013 L
.29131 .29173 L
.28248 .28292 L
.27346 .27391 L
.26511 .26558 L
.25654 .25702 L
.24856 .24906 L
.24112 .24164 L
.23343 .23396 L
.22623 .22677 L
.21878 .21934 L
.21178 .21236 L
.20521 .20579 L
.19837 .19897 L
.19225 .19287 L
s
.49758 .49639 m
.45121 .42716 L
.4295 .39474 L
.41396 .37155 L
.4013 .35264 L
.3894 .33488 L
.37905 .31943 L
.36894 .30434 L
.35989 .29082 L
.35171 .2786 L
.34347 .2663 L
.33592 .25504 L
.32898 .24467 L
.32189 .23409 L
.31532 .22428 L
.30858 .21422 L
.30231 .20486 L
.29646 .19612 L
.29041 .18709 L
.28475 .17864 L
.27889 .1699 L
.27339 .16168 L
.26822 .15397 L
.26285 .14594 L
.25804 .13876 L
s
.49833 .49598 m
.46635 .41904 L
.45137 .38302 L
.44066 .35724 L
.43192 .33623 L
.42372 .31649 L
.41658 .29931 L
.40961 .28254 L
.40336 .26752 L
.39772 .25394 L
.39203 .24026 L
.38683 .22775 L
.38204 .21623 L
.37715 .20446 L
.37262 .19356 L
.36797 .18238 L
.36365 .17198 L
.35961 .16227 L
.35544 .15223 L
.35154 .14284 L
.3475 .13312 L
.3437 .12399 L
.34014 .11542 L
.33643 .1065 L
.33311 .09852 L
s
.49915 .49574 m
.48278 .41403 L
.47511 .37578 L
.46963 .34841 L
.46516 .3261 L
.46096 .30514 L
.45731 .2869 L
.45374 .26909 L
.45054 .25314 L
.44765 .23872 L
.44475 .2242 L
.44208 .21091 L
.43963 .19868 L
.43713 .18618 L
.43481 .17461 L
.43243 .16274 L
.43022 .15169 L
.42815 .14138 L
.42602 .13072 L
.42402 .12075 L
.42195 .11043 L
.42001 .10074 L
.41819 .09163 L
.41629 .08216 L
.41459 .07369 L
s
.49999 .49565 m
.49987 .41233 L
.49981 .37331 L
.49977 .34539 L
.49973 .32264 L
.4997 .30127 L
.49967 .28267 L
.49965 .2645 L
.49962 .24824 L
.4996 .23353 L
.49958 .21872 L
.49956 .20516 L
.49954 .19269 L
.49952 .17995 L
.4995 .16814 L
.49948 .15604 L
.49947 .14477 L
.49945 .13425 L
.49944 .12339 L
.49942 .11321 L
.4994 .10269 L
.49939 .0928 L
.49938 .08351 L
.49936 .07386 L
.49935 .06522 L
s
gsave
.97826 .54348 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.54348 .97826 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97826 .5 m
1 .5 L
s
% Start of user PostScript
1.1 0 1.15 0 MAarrowhead1
% End of user PostScript
.5 .97826 m
.5 1 L
s
% Start of user PostScript
0 1.1 0 1.15 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{178.313, 178.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{17.6875, 159.563}, {159.625, 17.75}} -> {-1, -1, 0, 0}}],
 "  ",
 StyleBox["\n\t\t\t(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  A portion of  ",
 Cell[BoxData[
  SubscriptBox["D", "2"]]],
 "  and its image under  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["z", 
    FractionBox["1", "2"]]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .6193 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.22045e-016 1 -0.147002 1 [
[ 0 0 0 0 ]
[ 1 .6193 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .6193 L
0 .6193 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.53377 .43588 m .533 .44741 L .40582 .45287 L p 1 1 1 r
F P
0 g
s
.533 .44741 m .53377 .43588 L .63796 .41773 L p 1 1 1 r
F P
0 g
s
.63796 .41773 m .66043 .42529 L .533 .44741 L p 1 1 1 r
F P
0 g
s
.66043 .42529 m .63796 .41773 L .73041 .38647 L p 1 1 1 r
F P
0 g
s
.73041 .38647 m .77451 .38707 L .66043 .42529 L p 1 1 1 r
F P
0 g
s
.42984 .44026 m .40582 .45287 L .29252 .44238 L p .996 .996 .996 r
F P
0 g
s
.40582 .45287 m .42984 .44026 L .53377 .43588 L p 1 1 1 r
F P
0 g
s
.53411 .55179 m .53341 .58944 L .4049 .5653 L p .963 .963 .963 r
F P
0 g
s
.53341 .58944 m .53411 .55179 L .63961 .55486 L p .94 .94 .94 r
F P
0 g
s
.63961 .55486 m .66278 .59356 L .53341 .58944 L p .94 .94 .94 r
F P
0 g
s
.42928 .53188 m .4049 .5653 L .29108 .52153 L p .983 .983 .983 r
F P
0 g
s
.4049 .5653 m .42928 .53188 L .53411 .55179 L p .963 .963 .963 r
F P
0 g
s
.66278 .59356 m .63961 .55486 L .73354 .54155 L p .916 .916 .916 r
F P
0 g
s
.73354 .54155 m .7791 .57815 L .66278 .59356 L p .916 .916 .916 r
F P
0 g
s
.53458 .42381 m .53377 .43588 L .42984 .44026 L p 1 1 1 r
F P
0 g
s
.53377 .43588 m .53458 .42381 L .61449 .40983 L p 1 1 1 r
F P
0 g
s
.61449 .40983 m .63796 .41773 L .53377 .43588 L p 1 1 1 r
F P
0 g
s
.63796 .41773 m .61449 .40983 L .68473 .38585 L p 1 1 1 r
F P
0 g
s
.68473 .38585 m .73041 .38647 L .63796 .41773 L p 1 1 1 r
F P
0 g
s
.77451 .38707 m .73041 .38647 L .79911 .34432 L p 1 1 1 r
F P
0 g
s
.79911 .34432 m .86109 .33496 L .77451 .38707 L p 1 1 1 r
F P
0 g
s
.29252 .44238 m .33818 .43146 L .42984 .44026 L p .996 .996 .996 r
F P
0 g
s
.45491 .42709 m .42984 .44026 L .33818 .43146 L p .996 .996 .996 r
F P
0 g
s
.42984 .44026 m .45491 .42709 L .53458 .42381 L p 1 1 1 r
F P
0 g
s
.53485 .51251 m .53411 .55179 L .42928 .53188 L p .963 .963 .963 r
F P
0 g
s
.53411 .55179 m .53485 .51251 L .61553 .51463 L p .94 .94 .94 r
F P
0 g
s
.61553 .51463 m .63961 .55486 L .53411 .55179 L p .94 .94 .94 r
F P
0 g
s
.33818 .43146 m .29252 .44238 L .20732 .41805 L p .994 .994 .994 r
F P
0 g
s
.29108 .52153 m .33727 .4957 L .42928 .53188 L p .983 .983 .983 r
F P
0 g
s
.45464 .49711 m .42928 .53188 L .33727 .4957 L p .983 .983 .983 r
F P
0 g
s
.42928 .53188 m .45464 .49711 L .53485 .51251 L p .963 .963 .963 r
F P
0 g
s
.63961 .55486 m .61553 .51463 L .68664 .50387 L p .916 .916 .916 r
F P
0 g
s
.68664 .50387 m .73354 .54155 L .63961 .55486 L p .916 .916 .916 r
F P
0 g
s
.33727 .4957 m .29108 .52153 L .20625 .45977 L p .995 .995 .995 r
F P
0 g
s
.53542 .41114 m .53458 .42381 L .45491 .42709 L p 1 1 1 r
F P
0 g
s
.53458 .42381 m .53542 .41114 L .58993 .40157 L p 1 1 1 r
F P
0 g
s
.58993 .40157 m .61449 .40983 L .53458 .42381 L p 1 1 1 r
F P
0 g
s
.7791 .57815 m .73354 .54155 L .80356 .51346 L p .893 .893 .893 r
F P
0 g
s
.80356 .51346 m .86776 .5447 L .7791 .57815 L p .893 .893 .893 r
F P
0 g
s
.73041 .38647 m .68473 .38585 L .73578 .35388 L p 1 1 1 r
F P
0 g
s
.73578 .35388 m .79911 .34432 L .73041 .38647 L p 1 1 1 r
F P
0 g
s
.61449 .40983 m .58993 .40157 L .63738 .38521 L p 1 1 1 r
F P
0 g
s
.63738 .38521 m .68473 .38585 L .61449 .40983 L p 1 1 1 r
F P
0 g
s
.20732 .41805 m .27084 .41147 L .33818 .43146 L p .994 .994 .994 r
F P
0 g
s
.3854 .42017 m .33818 .43146 L .27084 .41147 L p .994 .994 .994 r
F P
0 g
s
.33818 .43146 m .3854 .42017 L .45491 .42709 L p .996 .996 .996 r
F P
0 g
s
.48112 .41332 m .45491 .42709 L .3854 .42017 L p .996 .996 .996 r
F P
0 g
s
.45491 .42709 m .48112 .41332 L .53542 .41114 L p 1 1 1 r
F P
0 g
s
.53561 .47151 m .53485 .51251 L .45464 .49711 L p .963 .963 .963 r
F P
0 g
s
.53485 .51251 m .53561 .47151 L .59049 .47279 L p .94 .94 .94 r
F P
0 g
s
.59049 .47279 m .61553 .51463 L .53485 .51251 L p .94 .94 .94 r
F P
0 g
s
.20625 .45977 m .27016 .44511 L .33727 .4957 L p .995 .995 .995 r
F P
0 g
s
.38491 .46905 m .33727 .4957 L .27016 .44511 L p .995 .995 .995 r
F P
0 g
s
.33727 .4957 m .38491 .46905 L .45464 .49711 L p .983 .983 .983 r
F P
0 g
s
.48104 .46091 m .45464 .49711 L .38491 .46905 L p .983 .983 .983 r
F P
0 g
s
.45464 .49711 m .48104 .46091 L .53561 .47151 L p .963 .963 .963 r
F P
0 g
s
.61553 .51463 m .59049 .47279 L .63834 .46506 L p .916 .916 .916 r
F P
0 g
s
.63834 .46506 m .68664 .50387 L .61553 .51463 L p .916 .916 .916 r
F P
0 g
s
.73354 .54155 m .68664 .50387 L .73843 .48176 L p .893 .893 .893 r
F P
0 g
s
.73843 .48176 m .80356 .51346 L .73354 .54155 L p .893 .893 .893 r
F P
0 g
s
.68473 .38585 m .63738 .38521 L .67106 .36365 L p 1 1 1 r
F P
0 g
s
.67106 .36365 m .73578 .35388 L .68473 .38585 L p 1 1 1 r
F P
0 g
s
.86109 .33496 m .79911 .34432 L .83266 .29545 L p 1 1 1 r
F P
0 g
s
.83266 .29545 m .9058 .27356 L .86109 .33496 L p 1 1 1 r
F P
0 g
s
.27084 .41147 m .33555 .40476 L .3854 .42017 L p .994 .994 .994 r
F P
0 g
s
.43426 .40848 m .3854 .42017 L .33555 .40476 L p .994 .994 .994 r
F P
0 g
s
.3854 .42017 m .43426 .40848 L .48112 .41332 L p .996 .996 .996 r
F P
0 g
s
.53631 .39784 m .53542 .41114 L .48112 .41332 L p 1 1 1 r
F P
0 g
s
.53542 .41114 m .53631 .39784 L .56421 .39292 L p 1 1 1 r
F P
0 g
s
.56421 .39292 m .58993 .40157 L .53542 .41114 L p 1 1 1 r
F P
0 g
s
.27016 .44511 m .33519 .4302 L .38491 .46905 L p .995 .995 .995 r
F P
0 g
s
.43407 .44156 m .38491 .46905 L .33519 .4302 L p .995 .995 .995 r
F P
0 g
s
.38491 .46905 m .43407 .44156 L .48104 .46091 L p .983 .983 .983 r
F P
0 g
s
.27084 .41147 m .20732 .41805 L .16475 .38385 L p .996 .996 .996 r
F P
0 g
s
.58993 .40157 m .56421 .39292 L .58825 .38454 L p 1 1 1 r
F P
0 g
s
.58825 .38454 m .63738 .38521 L .58993 .40157 L p 1 1 1 r
F P
0 g
s
.50854 .39893 m .48112 .41332 L .43426 .40848 L p .996 .996 .996 r
F P
0 g
s
.48112 .41332 m .50854 .39893 L .53631 .39784 L p 1 1 1 r
F P
0 g
s
.68664 .50387 m .63834 .46506 L .67235 .4496 L p .893 .893 .893 r
F P
0 g
s
.67235 .4496 m .73843 .48176 L .68664 .50387 L p .893 .893 .893 r
F P
0 g
s
.53641 .42867 m .53561 .47151 L .48104 .46091 L p .963 .963 .963 r
F P
0 g
s
.53561 .47151 m .53641 .42867 L .56441 .42923 L p .94 .94 .94 r
F P
0 g
s
.56441 .42923 m .59049 .47279 L .53561 .47151 L p .94 .94 .94 r
F P
0 g
s
.79911 .34432 m .73578 .35388 L .75924 .31742 L p 1 1 1 r
F P
0 g
s
.75924 .31742 m .83266 .29545 L .79911 .34432 L p 1 1 1 r
F P
0 g
s
.27016 .44511 m .20625 .45977 L .16475 .38385 L p 1 1 1 r
F P
0 g
s
.50856 .42319 m .48104 .46091 L .43407 .44156 L p .983 .983 .983 r
F P
0 g
s
.48104 .46091 m .50856 .42319 L .53641 .42867 L p .963 .963 .963 r
F P
0 g
s
.59049 .47279 m .56441 .42923 L .58856 .42507 L p .916 .916 .916 r
F P
0 g
s
.58856 .42507 m .63834 .46506 L .59049 .47279 L p .916 .916 .916 r
F P
0 g
s
.16475 .38385 m .23925 .38385 L .27084 .41147 L p .996 .996 .996 r
F P
0 g
s
.33555 .40476 m .27084 .41147 L .23925 .38385 L p .996 .996 .996 r
F P
0 g
s
.63738 .38521 m .58825 .38454 L .6049 .37364 L p 1 1 1 r
F P
0 g
s
.6049 .37364 m .67106 .36365 L .63738 .38521 L p 1 1 1 r
F P
0 g
s
.86776 .5447 m .80356 .51346 L .83789 .47364 L p .874 .874 .874 r
F P
0 g
s
.83789 .47364 m .91379 .49631 L .86776 .5447 L p .874 .874 .874 r
F P
0 g
s
.33555 .40476 m .4015 .39792 L .43426 .40848 L p .994 .994 .994 r
F P
0 g
s
.48484 .39638 m .43426 .40848 L .4015 .39792 L p .994 .994 .994 r
F P
0 g
s
.43426 .40848 m .48484 .39638 L .50854 .39893 L p .996 .996 .996 r
F P
0 g
s
.16475 .38385 m .23925 .38385 L .27016 .44511 L p 1 1 1 r
F P
0 g
s
.33519 .4302 m .27016 .44511 L .23925 .38385 L p 1 1 1 r
F P
0 g
s
.73578 .35388 m .67106 .36365 L .68553 .33948 L p 1 1 1 r
F P
0 g
s
.68553 .33948 m .75924 .31742 L .73578 .35388 L p 1 1 1 r
F P
0 g
s
.33519 .4302 m .40136 .41502 L .43407 .44156 L p .995 .995 .995 r
F P
0 g
s
.48482 .41317 m .43407 .44156 L .40136 .41502 L p .995 .995 .995 r
F P
0 g
s
.43407 .44156 m .48482 .41317 L .50856 .42319 L p .983 .983 .983 r
F P
0 g
s
.63834 .46506 m .58856 .42507 L .6053 .41697 L p .893 .893 .893 r
F P
0 g
s
.6053 .41697 m .67235 .4496 L .63834 .46506 L p .893 .893 .893 r
F P
0 g
s
.80356 .51346 m .73843 .48176 L .76229 .45106 L p .874 .874 .874 r
F P
0 g
s
.76229 .45106 m .83789 .47364 L .80356 .51346 L p .874 .874 .874 r
F P
0 g
s
.23925 .38385 m .31375 .38385 L .33555 .40476 L p .996 .996 .996 r
F P
0 g
s
.4015 .39792 m .33555 .40476 L .31375 .38385 L p .996 .996 .996 r
F P
0 g
s
.23925 .38385 m .31375 .38385 L .33519 .4302 L p 1 1 1 r
F P
0 g
s
.40136 .41502 m .33519 .4302 L .31375 .38385 L p 1 1 1 r
F P
0 g
s
.53725 .38385 m .53631 .39784 L .50854 .39893 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .56421 .39292 L .53631 .39784 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .58825 .38454 L .56421 .39292 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .50854 .39893 L .48484 .39638 L closepath p .996 .996 .996 r
F P
0 g
s
.53725 .38385 m .53641 .42867 L .50856 .42319 L closepath p .963 .963 .963 r
F P
0 g
s
.53725 .38385 m .56441 .42923 L .53641 .42867 L closepath p .94 .94 .94 r
F P
0 g
s
.67106 .36365 m .6049 .37364 L .61153 .36162 L p 1 1 1 r
F P
0 g
s
.61153 .36162 m .68553 .33948 L .67106 .36365 L p 1 1 1 r
F P
0 g
s
.73843 .48176 m .67235 .4496 L .68698 .42857 L p .874 .874 .874 r
F P
0 g
s
.68698 .42857 m .76229 .45106 L .73843 .48176 L p .874 .874 .874 r
F P
0 g
s
.53725 .38385 m .50856 .42319 L .48482 .41317 L closepath p .983 .983 .983 r
F P
0 g
s
.53725 .38385 m .58856 .42507 L .56441 .42923 L closepath p .916 .916 .916 r
F P
0 g
s
.31375 .38385 m .38825 .38385 L .4015 .39792 L p .996 .996 .996 r
F P
0 g
s
.46872 .39095 m .4015 .39792 L .38825 .38385 L p .996 .996 .996 r
F P
0 g
s
.4015 .39792 m .46872 .39095 L .48484 .39638 L p .994 .994 .994 r
F P
0 g
s
.53725 .38385 m .6049 .37364 L .58825 .38454 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .48484 .39638 L .46872 .39095 L closepath p .994 .994 .994 r
F P
0 g
s
.31375 .38385 m .38825 .38385 L .40136 .41502 L p 1 1 1 r
F P
0 g
s
.4687 .39957 m .40136 .41502 L .38825 .38385 L p 1 1 1 r
F P
0 g
s
.40136 .41502 m .4687 .39957 L .48482 .41317 L p .995 .995 .995 r
F P
0 g
s
.53725 .38385 m .48482 .41317 L .4687 .39957 L closepath p .995 .995 .995 r
F P
0 g
s
.53725 .38385 m .6053 .41697 L .58856 .42507 L closepath p .893 .893 .893 r
F P
0 g
s
.67235 .4496 m .6053 .41697 L .61197 .40617 L p .874 .874 .874 r
F P
0 g
s
.61197 .40617 m .68698 .42857 L .67235 .4496 L p .874 .874 .874 r
F P
0 g
s
.53725 .38385 m .61153 .36162 L .6049 .37364 L closepath p 1 1 1 r
F P
0 g
s
.9058 .27356 m .83266 .29545 L .82213 .24631 L p 1 1 1 r
F P
0 g
s
.82213 .24631 m .8961 .2106 L .9058 .27356 L p 1 1 1 r
F P
0 g
s
.38825 .38385 m .46275 .38385 L .46872 .39095 L p .996 .996 .996 r
F P
0 g
s
.53725 .38385 m .46872 .39095 L .46275 .38385 L closepath p .996 .996 .996 r
F P
0 g
s
.38825 .38385 m .46275 .38385 L .4687 .39957 L p 1 1 1 r
F P
0 g
s
.53725 .38385 m .4687 .39957 L .46275 .38385 L closepath p 1 1 1 r
F P
0 g
s
.83266 .29545 m .75924 .31742 L .74929 .28148 L p 1 1 1 r
F P
0 g
s
.74929 .28148 m .82213 .24631 L .83266 .29545 L p 1 1 1 r
F P
0 g
s
.53725 .38385 m .61197 .40617 L .6053 .41697 L closepath p .874 .874 .874 r
F P
0 g
s
.75924 .31742 m .68553 .33948 L .67755 .31612 L p 1 1 1 r
F P
0 g
s
.67755 .31612 m .74929 .28148 L .75924 .31742 L p 1 1 1 r
F P
0 g
s
.68553 .33948 m .61153 .36162 L .60687 .35024 L p 1 1 1 r
F P
0 g
s
.60687 .35024 m .67755 .31612 L .68553 .33948 L p 1 1 1 r
F P
0 g
s
.53725 .38385 m .60687 .35024 L .61153 .36162 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .59134 .34133 L .60687 .35024 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .56717 .33653 L .59134 .34133 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .53813 .33692 L .56717 .33653 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .50893 .34279 L .53813 .33692 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .48431 .35354 L .50893 .34279 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .46814 .36784 L .48431 .35354 L closepath p 1 1 1 r
F P
0 g
s
.17872 .30081 m .25309 .31804 L .23925 .38385 L p 1 1 1 r
F P
0 g
s
.23925 .38385 m .16475 .38385 L .17872 .30081 L p 1 1 1 r
F P
0 g
s
.25309 .31804 m .32609 .33495 L .31375 .38385 L p 1 1 1 r
F P
0 g
s
.31375 .38385 m .23925 .38385 L .25309 .31804 L p 1 1 1 r
F P
0 g
s
.32609 .33495 m .39776 .35154 L .38825 .38385 L p 1 1 1 r
F P
0 g
s
.38825 .38385 m .31375 .38385 L .32609 .33495 L p 1 1 1 r
F P
0 g
s
.39776 .35154 m .46814 .36784 L .46275 .38385 L p 1 1 1 r
F P
0 g
s
.46275 .38385 m .38825 .38385 L .39776 .35154 L p 1 1 1 r
F P
0 g
s
.53725 .38385 m .46275 .38385 L .46814 .36784 L closepath p 1 1 1 r
F P
0 g
s
.53725 .38385 m .60729 .39429 L .61197 .40617 L closepath p .86 .86 .86 r
F P
0 g
s
.53725 .38385 m .59168 .38313 L .60729 .39429 L closepath p .854 .854 .854 r
F P
0 g
s
.53725 .38385 m .56739 .37433 L .59168 .38313 L closepath p .863 .863 .863 r
F P
0 g
s
.53725 .38385 m .53824 .36912 L .56739 .37433 L closepath p .888 .888 .888 r
F P
0 g
s
.53725 .38385 m .50895 .36804 L .53824 .36912 L closepath p .926 .926 .926 r
F P
0 g
s
.53725 .38385 m .48429 .37086 L .50895 .36804 L closepath p .963 .963 .963 r
F P
0 g
s
.53725 .38385 m .46811 .37661 L .48429 .37086 L closepath p .987 .987 .987 r
F P
0 g
s
.17743 .34615 m .25231 .354 L .23925 .38385 L p .996 .996 .996 r
F P
0 g
s
.23925 .38385 m .16475 .38385 L .17743 .34615 L p .996 .996 .996 r
F P
0 g
s
.25231 .354 m .32568 .36168 L .31375 .38385 L p .996 .996 .996 r
F P
0 g
s
.31375 .38385 m .23925 .38385 L .25231 .354 L p .996 .996 .996 r
F P
0 g
s
.32568 .36168 m .3976 .36922 L .38825 .38385 L p .996 .996 .996 r
F P
0 g
s
.38825 .38385 m .31375 .38385 L .32568 .36168 L p .996 .996 .996 r
F P
0 g
s
.3976 .36922 m .46811 .37661 L .46275 .38385 L p .996 .996 .996 r
F P
0 g
s
.46275 .38385 m .38825 .38385 L .3976 .36922 L p .996 .996 .996 r
F P
0 g
s
.53725 .38385 m .46275 .38385 L .46811 .37661 L closepath p .996 .996 .996 r
F P
0 g
s
.68698 .42857 m .61197 .40617 L .60729 .39429 L p .86 .86 .86 r
F P
0 g
s
.76229 .45106 m .68698 .42857 L .67894 .40498 L p .86 .86 .86 r
F P
0 g
s
.60729 .39429 m .67894 .40498 L .68698 .42857 L p .86 .86 .86 r
F P
0 g
s
.83789 .47364 m .76229 .45106 L .75225 .41591 L p .86 .86 .86 r
F P
0 g
s
.67894 .40498 m .75225 .41591 L .76229 .45106 L p .86 .86 .86 r
F P
0 g
s
.67755 .31612 m .60687 .35024 L .59134 .34133 L p 1 1 1 r
F P
0 g
s
.91379 .49631 m .83789 .47364 L .8273 .4271 L p .86 .86 .86 r
F P
0 g
s
.75225 .41591 m .8273 .4271 L .83789 .47364 L p .86 .86 .86 r
F P
0 g
s
.42957 .3222 m .48431 .35354 L .46814 .36784 L p 1 1 1 r
F P
0 g
s
.46814 .36784 m .39776 .35154 L .42957 .3222 L p 1 1 1 r
F P
0 g
s
.42935 .35738 m .48429 .37086 L .46811 .37661 L p .987 .987 .987 r
F P
0 g
s
.46811 .37661 m .3976 .36922 L .42935 .35738 L p .987 .987 .987 r
F P
0 g
s
.8273 .4271 m .90413 .43856 L .91379 .49631 L p .86 .86 .86 r
F P
0 g
s
.67894 .40498 m .60729 .39429 L .59168 .38313 L p .854 .854 .854 r
F P
0 g
s
.74929 .28148 m .67755 .31612 L .64716 .29746 L p 1 1 1 r
F P
0 g
s
.59134 .34133 m .64716 .29746 L .67755 .31612 L p 1 1 1 r
F P
0 g
s
.64716 .29746 m .59134 .34133 L .56717 .33653 L p 1 1 1 r
F P
0 g
s
.47934 .29988 m .50893 .34279 L .48431 .35354 L p 1 1 1 r
F P
0 g
s
.48431 .35354 m .42957 .3222 L .47934 .29988 L p 1 1 1 r
F P
0 g
s
.37292 .28977 m .42957 .3222 L .39776 .35154 L p 1 1 1 r
F P
0 g
s
.39776 .35154 m .32609 .33495 L .37292 .28977 L p 1 1 1 r
F P
0 g
s
.47925 .35145 m .50895 .36804 L .48429 .37086 L p .963 .963 .963 r
F P
0 g
s
.48429 .37086 m .42935 .35738 L .47925 .35145 L p .963 .963 .963 r
F P
0 g
s
.59168 .38313 m .64826 .38238 L .67894 .40498 L p .854 .854 .854 r
F P
0 g
s
.64826 .38238 m .59168 .38313 L .56739 .37433 L p .863 .863 .863 r
F P
0 g
s
.37232 .34339 m .42935 .35738 L .3976 .36922 L p .987 .987 .987 r
F P
0 g
s
.3976 .36922 m .32568 .36168 L .37232 .34339 L p .987 .987 .987 r
F P
0 g
s
.56717 .33653 m .59839 .28715 L .64716 .29746 L p 1 1 1 r
F P
0 g
s
.59839 .28715 m .56717 .33653 L .53813 .33692 L p 1 1 1 r
F P
0 g
s
.53905 .28773 m .53813 .33692 L .50893 .34279 L p 1 1 1 r
F P
0 g
s
.50893 .34279 m .47934 .29988 L .53905 .28773 L p 1 1 1 r
F P
0 g
s
.82213 .24631 m .74929 .28148 L .70478 .25217 L p 1 1 1 r
F P
0 g
s
.64716 .29746 m .70478 .25217 L .74929 .28148 L p 1 1 1 r
F P
0 g
s
.75225 .41591 m .67894 .40498 L .64826 .38238 L p .854 .854 .854 r
F P
0 g
s
.53813 .33692 m .53905 .28773 L .59839 .28715 L p 1 1 1 r
F P
0 g
s
.53927 .35359 m .53824 .36912 L .50895 .36804 L p .926 .926 .926 r
F P
0 g
s
.50895 .36804 m .47925 .35145 L .53927 .35359 L p .926 .926 .926 r
F P
0 g
s
.56739 .37433 m .59906 .36433 L .64826 .38238 L p .863 .863 .863 r
F P
0 g
s
.59906 .36433 m .56739 .37433 L .53824 .36912 L p .888 .888 .888 r
F P
0 g
s
.53824 .36912 m .53927 .35359 L .59906 .36433 L p .888 .888 .888 r
F P
0 g
s
.31427 .2562 m .37292 .28977 L .32609 .33495 L p 1 1 1 r
F P
0 g
s
.32609 .33495 m .25309 .31804 L .31427 .2562 L p 1 1 1 r
F P
0 g
s
.31308 .32885 m .37232 .34339 L .32568 .36168 L p .987 .987 .987 r
F P
0 g
s
.32568 .36168 m .25231 .354 L .31308 .32885 L p .987 .987 .987 r
F P
0 g
s
.8961 .2106 m .82213 .24631 L .7643 .20538 L p 1 1 1 r
F P
0 g
s
.70478 .25217 m .7643 .20538 L .82213 .24631 L p 1 1 1 r
F P
0 g
s
.70478 .25217 m .64716 .29746 L .59839 .28715 L p 1 1 1 r
F P
0 g
s
.4484 .25501 m .47934 .29988 L .42957 .3222 L p 1 1 1 r
F P
0 g
s
.42957 .3222 m .37292 .28977 L .4484 .25501 L p 1 1 1 r
F P
0 g
s
.8273 .4271 m .75225 .41591 L .70713 .38161 L p .854 .854 .854 r
F P
0 g
s
.64826 .38238 m .70713 .38161 L .75225 .41591 L p .854 .854 .854 r
F P
0 g
s
.25351 .22142 m .31427 .2562 L .25309 .31804 L p 1 1 1 r
F P
0 g
s
.25309 .31804 m .17872 .30081 L .25351 .22142 L p 1 1 1 r
F P
0 g
s
.44804 .33402 m .47925 .35145 L .42935 .35738 L p .963 .963 .963 r
F P
0 g
s
.42935 .35738 m .37232 .34339 L .44804 .33402 L p .963 .963 .963 r
F P
0 g
s
.7643 .20538 m .82581 .15703 L .8961 .2106 L p 1 1 1 r
F P
0 g
s
.70713 .38161 m .64826 .38238 L .59906 .36433 L p .863 .863 .863 r
F P
0 g
s
.25149 .31374 m .31308 .32885 L .25231 .354 L p .987 .987 .987 r
F P
0 g
s
.25231 .354 m .17743 .34615 L .25149 .31374 L p .987 .987 .987 r
F P
0 g
s
.59839 .28715 m .631 .23557 L .70478 .25217 L p 1 1 1 r
F P
0 g
s
.631 .23557 m .59839 .28715 L .53905 .28773 L p 1 1 1 r
F P
0 g
s
.54001 .23611 m .53905 .28773 L .47934 .29988 L p 1 1 1 r
F P
0 g
s
.47934 .29988 m .4484 .25501 L .54001 .23611 L p 1 1 1 r
F P
0 g
s
.90413 .43856 m .8273 .4271 L .76842 .3808 L p .854 .854 .854 r
F P
0 g
s
.70713 .38161 m .76842 .3808 L .8273 .4271 L p .854 .854 .854 r
F P
0 g
s
.53905 .28773 m .54001 .23611 L .631 .23557 L p 1 1 1 r
F P
0 g
s
.7643 .20538 m .70478 .25217 L .631 .23557 L p 1 1 1 r
F P
0 g
s
.54037 .33719 m .53927 .35359 L .47925 .35145 L p .926 .926 .926 r
F P
0 g
s
.47925 .35145 m .44804 .33402 L .54037 .33719 L p .926 .926 .926 r
F P
0 g
s
.59906 .36433 m .63237 .35381 L .70713 .38161 L p .863 .863 .863 r
F P
0 g
s
.63237 .35381 m .59906 .36433 L .53927 .35359 L p .888 .888 .888 r
F P
0 g
s
.416 .20804 m .4484 .25501 L .37292 .28977 L p 1 1 1 r
F P
0 g
s
.37292 .28977 m .31427 .2562 L .416 .20804 L p 1 1 1 r
F P
0 g
s
.53927 .35359 m .54037 .33719 L .63237 .35381 L p .888 .888 .888 r
F P
0 g
s
.4152 .31568 m .44804 .33402 L .37232 .34339 L p .963 .963 .963 r
F P
0 g
s
.37232 .34339 m .31308 .32885 L .4152 .31568 L p .963 .963 .963 r
F P
0 g
s
.76842 .3808 m .8323 .37995 L .90413 .43856 L p .854 .854 .854 r
F P
0 g
s
.76842 .3808 m .70713 .38161 L .63237 .35381 L p .863 .863 .863 r
F P
0 g
s
.82581 .15703 m .7643 .20538 L .6651 .18163 L p 1 1 1 r
F P
0 g
s
.631 .23557 m .6651 .18163 L .7643 .20538 L p 1 1 1 r
F P
0 g
s
.6651 .18163 m .631 .23557 L .54001 .23611 L p 1 1 1 r
F P
0 g
s
.54103 .18186 m .54001 .23611 L .4484 .25501 L p 1 1 1 r
F P
0 g
s
.4484 .25501 m .416 .20804 L .54103 .18186 L p 1 1 1 r
F P
0 g
s
.38205 .1588 m .416 .20804 L .31427 .2562 L p 1 1 1 r
F P
0 g
s
.31427 .2562 m .25351 .22142 L .38205 .1588 L p 1 1 1 r
F P
0 g
s
.54001 .23611 m .54103 .18186 L .6651 .18163 L p 1 1 1 r
F P
0 g
s
.54153 .31986 m .54037 .33719 L .44804 .33402 L p .926 .926 .926 r
F P
0 g
s
.44804 .33402 m .4152 .31568 L .54153 .31986 L p .926 .926 .926 r
F P
0 g
s
.3806 .29635 m .4152 .31568 L .31308 .32885 L p .963 .963 .963 r
F P
0 g
s
.31308 .32885 m .25149 .31374 L .3806 .29635 L p .963 .963 .963 r
F P
0 g
s
.63237 .35381 m .66747 .34272 L .76842 .3808 L p .863 .863 .863 r
F P
0 g
s
.66747 .34272 m .63237 .35381 L .54037 .33719 L p .888 .888 .888 r
F P
0 g
s
.8323 .37995 m .76842 .3808 L .66747 .34272 L p .863 .863 .863 r
F P
0 g
s
.6651 .18163 m .7008 .12517 L .82581 .15703 L p 1 1 1 r
F P
0 g
s
.54037 .33719 m .54153 .31986 L .66747 .34272 L p .888 .888 .888 r
F P
0 g
s
.7008 .12517 m .6651 .18163 L .54103 .18186 L p 1 1 1 r
F P
0 g
s
.54209 .1248 m .54103 .18186 L .416 .20804 L p 1 1 1 r
F P
0 g
s
.416 .20804 m .38205 .1588 L .54209 .1248 L p 1 1 1 r
F P
0 g
s
.54103 .18186 m .54209 .1248 L .7008 .12517 L p 1 1 1 r
F P
0 g
s
.54276 .30149 m .54153 .31986 L .4152 .31568 L p .926 .926 .926 r
F P
0 g
s
.4152 .31568 m .3806 .29635 L .54276 .30149 L p .926 .926 .926 r
F P
0 g
s
.66747 .34272 m .7045 .33103 L .8323 .37995 L p .863 .863 .863 r
F P
0 g
s
.7045 .33103 m .66747 .34272 L .54153 .31986 L p .888 .888 .888 r
F P
0 g
s
.54153 .31986 m .54276 .30149 L .7045 .33103 L p .888 .888 .888 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 178.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 287}, {177.313, 0}} -> {0, 0, 0, 0}}],
 StyleBox["     ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% PlotRegion
.1 .9 .1 .9 MPlotRegion
% Scaling calculations
0.5 0.434783 0.5 0.434783 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
1 .5 L
s
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-8. 2. moveto 0 0 lineto
-8. -2. lineto fill
-8. 2. moveto 0 0 lineto
-8. -2. lineto
-8. 2. lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
.5 .49565 m
.50002 .49565 L
.50003 .49565 L
.50005 .49565 L
.50007 .49565 L
.5001 .49565 L
.50013 .49565 L
.50017 .49566 L
.5002 .49566 L
.50027 .49566 L
.50034 .49567 L
.50041 .49567 L
.50055 .49569 L
.5007 .49571 L
.50084 .49573 L
.50115 .49581 L
.50141 .49589 L
.50168 .49599 L
.5022 .49625 L
.50267 .49657 L
.50311 .49696 L
.50349 .4974 L
.50379 .49786 L
.50392 .49811 L
.50404 .49839 L
.50414 .49867 L
.50421 .49893 L
.50427 .49921 L
.5043 .49936 L
.50432 .4995 L
.50433 .49964 L
.50434 .49971 L
.50434 .49979 L
.50435 .49985 L
.50435 .49989 L
.50435 .49991 L
.50435 .49992 L
.50435 .49994 L
.50435 .49995 L
.50435 .49997 L
.50435 .49998 L
.50435 .5 L
.50435 .50002 L
.50435 .50004 L
.50435 .50005 L
.50435 .50007 L
.50435 .50009 L
.50435 .50012 L
.50435 .50015 L
.50434 .50019 L
Mistroke
.50434 .50026 L
.50434 .50032 L
.50432 .50046 L
.5043 .50061 L
.50428 .50076 L
.50425 .50092 L
.50418 .5012 L
.50409 .50147 L
.50398 .50175 L
.50373 .50223 L
.5034 .50271 L
.50302 .50312 L
.50257 .50351 L
.50209 .50381 L
.50159 .50405 L
.50132 .50414 L
.50103 .50422 L
.5009 .50425 L
.50076 .50428 L
.50064 .5043 L
.5005 .50432 L
.50037 .50433 L
.50026 .50434 L
.50019 .50434 L
.50013 .50435 L
.5001 .50435 L
.50008 .50435 L
.50007 .50435 L
.50005 .50435 L
.50003 .50435 L
.50002 .50435 L
.5 .50435 L
Mfstroke
.5001 .30551 m
.50085 .30551 L
.50154 .30552 L
.50233 .30552 L
.50308 .30554 L
.50441 .30556 L
.50585 .3056 L
.50744 .30565 L
.50913 .30573 L
.51215 .30589 L
.51527 .30611 L
.51818 .30636 L
.52481 .3071 L
.53153 .30808 L
.53766 .30919 L
.55129 .31239 L
.56292 .31597 L
.57534 .3207 L
.59863 .33237 L
.61938 .34646 L
.63924 .36422 L
.65592 .38374 L
.6694 .40445 L
.6752 .41556 L
.68073 .42816 L
.6852 .44063 L
.68853 .45223 L
.69121 .46445 L
.69235 .47125 L
.69321 .47772 L
.69382 .48388 L
.69405 .48699 L
.69425 .49044 L
.69438 .49337 L
.69443 .49502 L
.69444 .4958 L
.69446 .49653 L
.69447 .49723 L
.69448 .49786 L
.69448 .49856 L
.69449 .49932 L
.69449 .50004 L
.69449 .50082 L
.69448 .50157 L
.69448 .50225 L
.69447 .50305 L
.69445 .50382 L
.69442 .50525 L
.69437 .50679 L
.69431 .50846 L
Mistroke
.69415 .51148 L
.69397 .51427 L
.69339 .52066 L
.69255 .52743 L
.6915 .53396 L
.69013 .54097 L
.68698 .55352 L
.68305 .56572 L
.67804 .57827 L
.66686 .59992 L
.65208 .62124 L
.63529 .63972 L
.61501 .65684 L
.59344 .67057 L
.57116 .681 L
.55919 .68526 L
.54621 .68892 L
.54034 .69026 L
.53397 .6915 L
.52844 .6924 L
.52237 .6932 L
.51676 .69377 L
.51153 .69415 L
.50863 .6943 L
.506 .6944 L
.50454 .69444 L
.50377 .69445 L
.50296 .69447 L
.50225 .69448 L
.50147 .69448 L
.50076 .69449 L
.5001 .69449 L
Mfstroke
.50014 .22498 m
.5012 .22499 L
.50217 .22499 L
.50329 .225 L
.50435 .22502 L
.50623 .22506 L
.50828 .22511 L
.51053 .22519 L
.51291 .22529 L
.51718 .22552 L
.52159 .22583 L
.52571 .22619 L
.53508 .22723 L
.54459 .22862 L
.55325 .23019 L
.57252 .23472 L
.58898 .23978 L
.60654 .24646 L
.63946 .26297 L
.6688 .28289 L
.6969 .308 L
.72048 .33561 L
.73954 .36489 L
.74774 .3806 L
.75556 .39841 L
.76189 .41604 L
.76659 .43246 L
.77038 .44974 L
.77199 .45934 L
.7732 .46849 L
.77407 .4772 L
.7744 .48161 L
.77468 .48648 L
.77486 .49062 L
.77492 .49295 L
.77495 .49406 L
.77497 .49509 L
.77499 .49608 L
.775 .49697 L
.77501 .49797 L
.77501 .49903 L
.77502 .50006 L
.77501 .50117 L
.77501 .50221 L
.775 .50318 L
.77498 .50432 L
.77496 .5054 L
.77491 .50742 L
.77485 .5096 L
.77475 .51197 L
Mistroke
.77454 .51623 L
.77427 .52018 L
.77346 .52921 L
.77227 .53879 L
.77079 .54802 L
.76884 .55793 L
.7644 .57568 L
.75884 .59293 L
.75176 .61068 L
.73594 .64129 L
.71504 .67144 L
.6913 .69758 L
.66262 .72178 L
.63212 .7412 L
.60062 .75595 L
.5837 .76197 L
.56535 .76714 L
.55704 .76903 L
.54804 .77079 L
.54021 .77206 L
.53163 .77319 L
.52369 .77399 L
.5163 .77453 L
.51221 .77474 L
.50849 .77488 L
.50642 .77494 L
.50534 .77496 L
.50419 .77498 L
.50318 .775 L
.50208 .77501 L
.50108 .77501 L
.50014 .77502 L
Mfstroke
.50017 .16319 m
.50147 .16319 L
.50266 .1632 L
.50403 .16321 L
.50533 .16323 L
.50763 .16328 L
.51014 .16334 L
.51289 .16344 L
.51581 .16356 L
.52104 .16385 L
.52644 .16423 L
.53149 .16467 L
.54296 .16594 L
.55461 .16765 L
.56521 .16956 L
.58881 .17511 L
.60897 .1813 L
.63048 .18949 L
.6708 .20971 L
.70673 .2341 L
.74114 .26486 L
.77001 .29867 L
.79336 .33453 L
.80341 .35377 L
.81299 .37559 L
.82073 .39718 L
.82649 .41728 L
.83114 .43844 L
.83311 .45021 L
.83459 .46141 L
.83565 .47208 L
.83606 .47748 L
.8364 .48344 L
.83661 .48852 L
.8367 .49137 L
.83673 .49273 L
.83676 .49399 L
.83677 .4952 L
.83679 .49629 L
.8368 .49751 L
.83681 .49881 L
.83681 .50007 L
.83681 .50143 L
.8368 .50271 L
.83679 .5039 L
.83677 .50529 L
.83674 .50661 L
.83669 .50909 L
.8366 .51175 L
.83649 .51466 L
Mistroke
.83622 .51988 L
.8359 .52471 L
.8349 .53577 L
.83344 .5475 L
.83164 .55881 L
.82925 .57095 L
.8238 .59269 L
.817 .61381 L
.80833 .63555 L
.78896 .67304 L
.76336 .70996 L
.73429 .74197 L
.69917 .77161 L
.66181 .79539 L
.62323 .81346 L
.6025 .82083 L
.58003 .82716 L
.56986 .82948 L
.55883 .83163 L
.54925 .83319 L
.53873 .83457 L
.52902 .83556 L
.51997 .83622 L
.51495 .83648 L
.51039 .83665 L
.50787 .83672 L
.50654 .83675 L
.50513 .83677 L
.5039 .83679 L
.50255 .8368 L
.50132 .83681 L
.50017 .83681 L
Mfstroke
.50019 .11109 m
.5017 .1111 L
.50307 .11111 L
.50466 .11112 L
.50615 .11114 L
.50882 .11119 L
.5117 .11127 L
.51488 .11138 L
.51826 .11152 L
.5243 .11185 L
.53053 .11229 L
.53636 .1128 L
.54961 .11427 L
.56306 .11624 L
.5753 .11845 L
.60255 .12486 L
.62582 .13201 L
.65066 .14146 L
.69722 .16481 L
.73871 .19297 L
.77844 .22849 L
.81178 .26753 L
.83874 .30894 L
.85034 .33115 L
.8614 .35634 L
.87034 .38127 L
.87699 .40449 L
.88236 .42892 L
.88463 .44251 L
.88634 .45544 L
.88757 .46776 L
.88804 .47399 L
.88844 .48088 L
.88868 .48674 L
.88878 .49004 L
.88882 .4916 L
.88884 .49306 L
.88887 .49445 L
.88888 .49572 L
.8889 .49713 L
.8889 .49863 L
.88891 .50008 L
.8889 .50165 L
.88889 .50313 L
.88888 .5045 L
.88886 .5061 L
.88883 .50763 L
.88876 .51049 L
.88867 .51357 L
.88854 .51693 L
Mistroke
.88823 .52295 L
.88786 .52854 L
.88671 .5413 L
.88502 .55485 L
.88293 .56791 L
.88018 .58192 L
.87389 .60703 L
.86603 .63141 L
.85602 .65651 L
.83365 .69981 L
.8041 .74243 L
.77053 .7794 L
.72997 .81363 L
.68684 .84108 L
.64229 .86194 L
.61836 .87046 L
.59241 .87777 L
.58066 .88045 L
.56793 .88293 L
.55687 .88473 L
.54472 .88633 L
.5335 .88746 L
.52305 .88822 L
.51726 .88852 L
.512 .88872 L
.50908 .8888 L
.50755 .88883 L
.50592 .88886 L
.5045 .88888 L
.50294 .88889 L
.50152 .8889 L
.50019 .88891 L
Mfstroke
.5 .49565 m
.50004 .41233 L
.50006 .37331 L
.50008 .34539 L
.50009 .32264 L
.5001 .30127 L
.50011 .28267 L
.50012 .2645 L
.50013 .24824 L
.50013 .23353 L
.50014 .21872 L
.50015 .20516 L
.50015 .19269 L
.50016 .17995 L
.50017 .16814 L
.50017 .15604 L
.50018 .14477 L
.50018 .13425 L
.50019 .12339 L
.50019 .11321 L
.5002 .10269 L
.5002 .0928 L
.50021 .08351 L
.50021 .07386 L
.50022 .06522 L
s
.50085 .49574 m
.51714 .41402 L
.52476 .37576 L
.53022 .34838 L
.53467 .32606 L
.53884 .3051 L
.54248 .28686 L
.54603 .26904 L
.54921 .25309 L
.55208 .23866 L
.55498 .22414 L
.55763 .21085 L
.56007 .19862 L
.56256 .18612 L
.56486 .17454 L
.56723 .16267 L
.56943 .15162 L
.57149 .14131 L
.57361 .13065 L
.5756 .12067 L
.57766 .11035 L
.57959 .10066 L
.58141 .09155 L
.58329 .08208 L
.58498 .0736 L
s
.50167 .49598 m
.53357 .41901 L
.54851 .38297 L
.5592 .35718 L
.56791 .33616 L
.5761 .31641 L
.58322 .29923 L
.59018 .28245 L
.5964 .26742 L
.60204 .25383 L
.60771 .24016 L
.6129 .22763 L
.61767 .21611 L
.62255 .20434 L
.62707 .19344 L
.63171 .18225 L
.63602 .17184 L
.64005 .16213 L
.64421 .15209 L
.64811 .14269 L
.65214 .13297 L
.65592 .12384 L
.65948 .11526 L
.66318 .10634 L
.66648 .09835 L
s
.50242 .49638 m
.54872 .42711 L
.5704 .39467 L
.58591 .37146 L
.59855 .35254 L
.61043 .33477 L
.62077 .31931 L
.63086 .30421 L
.6399 .29068 L
.64807 .27845 L
.6563 .26614 L
.66383 .25487 L
.67076 .2445 L
.67785 .23391 L
.6844 .22409 L
.69113 .21403 L
.69739 .20466 L
.70324 .19592 L
.70928 .18688 L
.71493 .17842 L
.72078 .16967 L
.72627 .16146 L
.73143 .15373 L
.7368 .1457 L
.7416 .13852 L
s
.50308 .49692 m
.56199 .43801 L
.58958 .41042 L
.60932 .39068 L
.62541 .37459 L
.64053 .35947 L
.65368 .34632 L
.66652 .33348 L
.67802 .32198 L
.68843 .31157 L
.6989 .3011 L
.70848 .29152 L
.7173 .2827 L
.72631 .27369 L
.73466 .26534 L
.74322 .25678 L
.75119 .24881 L
.75862 .24138 L
.76631 .23369 L
.7735 .2265 L
.78094 .21906 L
.78793 .21207 L
.7945 .2055 L
.80133 .19867 L
.80744 .19256 L
s
.50362 .49758 m
.57289 .45128 L
.60533 .4296 L
.62854 .41409 L
.64746 .40145 L
.66523 .38957 L
.68069 .37923 L
.69579 .36914 L
.70932 .3601 L
.72155 .35193 L
.73386 .3437 L
.74513 .33617 L
.7555 .32924 L
.76609 .32215 L
.77591 .3156 L
.78597 .30887 L
.79534 .30261 L
.80408 .29676 L
.81312 .29072 L
.82158 .28507 L
.83033 .27922 L
.83854 .27373 L
.84627 .26857 L
.8543 .2632 L
.86148 .2584 L
s
.50402 .49833 m
.58099 .46643 L
.61703 .45149 L
.64282 .4408 L
.66384 .43209 L
.68359 .4239 L
.70077 .41678 L
.71755 .40982 L
.73258 .4036 L
.74617 .39796 L
.75984 .39229 L
.77237 .3871 L
.78389 .38233 L
.79566 .37745 L
.80656 .37293 L
.81775 .36829 L
.82816 .36398 L
.83787 .35995 L
.84791 .35579 L
.85731 .35189 L
.86703 .34786 L
.87616 .34408 L
.88474 .34052 L
.89366 .33682 L
.90165 .33352 L
s
.50426 .49915 m
.58598 .48286 L
.62424 .47524 L
.65162 .46978 L
.67394 .46533 L
.6949 .46116 L
.71314 .45752 L
.73096 .45397 L
.74691 .45079 L
.76134 .44792 L
.77586 .44502 L
.78915 .44237 L
.80138 .43993 L
.81388 .43744 L
.82546 .43514 L
.83733 .43277 L
.84838 .43057 L
.85869 .42851 L
.86935 .42639 L
.87933 .4244 L
.88965 .42234 L
.89934 .42041 L
.90845 .41859 L
.91792 .41671 L
.9264 .41502 L
s
.50435 .5 m
.58767 .49996 L
.62669 .49994 L
.65461 .49992 L
.67736 .49991 L
.69873 .4999 L
.71733 .49989 L
.7355 .49988 L
.75176 .49987 L
.76647 .49987 L
.78128 .49986 L
.79484 .49985 L
.80731 .49985 L
.82005 .49984 L
.83186 .49983 L
.84396 .49983 L
.85523 .49982 L
.86575 .49982 L
.87661 .49981 L
.88679 .49981 L
.89731 .4998 L
.9072 .4998 L
.91649 .49979 L
.92614 .49979 L
.93478 .49978 L
s
.50427 .50085 m
.586 .51705 L
.62427 .52464 L
.65165 .53007 L
.67397 .53449 L
.69494 .53865 L
.71319 .54227 L
.731 .5458 L
.74696 .54896 L
.76139 .55182 L
.77591 .5547 L
.78921 .55734 L
.80144 .55976 L
.81394 .56224 L
.82552 .56454 L
.8374 .56689 L
.84845 .56909 L
.85877 .57113 L
.86942 .57324 L
.8794 .57522 L
.88973 .57727 L
.89942 .57919 L
.90853 .581 L
.91801 .58288 L
.92648 .58456 L
s
.50402 .50166 m
.58103 .53349 L
.61708 .54839 L
.64288 .55906 L
.66391 .56775 L
.68366 .57591 L
.70085 .58302 L
.71764 .58996 L
.73267 .59617 L
.74627 .60179 L
.75995 .60745 L
.77248 .61263 L
.784 .61739 L
.79578 .62226 L
.80669 .62677 L
.81788 .63139 L
.8283 .6357 L
.83801 .63971 L
.84805 .64386 L
.85746 .64775 L
.86718 .65177 L
.87632 .65555 L
.8849 .65909 L
.89383 .66278 L
.90181 .66608 L
s
.50362 .50241 m
.57294 .54865 L
.6054 .57029 L
.62863 .58578 L
.64755 .59841 L
.66534 .61027 L
.68081 .62059 L
.69593 .63067 L
.70946 .63969 L
.7217 .64785 L
.73401 .65607 L
.74529 .66359 L
.75567 .67051 L
.76627 .67758 L
.77609 .68413 L
.78616 .69085 L
.79554 .6971 L
.80429 .70293 L
.81333 .70896 L
.82179 .71461 L
.83055 .72045 L
.83877 .72593 L
.8465 .73108 L
.85453 .73644 L
.86172 .74124 L
s
.50308 .50307 m
.56206 .56193 L
.58967 .58949 L
.60943 .60921 L
.62554 .62529 L
.64067 .64039 L
.65383 .65353 L
.66669 .66636 L
.6782 .67785 L
.68861 .68824 L
.6991 .6987 L
.70869 .70827 L
.71752 .71708 L
.72654 .72609 L
.73489 .73442 L
.74346 .74298 L
.75144 .75094 L
.75888 .75836 L
.76657 .76604 L
.77377 .77323 L
.78122 .78066 L
.78822 .78764 L
.79479 .79421 L
.80163 .80103 L
.80775 .80713 L
s
.50242 .50361 m
.54879 .57284 L
.5705 .60526 L
.58604 .62845 L
.5987 .64736 L
.6106 .66512 L
.62095 .68057 L
.63106 .69566 L
.64011 .70918 L
.64829 .7214 L
.65653 .7337 L
.66408 .74496 L
.67102 .75533 L
.67811 .76591 L
.68468 .77572 L
.69142 .78578 L
.69769 .79514 L
.70354 .80388 L
.70959 .81291 L
.71525 .82136 L
.72111 .8301 L
.72661 .83832 L
.73178 .84603 L
.73715 .85406 L
.74196 .86124 L
s
.50167 .50402 m
.53365 .58096 L
.54863 .61698 L
.55934 .64276 L
.56808 .66377 L
.57628 .68351 L
.58342 .70069 L
.59039 .71746 L
.59664 .73248 L
.60228 .74606 L
.60797 .75974 L
.61317 .77225 L
.61796 .78377 L
.62285 .79554 L
.62738 .80644 L
.63203 .81762 L
.63635 .82802 L
.64039 .83773 L
.64456 .84777 L
.64846 .85716 L
.6525 .86688 L
.6563 .87601 L
.65986 .88458 L
.66357 .8935 L
.66689 .90148 L
s
.50085 .50426 m
.51722 .58597 L
.52489 .62422 L
.53037 .65159 L
.53484 .6739 L
.53904 .69486 L
.54269 .7131 L
.54626 .73091 L
.54946 .74686 L
.55235 .76128 L
.55525 .7758 L
.55792 .78909 L
.56037 .80132 L
.56287 .81382 L
.56519 .82539 L
.56757 .83726 L
.56978 .84831 L
.57185 .85862 L
.57398 .86928 L
.57598 .87925 L
.57805 .88957 L
.57999 .89926 L
.58181 .90837 L
.58371 .91784 L
.58541 .92631 L
s
.50001 .50435 m
.50013 .58767 L
.50019 .62669 L
.50023 .65461 L
.50027 .67736 L
.5003 .69873 L
.50033 .71733 L
.50035 .7355 L
.50038 .75176 L
.5004 .76647 L
.50042 .78128 L
.50044 .79484 L
.50046 .80731 L
.50048 .82005 L
.5005 .83186 L
.50052 .84396 L
.50053 .85523 L
.50055 .86575 L
.50056 .87661 L
.50058 .88679 L
.5006 .89731 L
.50061 .9072 L
.50062 .91649 L
.50064 .92614 L
.50065 .93478 L
s
.5 .50435 m
.49998 .50435 L
.49997 .50435 L
.49995 .50435 L
.49993 .50435 L
.4999 .50435 L
.49987 .50435 L
.49983 .50434 L
.4998 .50434 L
.49973 .50434 L
.49966 .50433 L
.49959 .50433 L
.49945 .50431 L
.4993 .50429 L
.49916 .50427 L
.49885 .50419 L
.49859 .50411 L
.49832 .50401 L
.4978 .50375 L
.49733 .50343 L
.49689 .50304 L
.49651 .5026 L
.49621 .50214 L
.49608 .50189 L
.49596 .50161 L
.49586 .50133 L
.49579 .50107 L
.49573 .50079 L
.4957 .50064 L
.49568 .5005 L
.49567 .50036 L
.49566 .50029 L
.49566 .50021 L
.49565 .50015 L
.49565 .50011 L
.49565 .50009 L
.49565 .50008 L
.49565 .50006 L
.49565 .50005 L
.49565 .50003 L
.49565 .50002 L
.49565 .5 L
.49565 .49998 L
.49565 .49996 L
.49565 .49995 L
.49565 .49993 L
.49565 .49991 L
.49565 .49988 L
.49565 .49985 L
.49566 .49981 L
Mistroke
.49566 .49974 L
.49566 .49968 L
.49568 .49954 L
.4957 .49939 L
.49572 .49924 L
.49575 .49908 L
.49582 .4988 L
.49591 .49853 L
.49602 .49825 L
.49627 .49777 L
.4966 .49729 L
.49698 .49688 L
.49743 .49649 L
.49791 .49619 L
.49841 .49595 L
.49868 .49586 L
.49897 .49578 L
.4991 .49575 L
.49924 .49572 L
.49936 .4957 L
.4995 .49568 L
.49963 .49567 L
.49974 .49566 L
.49981 .49566 L
.49987 .49565 L
.4999 .49565 L
.49992 .49565 L
.49993 .49565 L
.49995 .49565 L
.49997 .49565 L
.49998 .49565 L
.5 .49565 L
Mfstroke
.4999 .69449 m
.49915 .69449 L
.49846 .69448 L
.49767 .69448 L
.49692 .69446 L
.49559 .69444 L
.49415 .6944 L
.49256 .69435 L
.49087 .69427 L
.48785 .69411 L
.48473 .69389 L
.48182 .69364 L
.47519 .6929 L
.46847 .69192 L
.46234 .69081 L
.44871 .68761 L
.43708 .68403 L
.42466 .6793 L
.40137 .66763 L
.38062 .65354 L
.36076 .63578 L
.34408 .61626 L
.3306 .59555 L
.3248 .58444 L
.31927 .57184 L
.3148 .55937 L
.31147 .54777 L
.30879 .53555 L
.30765 .52875 L
.30679 .52228 L
.30618 .51612 L
.30595 .51301 L
.30575 .50956 L
.30562 .50663 L
.30557 .50498 L
.30556 .5042 L
.30554 .50347 L
.30553 .50277 L
.30552 .50214 L
.30552 .50144 L
.30551 .50068 L
.30551 .49996 L
.30551 .49918 L
.30552 .49843 L
.30552 .49775 L
.30553 .49695 L
.30555 .49618 L
.30558 .49475 L
.30563 .49321 L
.30569 .49154 L
Mistroke
.30585 .48852 L
.30603 .48573 L
.30661 .47934 L
.30745 .47257 L
.3085 .46604 L
.30987 .45903 L
.31302 .44648 L
.31695 .43428 L
.32196 .42173 L
.33314 .40008 L
.34792 .37876 L
.36471 .36028 L
.38499 .34316 L
.40656 .32943 L
.42884 .319 L
.44081 .31474 L
.45379 .31108 L
.45966 .30974 L
.46603 .3085 L
.47156 .3076 L
.47763 .3068 L
.48324 .30623 L
.48847 .30585 L
.49137 .3057 L
.494 .3056 L
.49546 .30556 L
.49623 .30555 L
.49704 .30553 L
.49775 .30552 L
.49853 .30552 L
.49924 .30551 L
.4999 .30551 L
Mfstroke
.49986 .77502 m
.4988 .77501 L
.49783 .77501 L
.49671 .775 L
.49565 .77498 L
.49377 .77494 L
.49172 .77489 L
.48947 .77481 L
.48709 .77471 L
.48282 .77448 L
.47841 .77417 L
.47429 .77381 L
.46492 .77277 L
.45541 .77138 L
.44675 .76981 L
.42748 .76528 L
.41102 .76022 L
.39346 .75354 L
.36054 .73703 L
.3312 .71711 L
.3031 .692 L
.27952 .66439 L
.26046 .63511 L
.25226 .6194 L
.24444 .60159 L
.23811 .58396 L
.23341 .56754 L
.22962 .55026 L
.22801 .54066 L
.2268 .53151 L
.22593 .5228 L
.2256 .51839 L
.22532 .51352 L
.22514 .50938 L
.22508 .50705 L
.22505 .50594 L
.22503 .50491 L
.22501 .50392 L
.225 .50303 L
.22499 .50203 L
.22499 .50097 L
.22498 .49994 L
.22499 .49883 L
.22499 .49779 L
.225 .49682 L
.22502 .49568 L
.22504 .4946 L
.22509 .49258 L
.22515 .4904 L
.22525 .48803 L
Mistroke
.22546 .48377 L
.22573 .47982 L
.22654 .47079 L
.22773 .46121 L
.22921 .45198 L
.23116 .44207 L
.2356 .42432 L
.24116 .40707 L
.24824 .38932 L
.26406 .35871 L
.28496 .32856 L
.3087 .30242 L
.33738 .27822 L
.36788 .2588 L
.39938 .24405 L
.4163 .23803 L
.43465 .23286 L
.44296 .23097 L
.45196 .22921 L
.45979 .22794 L
.46837 .22681 L
.47631 .22601 L
.4837 .22547 L
.48779 .22526 L
.49151 .22512 L
.49358 .22506 L
.49466 .22504 L
.49581 .22502 L
.49682 .225 L
.49792 .22499 L
.49892 .22499 L
.49986 .22498 L
Mfstroke
.49983 .83681 m
.49853 .83681 L
.49734 .8368 L
.49597 .83679 L
.49467 .83677 L
.49237 .83672 L
.48986 .83666 L
.48711 .83656 L
.48419 .83644 L
.47896 .83615 L
.47356 .83577 L
.46851 .83533 L
.45704 .83406 L
.44539 .83235 L
.43479 .83044 L
.41119 .82489 L
.39103 .8187 L
.36952 .81051 L
.3292 .79029 L
.29327 .7659 L
.25886 .73514 L
.22999 .70133 L
.20664 .66547 L
.19659 .64623 L
.18701 .62441 L
.17927 .60282 L
.17351 .58272 L
.16886 .56156 L
.16689 .54979 L
.16541 .53859 L
.16435 .52792 L
.16394 .52252 L
.1636 .51656 L
.16339 .51148 L
.1633 .50863 L
.16327 .50727 L
.16324 .50601 L
.16323 .5048 L
.16321 .50371 L
.1632 .50249 L
.16319 .50119 L
.16319 .49993 L
.16319 .49857 L
.1632 .49729 L
.16321 .4961 L
.16323 .49471 L
.16326 .49339 L
.16331 .49091 L
.1634 .48825 L
.16351 .48534 L
Mistroke
.16378 .48012 L
.1641 .47529 L
.1651 .46423 L
.16656 .4525 L
.16836 .44119 L
.17075 .42905 L
.1762 .40731 L
.183 .38619 L
.19167 .36445 L
.21104 .32696 L
.23664 .29004 L
.26571 .25803 L
.30083 .22839 L
.33819 .20461 L
.37677 .18654 L
.3975 .17917 L
.41997 .17284 L
.43014 .17052 L
.44117 .16837 L
.45075 .16681 L
.46127 .16543 L
.47098 .16444 L
.48003 .16378 L
.48505 .16352 L
.48961 .16335 L
.49213 .16328 L
.49346 .16325 L
.49487 .16323 L
.4961 .16321 L
.49745 .1632 L
.49868 .16319 L
.49983 .16319 L
Mfstroke
.49981 .88891 m
.4983 .8889 L
.49693 .88889 L
.49534 .88888 L
.49385 .88886 L
.49118 .88881 L
.4883 .88873 L
.48512 .88862 L
.48174 .88848 L
.4757 .88815 L
.46947 .88771 L
.46364 .8872 L
.45039 .88573 L
.43694 .88376 L
.4247 .88155 L
.39745 .87514 L
.37418 .86799 L
.34934 .85854 L
.30278 .83519 L
.26129 .80703 L
.22156 .77151 L
.18822 .73247 L
.16126 .69106 L
.14966 .66885 L
.1386 .64366 L
.12966 .61873 L
.12301 .59551 L
.11764 .57108 L
.11537 .55749 L
.11366 .54456 L
.11243 .53224 L
.11196 .52601 L
.11156 .51912 L
.11132 .51326 L
.11122 .50996 L
.11118 .5084 L
.11116 .50694 L
.11113 .50555 L
.11112 .50428 L
.1111 .50287 L
.1111 .50137 L
.11109 .49992 L
.1111 .49835 L
.11111 .49687 L
.11112 .4955 L
.11114 .4939 L
.11117 .49237 L
.11124 .48951 L
.11133 .48643 L
.11146 .48307 L
Mistroke
.11177 .47705 L
.11214 .47146 L
.11329 .4587 L
.11498 .44515 L
.11707 .43209 L
.11982 .41808 L
.12611 .39297 L
.13397 .36859 L
.14398 .34349 L
.16635 .30019 L
.1959 .25757 L
.22947 .2206 L
.27003 .18637 L
.31316 .15892 L
.35771 .13806 L
.38164 .12954 L
.40759 .12223 L
.41934 .11955 L
.43207 .11707 L
.44313 .11527 L
.45528 .11367 L
.4665 .11254 L
.47695 .11178 L
.48274 .11148 L
.488 .11128 L
.49092 .1112 L
.49245 .11117 L
.49408 .11114 L
.4955 .11112 L
.49706 .11111 L
.49848 .1111 L
.49981 .11109 L
Mfstroke
.5 .50435 m
.49996 .58767 L
.49994 .62669 L
.49992 .65461 L
.49991 .67736 L
.4999 .69873 L
.49989 .71733 L
.49988 .7355 L
.49987 .75176 L
.49987 .76647 L
.49986 .78128 L
.49985 .79484 L
.49985 .80731 L
.49984 .82005 L
.49983 .83186 L
.49983 .84396 L
.49982 .85523 L
.49982 .86575 L
.49981 .87661 L
.49981 .88679 L
.4998 .89731 L
.4998 .9072 L
.49979 .91649 L
.49979 .92614 L
.49978 .93478 L
s
.49915 .50426 m
.48286 .58598 L
.47524 .62424 L
.46978 .65162 L
.46533 .67394 L
.46116 .6949 L
.45752 .71314 L
.45397 .73096 L
.45079 .74691 L
.44792 .76134 L
.44502 .77586 L
.44237 .78915 L
.43993 .80138 L
.43744 .81388 L
.43514 .82546 L
.43277 .83733 L
.43057 .84838 L
.42851 .85869 L
.42639 .86935 L
.4244 .87933 L
.42234 .88965 L
.42041 .89934 L
.41859 .90845 L
.41671 .91792 L
.41502 .9264 L
s
.49833 .50402 m
.46643 .58099 L
.45149 .61703 L
.4408 .64282 L
.43209 .66384 L
.4239 .68359 L
.41678 .70077 L
.40982 .71755 L
.4036 .73258 L
.39796 .74617 L
.39229 .75984 L
.3871 .77237 L
.38233 .78389 L
.37745 .79566 L
.37293 .80656 L
.36829 .81775 L
.36398 .82816 L
.35995 .83787 L
.35579 .84791 L
.35189 .85731 L
.34786 .86703 L
.34408 .87616 L
.34052 .88474 L
.33682 .89366 L
.33352 .90165 L
s
.49758 .50362 m
.45128 .57289 L
.4296 .60533 L
.41409 .62854 L
.40145 .64746 L
.38957 .66523 L
.37923 .68069 L
.36914 .69579 L
.3601 .70932 L
.35193 .72155 L
.3437 .73386 L
.33617 .74513 L
.32924 .7555 L
.32215 .76609 L
.3156 .77591 L
.30887 .78597 L
.30261 .79534 L
.29676 .80408 L
.29072 .81312 L
.28507 .82158 L
.27922 .83033 L
.27373 .83854 L
.26857 .84627 L
.2632 .8543 L
.2584 .86148 L
s
.49692 .50308 m
.43801 .56199 L
.41042 .58958 L
.39068 .60932 L
.37459 .62541 L
.35947 .64053 L
.34632 .65368 L
.33348 .66652 L
.32198 .67802 L
.31157 .68843 L
.3011 .6989 L
.29152 .70848 L
.2827 .7173 L
.27369 .72631 L
.26534 .73466 L
.25678 .74322 L
.24881 .75119 L
.24138 .75862 L
.23369 .76631 L
.2265 .7735 L
.21906 .78094 L
.21207 .78793 L
.2055 .7945 L
.19867 .80133 L
.19256 .80744 L
s
.49638 .50242 m
.42711 .54872 L
.39467 .5704 L
.37146 .58591 L
.35254 .59855 L
.33477 .61043 L
.31931 .62077 L
.30421 .63086 L
.29068 .6399 L
.27845 .64807 L
.26614 .6563 L
.25487 .66383 L
.2445 .67076 L
.23391 .67785 L
.22409 .6844 L
.21403 .69113 L
.20466 .69739 L
.19592 .70324 L
.18688 .70928 L
.17842 .71493 L
.16967 .72078 L
.16146 .72627 L
.15373 .73143 L
.1457 .7368 L
.13852 .7416 L
s
.49598 .50167 m
.41901 .53357 L
.38297 .54851 L
.35718 .5592 L
.33616 .56791 L
.31641 .5761 L
.29923 .58322 L
.28245 .59018 L
.26742 .5964 L
.25383 .60204 L
.24016 .60771 L
.22763 .6129 L
.21611 .61767 L
.20434 .62255 L
.19344 .62707 L
.18225 .63171 L
.17184 .63602 L
.16213 .64005 L
.15209 .64421 L
.14269 .64811 L
.13297 .65214 L
.12384 .65592 L
.11526 .65948 L
.10634 .66318 L
.09835 .66648 L
s
.49574 .50085 m
.41402 .51714 L
.37576 .52476 L
.34838 .53022 L
.32606 .53467 L
.3051 .53884 L
.28686 .54248 L
.26904 .54603 L
.25309 .54921 L
.23866 .55208 L
.22414 .55498 L
.21085 .55763 L
.19862 .56007 L
.18612 .56256 L
.17454 .56486 L
.16267 .56723 L
.15162 .56943 L
.14131 .57149 L
.13065 .57361 L
.12067 .5756 L
.11035 .57766 L
.10066 .57959 L
.09155 .58141 L
.08208 .58329 L
.0736 .58498 L
s
.49565 .5 m
.41233 .50004 L
.37331 .50006 L
.34539 .50008 L
.32264 .50009 L
.30127 .5001 L
.28267 .50011 L
.2645 .50012 L
.24824 .50013 L
.23353 .50013 L
.21872 .50014 L
.20516 .50015 L
.19269 .50015 L
.17995 .50016 L
.16814 .50017 L
.15604 .50017 L
.14477 .50018 L
.13425 .50018 L
.12339 .50019 L
.11321 .50019 L
.10269 .5002 L
.0928 .5002 L
.08351 .50021 L
.07386 .50021 L
.06522 .50022 L
s
.49573 .49915 m
.414 .48295 L
.37573 .47536 L
.34835 .46993 L
.32603 .46551 L
.30506 .46135 L
.28681 .45773 L
.269 .4542 L
.25304 .45104 L
.23861 .44818 L
.22409 .4453 L
.21079 .44266 L
.19856 .44024 L
.18606 .43776 L
.17448 .43546 L
.1626 .43311 L
.15155 .43091 L
.14123 .42887 L
.13058 .42676 L
.1206 .42478 L
.11027 .42273 L
.10058 .42081 L
.09147 .419 L
.08199 .41712 L
.07352 .41544 L
s
.49598 .49834 m
.41897 .46651 L
.38292 .45161 L
.35712 .44094 L
.33609 .43225 L
.31634 .42409 L
.29915 .41698 L
.28236 .41004 L
.26733 .40383 L
.25373 .39821 L
.24005 .39255 L
.22752 .38737 L
.216 .38261 L
.20422 .37774 L
.19331 .37323 L
.18212 .36861 L
.1717 .3643 L
.16199 .36029 L
.15195 .35614 L
.14254 .35225 L
.13282 .34823 L
.12368 .34445 L
.1151 .34091 L
.10617 .33722 L
.09819 .33392 L
s
.49638 .49759 m
.42706 .45135 L
.3946 .42971 L
.37137 .41422 L
.35245 .40159 L
.33466 .38973 L
.31919 .37941 L
.30407 .36933 L
.29054 .36031 L
.2783 .35215 L
.26599 .34393 L
.25471 .33641 L
.24433 .32949 L
.23373 .32242 L
.22391 .31587 L
.21384 .30915 L
.20446 .3029 L
.19571 .29707 L
.18667 .29104 L
.17821 .28539 L
.16945 .27955 L
.16123 .27407 L
.1535 .26892 L
.14547 .26356 L
.13828 .25876 L
s
.49692 .49693 m
.43794 .43807 L
.41033 .41051 L
.39057 .39079 L
.37446 .37471 L
.35933 .35961 L
.34617 .34647 L
.33331 .33364 L
.3218 .32215 L
.31139 .31176 L
.3009 .3013 L
.29131 .29173 L
.28248 .28292 L
.27346 .27391 L
.26511 .26558 L
.25654 .25702 L
.24856 .24906 L
.24112 .24164 L
.23343 .23396 L
.22623 .22677 L
.21878 .21934 L
.21178 .21236 L
.20521 .20579 L
.19837 .19897 L
.19225 .19287 L
s
.49758 .49639 m
.45121 .42716 L
.4295 .39474 L
.41396 .37155 L
.4013 .35264 L
.3894 .33488 L
.37905 .31943 L
.36894 .30434 L
.35989 .29082 L
.35171 .2786 L
.34347 .2663 L
.33592 .25504 L
.32898 .24467 L
.32189 .23409 L
.31532 .22428 L
.30858 .21422 L
.30231 .20486 L
.29646 .19612 L
.29041 .18709 L
.28475 .17864 L
.27889 .1699 L
.27339 .16168 L
.26822 .15397 L
.26285 .14594 L
.25804 .13876 L
s
.49833 .49598 m
.46635 .41904 L
.45137 .38302 L
.44066 .35724 L
.43192 .33623 L
.42372 .31649 L
.41658 .29931 L
.40961 .28254 L
.40336 .26752 L
.39772 .25394 L
.39203 .24026 L
.38683 .22775 L
.38204 .21623 L
.37715 .20446 L
.37262 .19356 L
.36797 .18238 L
.36365 .17198 L
.35961 .16227 L
.35544 .15223 L
.35154 .14284 L
.3475 .13312 L
.3437 .12399 L
.34014 .11542 L
.33643 .1065 L
.33311 .09852 L
s
.49915 .49574 m
.48278 .41403 L
.47511 .37578 L
.46963 .34841 L
.46516 .3261 L
.46096 .30514 L
.45731 .2869 L
.45374 .26909 L
.45054 .25314 L
.44765 .23872 L
.44475 .2242 L
.44208 .21091 L
.43963 .19868 L
.43713 .18618 L
.43481 .17461 L
.43243 .16274 L
.43022 .15169 L
.42815 .14138 L
.42602 .13072 L
.42402 .12075 L
.42195 .11043 L
.42001 .10074 L
.41819 .09163 L
.41629 .08216 L
.41459 .07369 L
s
.49999 .49565 m
.49987 .41233 L
.49981 .37331 L
.49977 .34539 L
.49973 .32264 L
.4997 .30127 L
.49967 .28267 L
.49965 .2645 L
.49962 .24824 L
.4996 .23353 L
.49958 .21872 L
.49956 .20516 L
.49954 .19269 L
.49952 .17995 L
.4995 .16814 L
.49948 .15604 L
.49947 .14477 L
.49945 .13425 L
.49944 .12339 L
.49942 .11321 L
.4994 .10269 L
.49939 .0928 L
.49938 .08351 L
.49936 .07386 L
.49935 .06522 L
s
gsave
.97826 .54348 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(u) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.54348 .97826 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(v) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97826 .5 m
1 .5 L
s
% Start of user PostScript
1.1 0 1.15 0 MAarrowhead1
% End of user PostScript
.5 .97826 m
.5 1 L
s
% Start of user PostScript
0 1.1 0 1.15 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{178.313, 178.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzlXVtvHDUUnu7sbjZJgbZQCaSqSZs2vQFtHuiFF1qQ4AH6AEjAa1QhtQ8I
VPo/+C/9gyFrOz5ez/edOWd2Nw1ipHS3nhn7nM/nZvvY+/zwzcvf/zh88+rF
4e53rw//evnqxd+73/75+rioPdc0zdv5324z/350/DX987Y5Ojqa33wnH7+F
j7YJpBx/m//9+r+99QO4tWks+/4sVfEc3Jr5qngKbm0Zq0Vl6N2vYlPPjJRZ
m0LvPu1p6nIoauNT6SYiOdXzNbg1mf87npegFzfm/4YiRN6zstrxwq2TSses
0h5EIl/H18TebroQuKhJVDbO/I54uw9Zd4xUGK1loWgb3P2CN7+Rm0d0u5qH
HdMBGYlDou8Rw3XkEYhlyka5tSm4G/FrHmOppa/VQKS/81FSHeI1Ym9E4Jon
QBUQ3KGyjXkJ0pFxVkGqD6Hoy6LRQn47fLaMaoRVXRbfJb2PeHtc9tFiPTV9
6bKQwcrazGBlSzdxW4m6T41SckL0iPWGi/YRkwer5t+LRH1mbBRVO8mEVIAh
7pB0co47YCMWkByiZmIPNZ+zKqiyiwVBEoveQM2jsg2sXrQtVAdiP3Zncz+9
VFXfiNAM1hwrh+jdMVYL8ZpIymK3NQ+qW/PLr0/LUC/ifj5/O4i0HIDHUSyD
FDZU+0EoWtQiRINY7K2aBgTQTJEDBJmYQOq3JkIoEmmtrU7HP+iXVgGdhgyU
Iq5IWPEq/K0mZ6yQnzikpoe8hpoWJGjfWMv0HqaRiWJwkBuZ5Kaon6JK72Kn
p4vTZQk5GS7Jg9zMNHObjowA7uRleLSWCcpN//iQmuxQwX58/xZrxRD8bWWJ
sNphq1rTMjgYm1/I/CE+Etu3K6FK1dTONBXPMqNWJ2RllMY8rTBls8HpuhP/
cyeDZQ0qiTO3GiergeG9jdm0Bq8SRadI+K7aZ7plXMaEWYGwRruIFit94mPu
FWLhsF919J6e5cHg6rDwCQ9WWZePul1ChPB2jv8sDMyvMNivzLnLN9IBPunU
xOht1kYVjyLeqG9qhRfPXSp7gYLt/A0J3i3OjsCjGXbUbxPQKXZL0WCPSLRJ
xkuIHMVPo+C3wSabjvepiixji2TcYQkldPpM7CWQdoxc6qHV0MA00WcFyVe2
sVBWiiXDxM+kFaqrsd3d3MtWX6Y5en2MxD0Ers3qUfRJZYf705XpWnx1LxdU
poVai1CEQjiZ6eKKugJoKl9FB11FuApwCQjuxVpu5scR4bPMFo5bG69+2THw
1oGe18kXs7hfYNGVL0QdmXIR3zFMDLRQsG8GR9qupHnTidqNePcG42DM5eGo
nEMZ4LcI9vYIuQUkUC2hi6d7HAEZDVrNDgoyvdIxVHKIT7R6FrEWiNmE0h7F
wT4BL8Fl2/umhgKRH5NKcyNkn+EdVXz0S8f1PhARkR1+tiup9EvKUOnTZ0E1
02MdtToRkjVZGadok+cEUWKPBkEho6axUNPPSRmlWAdoyEMTX8Xj/l516QXI
MiqDr4vHrpyYddEzgXbd+DgFoQiJsDGa9MrUtGaOYeTBTRwcHbgvvaSaMLyS
cbAaM31dzzpN1m+mBiCr+UcLSY13DRenal2JTe/MP6asn/SspTqw0YeiFkTK
T31UpqeqUYsemtrVNJPUiFZ59XyC5qIKh/XTNQ3dFq+c3KQrQFPw8HUOjeBn
Teup5owKW6GrTbS6UwYJsvfdhlxETlhPKkacTqME5hDqY0AmmsSpeY54THJZ
eR9b64UmaHobVXtkjJLSXDM+jpYF9RTRVu5iXz5q5IkChpbJRNMZk9Kur7TA
Ghc5MaFlgQZJNhHPWnR6+TlFLKerivNC1Ygfa9C7Ah4D9hIIS4dtVz2aPmU6
ZGvxzdWzYA1O0DLB8d9s/n8ZMiIXN6l4TFdlG2cihP0m69T5BmWSjFPHyJHd
blm1yCYy3+NpzwDH72cx7Jqf2otm9i+umDexZZ+sh8tLuVu6XAaOLq+Do6nU
HCH7Z15waT0sXpj/e0kaWDEvwY1/tB7StzJYbW6qo2EnRaEX31sHi6Ho4/Ww
OM2SJiOLikUinhLnhAesm3BO2wei+EPmsBG/M9jNR2VQM5YnVuc6pOYPl+dd
gk1JDEMjv5PvaGAijkMCg0n+NpBLMh+laLBr5gaFljIVCJ1nZrUK99m9guo6
8kPBtysqXR9YdLhVDwQ2O0yizwjKRkeOyk89G4GmstSBDOtvmieKlDpBxgeV
nThzino1y5l0bRGF4kmVYiA1UzFdeFZWnKmtEM9kHzchAMR92a1oUzqMSMMF
k+D0MU8mGfTtd3SBl3JFJhkiN4vik+UKNUpF2TRXqQhMRZR1hlgGRijORzME
gYa0mnc1i5V1upO6+GJCiCwTDJjHxSl11eSkyzsF7ndidVdyZdaZYWqWkAzx
Fb0zNdtNt0G4Mm1CUZrv9q1h4anzoYsxloStAat9hmQoGiOuaelTHAZKyT/l
9b5qOrTSBLrOZ02dc0KDdpe5AbEW06gH8VWl1FonQRP/NEWFdgkiDsZMDPn+
XJRVZ2EgcUQS7sqkdACo1s2lSDPCZzmJRYZI1hVbJV/KuiNOzVTS8i1cKWMc
MmURQ3fxSmbUTdoZi7Jl3RMkUdUqswutS50iFtbNXfU27HQpElQjFoWQEIl2
eTdnIAfTmy8WONgvVIjKFdpQSbZSrCKl1lcHiCGpULRCOfPTURSimbYGCr6z
G4aLiNHm6ntZqSqhIVp4OLmsnYyg1R/pFp0OC6jP8+V890dYCzJfhEGmYxTo
oCpUtBtf36faZB8qWXdKDUiL98OWLld/DmwagZ60E22DIkeM+LYZebTJBSGt
xVqzaIbBICm7xfg5S6vfFteT/mNNYmtK54roN+3982/TDGXhDA9rQDpdbI06
1EQw3WRqGDEN3WvK5MvqYfTFai0QUTahahuSudKcmQ3JVqtNBVjisc62det5
Jb4E6NVhZN2MfaT4dWs8UZ5q0DIlcGR9n8apBmhQb92aiyKyu/HbgJMrXPM8
VvaoOvTvt8bqnvp4XxUYMYOne/hIlaumh/zhbrL0aEhOp1IpdCf3lmHBq69I
LuUgFKs4pb19+mFt1iCQrqVbI1A934Wv+tsdlOHENtdKD50QcnWxHjj0rmik
Y68eAGkh1PHZmUWjhhbe7frcfdd39oHK7UEFnH2SRZcofZFYOyOiwu6gplNf
HUbdFDJzrYMisb0oRUGXESFtmWU+1xYgsdYYt/srEJV3fcqiLsHI6FrNhjiy
ZTZ2UTHyxoh0FK0cWPdfOfdUn3lPDD5iRPo1y6IxHXFLp+PWJwoDi2yVF30n
JE25CY0/KagJz+jHLRicBJ0DpTly4W550LJtmBHKNoSojiKEe3qOS8VPQqM+
VzkDqvOBUAs0WBYE8htUfR8V8ksVj6+2DCvDw0PSIw85hXqGj4saWotyALw+
1rA2L1kaKD8rNf8Nk3+rFNARecs6eOHAfyBSKDZces+m0qgc0UENP01Ffhqr
tf58xAWGyZDfizB0xKp+mmJgU8oPbqzg50HOxu+cDPuZl1+yVKkFQSpjNbFc
lCpI+s+OWyTj6KfiORmUV99+XIbXd/S7Qs25fwEHPGcH\
\>"],
  ImageRangeCache->{{{17.6875, 159.563}, {159.625, 17.75}} -> {-1, -1, 0, 0}}],
 StyleBox["  \n\t\t\t(c)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  A portion of ",
 StyleBox["R",
  FontFamily->"Courier New"],
 " and its image under  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["z", 
    FractionBox["1", "2"]]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["\t\t\tFigure 2.20",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Formation of the Riemann surface for  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["z", 
    FractionBox["1", "2"]]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["Exploration",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506703588875*^9, 3.506703588875*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to draw a picture of the Riemann surface for  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["z", 
    FractionBox["1", "2"]]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"r", " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
       RowBox[{"r", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
       RowBox[{
        RadicalBox["r", "2"], " ", 
        RowBox[{"Cos", "[", 
         FractionBox["\[Theta]", "2"], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]", ",", "0", ",", 
       RowBox[{"4", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"20", ",", "90"}], "}"}]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "y", ",", "z", ",", "r", ",", "\[Theta]"}], "}"}], 
        ",", 
        RowBox[{"Hue", "[", "x", "]"}]}], "]"}]}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
     RowBox[{"Axes", "\[Rule]", "None"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], "}"}]}], 
     ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1.3", ",", 
        RowBox[{"-", "3.2"}], ",", "2.0"}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.399795357984375*^9, {3.3997954495466275`*^9, 3.399795450031002*^9}, {
   3.399795741874752*^9, 3.3997957657966275`*^9}, {3.399795806937252*^9, 
   3.399795836718502*^9}, {3.399796081062252*^9, 3.3997960954216275`*^9}, {
   3.399796171093502*^9, 3.399796172156002*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.3997961799528775`*^9, 3.3997961881403775`*^9}}]
}, Open  ]]
}, Closed]],

Cell[TextData[{
 "\tThe beauty of this structure is that it makes this \"full square root \
function\" continuous for all ",
 Cell[BoxData[
  RowBox[{"z", "\[NotEqual]", "0"}]]],
 ".  Normally, the principal square root function would be discontinuous \
along the negative real axis, as points near ",
 Cell[BoxData[
  RowBox[{"-", "1"}]]],
 " but above that axis would get mapped to points close to ",
 Cell[BoxData["\[ImaginaryI]"]],
 ", and points near ",
 Cell[BoxData[
  RowBox[{"-", "1"}]]],
 " but below the axis would get mapped to points close to ",
 Cell[BoxData[
  RowBox[{"-", "\[ImaginaryI]"}]]],
 ".  "
}], "Text"],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",
 InitializationCell->True]
}, Closed]]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{934, 641},
WindowMargins->{{15, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 179, 3, 29, "Text"],
Cell[1730, 51, 353, 6, 47, "Text"],
Cell[2086, 59, 425, 7, 65, "Text"],
Cell[2514, 68, 2256, 87, 109, "Text",
 Evaluatable->False],
Cell[4773, 157, 859, 17, 101, "Text"],
Cell[5635, 176, 838, 29, 47, "Text",
 Evaluatable->False],
Cell[6476, 207, 315, 10, 29, "Text",
 Evaluatable->False],
Cell[6794, 219, 6372, 226, 449, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[13191, 449, 279, 8, 37, "Subsection",
 Evaluatable->False],
Cell[13473, 459, 764, 31, 37, "Text"],
Cell[14240, 492, 4200, 116, 387, "Input"],
Cell[18443, 610, 102, 3, 47, "Text"],
Cell[18548, 615, 3529, 99, 251, "Input"],
Cell[22080, 716, 1034, 36, 55, "Text"],
Cell[23117, 754, 4100, 113, 370, "Input"],
Cell[27220, 869, 102, 3, 47, "Text"],
Cell[27325, 874, 3393, 95, 251, "Input"],
Cell[30721, 971, 608, 22, 47, "Text"]
}, Closed]],
Cell[31344, 996, 613, 22, 40, "Text",
 Evaluatable->False],
Cell[31960, 1020, 3594, 128, 183, "Text"],
Cell[35557, 1150, 590, 25, 29, "Text"],
Cell[CellGroupData[{
Cell[36172, 1179, 279, 8, 37, "Subsection",
 Evaluatable->False],
Cell[36454, 1189, 661, 23, 37, "Text"],
Cell[37118, 1214, 3702, 102, 422, "Input"],
Cell[40823, 1318, 834, 31, 37, "Text"]
}, Closed]],
Cell[41672, 1352, 23478, 1216, 234, "Text"],
Cell[65153, 2570, 23375, 1214, 237, "Text"],
Cell[88531, 3786, 473, 22, 37, "Text"],
Cell[89007, 3810, 1369, 49, 133, "Text"],
Cell[90379, 3861, 668, 22, 47, "Text"],
Cell[91050, 3885, 10821, 443, 242, "Text"],
Cell[101874, 4330, 281, 11, 38, "Text"],
Cell[102158, 4343, 875, 20, 65, "Text"],
Cell[103036, 4365, 67651, 1860, 283, "Text"],
Cell[170690, 6227, 2528, 96, 91, "Text"],
Cell[173221, 6325, 1839, 68, 73, "Text"],
Cell[175063, 6395, 36668, 1849, 222, "Text"],
Cell[211734, 8246, 34325, 1807, 222, "Text"],
Cell[246062, 10055, 60735, 3249, 222, "Text"],
Cell[306800, 13306, 255, 10, 37, "Text"],
Cell[CellGroupData[{
Cell[307080, 13320, 215, 6, 37, "Subsection",
 Evaluatable->False],
Cell[307298, 13328, 234, 10, 37, "Text"],
Cell[CellGroupData[{
Cell[307557, 13342, 1722, 45, 135, "Input"],
Cell[309282, 13389, 96, 1, 31, "Input"]
}, Open  ]]
}, Closed]],
Cell[309405, 13394, 628, 18, 62, "Text"],
Cell[310036, 13414, 435, 8, 29, "Text"],
Cell[CellGroupData[{
Cell[310496, 13426, 407, 7, 29, "Text"],
Cell[310906, 13435, 130, 3, 31, "Input",
 InitializationCell->True]
}, Closed]]
}
]
*)

(* End of internal cache information *)
