(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    135090,       4353]
NotebookOptionsPosition[    129506,       4181]
NotebookOutlinePosition[    129870,       4197]
CellTagsIndexPosition[    129827,       4194]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[StyleBox["Chapter 3  Analytic and Harmonic Functions",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.532709170265625*^9, 3.532709171*^9}}],

Cell[TextData[{
 StyleBox["Overview",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tDoes the notion of a derivative of a complex function make sense?  If \
so, how should it be defined and what does it represent?  These and similar \
questions are the focus of this chapter.  As you might guess, complex \
derivatives have a meaningful definition, and many of the standard derivative \
theorems from from calculus (such as the product rule and chain rule) carry \
over for complex functions.  There are also some interesting applications.  \
But not everything is symmetric.  You will learn in this chapter that the \
mean value theorem for derivatives does not extend to complex functions.  In \
later chapters you will see that differentiable complex functions are, in \
some sense, much more \"differentiable\" than differentiable real functions."
}], "Text"],

Cell[TextData[StyleBox["Section 3.1  Differentiable and Analytic Functions",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tUsing our imagination, we take our lead from elementary calculus and \
define the derivative of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", written ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 ", by  \n\n",
 StyleBox["(3-1)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], " ", "=", " ", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", " ", "\[Rule]", " ", 
      SubscriptBox["z", "0"]}]], " ", 
    FractionBox[
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
      RowBox[{"f", 
       RowBox[{"(", 
        SubscriptBox["z", "0"], ")"}]}]}], 
     RowBox[{"z", " ", "-", " ", 
      SubscriptBox["z", "0"]}]]}]}]]],
 ",\n\nprovided that the limit exists.  If it does, we say that the function ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " is differentiable at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  If we write  ",
 Cell[BoxData[
  RowBox[{"\[CapitalDelta]z", "=", 
   RowBox[{"z", "-", 
    SubscriptBox["z", "0"]}]}]]],
 ",  then we can express Equation ",
 StyleBox["(3-1)",
  FontColor->RGBColor[0, 0, 1]],
 " in the form\n\n",
 StyleBox["(3-2)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], " ", "=", " ", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"\[CapitalDelta]z", " ", "\[Rule]", " ", "0"}]], " ", 
    FractionBox[
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["z", "0"], "+", "\[CapitalDelta]z"}], ")"}]}], " ", "-",
       " ", 
      RowBox[{"f", 
       RowBox[{"(", 
        SubscriptBox["z", "0"], ")"}]}]}], "\[CapitalDelta]z"]}]}]]],
 ".  \n  \n\tIf we let  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"\[CapitalDelta]w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "-", 
    RowBox[{"f", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}]}]}]]],
 ",  then we can use the ",
 StyleBox[ButtonBox["Leibniz's",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Leibniz.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " notation ",
 Cell[BoxData[
  FractionBox["dw", "dz"]]],
 " for the derivative:  \n\n",
 StyleBox["(3-3)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["dw", "dz"], " ", "=", " ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"\[CapitalDelta]z", " ", "\[Rule]", " ", "0"}]], " ", 
     FractionBox["\[CapitalDelta]w", "\[CapitalDelta]z"]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the limit definition to find the derivative  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Example", " ", "1."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506703717890625*^9, 3.506703717890625*^9}},
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "\[CapitalDelta]w", ",", "\[CapitalDelta]z", ",", "f", ",", "z", ",", 
      "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim1", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"f", "[", "Z", "]"}], "-", 
         RowBox[{"f", "[", 
          SubscriptBox["z", "0"], "]"}]}], 
        RowBox[{"Z", "-", 
         SubscriptBox["z", "0"]}]], ",", 
       RowBox[{"Z", "\[Rule]", 
        SubscriptBox["z", "0"]}], ",", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] \*SubscriptBox[\(z\), \(0\
\)]\)]\) \!\(\*FractionBox[\(f[z] - f[\*SubscriptBox[\(z\), \(0\)]]\), \(z - \
\*SubscriptBox[\(z\), \(0\)]\)]\) = \>\"", ",", "lim1"}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399019528921875*^9, 3.399019539546875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{"lim1", " ", "\[Equal]", " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", 
       SubscriptBox["z", "0"], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399019542921875*^9, 3.39901954378125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"lim2", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{
           SubscriptBox["z", "0"], "+", "\[CapitalDelta]z"}], "]"}], "-", 
         RowBox[{"f", "[", 
          SubscriptBox["z", "0"], "]"}]}], "\[CapitalDelta]z"], ",", 
       RowBox[{"\[CapitalDelta]z", "\[Rule]", "0"}], ",", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]z \[Rule] 0\)]\) \
\!\(\*FractionBox[\(f[\*SubscriptBox[\(z\), \(0\)] + \[CapitalDelta]z] - \
f[\*SubscriptBox[\(z\), \(0\)]]\), \(\[CapitalDelta]z\)]\) = \>\"", ",", 
      "lim2"}], " ", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39901955203125*^9, 3.39901955384375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{"lim2", " ", "\[Equal]", " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", 
       SubscriptBox["z", "0"], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399019556625*^9, 3.399019557625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalDelta]w", "=", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{
        SubscriptBox["z", "0"], "+", "\[CapitalDelta]z"}], "]"}], "-", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim3", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox["\[CapitalDelta]w", "\[CapitalDelta]z"], ",", 
       RowBox[{"\[CapitalDelta]z", "\[Rule]", "0"}], ",", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]z \[Rule] 0\)]\) \
\!\(\*FractionBox[\(\[CapitalDelta]w\), \(\[CapitalDelta]z\)]\) = \>\"", ",", 
      "lim3"}], " ", "]"}], ";"}], " "}]}]], "Input",
 CellChangeTimes->{3.399019561359375*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{"lim3", " ", "\[Equal]", " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", 
       SubscriptBox["z", "0"], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019530109375*^9, 3.399019567703125*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 3.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the limit definition to find the derivative of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", "3"]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  Using Equation ",
 StyleBox["(3-1)",
  FontColor->RGBColor[0, 0, 1]],
 ", we have  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], " ", "=", " ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "0"]}]], " ", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", 
         SubscriptBox["z", "0"]}], ")"}], "3"], 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "0"]}]]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                ", 
   RowBox[{"=", " ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "0"]}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], " ", "+", " ", 
         RowBox[{"z", " ", 
          SubscriptBox["z", "0"]}], " ", "+", " ", 
         SubsuperscriptBox["z", "0", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         SubscriptBox["z", "0"]}], ")"}], " "}], 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "0"]}]]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                ", 
   RowBox[{"=", " ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "0"]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z", "2"], "+", 
       RowBox[{"z", " ", 
        SubscriptBox["z", "0"]}], "+", 
       SubsuperscriptBox["z", "0", "2"]}], ")"}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                ", 
   RowBox[{"=", " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["z", "0", "2"], "+", 
      RowBox[{
       SubscriptBox["z", "0"], " ", 
       SubscriptBox["z", "0"]}], "+", 
      SubsuperscriptBox["z", "0", "2"]}], ")"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                ", 
   RowBox[{"=", 
    RowBox[{"3", 
     SubsuperscriptBox["z", "0", "2"]}]}]}]}]],
 "  \n\nWe can drop the subscript on ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " to obtain  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"3", 
    SuperscriptBox["z", "2"]}]}]]],
 "  as a general formula."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"3.1", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506703721609375*^9, 3.506703721625*^9}},
 AspectRatioFixed->False],

Cell["Enter the function f[z].", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "difQuotient", ",", "\[CapitalDelta]f\[CapitalDelta]z", ",", "f", ",", 
      "lim", ",", "sub", ",", "z", ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["z", "3"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f(z) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3990195785*^9}],

Cell["Form the difference quotient.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalDelta]f\[CapitalDelta]z", " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"f", "[", "Z", "]"}], "-", 
       RowBox[{"f", "[", 
        SubscriptBox["z", "0"], "]"}]}], 
      RowBox[{"Z", " ", "-", " ", 
       SubscriptBox["z", "0"]}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]z\)]\) = \
\!\(\*FractionBox[\(f[z] - f[\*SubscriptBox[\(z\), \(0\)]]\), \(z\\\  - \\\ \
\*SubscriptBox[\(z\), \(0\)]\)]\)\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]z\)]\) = \
\>\"", ",", "\[CapitalDelta]f\[CapitalDelta]z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019583015625*^9}],

Cell[TextData[{
 "Observe that substitution of   ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "  ", 
   StyleBox["for",
    FontFamily->"Times New Roman"], "  ", "z"}]]],
 "  indeterminate."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"sub0", " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"\[CapitalDelta]f\[CapitalDelta]z", ",", 
       RowBox[{
       "Z", " ", "\[Rule]", "\"\<\!\(\*SubscriptBox[\(z\), \(0\)]\)\>\""}]}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sub1", " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"\[CapitalDelta]f\[CapitalDelta]z", ",", 
       RowBox[{"Z", " ", "\[Rule]", 
        SubscriptBox["z", "0"]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Substitute Z = \!\(\*SubscriptBox[\(z\), \(0\)]\), \
\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]z\)]\) = \>\"", ",", 
      "\[CapitalDelta]f\[CapitalDelta]z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<              Get  \!\(\*FractionBox[\(\[CapitalDelta]f\), \(\
\[CapitalDelta]z\)]\) = \>\"", ",", "sub0"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<                   \!\(\*FractionBox[\(\[CapitalDelta]f\), \(\
\[CapitalDelta]z\)]\) = \>\"", ",", "sub1"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019589203125*^9}],

Cell["\<\
Calculate the derivative as the limit of the difference quotient.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"lim", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{"\[CapitalDelta]f\[CapitalDelta]z", ",", " ", 
       RowBox[{"Z", "\[Rule]", 
        SubscriptBox["z", "0"]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*FractionBox[\(df\), \(dz\)]\) = \!\(\*UnderscriptBox[\(lim\), \
\(\[CapitalDelta]z \[Rule] 0\)]\) \!\(\*FractionBox[\(f[z] - \
f[\*SubscriptBox[\(z\), \(0\)]]\), \(z\\\  - \\\ \*SubscriptBox[\(z\), \(0\)]\
\)]\)\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(df\), \(dz\)]\) = \!\(\*UnderscriptBox[\(lim\), \
\(\[CapitalDelta]z \[Rule] 0\)]\) \>\"", ",", 
      "\[CapitalDelta]f\[CapitalDelta]z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*FractionBox[\(df\), \(dz\)]\) = \>\"", ",", "lim"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019598078125*^9}],

Cell[TextData[{
 "Notice that the difference quotient can be simplified before substitution \
of  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "  ", 
   StyleBox["for",
    FontFamily->"Times New Roman"], "  ", "z"}]]],
 "  and can be used to find the derivative."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"difQuotient", " ", "=", " ", 
     RowBox[{"Simplify", "[", "\[CapitalDelta]f\[CapitalDelta]z", "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n", " ", "=", " ", 
     RowBox[{"Factor", "[", 
      RowBox[{"Numerator", "[", "\[CapitalDelta]f\[CapitalDelta]z", "]"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d", "=", 
     RowBox[{"Denominator", "[", "\[CapitalDelta]f\[CapitalDelta]z", "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"sub", " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"difQuotient", ",", 
       RowBox[{"Z", " ", "\[Rule]", 
        SubscriptBox["z", "0"]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*FractionBox[\(df\), \(dz\)]\) = \!\(\*UnderscriptBox[\(lim\), \
\(\[CapitalDelta]z \[Rule] 0\)]\) \!\(\*FractionBox[\(f[z] - \
f[\*SubscriptBox[\(z\), \(0\)]]\), \(z\\\  - \\\ \*SubscriptBox[\(z\), \(0\)]\
\)]\)\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(df\), \(dz\)]\) = \!\(\*UnderscriptBox[\(lim\), \
\(\[CapitalDelta]z \[Rule] 0\)]\) \>\"", ",", 
      "\[CapitalDelta]f\[CapitalDelta]z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(df\), \(dz\)]\) = \!\(\*UnderscriptBox[\(lim\), \
\(\[CapitalDelta]z \[Rule] 0\)]\) \>\"", ",", "n", ",", "\"\</(\>\"", ",", 
      "d", ",", "\"\<)\>\""}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(df\), \(dz\)]\) = \!\(\*UnderscriptBox[\(lim\), \
\(\[CapitalDelta]z \[Rule] 0\)]\) (\>\"", ",", "difQuotient", ",", 
      "\"\<)\>\""}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*FractionBox[\(df\), \(dz\)]\) = \>\"", ",", "sub"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019602609375*^9}],

Cell[TextData[{
 "Hence we have used the limit definition to find the derivative of  f[z]  at \
the point  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  \nThus, the derivative of   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "3"], "  ", 
     StyleBox["is",
      FontFamily->"Times New Roman"], "  ", 
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{"3", 
     SuperscriptBox["z", "2"]}]}]}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 "\tPay careful attention to the complex value ",
 Cell[BoxData["\[CapitalDelta]z"]],
 " in Equation ",
 StyleBox["(3-3)",
  FontColor->RGBColor[0, 0, 1]],
 "; the value of the limit must be independent of the manner in which  ",
 Cell[BoxData[
  RowBox[{"\[CapitalDelta]z", "\[Rule]", "0"}]]],
 ".  If we can find two curves that end at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " along which ",
 Cell[BoxData[
  FractionBox["\[CapitalDelta]w", "\[CapitalDelta]z"]]],
 " approaches distinct values, then ",
 Cell[BoxData[
  FractionBox["\[CapitalDelta]w", "\[CapitalDelta]z"]]],
 " does not have a limit as  ",
 Cell[BoxData[
  RowBox[{"\[CapitalDelta]z", "\[Rule]", "0"}]]],
 "  and ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " does not have a derivative at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  The same observation applies to the limits in Equations ",
 StyleBox["(3-2)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(3-1)",
  FontColor->RGBColor[0, 0, 1]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 3.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  ",
 "Show that the function ",
 " ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   OverscriptBox[
    RowBox[{"z", " "}], "_"]}]]],
 "  is ",
 StyleBox["nowhere ",
  FontColor->RGBColor[1, 0, 1]],
 "differentiable."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We choose two approaches to the point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], " ", "=", " ", 
   RowBox[{
    SubscriptBox["x", "0"], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["y", "0"]}]}]}]]],
 "  and compute limits of the difference quotients.  First, we approach ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], " ", "=", " ", 
   RowBox[{
    SubscriptBox["x", "0"], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["y", "0"]}]}]}]]],
 " along a line parallel to the x axis by forcing z to be of the form ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{"x", "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["y", "0"]}]}]}]]],
 ".   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", 
        SubscriptBox["z", "0"]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
        RowBox[{"f", 
         RowBox[{"(", 
          SubscriptBox["z", "0"], ")"}]}]}], 
       RowBox[{"z", " ", "-", " ", 
        SubscriptBox["z", "0"]}]]}], " ", "=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}], " ", "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["y", "0"]}]}], ")"}]}], " ", "-", " ", 
        RowBox[{"f", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["x", "0"], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["y", "0"]}]}], ")"}]}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}], " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]]}]}], "\[IndentingNewLine]", 
    "\n", "                                            ", 
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}], " ", "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}], " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}], " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]]}]}], "\[IndentingNewLine]", 
    "\n", "                                            ", 
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}], " ", "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}], " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", 
          SubscriptBox["x", "0"]}], ")"}], " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["y", "0"], "-", " ", 
           SubscriptBox["y", "0"]}], ")"}]}]}]]}]}], "\[IndentingNewLine]", 
    "\n", "                                            ", 
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}], " ", "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{"x", " ", "-", " ", 
        SubscriptBox["x", "0"]}], 
       RowBox[{"x", " ", "-", " ", 
        SubscriptBox["x", "0"]}]]}]}], "\n", "\[IndentingNewLine]", 
    "                                            ", 
    RowBox[{"=", " ", 
     RowBox[{"1", 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[".",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}]}]]],
 "    "
}], "Text"],

Cell[TextData[{
 "Next, we approach ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " along a line parallel to the y axis by forcing z to be of the form  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{
    SubscriptBox["x", "0"], "+", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]]],
 ".   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", 
        SubscriptBox["z", "0"]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
        RowBox[{"f", 
         RowBox[{"(", 
          SubscriptBox["z", "0"], ")"}]}]}], 
       RowBox[{"z", " ", "-", " ", 
        SubscriptBox["z", "0"]}]]}], " ", "=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], " ", "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["x", "0"], "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], " ", "-", " ", 
        RowBox[{"f", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["x", "0"], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["y", "0"]}]}], ")"}]}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]]}]}], "\[IndentingNewLine]", 
    "\n", "                                            ", 
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], " ", "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "-", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]]}]}], "\[IndentingNewLine]", 
    "\n", "                                            ", 
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], " ", "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "-", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "-", 
          SubscriptBox["x", "0"]}], ")"}], " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"(", 
          RowBox[{"y", "-", " ", 
           SubscriptBox["y", "0"]}], ")"}]}]}]]}]}], "\[IndentingNewLine]", 
    "\n", "                                            ", 
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], " ", "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["y", "0"]}]}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"-", " ", "\[ImaginaryI]"}], 
        RowBox[{"(", 
         RowBox[{"y", " ", "-", " ", 
          SubscriptBox["y", "0"]}], ")"}]}], 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{"y", " ", "-", " ", 
          SubscriptBox["y", "0"]}], ")"}]}]]}]}], "\n", "\[IndentingNewLine]",
     "                                            ", 
    RowBox[{"=", " ", 
     RowBox[{"-", " ", 
      RowBox[{"1", 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[".",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]}]}]}]}]]],
 "   "
}], "Text"],

Cell[TextData[{
 "\tThe limits along the two paths are different, so there is no possible \
value for the right side of Equation ",
 StyleBox["(3-1)",
  FontColor->RGBColor[0, 0, 1]],
 ".  Therefore ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   OverscriptBox[
    RowBox[{"z", " "}], "_"]}]]],
 "  is not differentiable at the point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", and since ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " was arbitrary, ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    OverscriptBox[
     RowBox[{"z", " "}], "_"], " "}]}]]],
 " is ",
 StyleBox["nowhere",
  FontColor->RGBColor[1, 0, 1]],
 " differentiable."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"3.2", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506703726203125*^9, 3.506703726203125*^9}},
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "\[CapitalDelta]f", ",", "\[CapitalDelta]f\[CapitalDelta]x", ",", 
      "\[CapitalDelta]f\[CapitalDelta]y", ",", "\[CapitalDelta]x", ",", 
      "\[CapitalDelta]y", ",", "f", ",", "x", ",", "y", ",", "z"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Conjugate", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f(z) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39901961171875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "First, form the difference quotient using  ",
 Cell[BoxData[
  RowBox[{"\[CapitalDelta]z", "=", "\[CapitalDelta]x"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalDelta]f\[CapitalDelta]x", " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{
         SubscriptBox["x", "0"], " ", "+", " ", "\[CapitalDelta]x", " ", "+", 
         " ", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["y", "0"]}]}], "]"}], "-", 
       RowBox[{"f", "[", 
        RowBox[{
         SubscriptBox["x", "0"], " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["y", "0"]}]}], "]"}]}], 
      RowBox[{
       SubscriptBox["x", "0"], " ", "+", " ", "\[CapitalDelta]x", " ", "+", 
       " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["y", "0"]}], "  ", "-", " ", 
       SubscriptBox["x", "0"], " ", "-", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["y", "0"]}]}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n", "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Numerator", "[", "\[CapitalDelta]f\[CapitalDelta]x", "]"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d", "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Denominator", "[", "\[CapitalDelta]f\[CapitalDelta]x", "]"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*FractionBox[\(df\), \(dz\)]\) = \!\(\*UnderscriptBox[\(lim\), \
\(\[CapitalDelta]x \[Rule] 0\)]\) \!\(\*FractionBox[\(f[\*SubscriptBox[\(x\), \
\(0\)]\\\  + \\\ \[CapitalDelta]x\\\  + \\\ \[ImaginaryI]\\\ \
\*SubscriptBox[\(y\), \(0\)]] - f[\*SubscriptBox[\(x\), \(0\)]\\\  + \\\ \
\[ImaginaryI]\\\ \*SubscriptBox[\(y\), \(0\)]]\), \(\*SubscriptBox[\(x\), \(0\
\)]\\\  + \\\ \[CapitalDelta]x\\\  + \\\ \[ImaginaryI]\\\ \
\*SubscriptBox[\(y\), \(0\)]\\\ \\\  - \\\ \*SubscriptBox[\(x\), \(0\)]\\\  - \
\\\ \[ImaginaryI]\\\ \*SubscriptBox[\(y\), \(0\)]\)]\)\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]x\)]\) = \
\>\"", ",", "\[CapitalDelta]f\[CapitalDelta]x"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]x\)]\) = \
\>\"", ",", "n", ",", "\"\</\>\"", ",", "d"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"\[CapitalDelta]f\[CapitalDelta]x", " ", "=", " ", 
     RowBox[{
     "ComplexExpand", "[", "\[CapitalDelta]f\[CapitalDelta]x", "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]x\)]\) = \
\>\"", ",", "\[CapitalDelta]f\[CapitalDelta]x"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019615359375*^9}],

Cell["And this limit is easy to compute.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]z \[Rule] 0\)]\) \
\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]z\)]\) = \
\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]x \[Rule] 0\)]\) \>\"", ",", 
      "n", ",", "\"\</\>\"", ",", "d", ",", "\"\< = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{"\[CapitalDelta]f\[CapitalDelta]x", ",", 
        RowBox[{"\[CapitalDelta]x", "\[Rule]", "0"}]}], "]"}]}], "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<where  \[CapitalDelta]z = \[CapitalDelta]x\>\"", "]"}],
     ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019620640625*^9}],

Cell[TextData[{
 "Second, form the difference quotient using  ",
 Cell[BoxData[
  RowBox[{"\[CapitalDelta]z", "=", 
   RowBox[{"\[ImaginaryI]", " ", "\[CapitalDelta]y"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalDelta]f\[CapitalDelta]y", " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{
         SubscriptBox["x", "0"], " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["y", "0"], "+", "\[CapitalDelta]y"}], ")"}]}]}], 
        "]"}], "-", 
       RowBox[{"f", "[", 
        RowBox[{
         SubscriptBox["x", "0"], " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["y", "0"]}]}], "]"}]}], 
      RowBox[{
       SubscriptBox["x", "0"], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["y", "0"], "+", "\[CapitalDelta]y"}], ")"}]}], "  ", 
       "-", " ", 
       SubscriptBox["x", "0"], " ", "-", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["y", "0"]}]}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n", "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Numerator", "[", "\[CapitalDelta]f\[CapitalDelta]y", "]"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d", "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Denominator", "[", "\[CapitalDelta]f\[CapitalDelta]y", "]"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\< \!\(\*FractionBox[\(df\), \(dz\)]\) = \
\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]y \[Rule] 0\)]\) \
\!\(\*FractionBox[\(f[\*SubscriptBox[\(x\), \(0\)]\\\  + \\\ \[ImaginaryI] \
\((\*SubscriptBox[\(y\), \(0\)] + \[CapitalDelta]y)\)] - f[\*SubscriptBox[\(x\
\), \(0\)]\\\  + \\\ \[ImaginaryI]\\\ \*SubscriptBox[\(y\), \(0\)]]\), \
\(\*SubscriptBox[\(x\), \(0\)]\\\  + \\\ \[ImaginaryI] \
\((\*SubscriptBox[\(y\), \(0\)] + \[CapitalDelta]y)\)\\\ \\\  - \\\ \
\*SubscriptBox[\(x\), \(0\)]\\\  - \\\ \[ImaginaryI]\\\ \*SubscriptBox[\(y\), \
\(0\)]\)]\)\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[ImaginaryI]\\\ \
\[CapitalDelta]y\)]\) = \>\"", ",", "\[CapitalDelta]f\[CapitalDelta]y"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[ImaginaryI]\\\ \
\[CapitalDelta]y\)]\) = \>\"", ",", "n", ",", "\"\</\>\"", ",", "d"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"\[CapitalDelta]f\[CapitalDelta]y", " ", "=", " ", 
     RowBox[{
     "ComplexExpand", "[", "\[CapitalDelta]f\[CapitalDelta]y", "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[ImaginaryI]\\\ \
\[CapitalDelta]y\)]\) = \>\"", ",", "\[CapitalDelta]f\[CapitalDelta]y"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3990196245625*^9}],

Cell["And this limit is easy to compute.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]z \[Rule] 0\)]\) \
\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]z\)]\) = \
\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]y \[Rule] 0\)]\) \>\"", ",", 
      "n", ",", "\"\</\>\"", ",", "d", ",", "\"\< = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{"\[CapitalDelta]f\[CapitalDelta]y", ",", 
        RowBox[{"\[CapitalDelta]y", "\[Rule]", "0"}]}], "]"}]}], "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<where  \[CapitalDelta]z = \[ImaginaryI] \[CapitalDelta]y\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019629140625*^9}],

Cell[TextData[{
 "Since the two limits are different for any point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], ",", " ", 
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 "  does ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " exist for any  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]z \[Rule] 0\)]\) \
\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]z\)]\) = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{"\[CapitalDelta]f\[CapitalDelta]x", ",", 
        RowBox[{"\[CapitalDelta]x", "\[Rule]", "0"}]}], "]"}], ",", 
      "\"\<,   where  \[CapitalDelta]z = \[CapitalDelta]x\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]z \[Rule] 0\)]\) \
\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]z\)]\) = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{"\[CapitalDelta]f\[CapitalDelta]y", ",", 
        RowBox[{"\[CapitalDelta]y", "\[Rule]", "0"}]}], "]"}], ",", 
      "\"\<,  where  \[CapitalDelta]z = \[ImaginaryI] \[CapitalDelta]y\>\""}],
      "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019634171875*^9}],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " differentiate  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   OverscriptBox[
    RowBox[{"z", " "}], "_"]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[x] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019638625*^9}],

Cell[TextData[{
 "The limit definition has shown that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   OverscriptBox[
    RowBox[{"z", " "}], "_"]}]]],
 "  is ",
 StyleBox["nowhere ",
  FontColor->RGBColor[1, 0, 1]],
 "differentiable."
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Remark 3.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  In Section 2.3 we showed that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   OverscriptBox[
    RowBox[{"z", " "}], "_"]}]]],
 "  is continuous for all ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ".  Thus, we have a simple example of a function that is continuous \
everywhere but differentiable nowhere.  Such functions are hard to construct \
in real variables. In some sense, the complex case has made pathological \
constructions simpler!"
}], "Text"],

Cell[TextData[{
 "\tWe seldom are interested in studying functions that aren't \
differentiable, or are differentiable at only a single point.  Complex \
functions that have a derivative at all points in a neighborhood of ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " deserve further study.  In Chapter 7 we demonstrate that, if the complex \
function ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " can be represented by a Taylor series at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", then it must be differentiable in some neighborhood of ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  Functions that are differentiable in neighborhoods of points are pillars \
of the complex analysis edifice; we give them a special name, as indicated in \
the following definition."
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 3.1 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Analytic Function",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/AnalyticFunction.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["  ",
  FontWeight->"Bold"],
 "The complex function ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " is analytic at the point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " provided there is some ",
 Cell[BoxData[
  RowBox[{"\[Epsilon]", ">", "0"}]]],
 " such that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " exists for all ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", 
   RowBox[{
    SubscriptBox["D", "\[Epsilon]"], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 ".  In other words, ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " must be differentiable not only at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", but also at all points in some ",
 Cell[BoxData["\[Epsilon]"]],
 "-neighborhood of ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ". "
}], "Text"],

Cell[TextData[{
 "\n\tIf ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is analytic at each point in the region ",
 StyleBox["R",
  FontFamily->"Courier New"],
 ", then we say that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is analytic on ",
 StyleBox["R",
  FontFamily->"Courier New"],
 ".  Again, we have a special term if ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is analytic on the whole complex plane. "
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 3.2 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Entire Function",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/EntireFunction.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["  ",
  FontWeight->"Bold"],
 "If ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is analytic on the whole complex plane then ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is said to be entire. "
}], "Text"],

Cell["\<\
\tPoints of nonanalyticity for a function are called singular points. They \
are important for certain applications in physics and engineering.\
\>", "Text"],

Cell["\<\
\tOur definition of the derivative for complex functions is formally the same \
as for real functions and is the natural extension from real variables to \
complex variables.  The basic differentiation formulas are identical to those \
for real functions, and we obtain the same rules for differentiating powers, \
sums, products, quotients, and compositions of functions.  We can easily \
establish the proof of the differentiation formulas by using the limit \
theorems.\
\>", "Text"],

Cell[TextData[StyleBox["The Rules for Differentiation.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tSuppose that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " are differentiable.  From Equation ",
 StyleBox["(3-2)",
  FontColor->RGBColor[0, 0, 1]],
 " and the technique exhibited in the solution to Example 3.1 we can \
establish the following rules, which are virtually identical to those for \
real-valued functions.  \n\n",
 Cell[BoxData[GridBox[{
    {
     StyleBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", "-", "4"}], ")"}], " ", "\[IndentingNewLine]", " "}],
      FontFamily->"Times New Roman",
      FontWeight->"Plain",
      FontColor->RGBColor[0, 0, 0.996109]], "           ", 
     StyleBox[
      RowBox[{
       RowBox[{
        RowBox[{
         StyleBox[
          FractionBox["d", "dz"],
          FontFamily->"Times New Roman"], 
         StyleBox["C",
          FontFamily->"Courier New",
          FontWeight->"Plain"]}], 
        StyleBox[" ",
         FontFamily->"Courier New",
         FontWeight->"Plain"], 
        StyleBox["=",
         FontFamily->"Courier New",
         FontWeight->"Plain"], 
        StyleBox[" ",
         FontFamily->"Courier New",
         FontWeight->"Plain"], 
        StyleBox["0",
         FontFamily->"Courier New",
         FontWeight->"Plain"]}], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontWeight->"Plain"], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontWeight->"Plain"], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontWeight->"Plain"], 
       RowBox[{
        StyleBox["where",
         FontFamily->"Times New Roman"], 
        StyleBox[" ",
         FontFamily->"Times New Roman"], 
        StyleBox["C",
         FontFamily->"Courier New",
         FontWeight->"Plain"], 
        StyleBox[" ",
         FontFamily->"Times New Roman"], 
        StyleBox["is",
         FontFamily->"Times New Roman"], 
        StyleBox[" ",
         FontFamily->"Times New Roman"], 
        StyleBox["a",
         FontFamily->"Times New Roman"], 
        StyleBox[" ",
         FontFamily->"Times New Roman"], 
        StyleBox["constant",
         FontFamily->"Times New Roman"]}], 
       StyleBox[" ",
        FontFamily->"Times New Roman"], 
       StyleBox[",",
        FontFamily->"Times New Roman"], 
       StyleBox["                                                           ",
        FontFamily->"Times New Roman"]}],
      FontSize->12,
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"3", "-", "5"}], ")"}],
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], "\[IndentingNewLine]"}], 
     "           ", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["d", "dz"], 
        SuperscriptBox["z", "n"]}], " ", "=", " ", 
       RowBox[{"n", " ", 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{
       StyleBox["where",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], " ", "n", " ", 
       StyleBox["is",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["a",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["positive",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["integer",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["                            ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"3", "-", "6"}], ")"}],
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], 
      StyleBox["  ",
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], "\[IndentingNewLine]"}], 
     "           ", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["d", "dz"], "[", 
        RowBox[{"C", " ", "f", 
         RowBox[{"(", "z", ")"}]}], "]"}], " ", "=", " ", 
       RowBox[{"C", " ", 
        RowBox[{"f", "'"}], 
        RowBox[{"(", "z", ")"}]}]}], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      "                                                 "}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"3", "-", "7"}], ")"}],
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], 
      StyleBox["  ",
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], "\[IndentingNewLine]"}], 
     "           ", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["d", "dz"], "[", 
        RowBox[{
         RowBox[{"f", 
          RowBox[{"(", "z", ")"}]}], "+", 
         RowBox[{"g", 
          RowBox[{"(", "z", ")"}]}]}], "]"}], " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "'"}], 
         RowBox[{"(", "z", ")"}]}], "+", 
        RowBox[{
         RowBox[{"g", "'"}], 
         RowBox[{"(", "z", ")"}]}]}]}], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[
       RowBox[{
        StyleBox["                                  ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], " "}]]}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"3", "-", "8"}], ")"}],
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], 
      StyleBox["  ",
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], "\[IndentingNewLine]"}], 
     "           ", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["d", "dz"], "[", 
        RowBox[{"f", 
         RowBox[{"(", "z", ")"}], "g", 
         RowBox[{"(", "z", ")"}]}], "]"}], " ", "=", " ", 
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", "z", ")"}], " ", 
         RowBox[{"g", "'"}], 
         RowBox[{"(", "z", ")"}]}], "+", 
        RowBox[{"g", 
         RowBox[{"(", "z", ")"}], " ", 
         RowBox[{"f", "'"}], 
         RowBox[{"(", "z", ")"}]}]}]}], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["      ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"3", "-", "9"}], ")"}],
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], 
      StyleBox["  ",
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], "\[IndentingNewLine]"}], 
     "           ", 
     StyleBox[
      RowBox[{
       StyleBox[
        RowBox[{
         RowBox[{
          FractionBox["d", "dz"], 
          FractionBox[
           RowBox[{"f", 
            RowBox[{"(", "z", ")"}]}], 
           RowBox[{"g", 
            RowBox[{"(", "z", ")"}]}]]}], "  ", "=", " ", 
         FractionBox[
          RowBox[{
           RowBox[{"g", 
            RowBox[{"(", "z", ")"}], " ", 
            RowBox[{"f", "'"}], 
            RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
           RowBox[{"f", 
            RowBox[{"(", "z", ")"}], " ", 
            RowBox[{"g", "'"}], 
            RowBox[{"(", "z", ")"}]}]}], 
          SuperscriptBox[
           RowBox[{"[", 
            RowBox[{"g", 
             RowBox[{"(", "z", ")"}]}], "]"}], "2"]]}],
        FontFamily->"Times New Roman"], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontWeight->"Plain"], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontWeight->"Plain"], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontWeight->"Plain"], 
       RowBox[{
        StyleBox[
         RowBox[{
          StyleBox["provided",
           FontFamily->"Times New Roman"], 
          StyleBox[" ",
           FontFamily->"Times New Roman"], 
          StyleBox["that",
           FontFamily->"Times New Roman"], 
          StyleBox[" ",
           FontFamily->"Courier New",
           FontWeight->"Plain"], 
          StyleBox["g",
           FontFamily->"Courier New",
           FontWeight->"Plain"], 
          StyleBox[
           RowBox[{"(", "z", ")"}],
           FontFamily->"Courier New",
           FontWeight->"Plain"]}],
         FontFamily->"Times New Roman"], 
        StyleBox["\[NotEqual]",
         FontFamily->"Courier New",
         FontWeight->"Plain"], 
        StyleBox["0",
         FontFamily->"Courier New",
         FontWeight->"Plain"]}], 
       StyleBox[" ",
        FontFamily->"Times New Roman"], 
       StyleBox[",",
        FontFamily->"Times New Roman"]}],
      FontSize->12,
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]},
    {
     StyleBox[
      RowBox[{"(", 
       RowBox[{"3", "-", "10"}], ")"}],
      FontFamily->"Times New Roman",
      FontWeight->"Plain",
      FontColor->RGBColor[0, 0, 0.996109]], "           ", 
     RowBox[{
      RowBox[{
       FractionBox["d", "dz"], "f", 
       RowBox[{"(", 
        RowBox[{"g", 
         RowBox[{"(", "z", ")"}]}], ")"}]}], " ", "=", " ", 
      RowBox[{
       RowBox[{"f", "'"}], "f", 
       RowBox[{"(", 
        RowBox[{"g", 
         RowBox[{"(", "z", ")"}]}], ")"}], " ", 
       RowBox[{"g", "'"}], 
       RowBox[{
        RowBox[{"(", "z", ")"}], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[".",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[
         RowBox[{
          StyleBox["                                       ",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], " "}]]}]}]}]}
   }]]],
 "  "
}], "Text"],

Cell[TextData[{
 "Important particular cases of Equations ",
 StyleBox["(3-9)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(3-10)",
  FontColor->RGBColor[0, 0, 1]],
 ", respectively, are  \n\n",
 Cell[BoxData[GridBox[{
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"3", "-", "11"}], ")"}],
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontColor->RGBColor[0, 0, 0.996109]], "\[IndentingNewLine]"}], 
     "           ", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["d", "dz"], 
        FractionBox["1", 
         SuperscriptBox["z", "n"]]}], "  ", "=", " ", 
       FractionBox[
        RowBox[{"-", "n"}], 
        SuperscriptBox["z", 
         RowBox[{"n", "+", "1"}]]]}], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[
       RowBox[{
        RowBox[{
         StyleBox["for",
          FontFamily->"Times New Roman"], 
         StyleBox[" ",
          FontFamily->"Courier New"], 
         StyleBox["z",
          FontFamily->"Courier New"]}], 
        StyleBox["\[NotEqual]",
         FontFamily->"Courier New"], 
        StyleBox["0",
         FontFamily->"Courier New"]}],
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{
       StyleBox["and",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], " ", "n", " ", 
       StyleBox["is",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["a",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["positive",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["integer",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["                              ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]},
    {
     StyleBox[
      RowBox[{"(", 
       RowBox[{"3", "-", "12"}], ")"}],
      FontFamily->"Times New Roman",
      FontWeight->"Plain",
      FontColor->RGBColor[0, 0, 0.996109]], "           ", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         FractionBox["d", "dz"], "[", 
         RowBox[{"f", 
          RowBox[{"(", "z", ")"}]}], "]"}], "n"], " ", "=", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"n", " ", "[", 
          RowBox[{"f", 
           RowBox[{"(", "z", ")"}]}], "]"}], 
         RowBox[{"n", "-", "1"}]], " ", 
        RowBox[{"f", "'"}], 
        RowBox[{"(", "z", ")"}]}]}], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{
       StyleBox["where",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], " ", "n", " ", 
       StyleBox["is",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["a",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["positive",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[
        RowBox[{"integer", " ", "."}],
        FontFamily->"Times New Roman",
        FontSize->12,
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]}]}
   }]]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{
  "Exploration", " ", "for", " ", "the", " ", "Rules", " ", "for", " ", 
   RowBox[{"Differentiation", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.5067037303125*^9, 3.506703730328125*^9}},
 AspectRatioFixed->False],

Cell["\<\
Enter the functions and differentiate.
Find the derivative of a scalar multiple.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "a", ",", "b", ",", "f", ",", "F", ",", "g1", ",", "g2", ",", "g3", ",", 
      "g4", ",", "g5", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"c", " ", "=", " ", 
     RowBox[{"a", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "b"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g1", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"c", " ", 
      RowBox[{"f", "[", "z", "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g1", "'"}], "[", "z", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Derivative of a scalar multiple.\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F[z] = \>\"", ",", 
      RowBox[{"g1", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F[z] = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{"g1", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"g1", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'[z] = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"g1", "'"}], "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019647796875*^9},
 AspectRatioFixed->True],

Cell["Find the derivative of a linear combination.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g2", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "1"], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["b", "1"]}]}], ")"}], " ", 
       RowBox[{"f", "[", "z", "]"}]}], " ", "+", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "2"], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["b", "2"]}]}], ")"}], " ", 
       RowBox[{"g", "[", "z", "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g2", "'"}], "[", "z", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Derivative of a linear combination.\>\"", "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F[z] = \>\"", ",", 
      RowBox[{"g2", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F[z] = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{"g2", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"g2", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'[z] = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"g2", "'"}], "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019652015625*^9},
 AspectRatioFixed->True],

Cell["Find the derivative of a product of two functions.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g3", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"f", "[", "z", "]"}], " ", 
      RowBox[{"g", "[", "z", "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g3", "'"}], "[", "z", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Derivative of the product of two functions.\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F[z] = \>\"", ",", 
      RowBox[{"g3", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"g3", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019659234375*^9},
 AspectRatioFixed->True],

Cell["Find the derivative of the quotient of two functions.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g4", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"f", "[", "z", "]"}], 
      RowBox[{"g", "[", "z", "]"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Derivative of the quotient of two functions.\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F[z] = \>\"", ",", 
      RowBox[{"g4", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'[z] = \>\"", ",", 
      RowBox[{"Together", "[", 
       RowBox[{
        RowBox[{"g4", "'"}], "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019663984375*^9}],

Cell["Find the derivative of the composition of two functions.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g5", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"f", "[", 
      RowBox[{"g", "[", "z", "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g5", "'"}], "[", "z", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Derivative of the composition of two functions.\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F[z] = \>\"", ",", 
      RowBox[{"g5", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'[z] = \>\"", ",", 
      RowBox[{"Together", "[", 
       RowBox[{
        RowBox[{"g5", "'"}], "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3990196675625*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 3.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  If we use Equation ",
 StyleBox["(3-12)",
  FontColor->RGBColor[0, 0, 1]],
 " with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", 
    RowBox[{"\[ImaginaryI]", " ", "2", "z"}], "+", "3"}]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"2", "z"}], "+", " ", 
    RowBox[{"2", "\[ImaginaryI]"}]}]}]]],
 ",  then we get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["d", "dz"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "+", 
        RowBox[{"\[ImaginaryI]", " ", "2", "z"}], "+", "3"}], ")"}], "4"]}], 
    " ", "=", " ", 
    RowBox[{"4", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "+", 
        RowBox[{"\[ImaginaryI]", " ", "2", "z"}], "+", "3"}], ")"}], "3"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "z"}], "+", " ", 
       RowBox[{"2", "\[ImaginaryI]"}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                       ", 
   RowBox[{"=", " ", 
    RowBox[{"8", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "+", 
        RowBox[{"\[ImaginaryI]", " ", "2", "z"}], "+", "3"}], ")"}], "3"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "+", " ", "\[ImaginaryI]"}], ")"}], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[".",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["  ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}]}]}]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"3.3", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.50670373309375*^9, 3.50670373309375*^9}},
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g", ",", "w", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["z", "2"], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "2", "z"}], " ", "+", " ", "3"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"f", "[", "z", "]"}], ")"}], "4"]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "w_", "]"}], "=", 
     SuperscriptBox["w", "4"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f(z) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'(z) = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< g(w) = \>\"", ",", 
      RowBox[{"g", "[", "w", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g'(w) = \>\"", ",", 
      RowBox[{
       RowBox[{"g", "'"}], "[", "w", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g'(f(z)) = \>\"", ",", 
      RowBox[{
       RowBox[{"g", "'"}], "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F(z) = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'(z) = \>\"", ",", 
      RowBox[{
       RowBox[{"F", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<F'(z) = g'[f[z] f'[z]\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'(z) = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"g", "'"}], "[", 
        RowBox[{"f", "[", "z", "]"}], "]"}], 
       RowBox[{
        RowBox[{"f", "'"}], "[", "z", "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3990196756875*^9}],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  This can be ",
 "compared",
 " with expanding F[z] and calculating the derivative"
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F(z) = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     RowBox[{"Expand", "[", 
      RowBox[{"F", "[", "z", "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F(z) = \>\"", ",", 
      RowBox[{"H", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'(z) = \>\"", ",", 
      RowBox[{
       RowBox[{"H", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<F'(z) = g'[f[z] f'[z]\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'(z) = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"g", "'"}], "[", 
        RowBox[{"f", "[", "z", "]"}], "]"}], 
       RowBox[{
        RowBox[{"f", "'"}], "[", "z", "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'(z) = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"g", "'"}], "[", 
         RowBox[{"f", "[", "z", "]"}], "]"}], 
        RowBox[{
         RowBox[{"f", "'"}], "[", "z", "]"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39901967975*^9}]
}, Closed]],

Cell[TextData[{
 "\tThe proofs of the rules given in Equations  through ",
 StyleBox["(3-10)",
  FontColor->RGBColor[0, 0, 1]],
 " depend on the validity of extending theorems for real functions to their \
complex companions.  Equation ",
 StyleBox["(3-8)",
  FontColor->RGBColor[0, 0, 1]],
 ", for example, relies on Theorem 3.1. "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 3.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is differentiable at  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  then ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is continuous at  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Proof.  From Equation (3-1), we obtain  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", " ", "\[Rule]", " ", 
      SubscriptBox["z", "0"]}]], " ", 
    FractionBox[
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
      RowBox[{"f", 
       RowBox[{"(", 
        SubscriptBox["z", "0"], ")"}]}]}], 
     RowBox[{"z", " ", "-", " ", 
      SubscriptBox["z", "0"]}]]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 ".  \n\nUsing the multiplicative property of limits given by Formula ",
 StyleBox["(2-19)",
  FontColor->RGBColor[0, 0, 1]],
 ", we get\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "0"]}]], " ", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
       RowBox[{"f", 
        RowBox[{"(", 
         SubscriptBox["z", "0"], ")"}]}]}], "]"}]}], "  ", "=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "0"]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
        RowBox[{"f", 
         RowBox[{"(", 
          SubscriptBox["z", "0"], ")"}]}]}], 
       RowBox[{"z", " ", "-", " ", 
        SubscriptBox["z", "0"]}]], 
      RowBox[{"(", 
       RowBox[{"z", " ", "-", " ", 
        SubscriptBox["z", "0"]}], ")"}]}]}]}], "\[IndentingNewLine]"}], "\n", 
  RowBox[{"                                                    ", 
   RowBox[{"=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "0"]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
        RowBox[{"f", 
         RowBox[{"(", 
          SubscriptBox["z", "0"], ")"}]}]}], 
       RowBox[{"z", " ", "-", " ", 
        SubscriptBox["z", "0"]}]], "  ", 
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"z", " ", "\[Rule]", " ", 
         SubscriptBox["z", "0"]}]], 
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", 
         SubscriptBox["z", "0"]}], ")"}]}]}]}]}], 
   "\n"}], "\[IndentingNewLine]", 
  RowBox[{"                                                    ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "'"}], 
      RowBox[{"(", 
       SubscriptBox["z", "0"], ")"}], "*", "0"}], "  ", "=", "  ", 
     RowBox[{"0", 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[".",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}]}]}]],
 "  \n\n This result implies that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", " ", "\[Rule]", " ", 
      SubscriptBox["z", "0"]}]], " ", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}]}], " ", "=", " ", 
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 ",  which is equivalent to showing that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is continuous at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 3.1 is also in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
 "\tWe can establish Equation ",
 StyleBox["(3-8)",
  FontColor->RGBColor[0, 0, 1]],
 " from Theorem 3.1.  Letting ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}], "g", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " and using Definition 3.1, we write   \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"h", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "0"]}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{"h", 
        RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
       RowBox[{"h", 
        RowBox[{"(", 
         SubscriptBox["z", "0"], ")"}]}]}], 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "0"]}]]}], "=", " ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "0"]}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}], "g", 
        RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
       RowBox[{"f", 
        RowBox[{"(", 
         SubscriptBox["z", "0"], ")"}], " ", "g", 
        RowBox[{"(", 
         SubscriptBox["z", "0"], ")"}]}]}], 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "0"]}]]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "If we subtract and add the term ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}], "g", 
   RowBox[{"(", "z", ")"}]}]]],
 " in the numerator, we get\n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"h", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], " ", "=", " ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "0"]}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}], "g", 
        RowBox[{"(", "z", ")"}]}], " ", "-", 
       RowBox[{"f", 
        RowBox[{"(", 
         SubscriptBox["z", "0"], ")"}], "g", 
        RowBox[{"(", "z", ")"}]}], "+", 
       RowBox[{"f", 
        RowBox[{"(", 
         SubscriptBox["z", "0"], ")"}], "g", 
        RowBox[{"(", "z", ")"}]}], "-", " ", 
       RowBox[{"f", 
        RowBox[{"(", 
         SubscriptBox["z", "0"], ")"}], " ", "g", 
        RowBox[{"(", 
         SubscriptBox["z", "0"], ")"}]}]}], 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "0"]}]]}]}], "\[IndentingNewLine]"}], "\n", 
  RowBox[{"                ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", 
        SubscriptBox["z", "0"]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", "z", ")"}], "g", 
         RowBox[{"(", "z", ")"}]}], " ", "-", 
        RowBox[{"f", 
         RowBox[{"(", 
          SubscriptBox["z", "0"], ")"}], "g", 
         RowBox[{"(", "z", ")"}]}]}], 
       RowBox[{"z", " ", "-", " ", 
        SubscriptBox["z", "0"]}]]}], " ", "+", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", 
        SubscriptBox["z", "0"]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", 
          SubscriptBox["z", "0"], ")"}], "g", 
         RowBox[{"(", "z", ")"}]}], "-", " ", 
        RowBox[{"f", 
         RowBox[{"(", 
          SubscriptBox["z", "0"], ")"}], " ", "g", 
         RowBox[{"(", 
          SubscriptBox["z", "0"], ")"}]}]}], 
       RowBox[{"z", " ", "-", " ", 
        SubscriptBox["z", "0"]}]]}]}]}], "\[IndentingNewLine]"}], "\n", 
  RowBox[{"                ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", 
        SubscriptBox["z", "0"]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"f", 
           RowBox[{"(", "z", ")"}]}], " ", "-", 
          RowBox[{"f", 
           RowBox[{"(", 
            SubscriptBox["z", "0"], ")"}]}]}], ")"}], "g", 
        RowBox[{"(", "z", ")"}]}], 
       RowBox[{"z", " ", "-", " ", 
        SubscriptBox["z", "0"]}]]}], " ", "+", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", 
        SubscriptBox["z", "0"]}]], " ", 
      FractionBox[
       RowBox[{"f", 
        RowBox[{"(", 
         SubscriptBox["z", "0"], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"g", 
           RowBox[{"(", "z", ")"}]}], "-", " ", 
          RowBox[{"f", 
           RowBox[{"(", 
            SubscriptBox["z", "0"], ")"}], " ", "g", 
           RowBox[{"(", 
            SubscriptBox["z", "0"], ")"}]}]}], ")"}]}], 
       RowBox[{"z", " ", "-", " ", 
        SubscriptBox["z", "0"]}]]}]}]}], "\[IndentingNewLine]"}], "\n", 
  RowBox[{"                ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", 
        SubscriptBox["z", "0"]}]], " ", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"f", 
          RowBox[{"(", "z", ")"}]}], " ", "-", 
         RowBox[{"f", 
          RowBox[{"(", 
           SubscriptBox["z", "0"], ")"}]}]}], 
        RowBox[{"z", " ", "-", " ", 
         SubscriptBox["z", "0"]}]], 
       RowBox[{
        UnderscriptBox["lim", 
         RowBox[{"z", " ", "\[Rule]", " ", 
          SubscriptBox["z", "0"]}]], " ", 
        RowBox[{"g", 
         RowBox[{"(", "z", ")"}]}]}]}]}], " ", "+", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", 
        SubscriptBox["z", "0"]}]], " ", 
      RowBox[{"f", 
       RowBox[{"(", 
        SubscriptBox["z", "0"], ")"}], " ", 
       RowBox[{
        UnderscriptBox["lim", 
         RowBox[{"z", " ", "\[Rule]", " ", 
          SubscriptBox["z", "0"]}]], " ", 
        FractionBox[
         RowBox[{
          RowBox[{"g", 
           RowBox[{"(", "z", ")"}]}], "-", " ", 
          RowBox[{"f", 
           RowBox[{"(", 
            SubscriptBox["z", "0"], ")"}], " ", "g", 
           RowBox[{"(", 
            SubscriptBox["z", "0"], ")"}]}]}], 
         RowBox[{"z", " ", "-", " ", 
          SubscriptBox["z", "0"]}]]}]}]}]}]}]}]}]],
 "   "
}], "Text"],

Cell[TextData[{
 "Using the definition of the derivative given by Equation ",
 StyleBox["(3-1)",
  FontColor->RGBColor[0, 0, 1]],
 " and the continuity of ",
 Cell[BoxData[
  RowBox[{"g", 
   RowBox[{"(", "z", ")"}]}]]],
 ", we obtain  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"h", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}], " ", "g", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "+", " ", 
    RowBox[{"f", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}], " ", 
     RowBox[{"g", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}]}]}]]],
 ",  which is what we wanted to establish.  We leave the proofs of the other \
rules as exercises."
}], "Text"],

Cell[TextData[{
 "\tThe rule for differentiating polynomials carries over to the complex case \
as well.  If we let P(z) be a polynomial of degree n, so   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["a", "0"], " ", "+", " ", 
      RowBox[{
       SubscriptBox["a", "1"], "z"}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["a", "2"], 
       SuperscriptBox["z", "2"]}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["a", "3"], 
       SuperscriptBox["z", "3"]}], " ", "+"}], "..."}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["a", "n"], 
     SuperscriptBox["z", "n"]}]}]}]]],
 ",  \n\nthen mathematical induction, along with Equations ",
 StyleBox["(3-5)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(3-7)",
  FontColor->RGBColor[0, 0, 1]],
 ", gives  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"P", "'"}], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["a", "1"], " ", "+", " ", 
      RowBox[{"2", 
       SubscriptBox["a", "2"], "z"}], " ", "+", " ", 
      RowBox[{"3", 
       SubscriptBox["a", "3"], 
       SuperscriptBox["z", "2"]}], " ", "+"}], "..."}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["a", 
      RowBox[{"n", "-", "1"}]], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}]}]}]]],
 ".  \n\nAgain, we leave the proof of this result as an exercise."
}], "Text"],

Cell[TextData[{
 "\tWe can use the differentiation rules as aids in determining when \
functions are analytic.  For example, Equation ",
 StyleBox["(3-9)",
  FontColor->RGBColor[0, 0, 1]],
 " tells us that if ",
 Cell[BoxData[
  RowBox[{"P", 
   RowBox[{"(", "z", ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "Q", 
   RowBox[{"(", "z", ")"}]}]]],
 " are polynomials, then their quotient  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"P", 
    RowBox[{"(", "z", ")"}]}], 
   RowBox[{"Q", 
    RowBox[{"(", "z", ")"}]}]]]],
 "   is analytic at all points where ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Q", 
    RowBox[{"(", "z", ")"}]}], "\[NotEqual]", "0"}]]],
 ".  This condition implies that the function ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", "z"]}]]],
 "  is analytic for all ",
 Cell[BoxData[
  RowBox[{"z", "\[NotEqual]", "0"}]]],
 ".  \n\n\tThe square root function is more complicated.  If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"|", "z", 
    SuperscriptBox["|", 
     FractionBox["1", "2"]]}]}]]],
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"\[ImaginaryI]", " ", 
    FractionBox[
     RowBox[{"Arg", 
      RowBox[{"(", "z", ")"}]}], "2"]}]]]],
 ",  then ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " is analytic at all points except ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 "  (because ",
 Cell[BoxData[
  RowBox[{"Arg", 
   RowBox[{"(", "0", ")"}]}]]],
 " is undefined) and at points that lie along the negative ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " axis.  The argument function, and therefore the function ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " itself, are not continuous at points that lie along the negative ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " axis."
}], "Text"],

Cell[TextData[{
 "\tWe close this section with a complex extension of a famous theorem, which \
is attributed to ",
 StyleBox[ButtonBox["Guillaume Fran\[CCedilla]ois Antoine Marquis de L'H\
\[OHat]pital",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/De_L'\
Hopital.html"], None}],
  FontVariations->{"Underline"->True}],
 " (1661-1704).  The proof of will be given in Chapter 7.  "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 3.2, (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["L'H\[OHat]pital's Rule",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/LHospitalsRule.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Assume that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " are both analytic at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  If ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", "0"}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", "0"}]]],
 ", and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"g", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "\[NotEqual]", "0"}]]],
 "  then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", "\[Rule]", 
      SubscriptBox["z", "0"]}]], " ", 
    FractionBox[
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     RowBox[{"g", 
      RowBox[{"(", "z", ")"}]}]]}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], 
    RowBox[{
     RowBox[{"g", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}]]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Proof of Theorem 3.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  ",
 "We defer the proof until Chapter 7, where we will learn some amazing things \
about analytic functions.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Exploration", " ", "for", " ", 
   RowBox[{"L", "'"}], 
   RowBox[{"Hospital", "'"}], "s", " ", 
   RowBox[{"Rule", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506703742671875*^9, 3.506703742671875*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can do it all, however care must be taken with the higher derivative \
cases.  Make the assumption that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", 
   RowBox[{
    RowBox[{"0", "  ", "and", "  ", "g", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "=", "0"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g", ",", "lim", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"lim", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"f", "[", "Z", "]"}], 
        RowBox[{"g", "[", "Z", "]"}]], ",", " ", 
       RowBox[{"Z", "\[Rule]", 
        SubscriptBox["z", "0"]}], ",", " ", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     f[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     g[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{"g", "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    g'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{"g", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \!\(\*FractionBox[\(f[\*SubscriptBox[\(z\), \(0\)]]\), \
\(g[\*SubscriptBox[\(z\), \(0\)]]\)]\) = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}], ",", "\"\</\>\"", ",", 
      RowBox[{"g", "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \!\(\*FractionBox[\(f[\*SubscriptBox[\(z\), \(0\)]]\), \
\(g[\*SubscriptBox[\(z\), \(0\)]]\)]\) = \>\"", ",", 
      FractionBox[
       RowBox[{"f", "[", 
        SubscriptBox["z", "0"], "]"}], 
       RowBox[{"g", "[", 
        SubscriptBox["z", "0"], "]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] \*SubscriptBox[\(z\), \(0\
\)]\)]\) \!\(\*FractionBox[\(f[z]\), \(g[z]\)]\) = \>\"", ",", "lim"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019698734375*^9}],

Cell[TextData[{
 "Now, make the second additional assumption that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", 
   RowBox[{
    RowBox[{"0", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman"], "  ", 
     RowBox[{"g", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "=", "0"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g", ",", "lim", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f", "'"}], "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"g", "'"}], "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"lim", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"f", "[", "Z", "]"}], 
        RowBox[{"g", "[", "Z", "]"}]], ",", " ", 
       RowBox[{"Z", "\[Rule]", 
        SubscriptBox["z", "0"]}], ",", " ", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      f[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      g[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{"g", "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     g'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{"g", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f''[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "'"}], "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    g''[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"g", "'"}], "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     \!\(\*FractionBox[\(f[\*SubscriptBox[\(z\), \(0\)]]\), \
\(g[\*SubscriptBox[\(z\), \(0\)]]\)]\) = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}], ",", "\"\</\>\"", ",", 
      RowBox[{"g", "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \!\(\*FractionBox[\(\(f'\)[\*SubscriptBox[\(z\), \(0\)]]\), \
\(\(g'\)[\*SubscriptBox[\(z\), \(0\)]]\)]\) = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}], ",", "\"\</\>\"", ",", 
      RowBox[{
       RowBox[{"g", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<      \!\(\*FractionBox[\(f[\*SubscriptBox[\(z\), \(0\)]]\), \
\(g[\*SubscriptBox[\(z\), \(0\)]]\)]\) = \>\"", ",", 
      FractionBox[
       RowBox[{"f", "[", 
        SubscriptBox["z", "0"], "]"}], 
       RowBox[{"g", "[", 
        SubscriptBox["z", "0"], "]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  \!\(\*UnderscriptBox[\(lim\), \(z \[Rule] \*SubscriptBox[\(z\), \
\(0\)]\)]\) \!\(\*FractionBox[\(f[z]\), \(g[z]\)]\) = \>\"", ",", "lim"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39901970490625*^9}],

Cell[TextData[{
 "The third additional assumption is that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "''"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", 
   RowBox[{
    RowBox[{"0", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman"], "  ", 
     RowBox[{"g", "''"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "=", "0"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g", ",", "lim", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f", "'"}], "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"g", "'"}], "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f", "''"}], "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"g", "''"}], "[", 
      SubscriptBox["z", "0"], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"lim", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"f", "[", "Z", "]"}], 
        RowBox[{"g", "[", "Z", "]"}]], ",", " ", 
       RowBox[{"Z", "\[Rule]", 
        SubscriptBox["z", "0"]}], ",", " ", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       f[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       g[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{"g", "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      g'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{"g", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     f''[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "'"}], "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     g''[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"g", "'"}], "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f'''[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"f", "'"}], "'"}], "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    g'''[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"g", "'"}], "'"}], "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<      \!\(\*FractionBox[\(f[\*SubscriptBox[\(z\), \(0\)]]\), \
\(g[\*SubscriptBox[\(z\), \(0\)]]\)]\) = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}], ",", "\"\</\>\"", ",", 
      RowBox[{"g", "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     \!\(\*FractionBox[\(\(f'\)[\*SubscriptBox[\(z\), \(0\)]]\), \(\
\(g'\)[\*SubscriptBox[\(z\), \(0\)]]\)]\) = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}], ",", "\"\</\>\"", ",", 
      RowBox[{
       RowBox[{"g", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \!\(\*FractionBox[\(\(f''\)[\*SubscriptBox[\(z\), \(0\)]]\), \(\
\(g''\)[\*SubscriptBox[\(z\), \(0\)]]\)]\) = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "''"}], "[", 
       SubscriptBox["z", "0"], "]"}], ",", "\"\</\>\"", ",", 
      RowBox[{
       RowBox[{"g", "''"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       \!\(\*FractionBox[\(f[\*SubscriptBox[\(z\), \(0\)]]\), \
\(g[\*SubscriptBox[\(z\), \(0\)]]\)]\) = \>\"", ",", 
      FractionBox[
       RowBox[{"f", "[", 
        SubscriptBox["z", "0"], "]"}], 
       RowBox[{"g", "[", 
        SubscriptBox["z", "0"], "]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \!\(\*UnderscriptBox[\(lim\), \(z \[Rule] \*SubscriptBox[\(z\), \
\(0\)]\)]\) \!\(\*FractionBox[\(f[z]\), \(g[z]\)]\) = \>\"", ",", "lim"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3990197154375*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use L'Hopital's rule to find  ",
 Cell[BoxData[
  RowBox[{
   UnderscriptBox["lim", 
    RowBox[{"z", "\[Rule]", 
     RowBox[{"1", "+", "\[ImaginaryI]"}]}]], 
   FractionBox[
    RowBox[{
     SuperscriptBox["z", "2"], " ", "+", " ", "z", " ", "-", " ", "1", " ", 
     "-", " ", 
     RowBox[{"3", "\[ImaginaryI]"}]}], 
    RowBox[{
     SuperscriptBox["z", "2"], " ", "-", " ", 
     RowBox[{"2", "z"}], " ", "+", " ", "2"}]]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Example", " ", "2."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.50670375159375*^9, 3.50670375159375*^9}},
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g", ",", "lim", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["z", "2"], " ", "+", " ", "z", " ", "-", " ", "1", " ", 
      "-", " ", 
      RowBox[{"3", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["z", "2"], " ", "-", " ", 
      RowBox[{"2", "z"}], " ", "+", " ", "2"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[z] = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39901972825*^9}],

Cell[TextData[{
 "Direct substitution of   ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"1", "+", "\[ImaginaryI]"}]}]]],
 "  is indeterminate."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(f[1 + \[ImaginaryI]]\), \(g[1 + \
\[ImaginaryI]]\)]\) = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}], ",", "\"\</\>\"", ",", 
      RowBox[{"g", "[", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(f[1 + \[ImaginaryI]]\), \(g[1 + \
\[ImaginaryI]]\)]\) = \>\"", ",", 
      FractionBox[
       RowBox[{"f", "[", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}], 
       RowBox[{"g", "[", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39901973165625*^9}],

Cell[TextData[{
 "Find the limit as  ",
 Cell[BoxData[
  RowBox[{"z", "\[Rule]", 
   RowBox[{"1", "+", "\[ImaginaryI]"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"lim", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"f", "[", "z", "]"}], 
        RowBox[{"g", "[", "z", "]"}]], ",", 
       RowBox[{"z", "\[Rule]", 
        RowBox[{"1", "+", "\[ImaginaryI]"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 1 + i\)]\) \
\!\(\*FractionBox[\(f[z]\), \(g[z]\)]\) = \!\(\*UnderscriptBox[\(lim\), \(z \
\[Rule] 1 + i\)]\) \>\"", ",", 
      FractionBox[
       RowBox[{"f", "[", "z", "]"}], 
       RowBox[{"g", "[", "z", "]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 1 + i\)]\) \
\!\(\*FractionBox[\(f[z]\), \(g[z]\)]\) = \!\(\*UnderscriptBox[\(lim\), \(z \
\[Rule] 1 + i\)]\) \>\"", ",", 
      FractionBox[
       RowBox[{"Factor", "[", 
        RowBox[{"f", "[", "z", "]"}], "]"}], 
       RowBox[{"Factor", "[", 
        RowBox[{"g", "[", "z", "]"}], "]"}]]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<           = \!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 1 + i\)]\) \
\>\"", ",", 
      RowBox[{"Cancel", "[", 
       FractionBox[
        RowBox[{"f", "[", "z", "]"}], 
        RowBox[{"g", "[", "z", "]"}]], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           =  \>\"", ",", "lim"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019736015625*^9}],

Cell["Which agrees with the L'Hopital rule computation.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"lim", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"f", "'"}], "[", "z", "]"}], 
        RowBox[{
         RowBox[{"g", "'"}], "[", "z", "]"}]], ",", 
       RowBox[{"z", "\[Rule]", 
        RowBox[{"1", "+", "\[ImaginaryI]"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 1 + i\)]\) \
\!\(\*FractionBox[\(\(f'\)[z]\), \(\(g'\)[z]\)]\) = \
\!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 1 + i\)]\) \>\"", ",", 
      FractionBox[
       RowBox[{
        RowBox[{"f", "'"}], "[", "z", "]"}], 
       RowBox[{
        RowBox[{"g", "'"}], "[", "z", "]"}]]}], "]"}], ";"}], " ", "\n", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<            = \>\"", ",", "lim"}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019740640625*^9}],

Cell[TextData[{
 "Which agrees with evaluation of the quotient  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{
    RowBox[{"f", "'"}], "[", 
    RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}], 
   RowBox[{
    RowBox[{"g", "'"}], "[", 
    RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}]]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  f'[1+\[ImaginaryI]] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  g'[1+\[ImaginaryI]] = \>\"", ",", 
      RowBox[{
       RowBox[{"g", "'"}], "[", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(\(f'\)[1 + \[ImaginaryI]]\), \(\(g'\)[1 + \
\[ImaginaryI]]\)]\) = (\>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}], ",", "\"\<)/\>\"", ",", 
      RowBox[{
       RowBox[{"g", "'"}], "[", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(\(f'\)[1 + \[ImaginaryI]]\), \(\(g'\)[1 + \
\[ImaginaryI]]\)]\) = \>\"", ",", 
      FractionBox[
       RowBox[{
        RowBox[{"f", "'"}], "[", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}], 
       RowBox[{
        RowBox[{"g", "'"}], "[", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], "]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399019744796875*^9}]
}, Closed]]
},
CellGrouping->Manual,
WindowSize->{936, 646},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 190, 3, 29, "Text"],
Cell[1741, 51, 879, 14, 137, "Text"],
Cell[2623, 67, 138, 2, 29, "Text"],
Cell[2764, 71, 3097, 117, 240, "Text"],
Cell[5864, 190, 327, 13, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[6216, 207, 271, 7, 37, "Subsection",
 Evaluatable->False],
Cell[6490, 216, 1117, 30, 148, "Input"],
Cell[7610, 248, 409, 11, 72, "Input"],
Cell[8022, 261, 972, 24, 124, "Input"],
Cell[8997, 287, 404, 11, 72, "Input"],
Cell[9404, 300, 946, 25, 123, "Input"],
Cell[10353, 327, 408, 11, 72, "Input"]
}, Closed]],
Cell[10776, 341, 333, 13, 26, "Text",
 Evaluatable->False],
Cell[11112, 356, 2493, 83, 293, "Text"],
Cell[CellGroupData[{
Cell[13630, 443, 275, 8, 37, "Subsection",
 Evaluatable->False],
Cell[13908, 453, 86, 2, 29, "Text",
 Evaluatable->False],
Cell[13997, 457, 601, 17, 112, "Input"],
Cell[14601, 476, 91, 2, 29, "Text",
 Evaluatable->False],
Cell[14695, 480, 933, 24, 164, "Input"],
Cell[15631, 506, 259, 10, 29, "Text",
 Evaluatable->False],
Cell[15893, 518, 1336, 34, 200, "Input"],
Cell[17232, 554, 135, 4, 29, "Text",
 Evaluatable->False],
Cell[17370, 560, 1080, 26, 182, "Input"],
Cell[18453, 588, 333, 11, 29, "Text",
 Evaluatable->False],
Cell[18789, 601, 2112, 53, 314, "Input"],
Cell[20904, 656, 536, 20, 47, "Text"]
}, Closed]],
Cell[21455, 679, 1045, 35, 68, "Text"],
Cell[22503, 716, 411, 19, 29, "Text",
 Evaluatable->False],
Cell[22917, 737, 6044, 184, 290, "Text"],
Cell[28964, 923, 5803, 177, 274, "Text"],
Cell[34770, 1102, 754, 30, 47, "Text"],
Cell[CellGroupData[{
Cell[35549, 1136, 278, 8, 37, "Subsection",
 Evaluatable->False],
Cell[35830, 1146, 736, 20, 112, "Input"],
Cell[36569, 1168, 202, 7, 29, "Text",
 Evaluatable->False],
Cell[36774, 1177, 2971, 72, 318, "Input"],
Cell[39748, 1251, 96, 2, 29, "Text",
 Evaluatable->False],
Cell[39847, 1255, 794, 18, 108, "Input"],
Cell[40644, 1275, 239, 8, 29, "Text",
 Evaluatable->False],
Cell[40886, 1285, 3093, 77, 324, "Input"],
Cell[43982, 1364, 96, 2, 29, "Text",
 Evaluatable->False],
Cell[44081, 1368, 815, 19, 109, "Input"],
Cell[44899, 1389, 422, 18, 29, "Text",
 Evaluatable->False],
Cell[45324, 1409, 1080, 23, 124, "Input"],
Cell[46407, 1434, 425, 20, 29, "Text",
 Evaluatable->False],
Cell[46835, 1456, 458, 14, 92, "Input"],
Cell[47296, 1472, 284, 12, 29, "Text"]
}, Closed]],
Cell[47595, 1487, 599, 18, 44, "Text"],
Cell[48197, 1507, 799, 19, 83, "Text"],
Cell[48999, 1528, 1267, 50, 47, "Text"],
Cell[50269, 1580, 450, 17, 65, "Text"],
Cell[50722, 1599, 615, 22, 29, "Text"],
Cell[51340, 1623, 167, 3, 29, "Text"],
Cell[51510, 1628, 496, 8, 65, "Text"],
Cell[52009, 1638, 164, 4, 29, "Text",
 Evaluatable->False],
Cell[52176, 1644, 14670, 475, 328, "Text"],
Cell[66849, 2121, 8301, 270, 111, "Text"],
Cell[CellGroupData[{
Cell[75175, 2395, 328, 9, 37, "Subsection",
 Evaluatable->False],
Cell[75506, 2406, 104, 3, 47, "Text"],
Cell[75613, 2411, 1629, 47, 252, "Input"],
Cell[77245, 2460, 60, 0, 29, "Text"],
Cell[77308, 2462, 1712, 52, 212, "Input"],
Cell[79023, 2516, 66, 0, 29, "Text"],
Cell[79092, 2518, 877, 27, 152, "Input"],
Cell[79972, 2547, 69, 0, 29, "Text"],
Cell[80044, 2549, 805, 24, 150, "Input"],
Cell[80852, 2575, 72, 0, 29, "Text"],
Cell[80927, 2577, 893, 27, 152, "Input"]
}, Closed]],
Cell[81835, 2607, 2420, 85, 109, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[84280, 2696, 276, 8, 37, "Subsection",
 Evaluatable->False],
Cell[84559, 2706, 2644, 80, 372, "Input"],
Cell[87206, 2788, 189, 7, 29, "Text"],
Cell[87398, 2797, 1652, 51, 212, "Input"]
}, Closed]],
Cell[89065, 2851, 344, 9, 44, "Text"],
Cell[89412, 2862, 417, 19, 29, "Text",
 Evaluatable->False],
Cell[89832, 2883, 3682, 123, 286, "Text"],
Cell[CellGroupData[{
Cell[93539, 3010, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[93683, 3016, 175, 4, 29, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[93873, 3023, 1418, 50, 76, "Text"],
Cell[95294, 3075, 4939, 158, 223, "Text"],
Cell[100236, 3235, 842, 30, 47, "Text"],
Cell[101081, 3267, 1518, 49, 173, "Text"],
Cell[102602, 3318, 2093, 74, 117, "Text"],
Cell[104698, 3394, 458, 11, 47, "Text"],
Cell[105159, 3407, 1550, 65, 76, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[106734, 3476, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[106878, 3482, 279, 9, 29, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[107194, 3496, 343, 10, 37, "Subsection",
 Evaluatable->False],
Cell[107540, 3508, 427, 15, 29, "Text"],
Cell[107970, 3525, 2908, 79, 384, "Input"],
Cell[110881, 3606, 461, 18, 29, "Text",
 Evaluatable->False],
Cell[111345, 3626, 4274, 119, 522, "Input"],
Cell[115622, 3747, 455, 18, 29, "Text",
 Evaluatable->False],
Cell[116080, 3767, 5601, 158, 640, "Input"]
}, Closed]],
Cell[121696, 3928, 603, 21, 40, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[122324, 3953, 269, 7, 37, "Subsection",
 Evaluatable->False],
Cell[122596, 3962, 983, 28, 152, "Input"],
Cell[123582, 3992, 206, 8, 29, "Text",
 Evaluatable->False],
Cell[123791, 4002, 866, 24, 130, "Input"],
Cell[124660, 4028, 190, 8, 29, "Text",
 Evaluatable->False],
Cell[124853, 4038, 1662, 46, 224, "Input"],
Cell[126518, 4086, 111, 2, 29, "Text",
 Evaluatable->False],
Cell[126632, 4090, 987, 28, 148, "Input"],
Cell[127622, 4120, 343, 13, 42, "Text",
 Evaluatable->False],
Cell[127968, 4135, 1522, 43, 190, "Input"]
}, Closed]]
}
]
*)

(* End of internal cache information *)
