(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    289861,       9615]
NotebookOptionsPosition[    281952,       9374]
NotebookOutlinePosition[    282344,       9391]
CellTagsIndexPosition[    282301,       9388]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[StyleBox["Section 3.2  The Cauchy-Riemann Equations",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.53270917728125*^9, 3.53270917796875*^9}}],

Cell[TextData[{
 "\tIn Section 3.1 we showed that computing the derivative of complex \
functions written in a form such as  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", "2"]}]]],
 "  is a rather simple task. But life isn't always so easy.  \nMany times we \
encounter complex functions written as  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "v", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}]}]]],
 ".   For example, suppose we had  \n\n",
 StyleBox["(3-13)\t",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", 
      RowBox[{"x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"u", 
       RowBox[{"(", 
        RowBox[{"x", ",", "y"}], ")"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "v", 
       RowBox[{"(", 
        RowBox[{"x", ",", "y"}], ")"}]}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "3"], "-", 
        RowBox[{"3", " ", "x", " ", 
         SuperscriptBox["y", "2"]}]}], ")"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["x", "2"], " ", "y"}], "-", 
         SuperscriptBox["y", "3"]}], ")"}]}]}]}]}]}]]],
 ".  \n\nIs there some criterion - perhaps involving the partial derivatives \
for  ",
 StyleBox["u(x,y)",
  FontFamily->"Courier New"],
 ",  and  ",
 StyleBox["v(x,y)",
  FontFamily->"Courier New"],
 "  -  that we can use to determine whether f is differentiable, and if so, \
to find the value of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 "?"
}], "Text"],

Cell[TextData[{
 "\tThe answer to this question is yes, thanks to the independent discovery \
of two important equations by the French mathematician ",
 StyleBox[ButtonBox["Augustin Louis Cauchy",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cauchy.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " (1789-1857) and the German mathematician ",
 StyleBox[ButtonBox["Georg Friedrich Bernhard Riemann",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Riemann.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " (1826-1866)."
}], "Text"],

Cell[TextData[{
 "\tFirst, let's reconsider the derivative of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", "2"]}]]],
 ".  As we have stated, the limit given in Equation ",
 StyleBox["(3-1)",
  FontColor->RGBColor[0, 0, 1]],
 " must not depend on how z approaches ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  We investigate two such approaches: a horizontal approach and a vertical \
approach to ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  Recall from our graphical analysis of  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["z", "2"]}]]],
 "  that the image of a square is a \"curvilinear quadrilateral.\"  For \
convenience, we let the square have vertices  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{"2", "+", "\[ImaginaryI]"}]}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{"2.01", "+", "\[ImaginaryI]"}]}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{"2", "+", 
    RowBox[{"1.01", "\[ImaginaryI]"}]}]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "3"], "=", 
   RowBox[{"2.01", "+", 
    RowBox[{"1.01", "\[ImaginaryI]"}]}]}]]],
 ".  Then the image points are  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "0"], "=", 
   RowBox[{"3", "+", 
    RowBox[{"4", " ", "\[ImaginaryI]"}]}]}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "1"], "=", 
   RowBox[{"3.0401", "+", 
    RowBox[{"4.02", " ", "\[ImaginaryI]"}]}]}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "2"], "=", 
   RowBox[{"2.9799", "+", 
    RowBox[{"4.04", " ", "\[ImaginaryI]"}]}]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "3"], "=", 
   RowBox[{"3.02", "+", 
    RowBox[{"4.0602", " ", "\[ImaginaryI]"}]}]}]]],
 ", as shown in Figure 3.1.  "
}], "Text"],

Cell[TextData[{
 StyleBox["\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
-166.583 83.3333 -83.25 83.3333 [
[.5 .07083 -14.375 -13 ]
[.5 .07083 14.375 0 ]
[.91667 .07083 -11.625 -13 ]
[.91667 .07083 11.625 0 ]
[.07083 .5 -28.75 -6.5 ]
[.07083 .5 0 6.5 ]
[.07083 .91667 -23.25 -6.5 ]
[.07083 .91667 0 6.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.5 .08333 m
.5 .08958 L
s
gsave
.5 .07083 -75.375 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.005) show
1.000 setlinewidth
grestore
.91667 .08333 m
.91667 .08958 L
s
gsave
.91667 .07083 -72.625 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.01) show
1.000 setlinewidth
grestore
0 .08333 m
1 .08333 L
s
.08333 .5 m
.08958 .5 L
s
gsave
.07083 .5 -89.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.005) show
1.000 setlinewidth
grestore
.08333 .91667 m
.08958 .91667 L
s
gsave
.07083 .91667 -84.25 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.01) show
1.000 setlinewidth
grestore
.08333 0 m
.08333 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 .165 .165 r
2 Mabswid
.08333 .08333 m
.11714 .08333 L
.15401 .08333 L
.18863 .08333 L
.22193 .08333 L
.25738 .08333 L
.2915 .08333 L
.32776 .08333 L
.3627 .08333 L
.39631 .08333 L
.43207 .08333 L
.4665 .08333 L
.49961 .08333 L
.53486 .08333 L
.56878 .08333 L
.60486 .08333 L
.6396 .08333 L
.67302 .08333 L
.70858 .08333 L
.74282 .08333 L
.77921 .08333 L
.81427 .08333 L
.848 .08333 L
.88388 .08333 L
.91667 .08333 L
s
0 1 0 r
1 Mabswid
[ .04 .04 ] 0 setdash
.08333 .91667 m
.11714 .91667 L
.15401 .91667 L
.18863 .91667 L
.22193 .91667 L
.25738 .91667 L
.2915 .91667 L
.32776 .91667 L
.3627 .91667 L
.39631 .91667 L
.43207 .91667 L
.4665 .91667 L
.49961 .91667 L
.53486 .91667 L
.56878 .91667 L
.60486 .91667 L
.6396 .91667 L
.67302 .91667 L
.70858 .91667 L
.74282 .91667 L
.77921 .91667 L
.81427 .91667 L
.848 .91667 L
.88388 .91667 L
.91667 .91667 L
s
1 .5 0 r
2 Mabswid
[ ] 0 setdash
.08333 .08333 m
.08333 .11714 L
.08333 .15401 L
.08333 .18863 L
.08333 .22193 L
.08333 .25738 L
.08333 .2915 L
.08333 .32776 L
.08333 .3627 L
.08333 .39631 L
.08333 .43207 L
.08333 .4665 L
.08333 .49961 L
.08333 .53486 L
.08333 .56878 L
.08333 .60486 L
.08333 .6396 L
.08333 .67302 L
.08333 .70858 L
.08333 .74282 L
.08333 .77921 L
.08333 .81427 L
.08333 .848 L
.08333 .88388 L
.08333 .91667 L
s
0 0 1 r
1 Mabswid
[ .04 .04 ] 0 setdash
.91667 .08333 m
.91667 .11714 L
.91667 .15401 L
.91667 .18863 L
.91667 .22193 L
.91667 .25738 L
.91667 .2915 L
.91667 .32776 L
.91667 .3627 L
.91667 .39631 L
.91667 .43207 L
.91667 .4665 L
.91667 .49961 L
.91667 .53486 L
.91667 .56878 L
.91667 .60486 L
.91667 .6396 L
.91667 .67302 L
.91667 .70858 L
.91667 .74282 L
.91667 .77921 L
.91667 .81427 L
.91667 .848 L
.91667 .88388 L
.91667 .91667 L
s
0 g
gsave
.5 .5 -80.625 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
67.750 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.125 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(plane) show
98.250 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.04 w
.08333 .08333 Mdot
0 0 1 r
.91667 .08333 Mdot
0 1 0 r
.08333 .91667 Mdot
1 0 1 r
.91667 .91667 Mdot
0 g
.5 Mabswid
[ ] 0 setdash
gsave
.18333 .14167 -77.8125 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 15.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
75.813 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
1.01667 .14167 -77.8125 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 15.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.18333 .95833 -77.8125 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 15.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
1.01667 .95833 -77.8125 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
70.188 15.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
75.813 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{213, 213},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztWs1u1DAQ9iZOslnRLnd+uue+AawKVYH2AKjiwAOsKkR7QKDSex+CEwXa
BR6h6qP0eUzGTuyNM3bsKNtuaCIlmcyMP3/2xIknztvZyeGHT7OTo4PZZO94
9uXw6ODrZPfzcaYKB4SQa9gnBGSWifnhmjDGwOh52uCnkHCQTIL9cjVML+AY
gSZArPwqBFGTpvXFIsSQmIm8RHRRXmhRxwHya8lpoRymg/2JET9C8akf/VeI
jjagL66quqdG/Fbo7xpptNP7UyN+K/T3EF3QmH62PTcC4nz1UQBbWjPqrE13
4U1LPtm2VQuL2zhcUMOZD1CuiqWkPRo4oSni5/ksqH+UPRLQmfSnqITdF6aH
cIrANBdSZhoL0zqc1gAuAfs5Od3chI5m67wO8gDsFRMvqkz7CKs3wqrcLSQs
1B+LOLBT8ldWoiI1Xp7TGtKmb0jBtGgMGegQkTRhY+FMWrGnQwUsxu9vDPkH
7upUTWIc5eU6fiJ+ThUMHcbyLwcSPp2EETuz9GegCungPGAXUop1p6tbvm3/
b6dK796MYhW7orNOfQy779SHrHNONxOy15KKeqt+dHF6b26DLSXlr2tjSh7K
KnnywiGSsrWSP8o5FT6L0FIhA9nlZY28NduIYYiTNrTFT72z/Paqckh7Nd0z
hCXLUy2PhhXRtBWhqxDuHcTgmA4oPn63QBlhy9wBWEOaf6MibmPWEkcuUYGR
bdtm5srJnW+ltyLJ9h3Sb/vm2rEbh5abqX1ECJpWtZIviv5l3/2XfR/DPoZ3
1qkPT/ed7nwMR/xUl1qJuQo26WLFB3smP9iPZG36DNR9WSsC5DmIsF7Axu0g
w/pCDMdzuISFi2Jpog3ke3Dks/IUpKReGjr6pRKZ5jpJfKgTIQ7p8kIk83OC
9koq7qAaSLVQFoiAuYZOzXa97q8NBGokoX5LNmGNu6bjgwR+cxCLCgNz6TBv
Jp6wfbdaLbAU6QQDimHpgjo3AUs+9LwPNmyRB/MLzFXFDhCwu1TVrAfnuNqy
1kplDC+kFJvdb+G3Fe/fbcjgHyAeLJA=\
\>"],
  ImageRangeCache->{{{0, 212}, {212, 0}} -> {1, 0, 0, 0}}],
 StyleBox["          ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
-42.5143 14.2857 -57.0714 14.2857 [
[.05714 .05893 -11.625 -13 ]
[.05714 .05893 11.625 0 ]
[.2 .05893 -11.625 -13 ]
[.2 .05893 11.625 0 ]
[.48571 .05893 -11.625 -13 ]
[.48571 .05893 11.625 0 ]
[.62857 .05893 -11.625 -13 ]
[.62857 .05893 11.625 0 ]
[.77143 .05893 -11.625 -13 ]
[.77143 .05893 11.625 0 ]
[.91429 .05893 -11.625 -13 ]
[.91429 .05893 11.625 0 ]
[.33036 .21429 -23.25 -6.5 ]
[.33036 .21429 0 6.5 ]
[.33036 .35714 -23.25 -6.5 ]
[.33036 .35714 0 6.5 ]
[.33036 .5 -23.25 -6.5 ]
[.33036 .5 0 6.5 ]
[.33036 .64286 -23.25 -6.5 ]
[.33036 .64286 0 6.5 ]
[.33036 .78571 -23.25 -6.5 ]
[.33036 .78571 0 6.5 ]
[.33036 .92857 -23.25 -6.5 ]
[.33036 .92857 0 6.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05714 .07143 m
.05714 .07768 L
s
gsave
.05714 .05893 -72.625 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.98) show
1.000 setlinewidth
grestore
.2 .07143 m
.2 .07768 L
s
gsave
.2 .05893 -72.625 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.99) show
1.000 setlinewidth
grestore
.48571 .07143 m
.48571 .07768 L
s
gsave
.48571 .05893 -72.625 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.01) show
1.000 setlinewidth
grestore
.62857 .07143 m
.62857 .07768 L
s
gsave
.62857 .05893 -72.625 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.02) show
1.000 setlinewidth
grestore
.77143 .07143 m
.77143 .07768 L
s
gsave
.77143 .05893 -72.625 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.03) show
1.000 setlinewidth
grestore
.91429 .07143 m
.91429 .07768 L
s
gsave
.91429 .05893 -72.625 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.04) show
1.000 setlinewidth
grestore
0 .07143 m
1 .07143 L
s
.34286 .21429 m
.34911 .21429 L
s
gsave
.33036 .21429 -84.25 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.01) show
1.000 setlinewidth
grestore
.34286 .35714 m
.34911 .35714 L
s
gsave
.33036 .35714 -84.25 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.02) show
1.000 setlinewidth
grestore
.34286 .5 m
.34911 .5 L
s
gsave
.33036 .5 -84.25 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.03) show
1.000 setlinewidth
grestore
.34286 .64286 m
.34911 .64286 L
s
gsave
.33036 .64286 -84.25 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.04) show
1.000 setlinewidth
grestore
.34286 .78571 m
.34911 .78571 L
s
gsave
.33036 .78571 -84.25 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.05) show
1.000 setlinewidth
grestore
.34286 .92857 m
.34911 .92857 L
s
gsave
.33036 .92857 -84.25 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.06) show
1.000 setlinewidth
grestore
.34286 0 m
.34286 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 .165 .165 r
2 Mabswid
.34286 .07143 m
.36604 .08302 L
.39133 .09566 L
.41509 .10753 L
.43794 .11895 L
.46226 .1311 L
.48569 .1428 L
.51059 .15523 L
.53458 .16721 L
.55767 .17874 L
.58224 .191 L
.6059 .2028 L
.62866 .21415 L
.65289 .22624 L
.67622 .23787 L
.70103 .25024 L
.72493 .26215 L
.74793 .27361 L
.77241 .2858 L
.79597 .29754 L
.82102 .31001 L
.84517 .32203 L
.8684 .3336 L
.89312 .3459 L
.91571 .35714 L
s
0 1 0 r
1 Mabswid
[ .037 .037 ] 0 setdash
.05571 .64286 m
.0789 .65456 L
.10419 .66733 L
.12794 .67932 L
.15079 .69085 L
.17512 .70313 L
.19854 .71494 L
.22344 .7275 L
.24744 .7396 L
.27053 .75124 L
.2951 .76362 L
.31876 .77554 L
.34152 .78701 L
.36575 .79921 L
.38908 .81096 L
.41389 .82345 L
.43779 .83548 L
.46079 .84706 L
.48526 .85937 L
.50883 .87123 L
.53388 .88383 L
.55802 .89597 L
.58126 .90765 L
.60598 .92007 L
.62857 .93143 L
s
1 .5 0 r
2 Mabswid
[ ] 0 setdash
.34286 .07143 m
.33126 .09461 L
.31862 .11989 L
.30673 .14363 L
.2953 .16647 L
.28312 .19077 L
.2714 .21417 L
.25893 .23904 L
.24691 .26299 L
.23535 .28604 L
.22304 .31056 L
.21118 .33417 L
.19978 .35687 L
.18763 .38105 L
.17593 .40431 L
.16349 .42904 L
.1515 .45287 L
.13996 .47579 L
.12768 .50017 L
.11585 .52365 L
.10328 .5486 L
.09115 .57264 L
.07948 .59577 L
.06707 .62037 L
.05571 .64286 L
s
0 0 1 r
1 Mabswid
[ .037 .037 ] 0 setdash
.91571 .35714 m
.90412 .38044 L
.89147 .40585 L
.87959 .42971 L
.86816 .45266 L
.85598 .47708 L
.84426 .5006 L
.83179 .52559 L
.81977 .54967 L
.80821 .57283 L
.7959 .59747 L
.78404 .6212 L
.77264 .64402 L
.76049 .66831 L
.74879 .69169 L
.73635 .71655 L
.72436 .74049 L
.71282 .76352 L
.70054 .78803 L
.68871 .81163 L
.67613 .8367 L
.66401 .86086 L
.65234 .88411 L
.63992 .90883 L
.62857 .93143 L
s
0 g
gsave
.55714 .5 -81.875 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
70.250 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.625 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(plane) show
100.750 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.04 w
.34286 .07143 Mdot
0 0 1 r
.91571 .35714 Mdot
0 1 0 r
.05571 .64286 Mdot
1 0 1 r
.62857 .93143 Mdot
0 g
.5 Mabswid
[ ] 0 setdash
gsave
.42571 .02857 -77.8125 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
70.188 15.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
75.813 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97143 .30714 -77.8125 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
70.188 15.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.813 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.08571 .7 -77.8125 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
70.188 15.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.813 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.72857 .92857 -77.8125 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
%%BeginResource: font Courier-Italic-MISO
%%BeginFont: Courier-Italic-MISO
/Courier-Italic /Courier-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Italic-MISO
%%IncludeFont: Courier-Italic-MISO
/Courier-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
70.188 15.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
75.813 13.875 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{213, 213},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 212}, {212, 0}} -> {2, 3, 0, 0}}],
 "  ",
 StyleBox["\n\t\tFigure 3.1",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 " The image of a small square with vertex  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{"2", "+", "\[ImaginaryI]"}]}]]],
 ",  under the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox["z", "2"]}]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["Exploration",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670380490625*^9, 3.50670380490625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["z", "2"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", " ", 
     RowBox[{"{", 
      RowBox[{"2.0", ",", "3.0", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0", ",", "2.0", ",", "0.1"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0.0", ",", "3.0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.0", ",", "2.0"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "3"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"2", ",", "3", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"1", ",", "2", ",", "0.5"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Vertical lines x = a, and horizontal lines y = b.\>\"",
      "]"}], ";"}], " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", "  ", 
     RowBox[{"{", 
      RowBox[{"2.0", ",", "3.0", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0", ",", "2.0", ",", "0.1"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "9"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "12"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["12", "9"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "9", ",", "3"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "12", ",", "4"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The image parabolas u= \!\(\*SuperscriptBox[\(a\), \
\(2\)]\)-\!\(\*FractionBox[SuperscriptBox[\(v\), \(2\)], \(4\\\ \
\*SuperscriptBox[\(a\), \(2\)]\)]\) and u = -\!\(\*SuperscriptBox[\(b\), \
\(2\)]\)+\!\(\*FractionBox[SuperscriptBox[\(v\), \(2\)], \(4\\\ \
\*SuperscriptBox[\(b\), \(2\)]\)]\) under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399020128515625*^9, 3.399020137421875*^9}, {
  3.399797218656002*^9, 3.399797218999752*^9}, {3.3997973194528775`*^9, 
  3.3997973219216275`*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We will need to zoom in closer to the point ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{"2", "+", "\[ImaginaryI]"}]}]]],
 ". "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["z", "2"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", " ", 
     RowBox[{"{", 
      RowBox[{"2.0", ",", "2.1", ",", "0.01"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0", ",", "1.1", ",", "0.01"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1.8", ",", "2.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.8", ",", "1.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1.0", "1.0"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"2.0", ",", "2.1", ",", "0.05"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"1.0", ",", "1.1", ",", "0.05"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1.8", ",", "0.8"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Vertical lines x = a, and horizontal lines y = b.\>\"",
      "]"}], ";"}], " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", " ", 
     RowBox[{"{", 
      RowBox[{"2.0", ",", "2.1", ",", "0.01"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0", ",", "1.1", ",", "0.01"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2.5", ",", "3.65"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"3.5", ",", "4.65"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"3.0", ",", "3.5", ",", "0.25"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"4.0", ",", "4.5", ",", "0.25"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2.5", ",", "3.5"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The image parabolas u= \!\(\*SuperscriptBox[\(a\), \
\(2\)]\)-\!\(\*FractionBox[SuperscriptBox[\(v\), \(2\)], \(4\\\ \
\*SuperscriptBox[\(a\), \(2\)]\)]\) and u = -\!\(\*SuperscriptBox[\(b\), \
\(2\)]\)+\!\(\*FractionBox[SuperscriptBox[\(v\), \(2\)], \(4\\\ \
\*SuperscriptBox[\(b\), \(2\)]\)]\) under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39902014796875*^9, 3.39902015409375*^9}, {
  3.399797225718502*^9, 3.3997972259528775`*^9}, {3.3997973113903775`*^9, 
  3.399797314968502*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We will need to zoom in closer to the point ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{"2", "+", "\[ImaginaryI]"}]}]]],
 ". "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["z", "2"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", " ", 
     RowBox[{"{", 
      RowBox[{"2.0", ",", "2.0101", ",", "0.001"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0", ",", "1.01", ",", "0.001"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1.98", ",", "2.0101"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.98", ",", "1.01"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1.0", "1.0"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"2.0", ",", "2.01", ",", "0.005"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"1.0", ",", "1.01", ",", "0.005"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1.98", ",", "0.98"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Vertical lines x = a, and horizontal lines y = b.\>\"",
      "]"}], ";"}], " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", " ", 
     RowBox[{"{", 
      RowBox[{"2.0", ",", "2.0101", ",", "0.00101"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0", ",", "1.01", ",", "0.001"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2.9", ",", "3.07"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"3.9", ",", "4.07"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"3.0", ",", "3.04", ",", "0.02"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"4.0", ",", "4.06", ",", "0.02"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2.9", ",", "3.9"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The image parabolas u= \!\(\*SuperscriptBox[\(a\), \
\(2\)]\)-\!\(\*FractionBox[SuperscriptBox[\(v\), \(2\)], \(4\\\ \
\*SuperscriptBox[\(a\), \(2\)]\)]\) and u = -\!\(\*SuperscriptBox[\(b\), \
\(2\)]\)+\!\(\*FractionBox[SuperscriptBox[\(v\), \(2\)], \(4\\\ \
\*SuperscriptBox[\(b\), \(2\)]\)]\) under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3990201575*^9, 3.399020162734375*^9}, {
  3.3997972308903775`*^9, 3.3997972311091275`*^9}, {3.3997972904528775`*^9, 
  3.399797304593502*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Now we are sufficiently close to see the image points are  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "0"], "=", 
   RowBox[{"3", "+", 
    RowBox[{"4", " ", "\[ImaginaryI]"}]}]}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "1"], "=", 
   RowBox[{"3.0401", "+", 
    RowBox[{"4.02", " ", "\[ImaginaryI]"}]}]}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "2"], "=", 
   RowBox[{"2.9799", "+", 
    RowBox[{"4.04", " ", "\[ImaginaryI]"}]}]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "3"], "=", 
   RowBox[{"3.02", "+", 
    RowBox[{"4.0602", " ", "\[ImaginaryI]"}]}]}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 "\tWe know that f is differentiable, so the limit of the difference quotient \
 ",
 Cell[BoxData[
  FractionBox[
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "-", 
    RowBox[{"f", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}]}], 
   RowBox[{"z", "-", 
    SubscriptBox["z", "0"]}]]]],
 "  exists no matter how we approach  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{"2", "+", "\[ImaginaryI]"}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Thus we can approximate  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", 
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}]}]]],
 "  by using a horizontal increment in ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ":  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f", "'"}], 
      RowBox[{"(", 
       RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}], "  ", "\[TildeTilde]", 
     " ", 
     FractionBox[
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", 
         SubscriptBox["z", "1"], ")"}]}], "-", 
       RowBox[{"f", 
        RowBox[{"(", 
         SubscriptBox["z", "0"], ")"}]}]}], 
      RowBox[{
       SubscriptBox["z", "1"], "-", 
       SubscriptBox["z", "0"]}]]}], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", 
         RowBox[{"2.01", "\[InvisibleSpace]", "+", "\[ImaginaryI]"}], ")"}]}],
        " ", "-", " ", 
       RowBox[{"f", 
        RowBox[{"(", 
         RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2.01", "\[InvisibleSpace]", "+", "\[ImaginaryI]"}], ")"}], 
       " ", "-", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}]], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3.0401", "\[InvisibleSpace]", "+", 
         RowBox[{"4.02", " ", "\[ImaginaryI]"}]}], ")"}], " ", "-", " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2.01", "\[InvisibleSpace]", "+", "\[ImaginaryI]"}], ")"}], 
       " ", "-", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{
    RowBox[{"=", "  ", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3.0401", "-", "3"}], "\[InvisibleSpace]", ")"}], "  ", "+", 
       "  ", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{"4.02", "-", "4"}], " ", ")"}]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2.01", "\[InvisibleSpace]", "-", "2"}], ")"}], " ", "-", " ", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{"1", "-", "1"}], ")"}]}]}]]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"0.0401", " ", "+", " ", 
       RowBox[{"0.02", "\[ImaginaryI]"}]}], 
      RowBox[{"0.01", "\[InvisibleSpace]"}]], "  ", "=", "  ", 
     RowBox[{"4.01", "\[InvisibleSpace] ", "+", " ", 
      RowBox[{"2", " ", "\[ImaginaryI]"}]}]}]}]}]}]],
 "   "
}], "Text"],

Cell[TextData[{
 "And, we can approximate  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", 
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}]}]]],
 "  by using a vertical increment in ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ":  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     StyleBox[
      RowBox[{
       RowBox[{"f", "'"}], 
       RowBox[{"(", 
        RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}],
      FontWeight->"Plain"], 
     StyleBox[" ",
      FontWeight->"Plain"], "\[TildeTilde]", "  ", 
     FractionBox[
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", 
         SubscriptBox["z", "2"], ")"}]}], " ", "-", " ", 
       RowBox[{"f", 
        RowBox[{"(", 
         SubscriptBox["z", "0"], ")"}]}]}], 
      RowBox[{
       SubscriptBox["z", "2"], " ", "-", "  ", 
       SubscriptBox["z", "0"]}]]}], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{"1.01", " ", "\[ImaginaryI]"}]}], ")"}]}], " ", "-", " ", 
       RowBox[{"f", 
        RowBox[{"(", 
         RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "+", 
         RowBox[{"1.01", " ", "\[ImaginaryI]"}]}], ")"}], " ", "-", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}]], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2.9799", "\[InvisibleSpace]", "+", 
         RowBox[{"4.04", "\[ImaginaryI]"}]}], ")"}], " ", "-", " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "+", 
         RowBox[{"1.01", " ", "\[ImaginaryI]"}]}], ")"}], " ", "-", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}]]}]}], "   ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2.9799", "\[InvisibleSpace]", "-", "3"}], ")"}], " ", "+", 
       " ", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{"4.04", "-", "4"}], " ", ")"}]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "-", "2"}], ")"}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{"1.01", " ", "-", "1"}], ")"}]}]}]], "  ", "=", "  ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"-", "0.0201"}], " ", "+", "  ", 
        RowBox[{"0.04", "\[ImaginaryI]"}]}], 
       RowBox[{"0.01", " ", "\[ImaginaryI]"}]], "  ", 
      StyleBox["=",
       FontWeight->"Plain"], 
      StyleBox["  ",
       FontWeight->"Plain"], 
      StyleBox[
       RowBox[{"4", "\[InvisibleSpace] ", "+", " ", 
        RowBox[{"2.01", " ", "\[ImaginaryI]"}]}],
       FontWeight->"Plain"]}]}]}]}]}], "Input"],
 "      "
}], "Text"],

Cell[TextData[{
 "Comparing these two results we see that \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}], "  ", "\[TildeTilde]", 
    "  ", 
    FractionBox[
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", 
        SubscriptBox["z", "1"], ")"}]}], " ", "-", " ", 
      RowBox[{"f", 
       RowBox[{"(", 
        SubscriptBox["z", "0"], ")"}]}]}], 
     RowBox[{
      SubscriptBox["z", "1"], "-", 
      SubscriptBox["z", "0"]}]]}], "  ", "=", "  ", 
   RowBox[{"4.01", "\[InvisibleSpace] ", "+", " ", 
    RowBox[{"2", " ", "\[ImaginaryI]"}]}]}], "\[IndentingNewLine]", 
  StyleBox["and",
   FontFamily->"Times New Roman",
   FontSize->12,
   FontWeight->"Plain",
   FontSlant->"Plain",
   FontVariations->{"StrikeThrough"->False,
   "Underline"->False},
   FontColor->GrayLevel[0]], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    StyleBox[
     RowBox[{
      RowBox[{"f", "'"}], 
      RowBox[{"(", 
       RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}],
     FontWeight->"Plain"], 
    StyleBox["  ",
     FontWeight->"Plain"], "\[TildeTilde]", "  ", 
    FractionBox[
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", 
        SubscriptBox["z", "2"], ")"}]}], " ", "-", " ", 
      RowBox[{"f", 
       RowBox[{"(", 
        SubscriptBox["z", "0"], ")"}]}]}], 
     RowBox[{
      SubscriptBox["z", "2"], " ", "-", "  ", 
      SubscriptBox["z", "0"]}]]}], "  ", "=", "  ", 
   RowBox[{"4", "\[InvisibleSpace] ", "+", " ", 
    RowBox[{"2.01", " ", "\[ImaginaryI]"}]}]}]}]],
 "  \n\nwhich leads us to speculate that ",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}],
    FontWeight->"Plain"], "  ", "=", "  ", 
   RowBox[{"4", "\[InvisibleSpace] ", "+", " ", 
    RowBox[{"2", " ", "\[ImaginaryI]"}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tThese computations lead to the idea of taking limits along the horizontal \
and vertical directions. When we do so, we get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"h", "\[Rule]", "0"}]], 
      FractionBox[
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", 
          RowBox[{"2", "+", "h", "+", "\[ImaginaryI]"}], ")"}]}], " ", "-", 
        " ", 
        RowBox[{"f", 
         RowBox[{"(", 
          RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}]}], "h"]}], "  ", "=", 
     "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"h", "\[Rule]", "0"}]], " ", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"2", "+", "h", "+", "\[ImaginaryI]"}], ")"}], "2"], " ", 
        "-", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}]}], "h"]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"h", "\[Rule]", "0"}]], " ", 
      FractionBox[
       RowBox[{"3", "+", 
        RowBox[{"4", " ", "h"}], "+", 
        SuperscriptBox["h", "2"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"4", "+", 
           RowBox[{"2", " ", "h"}]}], ")"}]}], " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}]}], "h"]}]}], "   ", 
    "=", "  ", 
    RowBox[{
     UnderscriptBox[
      RowBox[{" ", "lim"}], 
      RowBox[{"h", "\[Rule]", "0"}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{"4", "h"}], "+", 
       SuperscriptBox["h", "2"], " ", "+", " ", 
       RowBox[{"2", " ", "h", " ", "\[ImaginaryI]"}]}], "h"]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"h", "\[Rule]", "0"}]], 
      RowBox[{"(", 
       RowBox[{"4", "+", "h", " ", "+", " ", 
        RowBox[{"2", " ", "\[ImaginaryI]"}]}], ")"}]}], "  ", "=", "  ", 
     RowBox[{"4", " ", "+", " ", 
      RowBox[{"2", " ", "\[ImaginaryI]"}]}]}]}]}]}]],
 "   "
}], "Text"],

Cell["and", "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"h", "\[Rule]", "0"}]], 
      FractionBox[
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", 
          RowBox[{"2", "+", "\[ImaginaryI]", "+", 
           RowBox[{"\[ImaginaryI]", " ", "h"}]}], ")"}]}], " ", "-", " ", 
        RowBox[{"f", 
         RowBox[{"(", 
          RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}]}], 
       RowBox[{"\[ImaginaryI]", " ", "h"}]]}], "  ", "=", "   ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"h", "\[Rule]", "0"}]], " ", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"2", "+", "\[ImaginaryI]", "+", 
           RowBox[{"\[ImaginaryI]", " ", "h"}]}], ")"}], "2"], " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}]}], 
       RowBox[{"\[ImaginaryI]", " ", "h"}]]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"                      ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"h", "\[Rule]", "0"}]], " ", 
      FractionBox[
       RowBox[{"3", "-", 
        RowBox[{"2", " ", "h"}], "-", 
        SuperscriptBox["h", "2"], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"4", "+", 
           RowBox[{"4", " ", "h"}]}], ")"}], "\[ImaginaryI]"}], " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}]}], 
       RowBox[{"\[ImaginaryI]", " ", "h"}]]}]}], "  ", "=", "  ", 
    RowBox[{
     UnderscriptBox[
      RowBox[{" ", "lim"}], 
      RowBox[{"h", "\[Rule]", "0"}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], "h"}], "-", " ", 
       SuperscriptBox["h", "2"], "+", 
       RowBox[{"4", " ", "h", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"\[ImaginaryI]", " ", "h"}]]}]}], " ", 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"                      ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"h", "\[Rule]", "0"}]], 
      RowBox[{"(", " ", 
       RowBox[{"4", " ", "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "+", "h"}], ")"}], "\[ImaginaryI]"}]}], " ", ")"}]}], 
     "  ", "=", "  ", 
     RowBox[{"4", " ", "+", " ", 
      RowBox[{"2", " ", "\[ImaginaryI]"}]}]}]}]}]}]],
 "  "
}], "Text"],

Cell["\<\
\tWe now generalize this idea by taking limits of an arbitrary differentiable \
complex function and obtain an important result.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Numerical", " ", "Computations"}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506703808859375*^9, 3.506703808875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"h", "=", "0.1"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "0"], "=", 
     RowBox[{"2", "+", "\[ImaginaryI]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", 
     RowBox[{"2", "+", "h", "+", "\[ImaginaryI]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], "=", 
     RowBox[{"2", "+", "\[ImaginaryI]", "+", 
      RowBox[{"\[ImaginaryI]", " ", "h"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], "=", 
     RowBox[{"2", "+", "\[ImaginaryI]", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], " ", "h"}]}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(0\)]\) = \>\"", ",", 
      SubscriptBox["z", "0"]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) - \!\(\*SubscriptBox[\(z\), \
\(0\)]\) = (\>\"", ",", 
      SubscriptBox["z", "1"], " ", ",", "\"\<) - (\>\"", ",", 
      SubscriptBox["z", "0"], ",", "\"\<)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) - \!\(\*SubscriptBox[\(z\), \
\(0\)]\) = \>\"", ",", 
      RowBox[{
       SubscriptBox["z", "1"], "  ", "-", " ", 
       SubscriptBox["z", "0"]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\!\(\*SubscriptBox[\(z\), \(1\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "1"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[\!\(\*SubscriptBox[\(z\), \(1\)]\)] - f[\!\(\*SubscriptBox[\(z\), \
\(0\)]\)] = (\>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "1"], "]"}], ",", "\"\<) - (\>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}], ",", "\"\<)\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[\!\(\*SubscriptBox[\(z\), \(1\)]\)] - f[\!\(\*SubscriptBox[\(z\), \
\(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "[", 
        SubscriptBox["z", "1"], "]"}], " ", "-", " ", 
       RowBox[{"f", "[", 
        SubscriptBox["z", "0"], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] \[TildeTilde] \
\!\(\*FractionBox[\(f[\*SubscriptBox[\(z\), \(1\)]] - f[\*SubscriptBox[\(z\), \
\(0\)]]\), \(\*SubscriptBox[\(z\), \(1\)] - \*SubscriptBox[\(z\), \(0\)]\)]\)\
\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] \[TildeTilde] (\>\"", ",", 
      RowBox[{
       RowBox[{"f", "[", 
        SubscriptBox["z", "1"], "]"}], "-", 
       RowBox[{"f", "[", 
        SubscriptBox["z", "0"], "]"}]}], ",", "\"\<)/(\>\"", ",", 
      RowBox[{
       SubscriptBox["z", "1"], "-", 
       SubscriptBox["z", "0"]}], ",", "\"\<)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] \[TildeTilde] \>\"", ",", 
      FractionBox[
       RowBox[{
        RowBox[{"f", "[", 
         SubscriptBox["z", "1"], "]"}], "-", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "0"], "]"}]}], 
       RowBox[{
        SubscriptBox["z", "1"], "-", 
        SubscriptBox["z", "0"]}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The numerical approximation is\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[\>\"", ",", 
      SubscriptBox["z", "0"], ",", "\"\<] \[TildeTilde] \>\"", ",", 
      FractionBox[
       RowBox[{
        RowBox[{"f", "[", 
         SubscriptBox["z", "1"], "]"}], "-", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "0"], "]"}]}], 
       RowBox[{
        SubscriptBox["z", "1"], "-", 
        SubscriptBox["z", "0"]}]]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39902017546875*^9, 3.399020178515625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"h", "=", "0.1"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "0"], "=", 
     RowBox[{"2", "+", "\[ImaginaryI]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", 
     RowBox[{"2", "+", "h", "+", "\[ImaginaryI]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], "=", 
     RowBox[{"2", "+", "\[ImaginaryI]", "+", 
      RowBox[{"\[ImaginaryI]", " ", "h"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], "=", 
     RowBox[{"2", "+", "\[ImaginaryI]", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], " ", "h"}]}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(0\)]\) = \>\"", ",", 
      SubscriptBox["z", "0"]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["z", "2"]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) - \!\(\*SubscriptBox[\(z\), \
\(0\)]\) = (\>\"", ",", 
      SubscriptBox["z", "2"], " ", ",", "\"\<) - (\>\"", ",", 
      SubscriptBox["z", "0"], ",", "\"\<)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) - \!\(\*SubscriptBox[\(z\), \
\(0\)]\) = \>\"", ",", 
      RowBox[{
       SubscriptBox["z", "2"], "  ", "-", " ", 
       SubscriptBox["z", "0"]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\!\(\*SubscriptBox[\(z\), \(2\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "2"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[\!\(\*SubscriptBox[\(z\), \(2\)]\)] - f[\!\(\*SubscriptBox[\(z\), \
\(0\)]\)] = (\>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "2"], "]"}], ",", "\"\<) - (\>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}], ",", "\"\<)\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[\!\(\*SubscriptBox[\(z\), \(2\)]\)] - f[\!\(\*SubscriptBox[\(z\), \
\(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "[", 
        SubscriptBox["z", "2"], "]"}], " ", "-", " ", 
       RowBox[{"f", "[", 
        SubscriptBox["z", "0"], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] \[TildeTilde] \
\!\(\*FractionBox[\(f[\*SubscriptBox[\(z\), \(2\)]] - f[\*SubscriptBox[\(z\), \
\(0\)]]\), \(\*SubscriptBox[\(z\), \(2\)] - \*SubscriptBox[\(z\), \(0\)]\)]\)\
\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] \[TildeTilde] (\>\"", ",", 
      RowBox[{
       RowBox[{"f", "[", 
        SubscriptBox["z", "2"], "]"}], "-", 
       RowBox[{"f", "[", 
        SubscriptBox["z", "0"], "]"}]}], ",", "\"\<)/(\>\"", ",", 
      RowBox[{
       SubscriptBox["z", "2"], "-", 
       SubscriptBox["z", "0"]}], ",", "\"\<)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] \[TildeTilde] \>\"", ",", 
      FractionBox[
       RowBox[{
        RowBox[{"f", "[", 
         SubscriptBox["z", "2"], "]"}], "-", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "0"], "]"}]}], 
       RowBox[{
        SubscriptBox["z", "2"], "-", 
        SubscriptBox["z", "0"]}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The numerical approximation is\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[\>\"", ",", 
      SubscriptBox["z", "0"], ",", "\"\<] \[TildeTilde] \>\"", ",", 
      FractionBox[
       RowBox[{
        RowBox[{"f", "[", 
         SubscriptBox["z", "2"], "]"}], "-", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "0"], "]"}]}], 
       RowBox[{
        SubscriptBox["z", "2"], "-", 
        SubscriptBox["z", "0"]}]]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3990201818125*^9, 3.399020185515625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"h", "=", "0.1"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "0"], "=", 
     RowBox[{"2", "+", "\[ImaginaryI]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", 
     RowBox[{"2", "+", "h", "+", "\[ImaginaryI]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], "=", 
     RowBox[{"2", "+", "\[ImaginaryI]", "+", 
      RowBox[{"\[ImaginaryI]", " ", "h"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], "=", 
     RowBox[{"2", "+", "\[ImaginaryI]", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], " ", "h"}]}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(0\)]\) = \>\"", ",", 
      SubscriptBox["z", "0"]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["z", "3"]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) - \!\(\*SubscriptBox[\(z\), \
\(0\)]\) = (\>\"", ",", 
      SubscriptBox["z", "3"], " ", ",", "\"\<) - (\>\"", ",", 
      SubscriptBox["z", "0"], ",", "\"\<)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) - \!\(\*SubscriptBox[\(z\), \
\(0\)]\) = \>\"", ",", 
      RowBox[{
       SubscriptBox["z", "3"], "  ", "-", " ", 
       SubscriptBox["z", "0"]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[\!\(\*SubscriptBox[\(z\), \(3\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "3"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[\!\(\*SubscriptBox[\(z\), \(3\)]\)] - f[\!\(\*SubscriptBox[\(z\), \
\(0\)]\)] = (\>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "3"], "]"}], ",", "\"\<) - (\>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}], ",", "\"\<)\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[\!\(\*SubscriptBox[\(z\), \(3\)]\)] - f[\!\(\*SubscriptBox[\(z\), \
\(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "[", 
        SubscriptBox["z", "3"], "]"}], " ", "-", " ", 
       RowBox[{"f", "[", 
        SubscriptBox["z", "0"], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] \[TildeTilde] \
\!\(\*FractionBox[\(f[\*SubscriptBox[\(z\), \(3\)]] - f[\*SubscriptBox[\(z\), \
\(0\)]]\), \(\*SubscriptBox[\(z\), \(3\)] - \*SubscriptBox[\(z\), \(0\)]\)]\)\
\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] \[TildeTilde] (\>\"", ",", 
      RowBox[{
       RowBox[{"f", "[", 
        SubscriptBox["z", "3"], "]"}], "-", 
       RowBox[{"f", "[", 
        SubscriptBox["z", "0"], "]"}]}], ",", "\"\<)/(\>\"", ",", 
      RowBox[{
       SubscriptBox["z", "3"], "-", 
       SubscriptBox["z", "0"]}], ",", "\"\<)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] \[TildeTilde] \>\"", ",", 
      FractionBox[
       RowBox[{
        RowBox[{"f", "[", 
         SubscriptBox["z", "3"], "]"}], "-", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "0"], "]"}]}], 
       RowBox[{
        SubscriptBox["z", "3"], "-", 
        SubscriptBox["z", "0"]}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The numerical approximation is\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[\>\"", ",", 
      SubscriptBox["z", "0"], ",", "\"\<] \[TildeTilde] \>\"", ",", 
      FractionBox[
       RowBox[{
        RowBox[{"f", "[", 
         SubscriptBox["z", "3"], "]"}], "-", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "0"], "]"}]}], 
       RowBox[{
        SubscriptBox["z", "3"], "-", 
        SubscriptBox["z", "0"]}]]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399020189390625*^9, 3.39902019128125*^9}}],

Cell[TextData[{
 "\tWe can use the forward difference formula for numerical differentiation \
and get a more accurate approximation. \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], "  ", "\[TildeTilde]", "  ", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], "f", 
      RowBox[{"(", "z", ")"}]}], "+", 
     RowBox[{"4", "f", 
      RowBox[{"(", 
       RowBox[{"z", "+", 
        FractionBox["h", "2"]}], ")"}]}], "-", 
     RowBox[{"f", 
      RowBox[{"(", 
       RowBox[{"z", "+", "h"}], ")"}]}]}], 
    RowBox[{"h", " "}]]}]]]
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"h", "=", "0.1"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "0"], "=", 
     RowBox[{"2", "+", "\[ImaginaryI]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", 
     RowBox[{"2", "+", "h", "+", "\[ImaginaryI]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], "=", 
     RowBox[{"2", "+", "\[ImaginaryI]", "+", 
      RowBox[{"\[ImaginaryI]", " ", "h"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], "=", 
     RowBox[{"2", "+", "\[ImaginaryI]", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], " ", "h"}]}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(0\)]\) = \>\"", ",", 
      SubscriptBox["z", "0"]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) - \!\(\*SubscriptBox[\(z\), \
\(0\)]\) = (\>\"", ",", 
      SubscriptBox["z", "1"], " ", ",", "\"\<) - (\>\"", ",", 
      SubscriptBox["z", "0"], ",", "\"\<)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) - \!\(\*SubscriptBox[\(z\), \
\(0\)]\) = \>\"", ",", 
      RowBox[{
       SubscriptBox["z", "1"], "  ", "-", " ", 
       SubscriptBox["z", "0"]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[\!\(\*FractionBox[\(\*SubscriptBox[\(z\), \(1\)] + \
\*SubscriptBox[\(z\), \(0\)]\), \(2\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       FractionBox[
        RowBox[{
         SubscriptBox["z", "1"], "+", 
         SubscriptBox["z", "0"]}], "2"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f[\!\(\*SubscriptBox[\(z\), \(1\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "1"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<- f[\!\(\*SubscriptBox[\(z\), \(1\)]\)] + \
4f[\!\(\*FractionBox[\(\*SubscriptBox[\(z\), \(1\)] + \*SubscriptBox[\(z\), \
\(0\)]\), \(2\)]\)] - 3f[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = (\>\"", ",", 
      RowBox[{"-", " ", 
       RowBox[{"f", "[", 
        SubscriptBox["z", "1"], "]"}]}], ",", "\"\<) + 4(\>\"", ",", 
      RowBox[{"f", "[", 
       FractionBox[
        RowBox[{
         SubscriptBox["z", "1"], "+", 
         SubscriptBox["z", "0"]}], "2"], "]"}], ",", "\"\<) - 3(\>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<- f[\!\(\*SubscriptBox[\(z\), \(1\)]\)] + \
4f[\!\(\*FractionBox[\(\*SubscriptBox[\(z\), \(1\)] + \*SubscriptBox[\(z\), \
\(0\)]\), \(2\)]\)] - 3f[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = (\>\"", ",", 
      RowBox[{"-", " ", 
       RowBox[{"f", "[", 
        SubscriptBox["z", "1"], "]"}]}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{"4", 
       RowBox[{"f", "[", 
        FractionBox[
         RowBox[{
          SubscriptBox["z", "1"], "+", 
          SubscriptBox["z", "0"]}], "2"], "]"}]}], ",", "\"\<) - (\>\"", ",", 
      RowBox[{"3", 
       RowBox[{"f", "[", 
        SubscriptBox["z", "0"], "]"}]}], ",", "\"\<)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<- f[\!\(\*SubscriptBox[\(z\), \(1\)]\)] + \
4f[\!\(\*FractionBox[\(\*SubscriptBox[\(z\), \(1\)] + \*SubscriptBox[\(z\), \
\(0\)]\), \(2\)]\)] - 3f[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = (\>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"-", " ", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "1"], "]"}]}], "]"}], ",", "\"\<)+(\>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"4", 
        RowBox[{"f", "[", 
         FractionBox[
          RowBox[{
           SubscriptBox["z", "1"], "+", 
           SubscriptBox["z", "0"]}], "2"], "]"}]}], "]"}], ",", "\"\<)-(\>\"",
       ",", 
      RowBox[{"Re", "[", 
       RowBox[{"3", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "0"], "]"}]}], "]"}], ",", 
      "\"\<) + \[ImaginaryI]((\>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"-", " ", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "1"], "]"}]}], "]"}], ",", "\"\<)+(\>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"4", 
        RowBox[{"f", "[", 
         FractionBox[
          RowBox[{
           SubscriptBox["z", "1"], "+", 
           SubscriptBox["z", "0"]}], "2"], "]"}]}], "]"}], ",", "\"\<)-(\>\"",
       ",", 
      RowBox[{"Im", "[", 
       RowBox[{"3", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "0"], "]"}]}], "]"}], ",", "\"\<))\>\""}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<- f[\!\(\*SubscriptBox[\(z\), \(1\)]\)] + \
4f[\!\(\*FractionBox[\(\*SubscriptBox[\(z\), \(1\)] + \*SubscriptBox[\(z\), \
\(0\)]\), \(2\)]\)] - 3f[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "1"], "]"}]}], "+", 
       RowBox[{"4", 
        RowBox[{"f", "[", 
         FractionBox[
          RowBox[{
           SubscriptBox["z", "1"], "+", 
           SubscriptBox["z", "0"]}], "2"], "]"}]}], "-", 
       RowBox[{"3", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "0"], "]"}]}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] \[TildeTilde] \
\!\(\*FractionBox[\(\(-f[\*SubscriptBox[\(z\), \(1\)]]\) + 4  \
f[\*FractionBox[\(\*SubscriptBox[\(z\), \(1\)] + \*SubscriptBox[\(z\), \(0\)]\
\), \(2\)]] - 3  f[\*SubscriptBox[\(z\), \(0\)]]\), \(\*SubscriptBox[\(z\), \
\(1\)] - \*SubscriptBox[\(z\), \(0\)]\)]\)\>\"", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] \[TildeTilde] (\>\"", ",", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "1"], "]"}]}], "+", 
       RowBox[{"4", 
        RowBox[{"f", "[", 
         FractionBox[
          RowBox[{
           SubscriptBox["z", "1"], "+", 
           SubscriptBox["z", "0"]}], "2"], "]"}]}], "-", 
       RowBox[{"3", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "0"], "]"}]}]}], ",", "\"\<)/(\>\"", ",", 
      RowBox[{
       SubscriptBox["z", "1"], "-", 
       SubscriptBox["z", "0"]}], ",", "\"\<)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] \[TildeTilde] \>\"", ",", 
      RowBox[{"NumberForm", "[", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           RowBox[{"f", "[", 
            SubscriptBox["z", "1"], "]"}]}], "+", 
          RowBox[{"4", 
           RowBox[{"f", "[", 
            FractionBox[
             RowBox[{
              SubscriptBox["z", "1"], "+", 
              SubscriptBox["z", "0"]}], "2"], "]"}]}], "-", 
          RowBox[{"3", 
           RowBox[{"f", "[", 
            SubscriptBox["z", "0"], "]"}]}]}], 
         RowBox[{
          SubscriptBox["z", "1"], "-", 
          SubscriptBox["z", "0"]}]], ",", "12"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The numerical approximation is\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[\>\"", ",", 
      SubscriptBox["z", "0"], ",", "\"\<] \[TildeTilde] \>\"", ",", 
      RowBox[{"NumberForm", "[", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           RowBox[{"f", "[", 
            SubscriptBox["z", "1"], "]"}]}], "+", 
          RowBox[{"4", 
           RowBox[{"f", "[", 
            FractionBox[
             RowBox[{
              SubscriptBox["z", "1"], "+", 
              SubscriptBox["z", "0"]}], "2"], "]"}]}], "-", 
          RowBox[{"3", 
           RowBox[{"f", "[", 
            SubscriptBox["z", "0"], "]"}]}]}], 
         RowBox[{
          SubscriptBox["z", "1"], "-", 
          SubscriptBox["z", "0"]}]], ",", "12"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The true solution is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[\>\"", ",", 
      SubscriptBox["z", "0"], ",", "\"\<]  \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399020196265625*^9, 3.399020199296875*^9}}],

Cell[TextData[{
 StyleBox["Note.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  In this case the approximation is exact and the error is zero.  This is \
because ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", "2"]}]]],
 " is a polynomial of degree less than 3.  \n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  If we want to use a function for which the numerical approximation is not \
exact, then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", "3"]}]]],
 "  will suffice."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", "3"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"h", "=", "0.1"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "0"], "=", 
     RowBox[{"2", "+", "\[ImaginaryI]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], "=", 
     RowBox[{"2", "+", "h", "+", "\[ImaginaryI]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], "=", 
     RowBox[{"2", "+", "\[ImaginaryI]", "+", 
      RowBox[{"\[ImaginaryI]", " ", "h"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], "=", 
     RowBox[{"2", "+", "\[ImaginaryI]", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], " ", "h"}]}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(0\)]\) = \>\"", ",", 
      SubscriptBox["z", "0"]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) - \!\(\*SubscriptBox[\(z\), \
\(0\)]\) = (\>\"", ",", 
      SubscriptBox["z", "1"], " ", ",", "\"\<) - (\>\"", ",", 
      SubscriptBox["z", "0"], ",", "\"\<) = \>\"", ",", 
      RowBox[{
       SubscriptBox["z", "1"], "  ", "-", " ", 
       SubscriptBox["z", "0"]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[\!\(\*FractionBox[\(\*SubscriptBox[\(z\), \(1\)] + \
\*SubscriptBox[\(z\), \(0\)]\), \(2\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       FractionBox[
        RowBox[{
         SubscriptBox["z", "1"], "+", 
         SubscriptBox["z", "0"]}], "2"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f[\!\(\*SubscriptBox[\(z\), \(1\)]\)] = \>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "1"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<- f[\!\(\*SubscriptBox[\(z\), \(1\)]\)] + \
4f[\!\(\*FractionBox[\(\*SubscriptBox[\(z\), \(1\)] + \*SubscriptBox[\(z\), \
\(0\)]\), \(2\)]\)] - 3f[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = (\>\"", ",", 
      RowBox[{"-", " ", 
       RowBox[{"f", "[", 
        SubscriptBox["z", "1"], "]"}]}], ",", "\"\<) + 4(\>\"", ",", 
      RowBox[{"f", "[", 
       FractionBox[
        RowBox[{
         SubscriptBox["z", "1"], "+", 
         SubscriptBox["z", "0"]}], "2"], "]"}], ",", "\"\<) - 3(\>\"", ",", 
      RowBox[{"f", "[", 
       SubscriptBox["z", "0"], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<- f[\!\(\*SubscriptBox[\(z\), \(1\)]\)] + \
4f[\!\(\*FractionBox[\(\*SubscriptBox[\(z\), \(1\)] + \*SubscriptBox[\(z\), \
\(0\)]\), \(2\)]\)] - 3f[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = (\>\"", ",", 
      RowBox[{"-", " ", 
       RowBox[{"f", "[", 
        SubscriptBox["z", "1"], "]"}]}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{"4", 
       RowBox[{"f", "[", 
        FractionBox[
         RowBox[{
          SubscriptBox["z", "1"], "+", 
          SubscriptBox["z", "0"]}], "2"], "]"}]}], ",", "\"\<) - (\>\"", ",", 
      RowBox[{"3", 
       RowBox[{"f", "[", 
        SubscriptBox["z", "0"], "]"}]}], ",", "\"\<)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<- f[\!\(\*SubscriptBox[\(z\), \(1\)]\)] + \
4f[\!\(\*FractionBox[\(\*SubscriptBox[\(z\), \(1\)] + \*SubscriptBox[\(z\), \
\(0\)]\), \(2\)]\)] - 3f[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = (\>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"-", " ", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "1"], "]"}]}], "]"}], ",", "\"\<)+(\>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"4", 
        RowBox[{"f", "[", 
         FractionBox[
          RowBox[{
           SubscriptBox["z", "1"], "+", 
           SubscriptBox["z", "0"]}], "2"], "]"}]}], "]"}], ",", "\"\<)-(\>\"",
       ",", 
      RowBox[{"Re", "[", 
       RowBox[{"3", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "0"], "]"}]}], "]"}], ",", 
      "\"\<) + \[ImaginaryI]((\>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"-", " ", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "1"], "]"}]}], "]"}], ",", "\"\<)+(\>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"4", 
        RowBox[{"f", "[", 
         FractionBox[
          RowBox[{
           SubscriptBox["z", "1"], "+", 
           SubscriptBox["z", "0"]}], "2"], "]"}]}], "]"}], ",", "\"\<)-(\>\"",
       ",", 
      RowBox[{"Im", "[", 
       RowBox[{"3", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "0"], "]"}]}], "]"}], ",", "\"\<))\>\""}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<- f[\!\(\*SubscriptBox[\(z\), \(1\)]\)] + \
4f[\!\(\*FractionBox[\(\*SubscriptBox[\(z\), \(1\)] + \*SubscriptBox[\(z\), \
\(0\)]\), \(2\)]\)] - 3f[\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "1"], "]"}]}], "+", 
       RowBox[{"4", 
        RowBox[{"f", "[", 
         FractionBox[
          RowBox[{
           SubscriptBox["z", "1"], "+", 
           SubscriptBox["z", "0"]}], "2"], "]"}]}], "-", 
       RowBox[{"3", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "0"], "]"}]}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] \[TildeTilde] \
\!\(\*FractionBox[\(\(-f[\*SubscriptBox[\(z\), \(1\)]]\) + 4  \
f[\*FractionBox[\(\*SubscriptBox[\(z\), \(1\)] + \*SubscriptBox[\(z\), \(0\)]\
\), \(2\)]] - 3  f[\*SubscriptBox[\(z\), \(0\)]]\), \(\*SubscriptBox[\(z\), \
\(1\)] - \*SubscriptBox[\(z\), \(0\)]\)]\)\>\"", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] \[TildeTilde] (\>\"", ",", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "1"], "]"}]}], "+", 
       RowBox[{"4", 
        RowBox[{"f", "[", 
         FractionBox[
          RowBox[{
           SubscriptBox["z", "1"], "+", 
           SubscriptBox["z", "0"]}], "2"], "]"}]}], "-", 
       RowBox[{"3", 
        RowBox[{"f", "[", 
         SubscriptBox["z", "0"], "]"}]}]}], ",", "\"\<)/(\>\"", ",", 
      RowBox[{
       SubscriptBox["z", "1"], "-", 
       SubscriptBox["z", "0"]}], ",", "\"\<)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] \[TildeTilde] \>\"", ",", 
      RowBox[{"NumberForm", "[", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           RowBox[{"f", "[", 
            SubscriptBox["z", "1"], "]"}]}], "+", 
          RowBox[{"4", 
           RowBox[{"f", "[", 
            FractionBox[
             RowBox[{
              SubscriptBox["z", "1"], "+", 
              SubscriptBox["z", "0"]}], "2"], "]"}]}], "-", 
          RowBox[{"3", 
           RowBox[{"f", "[", 
            SubscriptBox["z", "0"], "]"}]}]}], 
         RowBox[{
          SubscriptBox["z", "1"], "-", 
          SubscriptBox["z", "0"]}]], ",", "12"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The numerical approximation is\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[\>\"", ",", 
      SubscriptBox["z", "0"], ",", "\"\<] \[TildeTilde] \>\"", ",", 
      RowBox[{"NumberForm", "[", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           RowBox[{"f", "[", 
            SubscriptBox["z", "1"], "]"}]}], "+", 
          RowBox[{"4", 
           RowBox[{"f", "[", 
            FractionBox[
             RowBox[{
              SubscriptBox["z", "1"], "+", 
              SubscriptBox["z", "0"]}], "2"], "]"}]}], "-", 
          RowBox[{"3", 
           RowBox[{"f", "[", 
            SubscriptBox["z", "0"], "]"}]}]}], 
         RowBox[{
          SubscriptBox["z", "1"], "-", 
          SubscriptBox["z", "0"]}]], ",", "12"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The true solution is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[\>\"", ",", 
      SubscriptBox["z", "0"], ",", "\"\<]  \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       SubscriptBox["z", "0"], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The error in the numerical approximation is\>\"", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f'[\!\(\*SubscriptBox[\(z\), \(0\)]\)] - \
\!\(\*FractionBox[\(\(-f[\*SubscriptBox[\(z\), \(1\)]]\) + 4  \
f[\*FractionBox[\(\*SubscriptBox[\(z\), \(1\)] + \*SubscriptBox[\(z\), \(0\)]\
\), \(2\)]] - 3  f[\*SubscriptBox[\(z\), \(0\)]]\), \(\*SubscriptBox[\(z\), \
\(1\)] - \*SubscriptBox[\(z\), \(0\)]\)]\) = \>\"", ",", 
      RowBox[{"Chop", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "'"}], "[", 
         SubscriptBox["z", "0"], "]"}], "-", " ", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           RowBox[{"f", "[", 
            SubscriptBox["z", "1"], "]"}]}], "+", 
          RowBox[{"4", 
           RowBox[{"f", "[", 
            FractionBox[
             RowBox[{
              SubscriptBox["z", "1"], "+", 
              SubscriptBox["z", "0"]}], "2"], "]"}]}], "-", 
          RowBox[{"3", 
           RowBox[{"f", "[", 
            SubscriptBox["z", "0"], "]"}]}]}], 
         RowBox[{
          SubscriptBox["z", "1"], "-", 
          SubscriptBox["z", "0"]}]]}], " ", "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399020203453125*^9, 3.39902020625*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Theorem 3.3 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Cauchy-Riemann Equations",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/Cauchy-RiemannEquations.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", 
      RowBox[{"x", "+", "\[ImaginaryI]y"}], ")"}]}], "=", 
    RowBox[{
     RowBox[{"u", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "v", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}]}]}]]],
 "  \n\nis differentiable at the point ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{
    SubscriptBox["x", "0"], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["y", "0"]}]}]}]]],
 ".  Then the partial derivatives of  u  and  v  exist at the point ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["x", "0"], ",", 
    SubscriptBox["y", "0"]}], ")"}]]],
 ", and  \n\n",
 StyleBox["(3-14)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["u", "x"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "0"], ",", 
       SubscriptBox["y", "0"]}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["v", "x"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "0"], ",", 
       SubscriptBox["y", "0"]}], ")"}]}]}]}]]],
 ",   and also  \n\n",
 StyleBox["(3-15)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["v", "y"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "0"], ",", 
       SubscriptBox["y", "0"]}], ")"}]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["u", "y"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "0"], ",", 
       SubscriptBox["y", "0"]}], ")"}]}]}]}]]],
 ".  \n\nEquating the real and imaginary parts of Equations ",
 StyleBox["(3-14)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(3-15)",
  FontColor->RGBColor[0, 0, 1]],
 " gives  \n\n",
 StyleBox["(3-16)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "x"], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "0"], ",", 
      SubscriptBox["y", "0"]}], ")"}]}], "=", 
   RowBox[{
    SubscriptBox["v", "y"], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "0"], ",", 
      SubscriptBox["y", "0"]}], ")"}]}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "y"], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "0"], ",", 
      SubscriptBox["y", "0"]}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["v", "x"]}], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "0"], ",", 
      SubscriptBox["y", "0"]}], ")"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 3.3 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Derivation of the Cauchy-Riemann Equations with ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Mathematica",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[".",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"Exploration", " ", "for", " ", "the", " ", "Cauchy"}], "-", 
   RowBox[{"Riemann", " ", 
    RowBox[{"Equations", "."}]}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506703813203125*^9, 3.506703813203125*^9}},
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "\[CapitalDelta]x", ",", "\[CapitalDelta]y", ",", "E1", ",", "E2", ",", 
      "E3", ",", "E4", ",", "E5", ",", "f", ",", "L1", ",", "L2", ",", "u", 
      ",", "v", ",", "x", ",", "y", ",", "z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Im", "[", "x", "]"}], ",", "0"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Im", "[", "y", "]"}], ",", "0"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"u", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", "0"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"v", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", "0"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Re", "[", "x", "]"}], ",", "x"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Re", "[", "y", "]"}], ",", "y"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"u", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"v", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x_", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "y_"}]}], "]"}], " ", ":=", " ", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"L1", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"x", "+", "\[CapitalDelta]x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "-", 
         RowBox[{"f", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], 
        "\[CapitalDelta]x"], ",", 
       RowBox[{"\[CapitalDelta]x", "\[Rule]", "0"}], ",", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"L2", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", 
            RowBox[{"(", 
             RowBox[{"y", "+", "\[CapitalDelta]y"}], ")"}]}]}], "]"}], "-", 
         RowBox[{"f", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], 
        RowBox[{"\[ImaginaryI]", " ", "\[CapitalDelta]y"}]], ",", 
       RowBox[{"\[CapitalDelta]y", "\[Rule]", "0"}], ",", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f(z) = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Re[f(z)] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", 
        RowBox[{"f", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Im[f(z)] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", 
        RowBox[{"f", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]x \[Rule] 0\)]\)  \
\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[CapitalDelta]x\)]\) = \
\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]x \[Rule] 0\)]\)  \
\!\(\*FractionBox[\(f[x + \[CapitalDelta]x + \[ImaginaryI]\\\ y] - f[x + \
\[ImaginaryI]\\\ y]\), \(\[CapitalDelta]x\)]\) = \>\"", ",", "L1"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]y \[Rule] 0\)]\) \
\!\(\*FractionBox[\(\[CapitalDelta]f\), \(\[ImaginaryI]\\\ \
\[CapitalDelta]y\)]\) = \!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]y \
\[Rule] 0\)]\) \!\(\*FractionBox[\(f[x + \[ImaginaryI] \((y + \
\[CapitalDelta]y)\)] - f[x + \[ImaginaryI]\\\ y]\), \(\[ImaginaryI]\\\ \
\[CapitalDelta]y\)]\) = \>\"", ",", "L2"}], "]"}], ";"}], " ", "\n", 
   RowBox[{"Print", "[", "\"\<\>\"", "]"}], "\n", 
   RowBox[{
    RowBox[{"E1", " ", "=", " ", 
     RowBox[{"L1", " ", "\[Equal]", " ", "L2"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "E1", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Equate the real and imaginary parts.\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The Cauchy-Riemann equations are:\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"E2", " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"E1", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], "\[Rule]", "0"}]}], "}"}]}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "E2", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"E3", " ", "=", " ", 
     RowBox[{"Thread", "[", 
      RowBox[{
       RowBox[{"-", "E1"}], ",", "Equal"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"E4", " ", "=", " ", 
     RowBox[{"Thread", "[", 
      RowBox[{
       RowBox[{"E2", "+", "E3"}], ",", "Equal"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"E5", " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"E4", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", "\[Rule]", "1"}], ",", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], "\[Rule]", 
          RowBox[{"-", "1"}]}]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "E5", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020217890625*^9}],

Cell[TextData[{
 "We have used ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to derive the Cauchy-Riemann equations  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "x"], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "0"], ",", 
      SubscriptBox["y", "0"]}], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["v", "y"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "0"], ",", 
       SubscriptBox["y", "0"]}], ")"}], "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman"], "  ", 
     SubscriptBox["u", "y"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "0"], ",", 
       SubscriptBox["y", "0"]}], ")"}]}], "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["v", "x"]}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "0"], ",", 
       SubscriptBox["y", "0"]}], ")"}]}]}]}]]],
 ".   "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tNote some of the important implications of this theorem.\n\t\n",
 StyleBox["(i).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "    If f is differentiable at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", then the Cauchy-Riemann Equations ",
 StyleBox["(3-16)",
  FontColor->RGBColor[0, 0, 1]],
 " will be satisfied at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", and we can use either either Equation ",
 StyleBox["(3-14)",
  FontColor->RGBColor[0, 0, 1]],
 " or ",
 StyleBox["(3-15)",
  FontColor->RGBColor[0, 0, 1]],
 " to evaluate ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]],
  AspectRatioFixed->True],
 ".   \n\t\n",
 StyleBox["(ii).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "   Taking the contrapositive, if Equations ",
 StyleBox["(3-16)",
  FontColor->RGBColor[0, 0, 1]],
 " are not satisfied at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", then we know automatically that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is not differentiable at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ". \n\n",
 StyleBox["(iii).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Even if Equations ",
 StyleBox["(3-16)",
  FontColor->RGBColor[0, 0, 1]],
 " are satisfied at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", we cannot necessarily conclude that f is differentiable at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".\n\n\tWe now illustrate each of these points."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 3.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  We know that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "=", 
    RowBox[{
     SuperscriptBox["x", "2"], "-", 
     SuperscriptBox["y", "2"], "+", 
     RowBox[{"\[ImaginaryI]", " ", "2", " ", "x", " ", "y"}]}]}]}]]],
 "  is differentiable and that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"2", "z"}]}]],
  AspectRatioFixed->True],
 ".  We also have  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], "=", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["y", "2"]}], ")"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{"2", " ", "x", " ", "y"}], ")"}]}]}]}]}]}]]],
 ".  \n\nIt is easy to verify that Equations ",
 StyleBox["(3-16)",
  FontColor->RGBColor[0, 0, 1]],
 " are indeed satisfied:\n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "x"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"2", "x"}], "=", 
    RowBox[{
     SubscriptBox["v", "y"], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "y"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], "y"}], "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["v", "x"]}], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}]}]]],
 ".  \n\nUsing Equations ",
 StyleBox["(3-14)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(3-15)",
  FontColor->RGBColor[0, 0, 1]],
 ", respectively, to compute ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]],
  AspectRatioFixed->True],
 "  gives\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["u", "x"], 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["v", "x"], 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"2", "x"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "2", "y"}]}], "=", 
     RowBox[{"2", "z", " "}]}]}]}]],
  AspectRatioFixed->True],
 ",   and   \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["v", "y"], 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["u", "y"], 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"2", "x"}], "-", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "y"}], ")"}]}]}], "=", 
     RowBox[{"2", "z"}]}]}]}]],
  AspectRatioFixed->True],
 ",\nas expected."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"3.4", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506703817265625*^9, 3.50670381728125*^9}},
 AspectRatioFixed->False],

Cell["Enter the function f[z] and determine u[x,y] and v[x,y].", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "x", ",", "y", ",", "u", ",", "v", ",", "w", ",", "w1", ",", 
      "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["z", "2"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  f[z] = \>\"", ",", "w"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<  f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39902022796875*^9}],

Cell["Verify that the Cauchy-Riemann equations hold.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Does \!\(\*SubscriptBox[\(\[PartialD]\), \(x\)]\) u[x,y] = \
\!\(\*SubscriptBox[\(\[PartialD]\), \(y\)]\) v[x,y] ?\>\"", "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Does \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ",", "\"\< = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ",", "\"\< ?  \>\"", ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], " ", 
        RowBox[{"u", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], "\[Equal]", 
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Does \!\(\*SubscriptBox[\(\[PartialD]\), \(y\)]\) u[x,y] = \
-\!\(\*SubscriptBox[\(\[PartialD]\), \(x\)]\) v[x,y] ?\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Does \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ",", "\"\< = \>\"", ",", 
      RowBox[{"-", 
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}], ",", "\"\< ?  \>\"", ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], " ", 
        RowBox[{"u", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], "\[Equal]", 
       RowBox[{"-", 
        RowBox[{
         SubscriptBox["\[PartialD]", "x"], " ", 
         RowBox[{"v", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020232484375*^9}],

Cell[TextData[{
 "We see that the Cauchy-Riemann equations hold.\n\nVerify that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], "[", "z", "]"}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["u", "x"], "[", 
     RowBox[{"x", ",", "y"}], "]"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{
      SubscriptBox["v", "x"], "[", 
      RowBox[{"x", ",", "y"}], "]"}]}]}]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"w1", " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "  ", "+", "  ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f'[z] = \!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] + \[ImaginaryI] \
\!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y]\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = (\>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ",", "\"\<) + \[ImaginaryI](\>\"", 
      ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ",", "\"\<)\>\""}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", "w1"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020237140625*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 3.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   OverscriptBox[
    RowBox[{"z", " "}], "_"], " "}]]],
 "  is ",
 StyleBox["nowhere",
  FontColor->RGBColor[1, 0, 1]],
 " differentiable."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", 
      RowBox[{"x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"x", "-", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"u", 
       RowBox[{"(", 
        RowBox[{"x", ",", "y"}], ")"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "v", 
       RowBox[{"(", 
        RowBox[{"x", ",", "y"}], ")"}]}]}]}]}]}]]],
 ",  where  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", "x"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{"-", "y"}]}]]],
 ".  Thus, for any point  ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"x", ",", "y"}], ")"}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "x"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", "1"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["v", "y"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{"-", "1"}]}]]],
 ".  The Cauchy-Riemann equations are ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " satisfied at any point ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 ", so we conclude that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   OverscriptBox[
    RowBox[{"z", " "}], "_"], " "}]]],
 "  is ",
 StyleBox["nowhere",
  FontColor->RGBColor[1, 0, 1]],
 " differentiable."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"3.5", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.50670381953125*^9, 3.50670381953125*^9}},
 AspectRatioFixed->False],

Cell["Enter the function f[z].", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "u", ",", "Ux", ",", "Ux0", ",", "Uy", ",", "Uy0", ",", "v", 
      ",", "Vx", ",", "Vx0", ",", "Vy", ",", "Vy0", ",", "w", ",", "x", ",", 
      "y"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Im", "[", "x", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Im", "[", "y", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Re", "[", "x", "]"}], ",", "x"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Re", "[", "y", "]"}], ",", "y"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{"Conjugate", "[", 
      RowBox[{"x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", "w"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"w", ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", "w"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020245671875*^9}],

Cell["Find the real and imaginary parts of  f[z].", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", "w", "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", "w", "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"0", ",", "0"}], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"0", ",", "0"}], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"0", ",", "0"}], "]"}], " ", "=", " ", "0"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<  f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  f[z] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020250140625*^9},
 AspectRatioFixed->True],

Cell["Determine if the Cauchy-Riemann equations hold.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Ux", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Uy", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vx", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vy", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] = \>\"", ",", "Ux"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] = \>\"", ",", "Uy"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y] = \>\"", ",", "Vx"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(y\)]\)[x,y] = \>\"", ",", "Vy"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] - \!\(\*SubscriptBox[\(v\), \
\(y\)]\)[x,y] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{"Ux", "-", "Vy"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] + \!\(\*SubscriptBox[\(v\), \
\(x\)]\)[x,y] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{"Uy", "+", "Vx"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020254328125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Hence the Cauchy-Riemann do not hold at any point.\n\nThus, we have shown \
that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", " ", 
   OverscriptBox[
    RowBox[{"z", " "}], "_"], " "}]]],
 "  is ",
 StyleBox["not ",
  FontColor->RGBColor[1, 0, 1]],
 "analytic for any value of  z."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 3.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the function defined by\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"{", GridBox[{
      {
       RowBox[{
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", " ", 
           OverscriptBox[
            RowBox[{"z", " "}], "_"], " ", ")"}], "2"], "z"], " ", "=", " ", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["x", "3"], "-", 
           RowBox[{"3", " ", "x", " ", 
            SuperscriptBox["y", "2"]}]}], 
          RowBox[{" ", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}]}]], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          FractionBox[
           RowBox[{
            SuperscriptBox["y", "3"], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["x", "2"], " ", "y"}]}], 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}]]}]}]}], 
       RowBox[{"  ", 
        RowBox[{
         RowBox[{
          RowBox[{
           StyleBox["when",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontVariations->{"StrikeThrough"->False,
            "Underline"->False},
            FontColor->GrayLevel[0]], 
           StyleBox["   ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontVariations->{"StrikeThrough"->False,
            "Underline"->False},
            FontColor->GrayLevel[0]], "z"}], "\[NotEqual]", "0"}], 
         StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], 
         StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], 
         StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]]}]}]},
      {
       RowBox[{"             ", "0", "                               "}], 
       RowBox[{"  ", 
        RowBox[{
         RowBox[{
          StyleBox["when",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], " ", "z"}], "\[NotEqual]", 
         RowBox[{"0", 
          StyleBox[" ",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], 
          StyleBox[".",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], 
          StyleBox["             ",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]]}]}]}]}
     }], 
    StyleBox["}",
     FontColor->GrayLevel[1]]}]}]]],
 "  \n\nis not differentiable at the point ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 " even though the Cauchy-Riemann equations are satisfied at ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"0", 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "0"}], ")"}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We must use limits to calculate the partial derivatives at ",
 StyleBox["(0,0)",
  FontFamily->"Courier New"],
 ". \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "x"], 
    RowBox[{"(", 
     RowBox[{"0", ",", "0"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"x", "\[Rule]", "0"}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{"u", 
        RowBox[{"(", 
         RowBox[{"x", ",", "0"}], ")"}]}], "-", 
       RowBox[{"u", 
        RowBox[{"(", 
         RowBox[{"0", ",", "0"}], ")"}]}]}], "x"]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"x", "\[Rule]", "0"}]], " ", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["x", "3"], "-", "0"}], 
         RowBox[{
          SuperscriptBox["x", "2"], "+", "0"}]], "-", "0"}], "x"]}], " ", "=",
      " ", 
     RowBox[{
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"x", "\[Rule]", "0"}]], " ", 
       FractionBox["x", "x"]}], "  ", "=", "  ", "1"}]}]}]}]]],
 ", \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "y"], 
    RowBox[{"(", 
     RowBox[{"0", ",", "0"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"y", "\[Rule]", "0"}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{"u", 
        RowBox[{"(", 
         RowBox[{"0", ",", "y"}], ")"}]}], "-", 
       RowBox[{"u", 
        RowBox[{"(", 
         RowBox[{"0", ",", "y"}], ")"}]}]}], "y"]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"y", "\[Rule]", "0"}]], " ", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"0", "-", "0"}], 
         RowBox[{"0", "+", 
          SuperscriptBox["y", "2"]}]], "-", "0"}], "y"]}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"y", "\[Rule]", "0"}]], "  ", 
       FractionBox["0", "y"]}], " ", "=", "  ", "0"}]}]}]}]]],
 ",   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["v", "x"], 
    RowBox[{"(", 
     RowBox[{"0", ",", "0"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"x", "\[Rule]", "0"}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{"v", 
        RowBox[{"(", 
         RowBox[{"x", ",", "0"}], ")"}]}], "-", 
       RowBox[{"v", 
        RowBox[{"(", 
         RowBox[{"0", ",", "0"}], ")"}]}]}], "x"]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"x", "\[Rule]", "0"}]], " ", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"0", "-", "0"}], 
         RowBox[{
          SuperscriptBox["x", "2"], "+", "0"}]], "-", "0"}], "x"]}], " ", "=",
      " ", 
     RowBox[{
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"x", "\[Rule]", "0"}]], " ", 
       FractionBox["0", "x"]}], " ", "=", "  ", "1"}]}]}]}]]],
 ", \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["v", "y"], 
    RowBox[{"(", 
     RowBox[{"0", ",", "0"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"y", "\[Rule]", "0"}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{"v", 
        RowBox[{"(", 
         RowBox[{"0", ",", "y"}], ")"}]}], "-", 
       RowBox[{"v", 
        RowBox[{"(", 
         RowBox[{"0", ",", "y"}], ")"}]}]}], "y"]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"y", "\[Rule]", "0"}]], " ", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["y", "3"], "-", "0"}], 
         RowBox[{"0", "+", 
          SuperscriptBox["y", "2"]}]], "-", "0"}], "y"]}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"y", "\[Rule]", "0"}]], " ", 
       FractionBox["y", "y"]}], "  ", "=", "  ", "1"}]}]}]}]]],
 ".\n\nThus we have shown that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "x"], 
    RowBox[{"(", 
     RowBox[{"0", ",", "0"}], ")"}]}], "=", "1"}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "y"], 
    RowBox[{"(", 
     RowBox[{"0", ",", "0"}], ")"}]}], "=", "0"}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["v", "x"], 
    RowBox[{"(", 
     RowBox[{"0", ",", "0"}], ")"}]}], "=", "0"}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["v", "y"], 
    RowBox[{"(", 
     RowBox[{"0", ",", "0"}], ")"}]}], "=", "1"}]]],
 "\n\nHence the Cauchy-Riemann equations hold at the point ",
 StyleBox["(0,0)",
  FontFamily->"Courier New"],
 ". "
}], "Text"],

Cell[TextData[{
 "\tWe now show that ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " is not differentiable at ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 ".  Letting ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " approach ",
 StyleBox["0",
  FontFamily->"Courier New"],
 " along the x axis gives \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", ",", "0"}], ")"}], "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", ",", "0"}], ")"}]}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"0", "\[ImaginaryI]"}]}], ")"}]}], "-", 
       RowBox[{"f", 
        RowBox[{"(", "0", ")"}]}]}], 
      RowBox[{"x", "+", 
       RowBox[{"0", "\[ImaginaryI]"}], "-", "0"}]]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", ",", "0"}], ")"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{"0", ",", "0"}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["x", "3"], "-", "0"}], 
         RowBox[{" ", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", "0"}]}]], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         FractionBox[
          RowBox[{"0", "-", "0"}], 
          RowBox[{
           SuperscriptBox["x", "2"], "+", "0"}]]}], "-", "0"}], "x"]}], " ", 
     "=", " ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", ",", "0"}], ")"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{"0", ",", "0"}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{
        FractionBox[
         SuperscriptBox["x", "3"], 
         RowBox[{" ", 
          SuperscriptBox["x", "2"]}]], "+", 
        RowBox[{"0", "\[ImaginaryI]"}], "-", "0"}], "x"]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                                     ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", ",", "0"}], ")"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{"0", ",", "0"}], ")"}]}]], " ", 
      FractionBox["x", "x"]}], "  ", "=", "  ", "1"}]}]}]}]],
 "  \n\nBut if we let ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " approach ",
 StyleBox["0",
  FontFamily->"Courier New"],
 " along the line  ",
 Cell[BoxData[
  RowBox[{"y", "=", "x"}]]],
 "  given by the parametric equations  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"t", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "y"}], "=", "t"}]}]]],
 ",  then  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"t", ",", "t"}], ")"}], "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", ",", "0"}], ")"}]}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", 
         RowBox[{"t", "+", 
          RowBox[{"\[ImaginaryI]", " ", "t"}]}], ")"}]}], "-", 
       RowBox[{"f", 
        RowBox[{"(", "0", ")"}]}]}], 
      RowBox[{"t", "+", 
       RowBox[{"\[ImaginaryI]", " ", "t"}], "-", "0"}]]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"t", ",", "t"}], ")"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{"0", ",", "0"}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["t", "3"], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["t", "3"]}]}], 
         RowBox[{" ", 
          RowBox[{
           SuperscriptBox["t", "2"], "+", 
           SuperscriptBox["t", "2"]}]}]], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         FractionBox[
          RowBox[{
           SuperscriptBox["t", "3"], "-", 
           RowBox[{"3", 
            SuperscriptBox["t", "3"]}]}], 
          RowBox[{
           SuperscriptBox["t", "2"], "+", 
           SuperscriptBox["t", "2"]}]]}], "-", "0"}], 
       RowBox[{"t", "+", 
        RowBox[{"\[ImaginaryI]", " ", "t"}]}]]}], " ", "=", " ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"t", ",", "t"}], ")"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{"0", ",", "0"}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SuperscriptBox["t", "3"]}], 
         RowBox[{" ", 
          RowBox[{"2", " ", 
           SuperscriptBox["t", "2"]}]}]], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         FractionBox[
          RowBox[{
           RowBox[{"-", "2"}], 
           SuperscriptBox["t", "3"]}], 
          RowBox[{"2", 
           SuperscriptBox["t", "2"]}]]}]}], 
       RowBox[{"t", "+", 
        RowBox[{"\[ImaginaryI]", " ", "t"}]}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                                     ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"t", ",", "t"}], ")"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{"0", ",", "0"}], ")"}]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "t"}], "-", 
        RowBox[{"\[ImaginaryI]", " ", "t"}]}], 
       RowBox[{"t", "+", 
        RowBox[{"\[ImaginaryI]", " ", "t"}]}]]}], "  ", "=", "  ", 
     RowBox[{"-", " ", "1"}]}]}]}]}]],
 "  \n\nThe two limits are distinct, so ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " is not differentiable at the origin. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"3.6", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506703824078125*^9, 3.506703824078125*^9}},
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"0", ",", "0"}], "]"}], "=", "0"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     FractionBox[
      RowBox[{
       SuperscriptBox["x", "3"], "-", 
       RowBox[{"3", " ", "x", " ", 
        SuperscriptBox["y", "2"]}]}], 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"]}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"0", ",", "0"}], "]"}], "=", "0"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     FractionBox[
      RowBox[{
       SuperscriptBox["y", "3"], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["x", "2"], " ", "y"}]}], 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"]}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"0", ",", "0"}], "]"}], "=", "0"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  f[z] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Ux0", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"u", "[", 
          RowBox[{"x", ",", "0"}], "]"}], "-", 
         RowBox[{"u", "[", 
          RowBox[{"0", ",", "0"}], "]"}]}], 
        RowBox[{"x", "-", "0"}]], ",", " ", 
       RowBox[{"x", "\[Rule]", "0"}], ",", " ", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vy0", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"v", "[", 
          RowBox[{"0", ",", "y"}], "]"}], "-", 
         RowBox[{"v", "[", 
          RowBox[{"0", ",", "0"}], "]"}]}], 
        RowBox[{"y", "-", "0"}]], ",", " ", 
       RowBox[{"y", "\[Rule]", "0"}], ",", " ", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Uy0", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"u", "[", 
          RowBox[{"0", ",", "y"}], "]"}], "-", 
         RowBox[{"u", "[", 
          RowBox[{"0", ",", "0"}], "]"}]}], 
        RowBox[{"y", "-", "0"}]], ",", " ", 
       RowBox[{"y", "\[Rule]", "0"}], ",", " ", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vx0", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"v", "[", 
          RowBox[{"x", ",", "0"}], "]"}], "-", 
         RowBox[{"v", "[", 
          RowBox[{"0", ",", "0"}], "]"}]}], 
        RowBox[{"x", "-", "0"}]], ",", " ", 
       RowBox[{"x", "\[Rule]", "0"}], ",", " ", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(x\)]\)[0,0] = \>\"", ",", "Ux0"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(y\)]\)[0,0] = \>\"", ",", "Uy0"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(x\)]\)[0,0] = \>\"", ",", "Vx0"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(y\)]\)[0,0] = \>\"", ",", "Vy0"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(u\), \(x\)]\)[0,0] =  \
\!\(\*SubscriptBox[\(v\), \(y\)]\)[0,0] ?    \>\"", ",", 
      RowBox[{"Ux0", "\[Equal]", "Vy0"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(u\), \(y\)]\)[0,0] = \
-\!\(\*SubscriptBox[\(v\), \(x\)]\)[0,0] ?    \>\"", ",", 
      RowBox[{"Uy0", "\[Equal]", 
       RowBox[{"-", "Vx0"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39902026365625*^9}],

Cell["Thus the Cauchy-Riemann equations hold at the origin.  ", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  f[z] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"limit1", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"x", ",", "0"}], "]"}], "-", 
         RowBox[{"f", "[", 
          RowBox[{"0", ",", "0"}], "]"}]}], 
        RowBox[{"x", "-", "0"}]], ",", " ", 
       RowBox[{"x", "\[Rule]", "0"}], ",", " ", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"limit2", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"t", ",", "t"}], "]"}], "-", 
         RowBox[{"f", "[", 
          RowBox[{"0", ",", "0"}], "]"}]}], 
        RowBox[{"t", "+", 
         RowBox[{"\[ImaginaryI]", " ", "t"}], "-", "0"}]], ",", " ", 
       RowBox[{"t", "\[Rule]", "0"}], ",", " ", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\((x, 0)\) \[Rule] \((0, 0)\)\)]\) \
\!\(\*FractionBox[\(f \((x + 0  \[ImaginaryI])\) - f \((0)\)\), \(x + 0  \
\[ImaginaryI] - 0\)]\) = \>\"", ",", 
      "\"\<\!\(\*UnderscriptBox[\(lim\), \(\((x, 0)\) \[Rule] \((0, 0)\)\)]\) \
\!\(\*FractionBox[\(\*SuperscriptBox[\(x\), \(3\)] - 0\), \(\*SuperscriptBox[\
\(x\), \(2\)] + 0\)]\)+\!\(\*FractionBox[\(\[ImaginaryI]\\\ \((0)\)\), \
\(\*SuperscriptBox[\(x\), \(2\)] + 0\)]\) = \>\"", ",", "limit1"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\((t, t)\) \[Rule] \((0, 0)\)\)]\) \
\!\(\*FractionBox[\(f \((t + \[ImaginaryI]\\\ t)\) - f \((0)\)\), \(t + \
\[ImaginaryI]\\\ t - 0\)]\) = \>\"", ",", 
      "\"\<\!\(\*UnderscriptBox[\(lim\), \(\((t, t)\) \[Rule] \((0, 0)\)\)]\) \
\!\(\*FractionBox[\(\*SuperscriptBox[\(t\), \(3\)] - \*SuperscriptBox[\(t\), \
\(3\)]\), \(\*SuperscriptBox[\(t\), \(2\)] + \*SuperscriptBox[\(t\), \
\(2\)]\)]\)+\!\(\*FractionBox[\(\[ImaginaryI]\\\ \
\((\(-\*SuperscriptBox[\(t\), \(3\)]\) + \*SuperscriptBox[\(t\), \(3\)])\)\), \
\(\*SuperscriptBox[\(t\), \(2\)] + \*SuperscriptBox[\(t\), \(2\)]\)]\) = \
\>\"", ",", "limit2"}], "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399020268859375*^9, 3.3990202710625*^9}}],

Cell[TextData[{
 "The two limits are distinct, so ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " is not differentiable at the origin. \n\nWe are done!"
}], "Text"],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can also explore another solution.\n\nEnter the function f[z]."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "u", ",", "Ux", ",", "Ux0", ",", "Uy", ",", "Uy0", ",", "v", 
      ",", "Vx", ",", "Vx0", ",", "Vy", ",", "Vy0", ",", "w", ",", "x", ",", 
      "y"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Im", "[", "x", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Im", "[", "y", "]"}], ",", "0"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"x", ",", 
      RowBox[{"Re", "[", "x", "]"}], ",", "x"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"TagSet", "[", 
     RowBox[{"y", ",", 
      RowBox[{"Re", "[", "y", "]"}], ",", "y"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"Conjugate", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "2"], 
      RowBox[{"x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", "w"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"w", ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", "w"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020274484375*^9}],

Cell["Find the real and imaginary parts of  f[z].", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", "w", "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", "w", "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"0", ",", "0"}], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"0", ",", "0"}], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"0", ",", "0"}], "]"}], " ", "=", " ", "0"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<  f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  f[z] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020278609375*^9},
 AspectRatioFixed->True],

Cell["Determine where the Cauchy-Riemann equations hold.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Ux", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Uy", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vx", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vy", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] = \>\"", ",", "Ux"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] = \>\"", ",", "Uy"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y] = \>\"", ",", "Vx"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(y\)]\)[x,y] = \>\"", ",", "Vy"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] - \!\(\*SubscriptBox[\(v\), \
\(y\)]\)[x,y] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{"Ux", "-", "Vy"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] + \!\(\*SubscriptBox[\(v\), \
\(x\)]\)[x,y] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{"Uy", "+", "Vx"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020282546875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "These equations are simultaneously zero, only when both  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["x", "2"], "-", 
       SuperscriptBox["y", "2"]}], ")"}]}], 
    RowBox[{
     SuperscriptBox["x", "2"], "+", 
     SuperscriptBox["y", "2"]}]], "=", 
   RowBox[{
    RowBox[{"0", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman"], "  ", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "8"}], " ", "x", " ", "y"}], 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"]}]]}], "=", "0"}]}]]],
 "  which appears to be only when  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "2"], "-", 
    SuperscriptBox["y", "2"]}], "=", 
   RowBox[{
    RowBox[{"0", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman"], "  ", "x", " ", "y"}], "=", "0"}]}]]],
 "  or at the origin.   But since they are not defined at the point ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"0", 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "0"}], ")"}]]],
 ", we must use limits to complete our investigation. \n\nLet's check to see \
if the Cauchy-Riemann equations hold at ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"0", 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "0"}], ")"}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Ux0", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"u", "[", 
          RowBox[{"x", ",", "0"}], "]"}], "-", 
         RowBox[{"u", "[", 
          RowBox[{"0", ",", "0"}], "]"}]}], 
        RowBox[{"x", "-", "0"}]], ",", " ", 
       RowBox[{"x", "\[Rule]", "0"}], ",", " ", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vy0", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"v", "[", 
          RowBox[{"0", ",", "y"}], "]"}], "-", 
         RowBox[{"v", "[", 
          RowBox[{"0", ",", "0"}], "]"}]}], 
        RowBox[{"y", "-", "0"}]], ",", " ", 
       RowBox[{"y", "\[Rule]", "0"}], ",", " ", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Uy0", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"u", "[", 
          RowBox[{"0", ",", "y"}], "]"}], "-", 
         RowBox[{"u", "[", 
          RowBox[{"0", ",", "0"}], "]"}]}], 
        RowBox[{"y", "-", "0"}]], ",", " ", 
       RowBox[{"y", "\[Rule]", "0"}], ",", " ", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vx0", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"v", "[", 
          RowBox[{"x", ",", "0"}], "]"}], "-", 
         RowBox[{"v", "[", 
          RowBox[{"0", ",", "0"}], "]"}]}], 
        RowBox[{"x", "-", "0"}]], ",", " ", 
       RowBox[{"x", "\[Rule]", "0"}], ",", " ", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(x\)]\)[0,0] = \>\"", ",", "Ux0"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(y\)]\)[0,0] = \>\"", ",", "Uy0"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(x\)]\)[0,0] = \>\"", ",", "Vx0"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(y\)]\)[0,0] = \>\"", ",", "Vy0"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(u\), \(x\)]\)[0,0] =  \
\!\(\*SubscriptBox[\(v\), \(y\)]\)[0,0] ?    \>\"", ",", 
      RowBox[{"Ux0", "\[Equal]", "Vy0"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(u\), \(y\)]\)[0,0] = \
-\!\(\*SubscriptBox[\(v\), \(x\)]\)[0,0] ?    \>\"", ",", 
      RowBox[{"Uy0", "\[Equal]", 
       RowBox[{"-", "Vx0"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020286609375*^9}],

Cell[TextData[{
 "We have shown that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "x"], 
    RowBox[{"(", 
     RowBox[{"0", ",", "0"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["v", "y"], 
     RowBox[{"(", 
      RowBox[{"0", ",", "0"}], ")"}], "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman"], "  ", 
     SubscriptBox["u", "y"], 
     RowBox[{"(", 
      RowBox[{"0", ",", "0"}], ")"}]}], "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["v", "x"]}], 
     RowBox[{"(", 
      RowBox[{"0", ",", "0"}], ")"}]}]}]}]]],
 ", that is, the Cauchy-Riemann equations do hold at the origin. \n\nBut,  \
f(z)  is ",
 StyleBox["not ",
  FontColor->RGBColor[1, 0, 1]],
 "differentiable at ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"0", 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "0"}], ")"}]]],
 " because the following two limits are distinct."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dfdx", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"x", ",", "0"}], "]"}], "-", 
         RowBox[{"f", "[", 
          RowBox[{"0", ",", "0"}], "]"}]}], "x"], ",", 
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"dfdt", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"t", ",", "t"}], "]"}], "-", 
         RowBox[{"f", "[", 
          RowBox[{"0", ",", "0"}], "]"}]}], 
        RowBox[{"t", "+", 
         RowBox[{"\[ImaginaryI]", " ", "t"}]}]], ",", 
       RowBox[{"t", "\[Rule]", "0"}], ",", 
       RowBox[{"Analytic", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Along  the  x-axis we have\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(x \[Rule] 0\)]\) \!\(\*FractionBox[\
\(df\), \(dx\)]\) = \!\(\*UnderscriptBox[\(lim\), \(x \[Rule] 0\)]\) \
\!\(\*FractionBox[\(f[x, 0] - f[0, 0]\), \(x\)]\)\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(x \[Rule] 0\)]\) \!\(\*FractionBox[\
\(df\), \(dx\)]\) = \!\(\*UnderscriptBox[\(lim\), \(x \[Rule] 0\)]\) (\>\"", 
      ",", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "0"}], "]"}], "-", 
       RowBox[{"f", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}], ",", "\"\<)/(\>\"", ",", "x", ",", 
      "\"\<)\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(x \[Rule] 0\)]\) \!\(\*FractionBox[\
\(df\), \(dx\)]\) = \!\(\*UnderscriptBox[\(lim\), \(x \[Rule] 0\)]\) (\>\"", 
      ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"x", ",", "0"}], "]"}], "-", 
         RowBox[{"f", "[", 
          RowBox[{"0", ",", "0"}], "]"}]}], ")"}], "/", "x"}], ",", 
      "\"\<)\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(x \[Rule] 0\)]\) \!\(\*FractionBox[\
\(df\), \(dx\)]\) = \>\"", ",", "dfdx"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Along the line y=t, y=t we have\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(t \[Rule] 0\)]\) \!\(\*FractionBox[\
\(df\), \(dt\)]\) = \!\(\*UnderscriptBox[\(lim\), \(t \[Rule] 0\)]\) \
\!\(\*FractionBox[\(f[t, t] - f[0, 0]\), \(t + \[ImaginaryI]\\\ t\)]\)\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(t \[Rule] 0\)]\) \!\(\*FractionBox[\
\(df\), \(dt\)]\) = \!\(\*UnderscriptBox[\(lim\), \(t \[Rule] 0\)]\) (\>\"", 
      ",", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"t", ",", "t"}], "]"}], "-", 
       RowBox[{"f", "[", 
        RowBox[{"0", ",", "0"}], "]"}]}], ",", "\"\<)/(\>\"", ",", 
      RowBox[{"t", "+", 
       RowBox[{"\[ImaginaryI]", " ", "t"}]}], ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(t \[Rule] 0\)]\) \!\(\*FractionBox[\
\(df\), \(dt\)]\) = \!\(\*UnderscriptBox[\(lim\), \(t \[Rule] 0\)]\) (\>\"", 
      ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"t", ",", "t"}], "]"}], "-", 
         RowBox[{"f", "[", 
          RowBox[{"0", ",", "0"}], "]"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"t", "+", 
         RowBox[{"\[ImaginaryI]", " ", "t"}]}], ")"}]}], ",", "\"\<)\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(t \[Rule] 0\)]\) \!\(\*FractionBox[\
\(df\), \(dt\)]\) = \>\"", ",", "dfdt"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020290859375*^9}],

Cell[TextData[{
 "The two limits are distinct, so w",
 "e have shown that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", " ", 
      OverscriptBox[
       RowBox[{"z", " "}], "_"], " ", ")"}], "2"], "z"]}]]],
 "  is not differentiable at the point ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 " even though the Cauchy-Riemann equations are satisfied at ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"0", 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "0"}], ")"}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[TextData[{
 "\tExample 3.6 reiterates that the mere satisfaction of the Cauchy-Riemann \
equations is not sufficient to guarantee the differentiability of a function. \
 The following theorem, however, gives conditions that guarantee the \
differentiability of f at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", so that which we can use Equation ",
 StyleBox["(3-14)",
  FontColor->RGBColor[0, 0, 1]],
 " or ",
 StyleBox["(3-15)",
  FontColor->RGBColor[0, 0, 1]],
 " to compute  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 ".  They are referred to as the Cauchy-Riemann conditions for \
differentiability."
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 3.4 (Cauchy-Riemann conditions for differentiability).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", 
      RowBox[{"x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "=", 
    RowBox[{
     RowBox[{"u", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "v", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}]}]}]]],
 "  be a continuous function that is defined in some neighborhood of the \
point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{
    SubscriptBox["x", "0"], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["y", "0"]}]}]}]]],
 ". If all the partial derivatives ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["u", "x"], ",", 
   SubscriptBox["u", "y"], ",", 
   RowBox[{
    SubscriptBox["v", "x"], " ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", 
    SubscriptBox["v", "y"]}]}]]],
 " are continuous at the point",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["x", "0"], ",", 
    SubscriptBox["y", "0"]}], ")"}]]],
 " and if the Cauchy-Riemann equations ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "x"], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "0"], ",", 
      SubscriptBox["y", "0"]}], ")"}]}], "=", 
   RowBox[{
    SubscriptBox["v", "y"], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "0"], ",", 
      SubscriptBox["y", "0"]}], ")"}]}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "y"], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "0"], ",", 
      SubscriptBox["y", "0"]}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["v", "x"]}], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "0"], ",", 
      SubscriptBox["y", "0"]}], ")"}]}]}]]],
 " hold at ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["x", "0"], ",", 
    SubscriptBox["y", "0"]}], ")"}]]],
 ", then  f(z)  is differentiable at  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " and the derivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 "can be computed with either formula ",
 StyleBox["(3-14)",
  FontColor->RGBColor[0, 0, 1]],
 " or ",
 StyleBox["(3-15)",
  FontColor->RGBColor[0, 0, 1]],
 ",  i.e.\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["u", "x"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "0"], ",", 
       SubscriptBox["y", "0"]}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["v", "x"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "0"], ",", 
       SubscriptBox["y", "0"]}], ")"}]}]}]}]]],
 ",  or  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["v", "y"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "0"], ",", 
       SubscriptBox["y", "0"]}], ")"}]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["u", "y"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "0"], ",", 
       SubscriptBox["y", "0"]}], ")"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 3.4 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
 StyleBox["Example 3.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  At the beginning of this section (Equation ",
 StyleBox["(3-13)",
  FontColor->RGBColor[0, 0, 1]],
 ") we defined the function  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"u", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "v", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["x", "3"], "-", 
     RowBox[{"3", " ", "x", " ", 
      SuperscriptBox["y", "2"]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["x", "2"], " ", "y"}], "-", 
        SuperscriptBox["y", "3"]}], ")"}]}]}]}]}]]],
 ".   \n\nShow that this function is differentiable for all ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ", and find its derivative."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We compute  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "x"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"3", 
      SuperscriptBox["x", "3"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["y", "2"]}]}], " ", "=", " ", 
    RowBox[{
     SubscriptBox["v", "y"], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "y"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", " ", "6"}], " ", "x", " ", "y"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"-", " ", 
      SubscriptBox["v", "x"]}], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}]}]]],
 ",  so the Cauchy-Riemann Equations ",
 StyleBox["(3-16)",
  FontColor->RGBColor[0, 0, 1]],
 ", are satisfied.  Moreover,  ",
 Cell[BoxData[
  RowBox[{"u", ",", "v", ",", 
   SubscriptBox["u", "x"], ",", 
   SubscriptBox["u", "y"], ",", 
   RowBox[{
    SubscriptBox["v", "x"], " ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", 
    SubscriptBox["v", "y"]}]}]]],
 "  are continuous everywhere.  By Theorem 3.4, ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " is differentiable everywhere, and, from Equation ",
 StyleBox["(3-14)",
  FontColor->RGBColor[0, 0, 1]],
 ",  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["u", "x"], 
       RowBox[{"(", 
        RowBox[{"x", ",", "y"}], ")"}]}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["v", "x"], 
       RowBox[{"(", 
        RowBox[{"x", ",", "y"}], ")"}]}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"3", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["y", "2"]}], "  ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "6", " ", "x", " ", "y"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["y", "2"], "+", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "x", " ", "y"}]}], ")"}]}], 
     "  ", "=", "  ", 
     RowBox[{
      RowBox[{"3", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "   ", "=", 
      "  ", 
      RowBox[{"3", 
       SuperscriptBox["z", "2"]}]}]}]}]}]}],
  AspectRatioFixed->True],
 "  \n\nAlternatively, from Equation ",
 StyleBox["(3-15)",
  FontColor->RGBColor[0, 0, 1]],
 ",\n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["v", "y"], 
       RowBox[{"(", 
        RowBox[{"x", ",", "y"}], ")"}]}], " ", "-", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["u", "y"], 
       RowBox[{"(", 
        RowBox[{"x", ",", "y"}], ")"}]}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"3", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["y", "2"]}], "  ", "-", " ", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", " ", "6"}], " ", "x", " ", "y"}], ")"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["y", "2"], "+", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "x", " ", "y"}]}], ")"}]}], 
     "  ", "=", "  ", 
     RowBox[{
      RowBox[{"3", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "   ", "=", 
      "  ", 
      RowBox[{"3", 
       SuperscriptBox["z", "2"]}]}]}]}]}]}],
  AspectRatioFixed->True],
 "  \n\nThis result isn't surprising because  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"x", "+", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["x", "3"], "-", 
    RowBox[{"3", " ", "x", " ", 
     SuperscriptBox["y", "2"]}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["x", "2"], " ", "y"}], "-", 
       SuperscriptBox["y", "3"]}], ")"}]}]}]}]]],
 "  and so the function ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " is really our old friend  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", "3"]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"3.7", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506703829125*^9, 3.506703829125*^9}},
 AspectRatioFixed->False],

Cell["Enter the function f[z] and determine u[x,y] and v[x,y].", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "x", ",", "y", ",", "u", ",", "v", ",", "w", ",", "w1", ",", 
      "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["z", "3"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  f[z] = \>\"", ",", "w"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<  f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39902030296875*^9}],

Cell["Verify that the Cauchy-Riemann equations hold.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Does \!\(\*SubscriptBox[\(\[PartialD]\), \(x\)]\) u[x,y] = \
\!\(\*SubscriptBox[\(\[PartialD]\), \(y\)]\) v[x,y] ?\>\"", "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Does \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ",", "\"\< = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ",", "\"\< ?  \>\"", ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], " ", 
        RowBox[{"u", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], "\[Equal]", 
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Does \!\(\*SubscriptBox[\(\[PartialD]\), \(y\)]\) u[x,y] = \
-\!\(\*SubscriptBox[\(\[PartialD]\), \(x\)]\) v[x,y] ?\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Does \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ",", "\"\< = \>\"", ",", 
      RowBox[{"-", 
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}], ",", "\"\< ?  \>\"", ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], " ", 
        RowBox[{"u", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], "\[Equal]", 
       RowBox[{"-", 
        RowBox[{
         SubscriptBox["\[PartialD]", "x"], " ", 
         RowBox[{"v", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020307125*^9}],

Cell[TextData[{
 "We see that the Cauchy-Riemann equations hold.\n\nVerify that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], "[", "z", "]"}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["u", "x"], "[", 
     RowBox[{"x", ",", "y"}], "]"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{
      SubscriptBox["v", "x"], "[", 
      RowBox[{"x", ",", "y"}], "]"}]}]}]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"w1", " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "  ", "+", "  ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f'[z] = \!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] + \[ImaginaryI] \
\!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y]\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = (\>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ",", "\"\<) + \[ImaginaryI](\>\"", 
      ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ",", "\"\<)\>\""}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", "w1"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020312234375*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Given  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", "  ", 
   RowBox[{
    SuperscriptBox["x", "6"], "-", 
    RowBox[{"15", " ", 
     SuperscriptBox["x", "4"], " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{"15", " ", 
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["y", "4"]}], "-", 
    SuperscriptBox["y", "6"], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", 
        SuperscriptBox["x", "5"], " ", "y"}], "-", 
       RowBox[{"20", " ", 
        SuperscriptBox["x", "3"], " ", 
        SuperscriptBox["y", "3"]}], "+", 
       RowBox[{"6", " ", "x", " ", 
        SuperscriptBox["y", "5"]}]}], ")"}]}]}]}]]],
 ".   \n\nShow that this function is differentiable for all ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ", and find its derivative."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "1."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.50670383196875*^9, 3.506703831984375*^9}},
 AspectRatioFixed->False],

Cell["Enter the function f[z] and determine u[x,y] and v[x,y].", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "x", ",", "y", ",", "u", ",", "v", ",", "w", ",", "w1", ",", 
      "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["z", "6"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  f[z] = \>\"", ",", "w"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<  f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020318828125*^9}],

Cell["Verify that the Cauchy-Riemann equations hold.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Does \!\(\*SubscriptBox[\(\[PartialD]\), \(x\)]\) u[x,y] = \
\!\(\*SubscriptBox[\(\[PartialD]\), \(y\)]\) v[x,y] ?\>\"", "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Does \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ",", "\"\< = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ",", "\"\< ?  \>\"", ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], " ", 
        RowBox[{"u", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], "\[Equal]", 
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Does \!\(\*SubscriptBox[\(\[PartialD]\), \(y\)]\) u[x,y] = \
-\!\(\*SubscriptBox[\(\[PartialD]\), \(x\)]\) v[x,y] ?\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Does \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ",", "\"\< = \>\"", ",", 
      RowBox[{"-", 
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}], ",", "\"\< ?  \>\"", ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], " ", 
        RowBox[{"u", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], "\[Equal]", 
       RowBox[{"-", 
        RowBox[{
         SubscriptBox["\[PartialD]", "x"], " ", 
         RowBox[{"v", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020323640625*^9}],

Cell[TextData[{
 "We see that the Cauchy-Riemann equations hold.\n\nVerify that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], "[", "z", "]"}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["u", "x"], "[", 
     RowBox[{"x", ",", "y"}], "]"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{
      SubscriptBox["v", "x"], "[", 
      RowBox[{"x", ",", "y"}], "]"}]}]}]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"w1", " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "  ", "+", "  ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f'[z] = \!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] + \[ImaginaryI] \
\!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y]\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = (\>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ",", "\"\<) + \[ImaginaryI](\>\"", 
      ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ",", "\"\<)\>\""}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", "w1"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3990203274375*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 3.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", 
      RowBox[{"x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "y"}]], " ", "cos", " ", "x"}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "y"}]], " ", "sin", " ", "x"}]}]}]}]]],
 "  is differentiable for all ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"x", "+", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]]],
 " and find its derivative."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We first write  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "y"}]], " ", "cos", " ", "x", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "v", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "y"}]], " ", "sin", " ", "x"}]}]}]]],
 "  and then compute the partial derivatives. \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "x"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["v", "y"], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " "}]}]]],
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", "y"}]]}], " ", "sin", " ", "x"}]]],
 ",   and \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["v", "x"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", " ", 
      SubscriptBox["u", "y"]}], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "y"}]], " ", "cos", " ", "x"}]}]}]]],
 ".  \n\nWe note that  ",
 Cell[BoxData[
  RowBox[{"u", ",", "v", ",", 
   SubscriptBox["u", "x"], ",", 
   SubscriptBox["u", "y"], ",", 
   RowBox[{
    SubscriptBox["v", "x"], " ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", 
    SubscriptBox["v", "y"]}]}]]],
 "  are continuous functions and that the Cauchy-Riemann equations hold for \
all values of ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"x", ",", "y"}], ")"}]]],
 ".  Hence, using Equation ",
 StyleBox["(3-14)",
  FontColor->RGBColor[0, 0, 1]],
 ", we write  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["u", "x"], 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["v", "x"], 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "y"}]]}], " ", "sin", " ", "x"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "y"}]], " ", "cos", " ", "x"}]}]}]}]]],
 ". \n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  Can you guess the \"complex\" form of  ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 "  ?"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"3.8", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506703835953125*^9, 3.506703835953125*^9}},
 AspectRatioFixed->False],

Cell["\<\
Enter the function f[z] and determine if the Cauchy-Riemann equations hold.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "u", ",", "Ux", ",", "Uy", ",", "v", ",", "Vx", ",", "Vy", ",",
       "w1", ",", "x", ",", "y", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "y"}]], " ", 
      RowBox[{"Cos", "[", "x", "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "y"}]], 
      RowBox[{"Sin", "[", "x", "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Ux", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Uy", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vx", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vy", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   f[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<   f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< v[x,y] = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] = \>\"", ",", "Ux"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] = \>\"", ",", "Uy"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y] = \>\"", ",", "Vx"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(y\)]\)[x,y] = \>\"", ",", "Vy"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] =  \
\!\(\*SubscriptBox[\(v\), \(y\)]\)[x,y] ?    \>\"", ",", 
      RowBox[{"Ux", "\[Equal]", "Vy"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] = \
-\!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y] ?    \>\"", ",", 
      RowBox[{"Uy", "\[Equal]", 
       RowBox[{"-", "Vx"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3990203345625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "The Cauchy-Riemann equations hold everywhere, so that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "y"}]], " ", "cos", 
     RowBox[{"(", "x", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "y"}]], " ", "sin", 
     RowBox[{"(", "x", ")"}]}]}]}]]],
 " is analytic for all values of  z."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] =  f[x + \[ImaginaryI] y] = \>\"", ",", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f'[z] = f'[x + \[ImaginaryI] y] = \
\!\(\*SubscriptBox[\(\[PartialD]\), \(x\)]\) u[x,y] + \[ImaginaryI] \
\!\(\*SubscriptBox[\(\[PartialD]\), \(x\)]\) v[x,y]\>\"", " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = f'[x + \[ImaginaryI] y] = \>\"", ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], " ", 
        RowBox[{"u", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", "x"], " ", 
         RowBox[{"v", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020338765625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can write this function as  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "z"}]], "=", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]], "=", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "y"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "x"}]}]]}]}]}]]],
 ",  and investigate  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"w1", " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "  ", "+", "  ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[x+\[ImaginaryI]y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[x+\[ImaginaryI]y] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\< f[x+\[ImaginaryI]y] = u[x,y] + \[ImaginaryI] v[x,y]\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[x+\[ImaginaryI]y] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[x+\[ImaginaryI]y] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f'[x+\[ImaginaryI]y] = \!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y]+ \
\[ImaginaryI] \!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y]\>\"", "]"}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[x+\[ImaginaryI]y] = \>\"", ",", "w1"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020342671875*^9}],

Cell[TextData[{
 "We have shown that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "z"}]], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "y"}], "+", "\[ImaginaryI]x"}]], " ", "=", " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "y"}]], " ", "cos", " ", "x"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "y"}]], " ", "sin", " ", "x"}]}]}]}]}]}]]],
 " is differentiable and hence analytic for all ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ".\n\n",
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "z"}]], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "y"}]], " ", "cos", " ", "x"}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "y"}]], " ", "sin", " ", "x"}]}]}]}]]],
 "  is an entire function."
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       SuperscriptBox["x", "2"], "-", 
       SuperscriptBox["y", "2"]}]], " ", "cos", 
     RowBox[{"(", 
      RowBox[{"2", " ", "x", " ", "y"}], ")"}]}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       SuperscriptBox["x", "2"], "-", 
       SuperscriptBox["y", "2"]}]], " ", "sin", 
     RowBox[{"(", 
      RowBox[{"2", " ", "x", " ", "y"}], ")"}]}]}]}]]],
 " is differentiable for all  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"x", "+", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]]],
 "  and find its derivative."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "2."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.50670383778125*^9, 3.50670383778125*^9}},
 AspectRatioFixed->False],

Cell["\<\
Enter the function f[z] and determine if the Cauchy-Riemann equations hold.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "u", ",", "Ux", ",", "Uy", ",", "v", ",", "Vx", ",", "Vy", ",",
       "w1", ",", "x", ",", "y", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["y", "2"]}]], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", "x", " ", "y"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["y", "2"]}]], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"2", " ", "x", " ", "y"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Ux", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Uy", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vx", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vy", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   f[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<   f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< v[x,y] = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] = \>\"", ",", "Ux"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] = \>\"", ",", "Uy"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y] = \>\"", ",", "Vx"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(y\)]\)[x,y] = \>\"", ",", "Vy"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] =  \
\!\(\*SubscriptBox[\(v\), \(y\)]\)[x,y] ?    \>\"", ",", 
      RowBox[{"Ux", "\[Equal]", "Vy"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] = \
-\!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y] ?    \>\"", ",", 
      RowBox[{"Uy", "\[Equal]", 
       RowBox[{"-", "Vx"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020352390625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "The Cauchy-Riemann equations hold everywhere, so that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       SuperscriptBox["x", "2"], "-", 
       SuperscriptBox["y", "2"]}]], " ", "cos", 
     RowBox[{"(", 
      RowBox[{"2", " ", "x", " ", "y"}], ")"}]}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       SuperscriptBox["x", "2"], "-", 
       SuperscriptBox["y", "2"]}]], " ", "sin", 
     RowBox[{"(", 
      RowBox[{"2", " ", "x", " ", "y"}], ")"}]}]}]}]]],
 " is analytic for all values of  z."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] =  f[x + \[ImaginaryI] y] = \>\"", ",", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = f'[x + \[ImaginaryI] y] = \>\"", ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], " ", 
        RowBox[{"u", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", "x"], " ", 
         RowBox[{"v", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3990203564375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can write this function as  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     SuperscriptBox["z", "2"]], "=", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]], "=", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       SuperscriptBox["x", "2"], "-", 
       SuperscriptBox["y", "2"], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "x", " ", "y"}]}]]}]}]}]]],
 ",  and investigate  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", 
      SuperscriptBox["z", "2"]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"w1", " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "  ", "+", "  ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[x+\[ImaginaryI]y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[x+\[ImaginaryI]y] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\< f[x+\[ImaginaryI]y] = u[x,y] + \[ImaginaryI] v[x,y]\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[x+\[ImaginaryI]y] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[x+\[ImaginaryI]y] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f'[x+\[ImaginaryI]y] = \!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y]+ \
\[ImaginaryI] \!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y]\>\"", "]"}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[x+\[ImaginaryI]y] = \>\"", ",", "w1"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399020359765625*^9}],

Cell[TextData[{
 "We have shown that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       SuperscriptBox["x", "2"], "-", 
       SuperscriptBox["y", "2"]}]], " ", "cos", 
     RowBox[{"(", 
      RowBox[{"2", " ", "x", " ", "y"}], ")"}]}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       SuperscriptBox["x", "2"], "-", 
       SuperscriptBox["y", "2"]}]], " ", "sin", 
     RowBox[{"(", 
      RowBox[{"2", " ", "x", " ", "y"}], ")"}]}]}]}]]],
 " is differentiable and hence analytic for all ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ".\n\n",
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     SuperscriptBox["z", "2"]], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["y", "2"]}]], " ", "cos", 
      RowBox[{"(", 
       RowBox[{"2", " ", "x", " ", "y"}], ")"}]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["y", "2"]}]], " ", "sin", 
      RowBox[{"(", 
       RowBox[{"2", " ", "x", " ", "y"}], ")"}]}]}]}]}]]],
 " is an entire function."
}], "Text"]
}, Closed]],

Cell["\<\
\tThe Cauchy-Riemann conditions are particularly useful in determining the \
set of points for which a function f is differentiable.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Example 3.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["x", "3"], "+", 
    RowBox[{"3", " ", "x", " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["x", "2"], " ", "y"}], "+", 
       SuperscriptBox["y", "3"]}], ")"}]}]}]}]]],
 "  is differentiable at points that lie on the ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["y",
  FontFamily->"Courier New"],
 " axes but analytic nowhere."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  Recall (Definition 3.1) that when we say a function is analytic \
at a point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " we mean that the function is differentiable not only at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", but also at every point in some  neighborhood of ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  With this in mind, we proceed to determine where the Cauchy-Riemann \
equations are satisfied.  We write  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["x", "3"], "+", 
    RowBox[{"3", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    SuperscriptBox["y", "3"]}]}]]],
 "  and compute the partial derivatives: \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "x"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"3", 
     SuperscriptBox["x", "3"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["y", "2"]}]}]}]]],
 ",   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["v", "y"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"3", 
     SuperscriptBox["x", "3"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["y", "2"]}]}]}]]],
 ",   and  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "y"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{"6", " ", "x", " ", "y", " "}]}]]],
 ",   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["v", "x"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{"6", " ", "x", " ", "y", " "}]}]]],
 ".  \n\nHere  ",
 Cell[BoxData[
  RowBox[{"u", ",", "v", ",", 
   SubscriptBox["u", "x"], ",", " ", 
   RowBox[{
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", 
    SubscriptBox["v", "y"]}]}]]],
 "  are continuous, and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "x"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    SubscriptBox["v", "y"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}]}]]],
 "  holds for all  ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"x", ",", "y"}], ")"}]]],
 ".  But  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "y"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", " ", 
     SubscriptBox["v", "x"]}], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}]}]]],
 "  iff  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"6", " ", "x", " ", "y"}], "=", " ", 
   RowBox[{
    RowBox[{"-", " ", "6"}], " ", "x", " ", "y"}]}]]],
 ",  which is equivalent to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"12", " ", "x", " ", "y"}], "=", " ", "0"}]]],
 ".  The Cauchy-Riemann equations hold only when  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"0", "   ", 
     StyleBox["or",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "y"}], "=", " ", "0"}]}]]],
 ",  and according to Theorem 3.4, ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " is differentiable only at points that lie on the coordinate axes.  But \
this means that ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " is nowhere analytic because any ",
 Cell[BoxData["\[Epsilon]"]],
 "-neighborhood about a point on either axis contains points that are not on \
those axes."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"3.9", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.5067038423125*^9, 3.5067038423125*^9}},
 AspectRatioFixed->False],

Cell["\<\
Enter the functions u[x,y]  and  v[x,y] and use them to form  f[z].  Then \
determine where the Cauchy-Riemann equations hold.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "u", ",", "Ux", ",", "Uy", ",", "v", ",", "Vx", ",", "Vy", ",", "x", ",",
       "y"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["x", "3"], " ", "+", " ", 
      RowBox[{"3", " ", "x", " ", 
       SuperscriptBox["y", "2"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["y", "3"], " ", "+", " ", 
      RowBox[{"3", " ", 
       SuperscriptBox["x", "2"], " ", "y"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Ux", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Uy", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vx", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vy", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   f[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<   f[z] = u[x,y] + \[ImaginaryI] v[x,y]\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< v[x,y] = \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] = \>\"", ",", "Ux"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] = \>\"", ",", "Uy"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y] = \>\"", ",", "Vx"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(y\)]\)[x,y] = \>\"", ",", "Vy"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(u\), \(x\)]\)[x,y] =  \
\!\(\*SubscriptBox[\(v\), \(y\)]\)[x,y] ?      \>\"", ",", 
      RowBox[{"Ux", "\[Equal]", "Vy"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] = \
-\!\(\*SubscriptBox[\(v\), \(x\)]\)[x,y] ?      \>\"", ",", 
      RowBox[{"Uy", "\[Equal]", 
       RowBox[{"-", "Vx"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(u\), \(y\)]\)[x,y] + \!\(\*SubscriptBox[\(v\
\), \(x\)]\)[x,y] = 0 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"Uy", "+", "Vx"}], "\[Equal]", "0"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3990203673125*^9}],

Cell[TextData[{
 "The Cauchy-Riemann equations hold only if  x y = 0  which occurs along the \
coordinate axes.  Furthermore, all of the partial derivatives  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "x"], " ", 
    RowBox[{"u", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}], "=", 
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"3", 
     SuperscriptBox["y", "2"]}]}]}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "y"], " ", 
    RowBox[{"u", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}], "=", 
   RowBox[{"6", " ", "x", " ", "y"}]}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "x"], " ", 
    RowBox[{"v", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}], "=", 
   RowBox[{"6", " ", "x", " ", "y"}]}]]],
 ", and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "y"], " ", 
    RowBox[{"v", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}], "=", 
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"3", 
     SuperscriptBox["y", "2"]}]}]}]]],
 "  are continuous.  Hence,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["x", "3"], "+", 
    RowBox[{"3", " ", "x", " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["x", "2"], " ", "y"}], "+", 
       SuperscriptBox["y", "3"]}], ")"}]}]}]}]]],
 " is differentiable only when  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"0", "  ", 
     StyleBox["or",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "y"}], "=", "0"}]}]]],
 ",  which occurs at points that lie on the coordinate axes.  Therefore,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["x", "3"], "+", 
    RowBox[{"3", " ", "x", " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["x", "2"], " ", "y"}], "+", 
       SuperscriptBox["y", "3"]}], ")"}]}]}]}]]],
 "  is ",
 StyleBox["nowhere",
  FontColor->RGBColor[1, 0, 1]],
 " analytic."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tWhen polar coordinates ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"r", ",", "\[Theta]"}], ")"}]]],
 " are used to locate points in the plane, we use Expression ",
 StyleBox["(2-2)",
  FontColor->RGBColor[0, 0, 1]],
 " for a complex function for convenience;  that is, \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"       ", 
   RowBox[{
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"u", 
       RowBox[{"(", 
        RowBox[{"x", ",", "y"}], ")"}]}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "v", 
       RowBox[{"(", 
        RowBox[{"x", ",", "y"}], ")"}]}]}]}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", 
       RowBox[{"r", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ")"}]}], " ", "=", 
     "  ", 
     RowBox[{
      RowBox[{"u", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"r", " ", "cos", " ", "\[Theta]"}], ",", 
         RowBox[{"r", " ", "sin", " ", "\[Theta]"}]}], ")"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "v", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"r", " ", "cos", " ", "\[Theta]"}], ",", 
         RowBox[{"r", " ", "sin", " ", "\[Theta]"}]}], ")"}]}]}]}], 
    "\[IndentingNewLine]", "\[IndentingNewLine]", "                   ", 
    RowBox[{"=", " ", 
     RowBox[{
      RowBox[{"U", 
       RowBox[{"(", 
        RowBox[{"r", ",", "\[Theta]"}], ")"}]}], "  ", "+", "  ", 
      RowBox[{"\[ImaginaryI]", " ", "V", 
       RowBox[{"(", 
        RowBox[{"r", ",", "\[Theta]"}], ")"}]}]}]}]}]}]]],
 "  \n\nwhere  ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", 
    RowBox[{"r", ",", "\[Theta]"}], ")"}], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "V", 
   RowBox[{"(", 
    RowBox[{"r", ",", "\[Theta]"}], ")"}]}]]],
 "  are real functions of the real variables ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"r", "  ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", "\[Theta]"}]}]]],
 ".  The polar form of the Cauchy-Riemann equations and a formula for finding \
f'(z) in terms of the partial derivatives of U(r,) and V(r,) are given in \
Theorem 3.5, which we ask you to prove in Exercise 10.  This theorem makes \
use of the validity of the Cauchy-Riemann equations for the functions u and \
v, so the relation between them and the functions ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", 
    RowBox[{"r", ",", "\[Theta]"}], ")"}], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "V", 
   RowBox[{"(", 
    RowBox[{"r", ",", "\[Theta]"}], ")"}]}]]],
 "  - namely,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"r", " ", "cos", " ", "\[Theta]"}], ",", 
       RowBox[{"r", " ", "sin", " ", "\[Theta]"}]}], ")"}]}], "=", 
    RowBox[{"U", 
     RowBox[{"(", 
      RowBox[{"r", " ", ",", "\[Theta]"}], ")"}]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"v", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"r", " ", "cos", " ", "\[Theta]"}], ",", 
       RowBox[{"r", " ", "sin", " ", "\[Theta]"}]}], ")"}]}], "=", 
    RowBox[{"V", 
     RowBox[{"(", 
      RowBox[{"r", " ", ",", "\[Theta]"}], ")"}]}]}]}]]],
 "  - is important."
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 3.5  (Polar Form of the Cauchy-Riemann equations).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", 
      RowBox[{"r", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ")"}]}], "=", 
    RowBox[{
     RowBox[{"U", 
      RowBox[{"(", 
       RowBox[{"r", ",", "\[Theta]"}], ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "V", 
      RowBox[{"(", 
       RowBox[{"r", ",", "\[Theta]"}], ")"}]}]}]}]}]]],
 "  be a continuous function that is defined in some neighborhood of the \
point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{
    SubscriptBox["r", "0"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Theta]", "0"]}]]}]}]]],
 ".  If all the partial derivatives  ",
 Cell[BoxData[
  RowBox[{"U", ",", "V", ",", 
   SubscriptBox["U", "r"], ",", 
   SubscriptBox["U", "\[Theta]"], ",", 
   RowBox[{
    SubscriptBox["V", "r"], " ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", 
    SubscriptBox["V", "\[Theta]"]}]}]]],
 "  are continuous at the point ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["r", "0"], ",", 
    SubscriptBox["\[Theta]", "0"]}], ")"}]]],
 " and if the polar form of the Cauchy-Riemann equations, \n\n",
 StyleBox["(3-22)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["U", "r"], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["r", "0"], ",", 
      SubscriptBox["\[Theta]", "0"]}], ")"}]}], "=", 
   RowBox[{
    FractionBox["1", 
     SubscriptBox["r", "0"]], 
    SubscriptBox["V", "\[Theta]"], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["r", "0"], ",", 
      SubscriptBox["\[Theta]", "0"]}], ")"}]}]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["V", "r"], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["r", "0"], ",", 
      SubscriptBox["\[Theta]", "0"]}], ")"}]}], "=", 
   RowBox[{
    FractionBox[
     RowBox[{"-", "1"}], 
     SubscriptBox["r", "0"]], 
    SubscriptBox["U", "\[Theta]"], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["r", "0"], ",", 
      SubscriptBox["\[Theta]", "0"]}], ")"}]}]}]]],
 ",    \n\nholds, then ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 " is differentiable at  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", and we can compute the derivative ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 " by using either  \n\n",
 StyleBox["(3-23)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["r", "0"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Theta]", "0"]}]]}], ")"}]}], " ", "=", "   ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SubscriptBox["\[Theta]", "0"]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["U", "r"], 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["r", "0"], ",", 
          SubscriptBox["\[Theta]", "0"]}], ")"}]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["V", "r"], 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["r", "0"], ",", 
          SubscriptBox["\[Theta]", "0"]}], ")"}]}]}], ")"}]}]}]}]]],
 ",    or    \n\n",
 StyleBox["(3-24)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["r", "0"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Theta]", "0"]}]]}], ")"}]}], " ", "=", "  "}]}]]],
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    SubscriptBox["r", "0"]], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", 
     SubscriptBox["\[Theta]", "0"]}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["V", "\[Theta]"], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["r", "0"], ",", 
        SubscriptBox["\[Theta]", "0"]}], ")"}]}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["U", "\[Theta]"], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["r", "0"], ",", 
        SubscriptBox["\[Theta]", "0"]}], ")"}]}]}], ")"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 3.5 is an exercise in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 3.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that, if f is is the principal square root function given by  \n\n\t\
\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     RowBox[{"r", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ")"}]}], " ", "=", "  ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["z", 
      FractionBox["1", "2"]], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["r", 
       FractionBox["1", "2"]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"cos", 
         FractionBox["\[Theta]", "2"]}], " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "sin", 
         FractionBox["\[Theta]", "2"]}]}], ")"}]}]}]}]}]]],
 "   \n\nwhere the domain is restricted to be  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"r", " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], ":", " ", 
     RowBox[{"r", ">", 
      RowBox[{
       RowBox[{"0", "  ", 
        StyleBox["and",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}], "  ", "-", "\[Pi]"}], "<", "\[Theta]", 
      "<", "\[Pi]"}]}]}], "}"}]]],
 ",  then the derivative is given by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", 
      SuperscriptBox["z", 
       RowBox[{"1", "/", "2"}]]}]], " ", "=", " ", 
    RowBox[{
     FractionBox["1", "2"], 
     SuperscriptBox["r", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", 
        FractionBox["\[Theta]", "2"]}], " ", "-", " ", 
       RowBox[{"\[ImaginaryI]", " ", "sin", 
        FractionBox["\[Theta]", "2"]}]}], ")"}]}]}]}]]],
 "  \n\nfor every point in the domain  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"r", " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], ":", " ", 
     RowBox[{"r", ">", 
      RowBox[{
       RowBox[{"0", "  ", 
        StyleBox["and",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}], "  ", "-", "\[Pi]"}], "<", "\[Theta]", 
      "<", "\[Pi]"}]}]}], "}"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution. We write  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", 
     RowBox[{"r", ",", "\[Theta]"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["r", 
     FractionBox["1", "2"]], " ", "cos", 
    FractionBox["\[Theta]", "2"]}]}]]],
 ",   and   \n\t\t\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"V", 
    RowBox[{"(", 
     RowBox[{"r", ",", "\[Theta]"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["r", 
     FractionBox["1", "2"]], " ", "sin", 
    FractionBox["\[Theta]", "2"]}]}]]],
 ".  \nThus,\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["U", "r"], 
    RowBox[{"(", 
     RowBox[{"r", ",", "\[Theta]"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     FractionBox["1", "r"], 
     SubscriptBox["V", "\[Theta]"], 
     RowBox[{"(", 
      RowBox[{"r", ",", "\[Theta]"}], ")"}]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox["1", "2"], 
     SuperscriptBox["r", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]], " ", "cos", 
     FractionBox["\[Theta]", "2"]}]}]}]]],
 ",   and   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["V", "r"], 
    RowBox[{"(", 
     RowBox[{"r", ",", "\[Theta]"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"-", "1"}], "r"], 
     SubscriptBox["U", "\[Theta]"], 
     RowBox[{"(", 
      RowBox[{"r", ",", "\[Theta]"}], ")"}]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox["1", "2"], 
     SuperscriptBox["r", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]], " ", "sin", 
     FractionBox["\[Theta]", "2"]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Since  ",
 Cell[BoxData[
  RowBox[{"U", ",", "V", ",", 
   SubscriptBox["U", "r"], ",", 
   SubscriptBox["U", "\[Theta]"], ",", 
   RowBox[{
    SubscriptBox["V", "x"], " ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", 
    SubscriptBox["V", "\[Theta]"]}]}]]],
 "  are continuous at every point in the domain (note the strict inequality \
in ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Pi]"}], "<", "\[Theta]", "<", "\[Pi]"}]]],
 "), we use Theorem 3.5 and Equation ",
 StyleBox["(3-23)",
  FontColor->RGBColor[0, 0, 1]],
 " to get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "'"}], 
      RowBox[{"(", 
       RowBox[{"r", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ")"}]}], "  ", "=", 
     "   ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Theta]"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["U", "r"], 
         RowBox[{"(", 
          RowBox[{"r", ",", "\[Theta]"}], ")"}]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["V", "r"], 
         RowBox[{"(", 
          RowBox[{"r", ",", "\[Theta]"}], ")"}]}]}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"              ", 
   RowBox[{"=", "   ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Theta]"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], 
        SuperscriptBox["r", 
         RowBox[{"-", 
          FractionBox["1", "2"]}]], " ", "cos", 
        FractionBox["\[Theta]", "2"]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        FractionBox["1", "2"], 
        SuperscriptBox["r", 
         RowBox[{"-", 
          FractionBox["1", "2"]}]], " ", "sin", 
        FractionBox["\[Theta]", "2"]}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"              ", 
   RowBox[{"=", "   ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Theta]"}]], 
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", "2"], 
        SuperscriptBox["r", 
         RowBox[{"-", 
          FractionBox["1", "2"]}]], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          FractionBox["\[Theta]", "2"]}]]}], ")"}]}], " ", "=", "   ", 
     RowBox[{
      FractionBox["1", "2"], 
      SuperscriptBox["r", 
       RowBox[{"-", 
        FractionBox["1", "2"]}]], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        FractionBox["\[Theta]", "2"]}]]}]}]}], "\[IndentingNewLine]"}], "\n", 
  RowBox[{"              ", 
   RowBox[{
    RowBox[{"=", "   ", 
     FractionBox["1", 
      RowBox[{"2", 
       SuperscriptBox["z", 
        FractionBox["1", "2"]]}]]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox["1", "2"], 
     SuperscriptBox["z", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]], "  "}]}]}]}]],
 "\n\nNote that ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " is discontinuous on the negative real axis and is undefined at the origin. \
 Using the terminology of Section 2.4, the negative real axis is a branch \
cut, and the origin is a branch point for this function.  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"3.10", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506703848265625*^9, 3.506703848265625*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"r", ",", "\[Theta]"}], "]"}], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman"], "   ", 
   RowBox[{"v", "[", 
    RowBox[{"r", ",", "\[Theta]"}], "]"}]}]]],
 " and use them to form f[z].  Then verify that polar form of the \
Cauchy-Riemann equations hold."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"r", ",", "\[Theta]", ",", "u", ",", "v"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", 
      RowBox[{"1", "/", "2"}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"r_", ",", "\[Theta]_"}], "]"}], "=", 
     RowBox[{
      SuperscriptBox["r", 
       RowBox[{"1", "/", "2"}]], 
      RowBox[{"Cos", "[", 
       FractionBox["\[Theta]", "2"], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"r_", ",", "\[Theta]_"}], "]"}], "=", 
     RowBox[{
      SuperscriptBox["r", 
       RowBox[{"1", "/", "2"}]], 
      RowBox[{"Sin", "[", 
       FractionBox["\[Theta]", "2"], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Ur", " ", "=", 
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], " ", 
      RowBox[{"u", "[", 
       RowBox[{"r", ",", "\[Theta]"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"U\[Theta]", " ", "=", 
     RowBox[{
      SubscriptBox["\[PartialD]", "\[Theta]"], " ", 
      RowBox[{"u", "[", 
       RowBox[{"r", ",", "\[Theta]"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Vr", " ", "=", 
     RowBox[{
      SubscriptBox["\[PartialD]", "r"], " ", 
      RowBox[{"v", "[", 
       RowBox[{"r", ",", "\[Theta]"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"V\[Theta]", " ", "=", 
     RowBox[{
      SubscriptBox["\[PartialD]", "\[Theta]"], " ", 
      RowBox[{"v", "[", 
       RowBox[{"r", ",", "\[Theta]"}], "]"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  f(z) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[r,\[Theta]] = \>\"", ",", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"r", ",", "\[Theta]"}], "]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"v", "[", 
         RowBox[{"r", ",", "\[Theta]"}], "]"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f[r,\[Theta]] = u[r,\[Theta]] + \[ImaginaryI] v[r,\[Theta]]\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[r,\[Theta]] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"r", ",", "\[Theta]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[r,\[Theta]] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"r", ",", "\[Theta]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(r\)]\) u[r,\[Theta]] = \>\"", 
      ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"r", ",", "\[Theta]"}], "]"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(\[Theta]\)]\) u[r,\[Theta]] = \
\>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "\[Theta]"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"r", ",", "\[Theta]"}], "]"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(r\)]\) v[r,\[Theta]] = \>\"", 
      ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], " ", 
       RowBox[{"v", "[", 
        RowBox[{"r", ",", "\[Theta]"}], "]"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(\[Theta]\)]\) v[r,\[Theta]] = \
\>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "\[Theta]"], " ", 
       RowBox[{"v", "[", 
        RowBox[{"r", ",", "\[Theta]"}], "]"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(\[PartialD]\), \(r\)]\) u[r,\[Theta]] = \
\!\(\*FractionBox[\(1\), \(r\)]\) \!\(\*SubscriptBox[\(\[PartialD]\), \(\
\[Theta]\)]\) v[r,\[Theta]] ?   \>\"", ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], " ", 
        RowBox[{"u", "[", 
         RowBox[{"r", ",", "\[Theta]"}], "]"}]}], "\[Equal]", 
       RowBox[{
        FractionBox["1", "r"], " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", "\[Theta]"], " ", 
         RowBox[{"v", "[", 
          RowBox[{"r", ",", "\[Theta]"}], "]"}]}]}]}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Is \!\(\*SubscriptBox[\(\[PartialD]\), \(r\)]\) v[r,\[Theta]] = \
\!\(\*FractionBox[\(-1\), \(r\)]\) \!\(\*SubscriptBox[\(\[PartialD]\), \(\
\[Theta]\)]\) u[r,\[Theta]] ?  \>\"", ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], " ", 
        RowBox[{"v", "[", 
         RowBox[{"r", ",", "\[Theta]"}], "]"}]}], "\[Equal]", 
       RowBox[{
        FractionBox[
         RowBox[{"-", "1"}], "r"], " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", "\[Theta]"], " ", 
         RowBox[{"u", "[", 
          RowBox[{"r", ",", "\[Theta]"}], "]"}]}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39902038153125*^9}],

Cell[TextData[{
 "  Second, find the derivative using polar formulae  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Theta]"}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"r", ",", "\[Theta]"}], "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], " ", 
        RowBox[{"v", "[", 
         RowBox[{"r", ",", "\[Theta]"}], "]"}]}]}]}], ")"}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Theta]"}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "r"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"r", ",", "\[Theta]"}], "]"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], " ", 
        RowBox[{"v", "[", 
         RowBox[{"r", ",", "\[Theta]"}], "]"}]}]}]}], ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f(z) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f(z) = \>\"", ",", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"r", ",", "\[Theta]"}], "]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"v", "[", 
         RowBox[{"r", ",", "\[Theta]"}], "]"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\< f(z) = u[r,\[Theta]] + \[ImaginaryI] v[r,\[Theta]]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f'(z) = \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(-\[ImaginaryI]\
\[Theta]\)]\)(\!\(\*SubscriptBox[\(\[PartialD]\), \(r\)]\) u[r,\[Theta]] + \
\[ImaginaryI] \!\(\*SubscriptBox[\(\[PartialD]\), \(r\)]\) \
v[r,\[Theta]])\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'(z) = \>\"", ",", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Theta]"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], " ", 
          RowBox[{"u", "[", 
           RowBox[{"r", ",", "\[Theta]"}], "]"}]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], " ", 
           RowBox[{"v", "[", 
            RowBox[{"r", ",", "\[Theta]"}], "]"}]}]}]}], ")"}]}]}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'(z) = \>\"", ",", 
      RowBox[{
       RowBox[{"ComplexExpand", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Theta]"}]], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[PartialD]", "r"], " ", 
          RowBox[{"u", "[", 
           RowBox[{"r", ",", "\[Theta]"}], "]"}]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], " ", 
           RowBox[{"v", "[", 
            RowBox[{"r", ",", "\[Theta]"}], "]"}]}]}]}], ")"}]}]}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'(z) = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"ComplexExpand", "[", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Theta]"}]], "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[PartialD]", "r"], " ", 
           RowBox[{"u", "[", 
            RowBox[{"r", ",", "\[Theta]"}], "]"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{
            SubscriptBox["\[PartialD]", "r"], " ", 
            RowBox[{"v", "[", 
             RowBox[{"r", ",", "\[Theta]"}], "]"}]}]}]}], ")"}]}], "]"}]}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'(z) = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399797390999752*^9}],

Cell[TextData[{
 "We have shown that if  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", 
     RowBox[{"1", "/", "2"}]], "=", 
    RowBox[{
     SuperscriptBox["r", 
      RowBox[{"1", "/", "2"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", 
        RowBox[{"(", 
         FractionBox["\[Theta]", "2"], ")"}]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "sin", 
        RowBox[{"(", 
         FractionBox["\[Theta]", "2"], ")"}]}]}], ")"}]}]}]}]]],
 "  where the domain is restricted to be  ",
 Cell[BoxData[
  RowBox[{"r", ">", 
   RowBox[{
    RowBox[{"0", "  ", "and"}], "  ", "-", "\[Pi]"}], "<", "\[Theta]", "<", 
   "\[Pi]"}]]],
 ",  then the derivative is given by  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", 
      SuperscriptBox["z", 
       RowBox[{"1", "/", "2"}]]}]], "=", 
    RowBox[{
     FractionBox[
      SuperscriptBox["r", 
       RowBox[{
        RowBox[{"-", "1"}], "/", "2"}]], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", 
        RowBox[{"(", 
         FractionBox["\[Theta]", "2"], ")"}]}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "sin", 
        RowBox[{"(", 
         FractionBox["\[Theta]", "2"], ")"}]}]}], ")"}]}]}]}]]],
 "  where  ",
 Cell[BoxData[
  RowBox[{"r", ">", 
   RowBox[{
    RowBox[{"0", "  ", "and"}], "  ", "-", "\[Pi]"}], "<", "\[Theta]", "<", 
   "\[Pi]"}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell["\<\
\tTwo important consequences of the Cauchy-Riemann equations close this \
section.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Theorem 3.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{"f", " ", "=", " ", 
   RowBox[{"u", "+", 
    RowBox[{"\[ImaginaryI]", " ", "v"}]}]}]]],
 "  be an analytic function on the domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  Suppose for all  ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", "D"}]]],
 "  that  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "|", 
   RowBox[{"\[Congruent]", " ", "K"}]}]]],
 ",  where ",
 StyleBox["K",
  FontFamily->"Courier New"],
 " is a constant.  Then ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " is constant on ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 3.6 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Theorem 3.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{"f", " ", "=", " ", 
   RowBox[{"u", "+", 
    RowBox[{"\[ImaginaryI]", " ", "v"}]}]}]]],
 "  be an analytic function on the domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".   If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], "\[Congruent]", "0"}]]],
 "  for all  ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", "D"}]]],
 ",  then ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " is constant on ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 3.7 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",
 InitializationCell->True]
}, Closed]]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{947, 645},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 193, 3, 29, "Text"],
Cell[1744, 51, 1996, 67, 158, "Text"],
Cell[3743, 120, 679, 17, 47, "Text"],
Cell[4425, 139, 1883, 69, 83, "Text"],
Cell[6311, 210, 32139, 1347, 248, "Text"],
Cell[CellGroupData[{
Cell[38475, 1561, 172, 4, 37, "Subsection"],
Cell[38650, 1567, 3507, 91, 374, "Input"],
Cell[42160, 1660, 185, 7, 29, "Text"],
Cell[42348, 1669, 3763, 97, 414, "Input"],
Cell[46114, 1768, 185, 7, 29, "Text"],
Cell[46302, 1777, 3790, 97, 414, "Input"],
Cell[50095, 1876, 663, 26, 29, "Text"]
}, Closed]],
Cell[50773, 1905, 494, 19, 37, "Text"],
Cell[51270, 1926, 2851, 92, 127, "Text"],
Cell[54124, 2020, 3123, 102, 125, "Text"],
Cell[57250, 2124, 1958, 66, 161, "Text"],
Cell[59211, 2192, 2498, 77, 172, "Text"],
Cell[61712, 2271, 19, 0, 29, "Text"],
Cell[61734, 2273, 2627, 82, 138, "Text"],
Cell[64364, 2357, 152, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[64541, 2364, 219, 5, 37, "Subsection"],
Cell[64763, 2371, 5559, 152, 586, "Input"],
Cell[70325, 2525, 5558, 152, 586, "Input"],
Cell[75886, 2679, 5559, 152, 586, "Input"],
Cell[81448, 2833, 622, 21, 83, "Text"],
Cell[82073, 2856, 10340, 284, 880, "Input"],
Cell[92416, 3142, 656, 23, 65, "Text"],
Cell[93075, 3167, 11516, 315, 952, "Input"]
}, Closed]],
Cell[104606, 3485, 3391, 132, 246, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[108022, 3621, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[108166, 3627, 170, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[108351, 3634, 339, 12, 26, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[108715, 3650, 355, 10, 37, "Subsection",
 Evaluatable->False],
Cell[109073, 3662, 7413, 207, 764, "Input"],
Cell[116489, 3871, 948, 37, 31, "Text",
 Evaluatable->False]
}, Closed]],
Cell[117452, 3911, 1531, 57, 170, "Text"],
Cell[118986, 3970, 3515, 136, 270, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[122526, 4110, 277, 8, 37, "Subsection",
 Evaluatable->False],
Cell[122806, 4120, 72, 0, 29, "Text"],
Cell[122881, 4122, 2187, 67, 292, "Input"],
Cell[125071, 4191, 62, 0, 29, "Text"],
Cell[125136, 4193, 2177, 62, 152, "Input"],
Cell[127316, 4257, 447, 16, 65, "Text"],
Cell[127766, 4275, 2131, 65, 212, "Input"]
}, Closed]],
Cell[129912, 4343, 393, 17, 26, "Text",
 Evaluatable->False],
Cell[130308, 4362, 1751, 72, 67, "Text"],
Cell[CellGroupData[{
Cell[132084, 4438, 276, 8, 37, "Subsection",
 Evaluatable->False],
Cell[132363, 4448, 40, 0, 29, "Text"],
Cell[132406, 4450, 1579, 44, 232, "Input"],
Cell[133988, 4496, 59, 0, 29, "Text"],
Cell[134050, 4498, 2137, 65, 272, "Input"],
Cell[136190, 4565, 63, 0, 29, "Text"],
Cell[136256, 4567, 2341, 69, 272, "Input"],
Cell[138600, 4638, 396, 15, 65, "Text",
 Evaluatable->False]
}, Closed]],
Cell[139011, 4656, 4776, 148, 128, "Text",
 Evaluatable->False],
Cell[143790, 4806, 4772, 176, 348, "Text"],
Cell[148565, 4984, 6022, 203, 323, "Text"],
Cell[CellGroupData[{
Cell[154612, 5191, 278, 8, 37, "Subsection",
 Evaluatable->False],
Cell[154893, 5201, 5387, 163, 608, "Input"],
Cell[160283, 5366, 71, 0, 29, "Text"],
Cell[160357, 5368, 2735, 64, 249, "Input"],
Cell[163095, 5434, 167, 5, 65, "Text"],
Cell[163265, 5441, 173, 5, 65, "Text"],
Cell[163441, 5448, 1704, 48, 255, "Input"],
Cell[165148, 5498, 59, 0, 29, "Text"],
Cell[165210, 5500, 2137, 65, 272, "Input"],
Cell[167350, 5567, 66, 0, 29, "Text"],
Cell[167419, 5569, 2341, 69, 272, "Input"],
Cell[169763, 5640, 1765, 61, 100, "Text",
 Evaluatable->False],
Cell[171531, 5703, 3151, 91, 340, "Input"],
Cell[174685, 5796, 1142, 42, 67, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[175852, 5842, 4463, 120, 474, "Input"],
Cell[180318, 5964, 826, 31, 58, "Text",
 Evaluatable->False]
}, Open  ]]
}, Closed]],
Cell[181171, 5999, 693, 21, 62, "Text"],
Cell[181867, 6022, 3759, 147, 161, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[185651, 6173, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[185795, 6179, 170, 4, 29, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[185980, 6186, 1109, 36, 104, "Text",
 Evaluatable->False],
Cell[187092, 6224, 5170, 179, 281, "Text"],
Cell[CellGroupData[{
Cell[192287, 6407, 272, 8, 37, "Subsection",
 Evaluatable->False],
Cell[192562, 6417, 72, 0, 29, "Text"],
Cell[192637, 6419, 2187, 67, 292, "Input"],
Cell[194827, 6488, 62, 0, 29, "Text"],
Cell[194892, 6490, 2174, 62, 152, "Input"],
Cell[197069, 6554, 447, 16, 65, "Text"],
Cell[197519, 6572, 2131, 65, 212, "Input"]
}, Closed]],
Cell[199665, 6640, 1040, 34, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[200730, 6678, 271, 7, 37, "Subsection",
 Evaluatable->False],
Cell[201004, 6687, 72, 0, 29, "Text"],
Cell[201079, 6689, 2188, 67, 292, "Input"],
Cell[203270, 6758, 62, 0, 29, "Text"],
Cell[203335, 6760, 2177, 62, 152, "Input"],
Cell[205515, 6824, 447, 16, 65, "Text"],
Cell[205965, 6842, 2129, 65, 212, "Input"]
}, Closed]],
Cell[208109, 6910, 860, 29, 26, "Text",
 Evaluatable->False],
Cell[208972, 6941, 3228, 114, 233, "Text"],
Cell[CellGroupData[{
Cell[212225, 7059, 278, 8, 37, "Subsection",
 Evaluatable->False],
Cell[212506, 7069, 99, 2, 29, "Text"],
Cell[212608, 7073, 3931, 117, 432, "Input"],
Cell[216542, 7192, 547, 18, 29, "Text",
 Evaluatable->False],
Cell[217092, 7212, 1353, 37, 132, "Input"],
Cell[218448, 7251, 826, 30, 31, "Text",
 Evaluatable->False],
Cell[219277, 7283, 2775, 81, 315, "Input"],
Cell[222055, 7366, 1563, 49, 67, "Text"]
}, Closed]],
Cell[223633, 7418, 953, 32, 30, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[224611, 7454, 270, 7, 37, "Subsection",
 Evaluatable->False],
Cell[224884, 7463, 99, 2, 29, "Text"],
Cell[224986, 7467, 4144, 123, 443, "Input"],
Cell[229133, 7592, 767, 24, 33, "Text",
 Evaluatable->False],
Cell[229903, 7618, 993, 28, 92, "Input"],
Cell[230899, 7648, 869, 31, 33, "Text",
 Evaluatable->False],
Cell[231771, 7681, 2764, 81, 318, "Input"],
Cell[234538, 7764, 1578, 52, 73, "Text"]
}, Closed]],
Cell[236131, 7819, 156, 3, 26, "Text"],
Cell[236290, 7824, 764, 28, 32, "Text",
 Evaluatable->False],
Cell[237057, 7854, 4020, 147, 215, "Text"],
Cell[CellGroupData[{
Cell[241102, 8005, 274, 8, 37, "Subsection",
 Evaluatable->False],
Cell[241379, 8015, 150, 3, 29, "Text"],
Cell[241532, 8020, 4171, 123, 452, "Input"],
Cell[245706, 8145, 2542, 91, 71, "Text",
 Evaluatable->False]
}, Closed]],
Cell[248263, 8239, 4057, 127, 231, "Text"],
Cell[252323, 8368, 5178, 187, 233, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[257526, 8559, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[257670, 8565, 182, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[257867, 8572, 2789, 91, 206, "Text",
 Evaluatable->False],
Cell[260659, 8665, 1652, 61, 229, "Text"],
Cell[262314, 8728, 3750, 120, 300, "Text"],
Cell[CellGroupData[{
Cell[266089, 8852, 279, 8, 37, "Subsection",
 Evaluatable->False],
Cell[266371, 8862, 369, 12, 29, "Text"],
Cell[266743, 8876, 5574, 162, 536, "Input"],
Cell[272320, 9040, 1291, 44, 29, "Text"],
Cell[273614, 9086, 3482, 99, 260, "Input"],
Cell[277099, 9187, 1554, 57, 69, "Text"]
}, Closed]],
Cell[278668, 9247, 106, 3, 26, "Text"],
Cell[278777, 9252, 794, 33, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[279596, 9289, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[279740, 9295, 170, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[279925, 9302, 657, 28, 26, "Text"],
Cell[CellGroupData[{
Cell[280607, 9334, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[280751, 9340, 170, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[280936, 9347, 435, 8, 26, "Text"],
Cell[CellGroupData[{
Cell[281396, 9359, 407, 7, 29, "Text"],
Cell[281806, 9368, 130, 3, 31, "Input",
 InitializationCell->True]
}, Closed]]
}
]
*)

(* End of internal cache information *)
