(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     70411,       2213]
NotebookOptionsPosition[     67987,       2134]
NotebookOutlinePosition[     68379,       2151]
CellTagsIndexPosition[     68336,       2148]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[StyleBox["Chapter 6  Complex Integration",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.5327093585625*^9, 3.532709359453125*^9}}],

Cell[TextData[{
 StyleBox["Overview",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tOf the two main topics studied in calculus - differentiation and \
integration - we have so far only studied derivatives of complex functions.  \
We now turn to the problem of integrating complex functions.  The theory you \
will learn is elegant, powerful, and a useful tool for physicists and \
engineers.  It also connects widely with other branches of mathematics.  For \
example, even though the ideas presented here belong to the general area of \
mathematics known as analysis, you will see as an application of them one of \
the simplest proofs of the fundamental theorem of algebra. "
}], "Text",
 CellChangeTimes->{{3.39928771425*^9, 3.399287720546875*^9}, 
   3.399882467875*^9}],

Cell[TextData[StyleBox["6.1  Complex Integrals",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell["\<\
\tIn Chapter 3 we saw how the derivative of a complex function is defined.  \
We now turn our attention to the problem of integrating complex functions.  \
We will find that integrals of analytic functions are well behaved and that \
many properties from calculus carry over to the complex case.  \
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
\tWe introduce the integral of a complex function by defining the integral of \
a complex-valued function of a real variable\
\>", "Text"],

Cell[TextData[{
 StyleBox["Definition 6.1 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Definite Integral",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/FundamentalTheoremsofCalculus.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[" of a Complex Integrand).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "v", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 "  where ",
 StyleBox["u(t)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v(t)",
  FontFamily->"Courier New"],
 " are real-valued functions of the real variable ",
 StyleBox["t",
  FontFamily->"Courier New"],
 " for  ",
 Cell[BoxData[
  RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "b"}]]],
 " .  Then\n\n",
 StyleBox["(6-1)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "   ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"u", 
         RowBox[{"(", "t", ")"}]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "v", 
         RowBox[{"(", "t", ")"}]}]}], ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "   ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
      RowBox[{"u", 
       RowBox[{"(", "t", ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "+", "  ", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
       RowBox[{"v", 
        RowBox[{"(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tWe generally evaluate integrals of this type by finding the \
antiderivatives of ",
 StyleBox["u(t)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v(t)",
  FontFamily->"Courier New"],
 " and evaluating the definite integrals on the right side of Equation ",
 StyleBox["(6-1)",
  FontColor->RGBColor[0, 0, 1]],
 ".  That is, if  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"U", "'"}], 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{"u", 
    RowBox[{"(", "t", ")"}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"V", "'"}], 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{"v", 
    RowBox[{"(", "t", ")"}]}]}]]],
 ",  we have  \n\n",
 StyleBox["(6-2)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
      RowBox[{"u", 
       RowBox[{"(", "t", ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "+", "  ", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
       RowBox[{"v", 
        RowBox[{"(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"U", 
      RowBox[{"(", "b", ")"}]}], "-", 
     RowBox[{"U", 
      RowBox[{"(", "a", ")"}]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"V", 
         RowBox[{"(", "b", ")"}]}], "-", 
        RowBox[{"V", 
         RowBox[{"(", "a", ")"}]}]}], ")"}]}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Example 6.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"t", "-", "\[ImaginaryI]"}], ")"}], "3"], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", " ", 
   RowBox[{"-", 
    FractionBox["5", "4"]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We write the integrand in terms of its real and imaginary parts, \
i.e.,   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"t", "-", "\[ImaginaryI]"}], ")"}], "3"], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["t", "3"], "-", 
     RowBox[{"3", " ", "t"}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         SuperscriptBox["t", "2"]}], "+", "1"}], ")"}]}]}]}]}]]],
 ".  Here,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", "t", ")"}]}], " ", "=", "  ", 
   RowBox[{
    SuperscriptBox["t", "3"], "-", 
    RowBox[{"3", " ", "t"}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", " ", "3"}], " ", 
     SuperscriptBox["t", "2"]}], "+", "1"}]}]]],
 ".  The integrals of ",
 StyleBox["u(t)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v(t)",
  FontFamily->"Courier New"],
 " are  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
    RowBox[{"u", 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "1"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["t", "3"], "-", 
        RowBox[{"3", " ", "t"}]}], ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SuperscriptBox["t", "4"], "4"], "-", 
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["t", "2"]}], "2"]}], ")"}], 
      UnderoverscriptBox["\[VerticalSeparator]", 
       RowBox[{"t", "=", "0"}], 
       RowBox[{"t", "=", "1"}]]}], "  ", "=", "  ", 
     RowBox[{"-", 
      FractionBox["5", "4"]}]}]}]}]]],
 ",   and  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
    RowBox[{"v", 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "1"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         SuperscriptBox["t", "2"]}], "+", "1"}], ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "   ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["t", "3"]}], "+", "t"}], ")"}], 
      UnderoverscriptBox["\[VerticalSeparator]", 
       RowBox[{"t", "=", "0"}], 
       RowBox[{"t", "=", "1"}]]}], "  ", "=", "  ", "0"}]}]}]]],
 ".  \n\nHence, by Definition ",
 StyleBox["(6-1)",
  FontColor->RGBColor[0, 0, 1]],
 ",  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"t", "-", "\[ImaginaryI]"}], ")"}], "3"], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
      RowBox[{"u", 
       RowBox[{"(", "t", ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
       RowBox[{"v", 
        RowBox[{"(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                             ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["5", "4"]}], "+", " ", 
      RowBox[{"0", "\[ImaginaryI]"}]}]}], "  ", "=", "  ", 
    RowBox[{"-", 
     FractionBox["5", "4"]}], " "}]}]}]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"6.1", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670476209375*^9, 3.50670476209375*^9}}],

Cell[TextData[{
 StyleBox["Method (i).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Expand the integrand f[t] into its real and imaginary parts, then \
integrate u[t] and v[t]."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"t", ",", "u", ",", "v", ",", "w"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "Int", ",", "ImInt", ",", "ImVal", ",", "ReInt", ",", "ReVal", 
      ",", "Val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"w", "=", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"t", " ", "-", " ", "\[ImaginaryI]"}], ")"}], "3"]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", "w", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Int", " ", "=", " ", 
     RowBox[{
      RowBox[{"U", "[", "t", "]"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"V", "[", "t", "]"}]}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ReVal", " ", "=", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ImVal", " ", "=", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Val", " ", "=", " ", 
     RowBox[{"ReVal", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "ImVal"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<f[t] = u[t] + \[ImaginaryI] v[t]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[t] = \>\"", ",", 
      RowBox[{"u", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[t] = \>\"", ",", 
      RowBox[{"v", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[t] = \[Integral]u[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<V[t] = \[Integral]v[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{"V", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\[Integral]u[t]\[DifferentialD]t + \[ImaginaryI] \[Integral]v[t]\
\[DifferentialD]t = (\>\"", ",", 
      RowBox[{"U", "[", "t", "]"}], ",", "\"\<) + \[ImaginaryI](\>\"", ",", 
      RowBox[{"V", "[", "t", "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)\>\"", ",", 
      "w", ",", 
      "\"\<\[DifferentialD]t = \!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(0\), \(1\)]\)u[t]\[DifferentialD]t + \[ImaginaryI] \!\(\*SubsuperscriptBox[\
\(\[Integral]\), \(0\), \(1\)]\)v[t]\[DifferentialD]t\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)\>\"", ",", 
      "w", ",", 
      "\"\<\[DifferentialD]t = (U[1]-U[0]) + \[ImaginaryI](V[1]-V[0])\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)\>\"", ",", 
      "w", ",", "\"\<\[DifferentialD]t = (\>\"", ",", "ReVal", ",", 
      "\"\<) + \[ImaginaryI](\>\"", ",", "ImVal", ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)\>\"", ",", 
      "w", ",", "\"\<\[DifferentialD]t = \>\"", ",", "Val"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399287767953125*^9, 3.441802450125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method (ii).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Compute the integral directly using a complex function for the integrand."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "t", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "val"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"t", " ", "-", " ", "\[ImaginaryI]"}], ")"}], "3"]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[t] = \[Integral]\>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", "\"\<\[DifferentialD]t = \>\"", ",", 
      RowBox[{"F", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)\>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", 
      "\"\<\[DifferentialD]t = F[1] - F[0]\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)\>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", "\"\<\[DifferentialD]t = (\>\"", ",", 
      RowBox[{"F", "[", "1", "]"}], " ", ",", "\"\<) - (\>\"", ",", 
      RowBox[{"F", "[", "0", "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)\>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", "\"\<\[DifferentialD]t = \>\"", ",", 
      "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39928777403125*^9, 3.44180245328125*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 6.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", 
     RowBox[{"\[Pi]", "/", "2"}]], " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"t", "+", 
       RowBox[{"\[ImaginaryI]", " ", "t"}]}]], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox["\[Pi]", "2"]], "-", "1"}], ")"}]}], " ", "+", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"\[ImaginaryI]", " "}], "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox["\[Pi]", "2"]], "+", "1"}], ")"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We use the method suggested by Definitions ",
 StyleBox["(6-1)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(6-2)",
  FontColor->RGBColor[0, 0, 1]],
 ".  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", 
      RowBox[{"\[Pi]", "/", "2"}]], " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"t", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "t"}]}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[Pi]", "/", "2"}]], " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "t"], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[Pi]", "/", "2"}]], " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "t"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"cos", " ", "t"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", "sin", " ", "t"}]}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[Pi]", "/", "2"}]], " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "t"], " ", "cos", " ", "t", "  ", 
       RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", 
        RowBox[{"\[Pi]", "/", "2"}]], " ", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "t"], " ", "sin", " ", "t", "  ", 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "We can evaluate each of the integrals via integration by parts.  For \
example,  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", 
      RowBox[{"\[Pi]", "/", "2"}]], " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "t"], " ", "cos", " ", "t", "  ", 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "t"], " ", "sin", " ", "t"}], ")"}], 
     UnderoverscriptBox["\[VerticalSeparator]", 
      RowBox[{"t", "=", "0"}], 
      RowBox[{"t", "=", 
       RowBox[{"\[Pi]", "/", "2"}]}]], "   ", 
     RowBox[{"-", "    ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", 
        RowBox[{"\[Pi]", "/", "2"}]], 
       RowBox[{"sin", " ", "t", "  ", 
        SuperscriptBox["\[ExponentialE]", "t"], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                 ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[Pi]", "/", "2"}]], " ", "sin", 
        FractionBox["\[Pi]", "2"]}], " ", "-", " ", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "0"], " ", "sin", " ", "0"}]}], 
      ")"}], "  ", "-", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[Pi]", "/", "2"}]], 
      RowBox[{"sin", " ", "t", "  ", 
       SuperscriptBox["\[ExponentialE]", "t"], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], " ", "\[IndentingNewLine]", 
   " "}], "\[IndentingNewLine]", 
  RowBox[{"                                 ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[Pi]", "/", "2"}]], "1"}], "-", 
       RowBox[{"1", "*", "0"}]}], ")"}], "  ", "-", "   ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[Pi]", "/", "2"}]], " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "t"], "sin", " ", "t", "  ", 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                 ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[Pi]", "/", "2"}]], "  ", "-", "   ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[Pi]", "/", "2"}]], " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "t"], "sin", " ", "t", "  ", 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                 ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[Pi]", "/", "2"}]], "  ", "-", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "t"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "cos"}], " ", "t"}], ")"}]}], ")"}]}], 
     UnderoverscriptBox["\[VerticalSeparator]", 
      RowBox[{"t", "=", "0"}], 
      RowBox[{"t", "=", 
       RowBox[{"\[Pi]", "/", "2"}]}]], "  ", 
     RowBox[{"+", "   ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", 
        RowBox[{"\[Pi]", "/", "2"}]], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", " ", "cos"}], " ", "t", " ", 
          SuperscriptBox["\[ExponentialE]", "t"]}], ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                 ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[Pi]", "/", "2"}]], "  ", "+", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "t"], " ", "cos", " ", "t"}], 
       ")"}]}], 
     UnderoverscriptBox["\[VerticalSeparator]", 
      RowBox[{"t", "=", "0"}], 
      RowBox[{"t", "=", 
       RowBox[{"\[Pi]", "/", "2"}]}]], "  ", 
     RowBox[{"-", "   ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", 
        RowBox[{"\[Pi]", "/", "2"}]], " ", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "t"], "cos", " ", "t", "  ", 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                 ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[Pi]", "/", "2"}]], "  ", "+", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[Pi]", "/", "2"}]], "*", "0"}], "-", 
     RowBox[{"1", "*", "1"}], "  ", "-", "   ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[Pi]", "/", "2"}]], " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "t"], "cos", " ", "t", "  ", 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                 ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[Pi]", "/", "2"}]], "-", "1", "  ", "-", "   ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[Pi]", "/", "2"}]], " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "t"], "cos", " ", "t", "  ", 
       RowBox[{"\[DifferentialD]", "t"}], " "}]}]}]}]}]}]],
 "   "
}], "Text"],

Cell[TextData[{
 "Adding  ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", 
    RowBox[{"\[Pi]", "/", "2"}]], " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "t"], "cos", " ", "t", " ", 
    RowBox[{"\[DifferentialD]", "t"}]}]}]]],
 "  to both sides of this equation and then dividing by ",
 StyleBox["2",
  FontFamily->"Courier New"],
 " gives  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", 
     RowBox[{"\[Pi]", "/", "2"}]], " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "t"], " ", "cos", " ", "t", " ", 
     RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[Pi]", "/", "2"}]], "-", "1"}], ")"}]}]}]]],
 ".  Likewise,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", 
      RowBox[{"\[Pi]", "/", "2"}]], 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "t"], " ", "sin", " ", "t", " ", 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}], " ", "=", " ", 
   RowBox[{"\[ImaginaryI]", " ", 
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[Pi]", "/", "2"}]], "+", "1"}], ")"}]}]}]]],
 ".  Therefore,  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", 
     RowBox[{"\[Pi]", "/", "2"}]], " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"t", "+", 
       RowBox[{"\[ImaginaryI]", " ", "t"}]}]], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox["\[Pi]", "2"]], "-", "1"}], ")"}]}], " ", "+", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"\[ImaginaryI]", " "}], "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox["\[Pi]", "2"]], "+", "1"}], ")"}]}]}]}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"6.2", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506704766484375*^9, 3.5067047665*^9}}],

Cell[TextData[{
 StyleBox["Method (i).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Expand the integrand f[t] into its real and imaginary parts, then \
integrate u[t] and v[t]."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"t", ",", "u", ",", "v", ",", "w"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "Int", ",", "ImInt", ",", "ImVal", ",", "ReInt", ",", "ReVal", 
      ",", "Val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"w", "=", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"t", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "t"}]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", "w", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       RowBox[{"f", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       RowBox[{"f", "[", "t", "]"}], "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"V", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Int", " ", "=", " ", 
     RowBox[{
      RowBox[{"U", "[", "t", "]"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"V", "[", "t", "]"}]}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ReVal", " ", "=", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[Pi]", "/", "2"}]], 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ImVal", " ", "=", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[Pi]", "/", "2"}]], 
      RowBox[{
       RowBox[{"v", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Val", " ", "=", " ", 
     RowBox[{"ReVal", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "ImVal"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<f[t] = u[t] + \[ImaginaryI] v[t]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[t] = \>\"", ",", 
      RowBox[{"u", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[t] = \>\"", ",", 
      RowBox[{"v", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[t] = \[Integral]u[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<V[t] = \[Integral]v[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{"V", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[\!\(\*FractionBox[\(\[Pi]\), \(2\)]\)] = \>\"", ",", 
      RowBox[{"U", "[", 
       FractionBox["\[Pi]", "2"], "]"}], ",", "\"\<,   \>\"", ",", " ", 
      "\"\<U[0] = \>\"", ",", 
      RowBox[{"U", "[", "0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<V[\!\(\*FractionBox[\(\[Pi]\), \(2\)]\)] = \>\"", ",", 
      RowBox[{"V", "[", 
       FractionBox["\[Pi]", "2"], "]"}], ",", "\"\<,   \>\"", ",", 
      "\"\<V[0] = \>\"", ",", 
      RowBox[{"V", "[", "0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\[Integral]u[t]\[DifferentialD]t + \[ImaginaryI] \[Integral]v[t]\
\[DifferentialD]t = \>\"", ",", "Int"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]/2\)]\)\>\"",
       ",", "w", ",", 
      "\"\<\[DifferentialD]t = \!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(0\), \(\[Pi]/2\)]\)u[t]\[DifferentialD]t + \[ImaginaryI] \
\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]/2\)]\)v[t]\
\[DifferentialD]t\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]/2\)]\)\>\"",
       ",", "w", ",", 
      "\"\<\[DifferentialD]t = (U[1]-U[0]) + \[ImaginaryI](V[1]-V[0])\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]/2\)]\)\>\"",
       ",", "w", ",", "\"\<\[DifferentialD]t = \>\"", ",", "ReVal", ",", 
      "\"\< + \[ImaginaryI](\>\"", ",", "ImVal", ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]/2\)]\)\>\"",
       ",", "w", ",", "\"\<\[DifferentialD]t = \>\"", ",", "Val"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39928778478125*^9, 3.441802455828125*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tComplex integrals have properties that are similar to those of real \
integrals.  We now trace through several commonalities.  Let  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "v", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    RowBox[{"p", 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "q", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 "  be continuous on  ",
 Cell[BoxData[
  RowBox[{
  "a", " ", "\[LessEqual]", " ", "t", " ", "\[LessEqual]", " ", "b"}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "Using Definition ",
 StyleBox["(6-1)",
  FontColor->RGBColor[0, 0, 1]],
 ", we can easily show that the integral of their sum is the sum of their \
integrals, that is\n\n",
 StyleBox["(6-3)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", "t", ")"}]}], "+", 
       RowBox[{"g", 
        RowBox[{"(", "t", ")"}]}]}], ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "+", "  ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
     RowBox[{"g", 
      RowBox[{"(", "t", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 ".  \n"
}], "Text"],

Cell[TextData[{
 "If we divide the interval  ",
 Cell[BoxData[
  RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "b"}]]],
 "  into  ",
 Cell[BoxData[
  RowBox[{"a", "\[LessEqual]", "t", "\[LessEqual]", "c"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"c", "\[LessEqual]", "t", "\[LessEqual]", "b"}]]],
 "  and integrate ",
 StyleBox["f(t)",
  FontFamily->"Courier New"],
 " over these subintervals by using ",
 StyleBox["(6-1)",
  FontColor->RGBColor[0, 0, 1]],
 ", then we get  \n\n",
 StyleBox["(6-4)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "c"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "+", "  ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "c", "b"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 ".  \n"
}], "Text"],

Cell[TextData[{
 "Similarly, if  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "+", 
   RowBox[{"\[ImaginaryI]", " ", "\[Beta]"}]}]]],
 "  denotes a complex constant, then\n\n",
 StyleBox["(6-5)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"c", "+", 
       RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], "f", 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"c", "+", 
      RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], "  ", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 ".  \n"
}], "Text"],

Cell[TextData[{
 "If the limits of integration are reversed, then\n\n",
 StyleBox["(6-6)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{"-", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "b", "a"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 ".  \n"
}], "Text"],

Cell[TextData[{
 "The integral of the product ",
 StyleBox["f(t)g(t)",
  FontFamily->"Courier New"],
 " becomes\n\n",
 StyleBox["(6-7)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}], "g", 
      RowBox[{"(", "t", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"u", 
         RowBox[{"(", "t", ")"}]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "v", 
         RowBox[{"(", "t", ")"}]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p", 
         RowBox[{"(", "t", ")"}]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "q", 
         RowBox[{"(", "t", ")"}]}]}], ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}], "\[IndentingNewLine]", 
   " "}], "\[IndentingNewLine]", 
  RowBox[{" ", 
   RowBox[{"=", "   ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", 
          RowBox[{"(", "t", ")"}], " ", "p", 
          RowBox[{"(", "t", ")"}]}], "-", 
         RowBox[{"v", 
          RowBox[{"(", "t", ")"}], " ", "q", 
          RowBox[{"(", "t", ")"}]}]}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "+", "  ", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"u", 
           RowBox[{"(", "t", ")"}], " ", "q", 
           RowBox[{"(", "t", ")"}]}], "+", 
          RowBox[{"v", 
           RowBox[{"(", "t", ")"}], " ", "p", 
           RowBox[{"(", "t", ")"}]}]}], ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}]}]}]],
 "   \n"
}], "Text"],

Cell[TextData[{
 StyleBox["Example 6.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Let us verify property ",
 StyleBox["(6-5)",
  FontColor->RGBColor[0, 0, 1]],
 ".  We start by writing \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"c", "+", 
        RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], "f", 
      RowBox[{"(", "t", ")"}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"c", "+", 
        RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"u", 
         RowBox[{"(", "t", ")"}]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "v", 
         RowBox[{"(", "t", ")"}]}]}], ")"}]}]}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "                                ", 
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{"c", " ", "u", 
       RowBox[{"(", "t", ")"}]}], "-", 
      RowBox[{"d", " ", "v", 
       RowBox[{"(", "t", ")"}]}], "  ", "+", "  ", 
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", " ", "v", 
          RowBox[{"(", "t", ")"}]}], " ", "+", " ", 
         RowBox[{"d", " ", "u", 
          RowBox[{"(", "t", ")"}]}]}], ")"}]}]}]}]}]}]]],
 "  \n\nUsing Definition ",
 StyleBox["(6-1)",
  FontColor->RGBColor[0, 0, 1]],
 ", we write the left side of Equation ",
 StyleBox["(6-5)",
  FontColor->RGBColor[0, 0, 1]],
 " as  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"c", "+", 
       RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"u", 
        RowBox[{"(", "t", ")"}]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "v", 
        RowBox[{"(", "t", ")"}]}]}], ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"=", "  ", 
   RowBox[{
    RowBox[{"c", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
      RowBox[{"u", 
       RowBox[{"(", "t", ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], " ", "-", " ", 
    RowBox[{"d", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
      RowBox[{"v", 
       RowBox[{"(", "t", ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], "  ", "+", "  ", 
    RowBox[{"\[ImaginaryI]", " ", "c", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
      RowBox[{"v", 
       RowBox[{"(", "t", ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "d", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
      RowBox[{"u", 
       RowBox[{"(", "t", ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}]}]],
 "  \n\nwhich is equivalent to  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"c", "+", 
       RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"u", 
        RowBox[{"(", "t", ")"}]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "v", 
        RowBox[{"(", "t", ")"}]}]}], ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"c", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
       RowBox[{"u", 
        RowBox[{"(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}], "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "d", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
       RowBox[{"u", 
        RowBox[{"(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}], "  ", "+", "  ", 
     RowBox[{"c", " ", "\[ImaginaryI]", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
       RowBox[{"v", 
        RowBox[{"(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}], " ", "+", 
     RowBox[{"\[ImaginaryI]", " ", "d", " ", "\[ImaginaryI]", "  ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
       RowBox[{"v", 
        RowBox[{"(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"c", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
       RowBox[{"u", 
        RowBox[{"(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}], "  ", "+", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"c", "+", 
        RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], " ", "\[ImaginaryI]", 
      " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
       RowBox[{"v", 
        RowBox[{"(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"=", "  ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"c", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
       RowBox[{"u", 
        RowBox[{"(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
        RowBox[{"v", 
         RowBox[{"(", "t", ")"}], 
         RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], " ", ")"}]}]}]}]],
 "   \n\nTherefore,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"c", "+", 
       RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], "f", 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"c", "+", 
      RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"6.3", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506704770390625*^9, 3.506704770390625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "c", ",", "d", ",", "int1", ",", "int2", ",", "t", ",", "u", ",", "v"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"int1", " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"c", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "d"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", "[", "t", "]"}], " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"v", "[", "t", "]"}]}]}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"int2", " ", "=", " ", 
     RowBox[{"MapAll", "[", 
      RowBox[{"Distribute", ",", "int1"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"int1", ",", "\"\< = \>\""}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "int2", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"int2", " ", "\[Equal]", " ", 
      RowBox[{"MapAll", "[", 
       RowBox[{"Distribute", ",", "int1"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3992877961875*^9, {3.39928782675*^9, 3.3992878374375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tIt is worthwhile to point out the similarity between equation ",
 StyleBox["(6-2)",
  FontColor->RGBColor[0, 0, 1]],
 " and its counterpart in calculus.  Suppose that ",
 StyleBox["U",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["V",
  FontFamily->"Courier New"],
 " are differentiable on  ",
 Cell[BoxData[
  RowBox[{"a", "<", "t", "<", "b"}]]],
 "  \nand  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    RowBox[{"U", 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "V", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 ".  Since ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"F", "'"}], 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"U", "'"}], 
      RowBox[{"(", "t", ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"V", "'"}], 
      RowBox[{"(", "t", ")"}]}]}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"u", 
       RowBox[{"(", "t", ")"}]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "v", 
       RowBox[{"(", "t", ")"}]}]}], "=", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}]}]}]}]}]]],
 ",  equation ",
 StyleBox["(6-2)",
  FontColor->RGBColor[0, 0, 1]],
 " takes on the familiar form \n\n",
 StyleBox["(6-8)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"F", 
      RowBox[{"(", "t", ")"}]}], 
     SubsuperscriptBox["|", 
      RowBox[{"t", "=", "a"}], 
      RowBox[{"t", "=", "b"}]]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"F", 
      RowBox[{"(", "b", ")"}]}], "-", 
     RowBox[{"F", 
      RowBox[{"(", "a", ")"}]}]}]}]}]]],
 ".\n\t\t\t\nwhere ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"F", "'"}], 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}]}]}]]],
 ".  We can view Equation ",
 StyleBox["(6-8)",
  FontColor->RGBColor[0, 0, 1]],
 " as an extension of the fundamental theorem of calculus.  In Section 6.5 we \
show how to generalize this extension to analytic functions of a complex \
variable.  For now, we simply note an important case of Equation ",
 StyleBox["(6-8)",
  FontColor->RGBColor[0, 0, 1]],
 ": \n\n",
 StyleBox["(6-9)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "b", ")"}]}], "-", 
    RowBox[{"f", 
     RowBox[{"(", "a", ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 6.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use Equation ",
 StyleBox["(6-8)",
  FontColor->RGBColor[0, 0, 1]],
 " to show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", 
     RowBox[{"\[Pi]", "/", "2"}]], " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"t", "+", 
       RowBox[{"\[ImaginaryI]", " ", "t"}]}]], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[Pi]", "/", "2"}]], "-", "1"}], ")"}]}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{"\[ImaginaryI]", " "}], "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[Pi]", "/", "2"}]], "+", "1"}], ")"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We seek a function ",
 StyleBox["F",
  FontFamily->"Courier New"],
 " with the property that   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"F", "'"}], 
    RowBox[{"(", "t", ")"}]}], "=", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], " ", "t"}]]}]]],
 ".  We note that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"1", "+", "\[ImaginaryI]"}]], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], " ", "t"}]]}]}]]],
 " satisfies this requirement, so \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", 
      RowBox[{"\[Pi]", "/", "2"}]], " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"t", "+", 
        RowBox[{"\[ImaginaryI]", " ", "t"}]}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", " ", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"1", "+", "\[ImaginaryI]"}]], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], " ", "t"}]]}], ")"}], 
      UnderoverscriptBox["\[VerticalSeparator]", 
       RowBox[{"t", "=", "0"}], 
       RowBox[{"t", "=", 
        RowBox[{"\[Pi]", "/", "2"}]}]]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{"1", "+", "\[ImaginaryI]"}]], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], " ", 
         RowBox[{"\[Pi]", "/", "2"}]}]]}], " ", "-", " ", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"1", "+", "\[ImaginaryI]"}]], " ", 
       SuperscriptBox["\[ExponentialE]", "0"]}]}]}]}], 
   "  "}], "\[IndentingNewLine]", 
  RowBox[{"                           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{"1", "+", "\[ImaginaryI]"}]], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{" ", 
         RowBox[{"\[Pi]", "/", "2"}]}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", "  ", 
         RowBox[{"\[Pi]", "/", "2"}]}]]}], "-", " ", 
      FractionBox["1", 
       RowBox[{"1", "+", "\[ImaginaryI]"}]]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{"1", "+", "\[ImaginaryI]"}]], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{" ", 
         RowBox[{"\[Pi]", "/", "2"}]}]], "\[ImaginaryI]"}], " ", "-", " ", 
      FractionBox["1", 
       RowBox[{"1", "+", "\[ImaginaryI]"}]]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                           ", 
   RowBox[{"=", "   ", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"1", "+", "\[ImaginaryI]"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{" ", 
           RowBox[{"\[Pi]", "/", "2"}]}]]}], " ", "-", "1"}], ")"}]}], "  ", 
     "=", "  ", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[Pi]", "/", "2"}]]}]}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                           ", 
   RowBox[{"=", "   ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[Pi]", "/", "2"}]], "-", "1"}], ")"}]}], "+", " ", 
     RowBox[{
      FractionBox["\[ImaginaryI]", "2"], " ", 
      RowBox[{"(", " ", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[Pi]", "/", "2"}]], "+", "1"}], ")"}]}]}]}]}]}]],
 "  \n\nwhich is the same result we obtained in Example 6.2, but with a lot \
less work."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"6.4", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506704774171875*^9, 3.506704774171875*^9}}],

Cell[TextData[{
 "\n",
 StyleBox["Method (ii).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Compute the integral directly using a complex function for the integrand."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "t", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "val"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], "=", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"t", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "t"}]}]]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"t", "+", 
         RowBox[{"\[ImaginaryI]", " ", "t"}]}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[Pi]", "/", "2"}]], 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[t] = \[Integral]\>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", "\"\<\[DifferentialD]t = \>\"", ",", 
      RowBox[{"F", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]/2\)]\)\>\"",
       ",", 
      RowBox[{"f", "[", "t", "]"}], ",", 
      "\"\<\[DifferentialD]t = F[1] - F[0]\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]/2\)]\)\>\"",
       ",", 
      RowBox[{"f", "[", "t", "]"}], ",", "\"\<\[DifferentialD]t = \>\"", ",", 
      RowBox[{"F", "[", "1", "]"}], " ", ",", "\"\< - (\>\"", ",", 
      RowBox[{"F", "[", "0", "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]/2\)]\)\>\"",
       ",", 
      RowBox[{"f", "[", "t", "]"}], ",", "\"\<\[DifferentialD]t = \>\"", ",", 
      "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]/2\)]\)\>\"",
       ",", 
      RowBox[{"f", "[", "t", "]"}], ",", "\"\<\[DifferentialD]t = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", "val", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399287848234375*^9, 3.441802456734375*^9},
 AspectRatioFixed->True],

Cell["\<\
Which is the same result we obtained in Example 6.2, but with a lot less work.\
\>", "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Remark 6.1",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Example 6.4 illustrates the potential computational advantage we have \
when we lift our sights to the complex domain.  Using ordinary calculus \
techniques to evaluate ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", 
    RowBox[{"\[Pi]", "/", "2"}]], " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "t"], " ", "cos", " ", "t", "  ", 
    RowBox[{"\[DifferentialD]", "t"}]}]}]]],
 ", for example, required a lengthy integration by parts procedure (Example \
6.2).  When we recognize this expression as the real part of ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", 
    RowBox[{"\[Pi]", "/", "2"}]], " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"t", "+", 
      RowBox[{"\[ImaginaryI]", " ", "t"}]}]], 
    RowBox[{"\[DifferentialD]", "t"}]}]}]]],
 ", however, the solution comes quickly.  This is just one of the many \
reasons why good physicists and engineers, in addition to mathematicians, \
benefit from a thorough working knowledge of complex analysis."
}], "Text"],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "t"}]], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "=", " ", 
   RowBox[{"2", "\[ImaginaryI]"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{
  "Explore", " ", "Solution", " ", "for", " ", "Extra", " ", "Example", " ", 
   "1."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506704777984375*^9, 3.506704777984375*^9}}],

Cell["\<\
Compute the integral directly using a complex function for the integrand.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "int", ",", "t", ",", "val"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", 
     SuperscriptBox[
      RowBox[{"\[ExponentialE]", " "}], 
      RowBox[{"\[ImaginaryI]", " ", "t"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "t_", "]"}], "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[t] = \[Integral]f[t]\[DifferentialD]t = \>\"", ",", 
      RowBox[{"F", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\[Pi]] = \>\"", ",", 
      RowBox[{"F", "[", "\[Pi]", "]"}], ",", "\"\<,  F[0] = \>\"", ",", 
      RowBox[{"F", "[", "0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]\)]\)f[t]\
\[DifferentialD]t = F[\[Pi]] - F[0]\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]\)]\)f[t]\
\[DifferentialD]t = (\>\"", ",", 
      RowBox[{"F", "[", "\[Pi]", "]"}], ",", "\"\<) - (\>\"", ",", 
      RowBox[{"F", "[", "0", "]"}], ",", "\"\<) = \>\"", ",", "val"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 AspectRatioFixed->True]
}, Closed]]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{923, 628},
WindowMargins->{{9, Automatic}, {Automatic, 3}},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 182, 3, 29, "Text"],
Cell[1733, 51, 791, 14, 119, "Text"],
Cell[2527, 67, 110, 2, 29, "Text"],
Cell[2640, 71, 367, 7, 47, "Text",
 Evaluatable->False],
Cell[3010, 80, 148, 3, 29, "Text"],
Cell[3161, 85, 2092, 73, 87, "Text",
 Evaluatable->False],
Cell[5256, 160, 1835, 66, 87, "Text",
 Evaluatable->False],
Cell[7094, 228, 494, 19, 35, "Text",
 Evaluatable->False],
Cell[7591, 249, 4026, 137, 275, "Text"],
Cell[CellGroupData[{
Cell[11642, 390, 229, 6, 37, "Subsection"],
Cell[11874, 398, 205, 6, 29, "Text"],
Cell[12082, 406, 5575, 152, 733, "Input"],
Cell[17660, 560, 233, 7, 29, "Text",
 Evaluatable->False],
Cell[17896, 569, 2475, 66, 346, "Input"]
}, Closed]],
Cell[20386, 638, 907, 32, 42, "Text",
 Evaluatable->False],
Cell[21296, 672, 1949, 56, 112, "Text"],
Cell[23248, 730, 5599, 152, 412, "Text"],
Cell[28850, 884, 2117, 69, 111, "Text"],
Cell[CellGroupData[{
Cell[30992, 957, 226, 6, 37, "Subsection"],
Cell[31221, 965, 251, 8, 29, "Text",
 Evaluatable->False],
Cell[31475, 975, 6283, 169, 823, "Input"]
}, Closed]],
Cell[37773, 1147, 760, 27, 44, "Text"],
Cell[38536, 1176, 962, 33, 87, "Text"],
Cell[39501, 1211, 1135, 39, 87, "Text"],
Cell[40639, 1252, 829, 29, 87, "Text"],
Cell[41471, 1283, 550, 19, 87, "Text"],
Cell[42024, 1304, 1935, 63, 130, "Text"],
Cell[43962, 1369, 6446, 199, 468, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[50433, 1572, 231, 6, 37, "Subsection"],
Cell[50667, 1580, 1349, 37, 185, "Input"]
}, Closed]],
Cell[52031, 1620, 2831, 105, 178, "Text"],
Cell[54865, 1727, 975, 35, 38, "Text",
 Evaluatable->False],
Cell[55843, 1764, 4317, 132, 245, "Text"],
Cell[CellGroupData[{
Cell[60185, 1900, 231, 6, 37, "Subsection"],
Cell[60419, 1908, 240, 8, 47, "Text",
 Evaluatable->False],
Cell[60662, 1918, 2954, 80, 382, "Input"],
Cell[63619, 2000, 102, 2, 29, "Text"]
}, Closed]],
Cell[63736, 2005, 1150, 28, 88, "Text"],
Cell[64889, 2035, 476, 17, 33, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[65390, 2056, 260, 7, 37, "Subsection"],
Cell[65653, 2065, 143, 4, 29, "Text",
 Evaluatable->False],
Cell[65799, 2071, 2172, 60, 334, "Input"]
}, Closed]]
}
]
*)

(* End of internal cache information *)
