(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     99292,       3368]
NotebookOptionsPosition[     96766,       3284]
NotebookOutlinePosition[     97159,       3301]
CellTagsIndexPosition[     97116,       3298]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[StyleBox["6.4  The Fundamental Theorems of Integration",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.532709382703125*^9, 3.532709383484375*^9}}],

Cell[TextData[{
 "\tLet ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " be analytic in the simply connected domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  The theorems in this section show that an antiderivative ",
 StyleBox["F",
  FontFamily->"Courier New"],
 " can be constructed by contour integration.  A consequence will be the fact \
that in a simply connected domain, the integral of an analytic function f \
along any contour joining  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "  ", "to", "  ", 
   SubscriptBox["z", "2"]}]]],
 "  is the same, and its value is given by  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", 
     SubscriptBox["z", "2"], ")"}]}], "-", 
   RowBox[{"F", 
    RowBox[{"(", 
     SubscriptBox["z", "1"], ")"}]}]}]]],
 ".  As a result, we can use the antiderivative formulas from calculus to \
compute the value of definite integrals.  The next two theorems are \
generalizations of the ",
 StyleBox[ButtonBox["Fundamental Theorems of Calculus",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/FundamentalTheoremsofCalculus.html"], 
    None}],
  FontVariations->{"Underline"->True}],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Theorem 6.8 (Indefinite Integrals or Antiderivatives).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " be analytic in the simply connected domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  If  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  is a fixed value in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " and if ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is any contour in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " with initial point  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  and terminal point ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ", then the function \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", "C"], "  ", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      SubscriptBox["z", "0"], "z"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "\[Zeta]", ")"}], 
      RowBox[{"\[DifferentialD]", "\[Zeta]"}]}]}]}]}]]],
 "  \n\nis well-defined and analytic in D, with its derivative given by  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"F", "'"}], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ".   "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 6.8 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Remark 6.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  It is important to stress that the line integral of an analytic function \
is independent of path.  In Example 6.9 we showed that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", 
     SubscriptBox["C", "1"]], " ", 
    RowBox[{"z", " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", 
      SubscriptBox["C", "2"]], " ", 
     RowBox[{"z", " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}], " ", "=", " ", 
    RowBox[{"4", "+", 
     RowBox[{"2", "\[ImaginaryI]"}]}]}]}]]],
 ",  where ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " and ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 " were different contours joining  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "1"}], "-", 
   RowBox[{"\[ImaginaryI]", "  ", 
    StyleBox["to",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", "3"}], "+", "\[ImaginaryI]"}]]],
 ".  Because the integrand  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", "z"}]]],
 " is an analytic function, Theorem 6.8 lets us know ahead of time that the \
value of the two integrals is the same; hence one calculation would have \
sufficed.  If you ever have to compute a line integral of an analytic \
function over a difficult contour, change the contour to something easier.  \
You are guaranteed to get the same answer.  Of course, you must be sure that \
the function you're dealing with is analytic in a simply connected domain \
containing your original and new contours."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Exploration", "."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670498553125*^9, 3.50670498553125*^9}}],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", "z"}]],
  AspectRatioFixed->True],
 "  and the initial point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["Z", "0"], "=", 
   RowBox[{
    RowBox[{"-", "1"}], "-", "\[ImaginaryI]"}]}]],
  AspectRatioFixed->True],
 "  and terminal point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["Z", "1"], "=", 
   RowBox[{"3", "+", "\[ImaginaryI]"}]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "path", ",", "val1", ",", "val2"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "0"], "=", 
     RowBox[{
      RowBox[{"-", "1"}], "-", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], "=", 
     RowBox[{"3", "+", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val1", " ", "=", " ", 
     RowBox[{
      RowBox[{"F", "[", 
       SubscriptBox["Z", "1"], "]"}], " ", "-", " ", 
      RowBox[{"F", "[", 
       SubscriptBox["Z", "0"], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val2", " ", "=", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       SubscriptBox["Z", "0"], 
       SubscriptBox["Z", "1"]], 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"path", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.035", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "0"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "0"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.035", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"Dashing", "[", 
           RowBox[{"{", 
            RowBox[{"0.03", ",", "0.03"}], "}"}], "]"}], ",", 
          RowBox[{"Arrowheads", "[", 
           RowBox[{"{", 
            RowBox[{"0.0", ",", "0.05"}], "}"}], "]"}], ",", 
          RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                SubscriptBox["Z", "0"], "]"}], ",", 
               RowBox[{"Im", "[", 
                SubscriptBox["Z", "0"], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                SubscriptBox["Z", "1"], "]"}], ",", 
               RowBox[{"Im", "[", 
                SubscriptBox["Z", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], 
         "}"}]}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"path", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.2"}], ",", "3.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   F[z] = \[Integral]\>\"", ",", "\"\<(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)\[DifferentialD]z = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"F", "[", 
       SubscriptBox["Z", "1"], "]"}], ",", "\"\<,  and  F[\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"F", "[", 
       SubscriptBox["Z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<It is permissible to use the straight line path.\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral]\>\"", 
       SubscriptBox["Z", "0"], 
       SubscriptBox["Z", "1"]], ",", "\"\<(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)\[DifferentialD]z = F[\>\"", 
      ",", 
      SubscriptBox["Z", "1"], ",", "\"\<] - F[\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<]\>\""}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<         = (\>\"", ",", 
      RowBox[{"F", "[", 
       SubscriptBox["Z", "1"], "]"}], " ", ",", "\"\<) - (\>\"", ",", " ", 
      RowBox[{"F", "[", 
       SubscriptBox["Z", "0"], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<         = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", "val1", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral]\>\"", 
       SubscriptBox["Z", "0"], 
       SubscriptBox["Z", "1"]], ",", "\"\<(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)\[DifferentialD]z = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", "val2", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral]\>\"", 
       SubscriptBox["Z", "0"], 
       SubscriptBox["Z", "1"]], ",", "\"\<(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)\[DifferentialD]z = \>\"", ",", 
      RowBox[{"N", "[", "val2", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399308567921875*^9, 3.399308574453125*^9}, {
  3.39988283946875*^9, 3.3998828411875*^9}, {3.39988307021875*^9, 
  3.3998830928125*^9}, {3.39988312409375*^9, 3.3998831614375*^9}, {
  3.39988319146875*^9, 3.399883191984375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tIf we set ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   SubscriptBox["z", "1"]}]]],
 " in Theorem 6.8, then we obtain the following familiar result for \
evaluating a definite integral of an analytic function. "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 6.9 (Definite Integrals).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 "  be analytic in a simply connected domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  If  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  and  ",
 Cell[BoxData[
  SubscriptBox["z", "1"]]],
 "  are two points in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " joined by a contour C, then \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     SubscriptBox["z", "0"], 
     SubscriptBox["z", "1"]], " ", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"F", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}]}], "-", 
    RowBox[{"F", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}]}]}]]],
 ",  \n\nwhere ",
 StyleBox["F(z)",
  FontFamily->"Courier New"],
 " is any antiderivative of ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 6.9 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]],

Cell["\<\
\tTheorem 6.9 gives an important method for evaluating definite integrals \
when the integrand is an analytic function in a simply connected domain.  In \
essence, it permits you to use all the rules of integration that you learned \
in calculus.  When the conditions of Theorem 6.9 are met, applying it is \
generally much easier than parametrizing a contour.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Example 6.17.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", 
       SuperscriptBox["z", 
        RowBox[{"1", "/", "2"}]]}]], " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "=", 
   RowBox[{"1", "+", "\[ImaginaryI]"}]}]]],
 " where ",
 Cell[BoxData[
  SuperscriptBox["z", 
   RowBox[{"1", "/", "2"}]]]],
 " is the principal branch of the square root function and ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is the line segment joining  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"4", "  ", 
    StyleBox["to",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", "8"}], "+", 
   RowBox[{"6", "\[ImaginaryI]"}]}]]],
 ".  \n\nRemark. Sometimes we write this as   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "4", 
     RowBox[{"8", " ", "+", " ", 
      RowBox[{"6", "\[ImaginaryI]"}]}]], 
    RowBox[{
     FractionBox[
      SuperscriptBox["z", 
       RowBox[{
        RowBox[{"-", "1"}], "/", "2"}]], "2"], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "=", 
   RowBox[{"1", "+", "\[ImaginaryI]"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .57 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0178125 0.0890625 [
[.2619 .00531 -3 -9 ]
[.2619 .00531 3 0 ]
[.5 .00531 -3 -9 ]
[.5 .00531 3 0 ]
[.7381 .00531 -3 -9 ]
[.7381 .00531 3 0 ]
[.97619 .00531 -3 -9 ]
[.97619 .00531 3 0 ]
[1.025 .01781 0 -6.28125 ]
[1.025 .01781 10 6.28125 ]
[.01131 .19594 -6 -4.5 ]
[.01131 .19594 0 4.5 ]
[.01131 .37406 -6 -4.5 ]
[.01131 .37406 0 4.5 ]
[.01131 .55219 -6 -4.5 ]
[.01131 .55219 0 4.5 ]
[.02381 .595 -5 0 ]
[.02381 .595 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .57 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01781 m
.2619 .02406 L
s
[(2)] .2619 .00531 0 1 Mshowa
.5 .01781 m
.5 .02406 L
s
[(4)] .5 .00531 0 1 Mshowa
.7381 .01781 m
.7381 .02406 L
s
[(6)] .7381 .00531 0 1 Mshowa
.97619 .01781 m
.97619 .02406 L
s
[(8)] .97619 .00531 0 1 Mshowa
0 .01781 m
1 .01781 L
s
gsave
1.025 .01781 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .19594 m
.03006 .19594 L
s
[(2)] .01131 .19594 1 0 Mshowa
.02381 .37406 m
.03006 .37406 L
s
[(4)] .01131 .37406 1 0 Mshowa
.02381 .55219 m
.03006 .55219 L
s
[(6)] .01131 .55219 1 0 Mshowa
.02381 0 m
.02381 .57 L
s
gsave
.02381 .595 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .57 L
0 .57 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto fill
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto
-15. 3.75 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 0 1 r
.035 w
.5 .01781 Mdot
1 0 0 r
.97619 .55219 Mdot
0 1 0 r
.5 Mabswid
[ .03 .03 ] 0 setdash
.5 .01781 m
.97619 .55219 L
s
% Start of user PostScript
4. 0 8. 6. MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{299, 170.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzN2cdPVEEcB/DH211c9CBS9EosscDFhotguQhqYgT0Yk02iMIBqYmARgXU
qIAaFTDGerHgxXqxnmwX68Xeo8R/Yt2Zx5sMu9/vvhd8hDXs7Di/z2/qIwPL
qnBTVWVNuKm6IpxT0hCuq6quaMwprm2INvlSDCMl1zCM/hxD1CPR6mARiX5F
8kRhGKXizS+aF4qaT9QWqFqBqJmiNk3jhozJmngVgbZ8WfqHtNk9xzdPtSpl
oKOQKAMJchN3WQ66JBkhp1XHZRTEdI7aEgyor1qOVqhqBWouodi56Ic3CQwm
ywweb7Q7jJzhqF6UqaLhtBvUriYZJfZOiH+ZPLtOlEGVHbONWVZtgnhrEQ1+
+fT6tedYvlrF/9JA9wlGDrHn1RrDp8ZgGLWNG8YW1NvPtj2oHTjl5vhMO6ol
9vHEZsB7OW8BvGf4T91ox3eD5RzjfA/gRznfC/gRztsA7+a8HfAuzjsA70ze
k3GKHwTLOcD5IcD3c34Y8H2e8U7AOzjvAryd827A25L3II+D6e7i/ATgOzk/
CXirZ7wH8BbOewFv5rwP8B3eHMR48SZ/8vC7kTHxgENOOojLceRFeBYsq8FK
nAASfaANdVGvzzfuhyq0zHOglzptBXK2aK0JEtHGnwe8lvMLgG/n/CLgNd48
JaMRvwSWU8X5ZcC3cX4F8K2cXwW8kvN+wLdwfg3wiuQ9Gaf4dbCczZzfAHwT
5zcB38j5LcA3cH4b8PWc3wF8XfKejFP8LljOWs7vAb6G8/uAl3vGHwBexvlD
wEs5fwT4am8OQt51MoxuOF1mgLjpkCOvwYDqXV5lj8FiVmrc3a2JellhJcTe
+6yLJ6CL5dqumMNIRNv9FPASzp8BXsz5c8CXefNsjET8BZjuUs5fAr6E81eA
L/aMvwZ8EedvAC/i/C3ghcl7kE7xd2A5+Zy/B3w+5x8An8f5R8Dncv4J8Dmc
fwZ89sjt7E9RmmK0BB+0/hCl/EAyl6Pvogw4oK+iDAo0i6Mvokxzg8YKNJOj
b6qnGQ4TDzoguU9jBJrO0S9Rpjqg32qfxD2mBaZYOfLekino97Q/6ihksp7j
7q4bGKQSRNTLdNmbvMcGrClGW001k8muZx/UOP21Gs06VZtjuhrHFUcH8dda
T0T9vcHp+0fW80aunq02WLZmW60T2awSfNyuzzo2X/WfqY0af9o6yVKbbQz9
xP9/dsdI+Qck2Sgn\
\>"],
  ImageRangeCache->{{{0, 298}, {169.125, 0}} -> {0, 0, 0, 0}}],
 "        "
}], "Text",
 CellChangeTimes->{{3.5067611550625*^9, 3.50676115596875*^9}}],

Cell[TextData[{
 "Solution.  We showed in Chapter 3 that if  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", 
    FractionBox["1", "2"]]}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"F", "'"}], 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"2", 
     SuperscriptBox["z", 
      RowBox[{"1", "/", "2"}]]}]]}]]],
 ",  where the principal branch of the square root function is used in both \
the formulas for ",
 StyleBox["F(z)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["F'(z)",
  FontFamily->"Courier New"],
 ".  We note that ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is contained in the simply connected domain ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "4"], 
   RowBox[{"(", 
    RowBox[{"6", "+", 
     RowBox[{"3", "\[ImaginaryI]"}]}], ")"}]}]]],
 ", which is the open disk of radius ",
 StyleBox["4",
  FontFamily->"Courier New"],
 " centered at the midpoint of the segment C.  Since  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"2", 
     SuperscriptBox["z", 
      RowBox[{"1", "/", "2"}]]}]]}]]],
 "  is analytic in the domain ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "4"], 
   RowBox[{"(", 
    RowBox[{"6", "+", 
     RowBox[{"3", "\[ImaginaryI]"}]}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "z", ")"}]}]]],
 "is an anti-derivative of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 ", Theorem 6.9 guarantees that  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", 
       SuperscriptBox["z", 
        RowBox[{"1", "/", "2"}]]}]], " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "4", 
      RowBox[{"8", " ", "+", " ", 
       RowBox[{"6", "\[ImaginaryI]"}]}]], 
     RowBox[{
      FractionBox[
       SuperscriptBox["z", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}]], "2"], 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"F", 
      RowBox[{"(", 
       RowBox[{"8", "+", 
        RowBox[{"6", "\[ImaginaryI]"}]}], ")"}]}], " ", "-", " ", 
     RowBox[{"F", 
      RowBox[{"(", "4", ")"}]}]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"                        ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"8", " ", "+", 
         RowBox[{"6", "\[ImaginaryI]"}]}], ")"}], 
       FractionBox["1", "2"]], "  ", "-", "  ", 
      SuperscriptBox[
       RowBox[{"(", "4", ")"}], 
       FractionBox["1", "2"]]}], "  ", "=", "  ", 
     RowBox[{"3", "+", "\[ImaginaryI]", "  ", "-", "  ", "2"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                        ", 
   RowBox[{"=", "  ", 
    RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}]}]}]}]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"6.17", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.5067049909375*^9, 3.506704990953125*^9}}],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    SuperscriptBox["z", 
     RowBox[{
      RowBox[{"-", "1"}], "/", "2"}]], "2"]}]],
  AspectRatioFixed->True],
 "  and the initial point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["Z", "0"], "=", "4"}]],
  AspectRatioFixed->True],
 "  and terminal point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["Z", "1"], "=", 
   RowBox[{"8", "+", 
    RowBox[{"6", "\[ImaginaryI]"}]}]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "path", ",", "val1", ",", "val2"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      SuperscriptBox["z", 
       RowBox[{
        RowBox[{"-", "1"}], "/", "2"}]], "2"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "0"], "=", "4"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], "=", 
     RowBox[{"8", "+", 
      RowBox[{"6", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val1", " ", "=", " ", 
     RowBox[{
      RowBox[{"F", "[", 
       SubscriptBox["Z", "1"], "]"}], " ", "-", " ", 
      RowBox[{"F", "[", 
       SubscriptBox["Z", "0"], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val2", " ", "=", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       SubscriptBox["Z", "0"], 
       SubscriptBox["Z", "1"]], 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"path", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.035", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "0"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "0"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.035", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"Dashing", "[", 
           RowBox[{"{", 
            RowBox[{"0.03", ",", "0.03"}], "}"}], "]"}], ",", 
          RowBox[{"Arrowheads", "[", 
           RowBox[{"{", 
            RowBox[{"0.0", ",", "0.05"}], "}"}], "]"}], ",", 
          RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                SubscriptBox["Z", "0"], "]"}], ",", 
               RowBox[{"Im", "[", 
                SubscriptBox["Z", "0"], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                SubscriptBox["Z", "1"], "]"}], ",", 
               RowBox[{"Im", "[", 
                SubscriptBox["Z", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], 
         "}"}]}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"path", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.2"}], ",", "8.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.2"}], ",", "6.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "8", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "6", ",", "2"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    F[z] = \[Integral]\>\"", ",", "\"\<(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)\[DifferentialD]z = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"F", "[", 
       SubscriptBox["Z", "1"], "]"}], ",", "\"\<,  and  F[\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"F", "[", 
       SubscriptBox["Z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<It is permissible to use the straight line path.\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral]\>\"", 
       SubscriptBox["Z", "0"], 
       SubscriptBox["Z", "1"]], ",", "\"\<(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)\[DifferentialD]z = F[\>\"", 
      ",", 
      SubscriptBox["Z", "1"], ",", "\"\<] - F[\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<]\>\""}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              = (\>\"", ",", 
      RowBox[{"F", "[", 
       SubscriptBox["Z", "1"], "]"}], " ", ",", "\"\<) - (\>\"", ",", " ", 
      RowBox[{"F", "[", 
       SubscriptBox["Z", "0"], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", "val1", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral]\>\"", 
       SubscriptBox["Z", "0"], 
       SubscriptBox["Z", "1"]], ",", "\"\<(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)\[DifferentialD]z = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", "val2", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral]\>\"", 
       SubscriptBox["Z", "0"], 
       SubscriptBox["Z", "1"]], ",", "\"\<(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)\[DifferentialD]z = \>\"", ",", 
      RowBox[{"N", "[", "val2", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399308612453125*^9, 3.3993086153125*^9}, {
  3.399882900546875*^9, 3.399882900875*^9}, {3.39988322978125*^9, 
  3.399883251890625*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 6.18.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{"cos", 
     RowBox[{"(", "z", ")"}], " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", " ", "sin"}], " ", "1"}], "  ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "sinh", " ", "1"}]}]}]]],
 ",  where ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is the line segment between ",
 Cell[BoxData[
  RowBox[{"1", " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "\[ImaginaryI]"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0833333 0.833333 0.0833333 0.833333 [
[.5 .07083 -8.09375 -20.125 ]
[.5 .07083 8.09375 0 ]
[.91667 .07083 -3 -9 ]
[.91667 .07083 3 0 ]
[1.025 .08333 0 -6.28125 ]
[1.025 .08333 10 6.28125 ]
[.07083 .5 -16.1875 -10.0625 ]
[.07083 .5 0 10.0625 ]
[.07083 .91667 -6 -4.5 ]
[.07083 .91667 0 4.5 ]
[.08333 1.025 -5 0 ]
[.08333 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.5 .08333 m
.5 .08958 L
s
gsave
.5 .07083 -69.0938 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.063 moveto
(\\200\\200) show
69.000 17.063 moveto
(\\200) show
71.063 17.063 moveto
(\\200) show
66.063 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.91667 .08333 m
.91667 .08958 L
s
[(1)] .91667 .07083 0 1 Mshowa
0 .08333 m
1 .08333 L
s
gsave
1.025 .08333 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .5 m
.08958 .5 L
s
gsave
.07083 .5 -77.1875 -14.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.063 moveto
(\\200\\200) show
69.000 17.063 moveto
(\\200) show
71.063 17.063 moveto
(\\200) show
66.063 23.125 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.08333 .91667 m
.08958 .91667 L
s
[(1)] .07083 .91667 1 0 Mshowa
.08333 0 m
.08333 1 L
s
gsave
.08333 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto fill
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto
-15. 3.75 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 0 1 r
.035 w
.91667 .08333 Mdot
1 0 0 r
.08333 .91667 Mdot
0 1 0 r
.5 Mabswid
[ .03 .03 ] 0 setdash
.91667 .08333 m
.08333 .91667 L
s
% Start of user PostScript
1. 0 0 1. MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{173, 173},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzd2GlPE1EUBuABWijgwuKaCDQCRsAIGNkUMALKYsCiIMpiLFVpjSyB8sEl
cYtL3KIhEP9Ef+PYc2c6TNv3nbbkfqLJzJR7n3vOPXNnyHQmw/Hos9VwPBYJ
B0c3wxvRWGQreHt9M9lUUmQYRkK2oCHfzeRXe5cwTNOUTnUIycEnHY9cDUaJ
oWzym2zzVtc06LJH3QNdD90BfWld++lUzGJpmE+bl304CeJ2OVNOdtjR1EeF
meMDdw/UFZe9X1rOcdTroD7Q6zHwGmg7NCF6ncWt5wP7Mq8AhLZlL01mXR4r
ZR53YmZcIgHrr3I5fEpdMyqOc4eYRqV89WckkE95YeX3OG2mE1/lqwY4kKMu
uYNcc0xuVTmK5KGsclNtHmuzBXiD7htsAyQ5z/k64I2crwHexPkq4M26K34B
klzkPAZ4C+dRwFs5XwG8TXfFT0GSy5xHAG/nfBnwDs7DgHfqrvgxSHKV8yXA
uzhfBLyb8wXAe3RXPAeSXOf8AeD9nM8CPqCNzwA+qPsETYMkNzkPAT7E+V3A
hzmfAnxEd8V3QJJRzicAH+N8HPBxzscAn9Bd8S2QZJLzEcCnOB8G3Fp369lE
PRUHwMAhMDDkGpjBUZtddAXoQhltXgm6ykDbDTDB++4JZv2AQEkHQZQZ17zV
0xIqbgAMnOXr0A+49f/MKi4guDTHlaMms8eT9IIkHo/IPYAvcN4N+KLrhKsf
M2ilPAbmu9hdIMRSYSEKvLwK5FfABJ/kcx11goFhvggdgC9z3g54hPOD/Qe7
BJI857wN8BXOWwGPct4CeEx3xRdAkpecNwO+ynkT4GucNwK+rrviIEiyyXkD
4Fuc1wMe57wO8G3dFZ8FSV5xfgbw15yfBvyNNn4K8Le6T1AtSPKO8xrA33Ne
DfgHzqsA/6i74qMgyWfOjwD+hfNKwL9y7pN9sWgfGPgtx0Clf3Ok3g/5Bf3K
gUoF/eSoWPYBQT/cKP3pLLlVCPnuScqzomQ+hHpPpcyjaDl5qt4/2f2pN2jq
hdpfq/+YfYKM1Ls021hox0JV+HwY1mLt5kBqcSW6q8MjsF9gWsysE6hi2Q+Q
+288fSDYwW6Qw9CVyPtQ65zBf1bDCRDV43F9F4+Sz54rQ/YPGbu3xr6RjczX
uXlUYhT9B7Qy6Nc=\
\>"],
  ImageRangeCache->{{{0, 172}, {172, 0}} -> {0, 0, 0, 0}}],
 "        "
}], "Text",
 CellChangeTimes->{{3.50676115859375*^9, 3.50676115940625*^9}}],

Cell[TextData[{
 "Solution.  An antiderivative of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"cos", " ", "z"}]}]]],
 "  is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"sin", " ", "z"}]}]]],
 ".  Because ",
 StyleBox["F(z)",
  FontFamily->"Courier New"],
 " is entire, we use Theorem 6.9 to conclude that \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{"cos", 
      RowBox[{"(", "z", ")"}], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "1", "\[ImaginaryI]"], " ", 
     RowBox[{"cos", 
      RowBox[{"(", "z", ")"}], 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "1", "\[ImaginaryI]"], " ", 
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}], 
       RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"F", 
       RowBox[{"(", "\[ImaginaryI]", ")"}]}], "-", 
      RowBox[{"F", 
       RowBox[{"(", "1", ")"}]}]}]}]}], "\[IndentingNewLine]", 
   " "}], "\[IndentingNewLine]", 
  RowBox[{"                            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"sin", " ", "\[ImaginaryI]"}], "  ", "-", "  ", 
     RowBox[{"sin", " ", "1"}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", "sinh", " ", "1"}], "  ", "-", "  ", 
     RowBox[{"sin", " ", "1"}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "  ", "sin"}], " ", "1"}], "  ", "+", "  ", 
     RowBox[{"\[ImaginaryI]", " ", "sinh", " ", "1"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"-", " ", "0.8414709848078965`"}], " ", "+", " ", 
     RowBox[{"1.1752011936438014`", " ", "\[ImaginaryI]"}]}]}]}]}]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"6.18", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.5067049939375*^9, 3.506704993953125*^9}}],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   RowBox[{"Cos", "[", "z", "]"}]}]],
  AspectRatioFixed->True],
 "  and the initial point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["Z", "0"], "=", "1"}]],
  AspectRatioFixed->True],
 "  and terminal point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["Z", "1"], "=", "\[ImaginaryI]"}]],
  AspectRatioFixed->True],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g", ",", "path", ",", "val1", ",", "val2"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Cos", "[", "z", "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "0"], "=", "1"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], "=", "\[ImaginaryI]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val1", " ", "=", " ", 
     RowBox[{
      RowBox[{"g", "[", 
       SubscriptBox["Z", "1"], "]"}], " ", "-", " ", 
      RowBox[{"g", "[", 
       SubscriptBox["Z", "0"], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val2", " ", "=", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       SubscriptBox["Z", "0"], 
       SubscriptBox["Z", "1"]], 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"path", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.035", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "0"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "0"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.035", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"Dashing", "[", 
           RowBox[{"{", 
            RowBox[{"0.03", ",", "0.03"}], "}"}], "]"}], ",", 
          RowBox[{"Arrowheads", "[", 
           RowBox[{"{", 
            RowBox[{"0.0", ",", "0.05"}], "}"}], "]"}], ",", 
          RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                SubscriptBox["Z", "0"], "]"}], ",", 
               RowBox[{"Im", "[", 
                SubscriptBox["Z", "0"], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                SubscriptBox["Z", "1"], "]"}], ",", 
               RowBox[{"Im", "[", 
                SubscriptBox["Z", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], 
         "}"}]}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"path", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[z] = \[Integral]\>\"", ",", "\"\<(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)\[DifferentialD]z = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"g", "[", 
       SubscriptBox["Z", "1"], "]"}], ",", "\"\<,  and  g[\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"g", "[", 
       SubscriptBox["Z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<It is permissible to use the straight line path.\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral]\>\"", 
       SubscriptBox["Z", "0"], 
       SubscriptBox["Z", "1"]], ",", "\"\<(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)\[DifferentialD]z = g[\>\"", 
      ",", 
      SubscriptBox["Z", "1"], ",", "\"\<] - g[\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<]\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<            = (\>\"", ",", 
      RowBox[{"g", "[", 
       SubscriptBox["Z", "1"], "]"}], " ", ",", "\"\<) - (\>\"", ",", " ", 
      RowBox[{"g", "[", 
       SubscriptBox["Z", "0"], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<            = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", "val1", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral]\>\"", 
       SubscriptBox["Z", "0"], 
       SubscriptBox["Z", "1"]], ",", "\"\<(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)\[DifferentialD]z = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", "val2", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral]\>\"", 
       SubscriptBox["Z", "0"], 
       SubscriptBox["Z", "1"]], ",", "\"\<(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)\[DifferentialD]z = \>\"", ",", 
      RowBox[{"N", "[", "val2", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3993086293125*^9, 3.3993086319375*^9}, {
  3.399882906453125*^9, 3.399882906625*^9}, {3.399883273515625*^9, 
  3.399883286484375*^9}, {3.39988339234375*^9, 3.399883392953125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 6.19.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox[" ",
  FontWeight->"Bold"],
 " We let ",
 Cell[BoxData[
  RowBox[{"D", "=", 
   RowBox[{"{", 
    RowBox[{"z", "=", 
     RowBox[{"r", " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], ":", " ", 
       RowBox[{"r", ">", 
        RowBox[{
         RowBox[{"0", " ", "and"}], " ", "-", "\[Pi]"}], "<", "\[Theta]", "<",
         "\[Pi]"}]}]}]}], "}"}]}]]],
 " be the simply connected domain which is the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-plane slit along the negative ",
 StyleBox["x",
  FontFamily->"Courier New"],
 "-axis, shown in Figure 6.32.  We know that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", "z"]}]]],
 " is analytic in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", and has an antiderivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"Log", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " for all ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  If ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a contour in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " that joins the point ",
 Cell[BoxData[
  SubscriptBox["z", "1"]]],
 " to the point ",
 Cell[BoxData[
  SubscriptBox["z", "2"]]],
 ", then Theorem 6.9 implies that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     SubscriptBox["z", "1"], 
     SubscriptBox["z", "2"]], " ", 
    RowBox[{
     FractionBox["1", "z"], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"Log", " ", 
     SubscriptBox["z", "2"]}], "-", 
    RowBox[{"Log", " ", 
     SubscriptBox["z", "1"]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.454545 0.5 0.454545 [
[.04545 .4875 -6 -9 ]
[.04545 .4875 6 0 ]
[.95455 .4875 -3 -9 ]
[.95455 .4875 3 0 ]
[1.025 .5 0 -6.28125 ]
[1.025 .5 10 6.28125 ]
[.4875 .04545 -12 -4.5 ]
[.4875 .04545 0 4.5 ]
[.4875 .95455 -6 -4.5 ]
[.4875 .95455 0 4.5 ]
[.5 1.025 -5 0 ]
[.5 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04545 .5 m
.04545 .50625 L
s
[(-1)] .04545 .4875 0 1 Mshowa
.95455 .5 m
.95455 .50625 L
s
[(1)] .95455 .4875 0 1 Mshowa
0 .5 m
1 .5 L
s
gsave
1.025 .5 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .04545 m
.50625 .04545 L
s
[(-1)] .4875 .04545 1 0 Mshowa
.5 .95455 m
.50625 .95455 L
s
[(1)] .4875 .95455 1 0 Mshowa
.5 0 m
.5 1 L
s
gsave
.5 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.03 w
.04545 .50945 Mdot
1 0 0 r
.04545 .49055 Mdot
0 1 0 r
.5 Mabswid
[ .031 .031 ] 0 setdash
newpath
.5 .5 .45455 -179.049 179.049 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{206, 206},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzVmglT00AYhpejiIogglouW+RsuQ+5z3IU5T4cdBS1Ms7gDAwO+qP8Nf6l
2N1v8yXFd0NWYqd2pk2b73nf3f12kzS72c79OPtykfvx9TSXzF7lvp19Pf2e
XL+8yu+qKBNC/JLvpJDfnfxX/fFROI4jKoT6kf8m3+fqU5R+6FhuYjJQYYbe
glBIXOUo/47Jz5gbcDzNF9Lsy02ljFSGLCyma+6Iz2SxIzfKvDqkRZ38LJeK
d2SRZYtaHRJepX3Ceq7tMQnX2CkO8Meg3UckXGFhMxA2A+GuuU9b2ExD87wj
CfA2jm4TPss7ngM8wdFNwqc4W512Y68LNGvVjHdzwRoaA/oUEPayMEPCUSBM
A2EacItkMcyeA+ZGDzI0ZJeZIVDwjBkfBvg04agJo8BiBHBTZJECoTFggbI6
SRa9IDQOLFCPTpCF1/uT5lyiERWAW54rp4D7iBmfBjj1lGgHoVlgMQM4Ghve
kewLzQGLWcANkkUChOaBxRzgBuwsdFa9U83SDRA86kL31BKwSBUDR2fqDLBY
BhwdJKIJhFaARYZzqYVxIFwFwhXAdZPFUxBaM6feEn8C8HW7jg0IrQP3jsjw
LMDp6igaQOglsNgAXHtkFo9A6BWweAm4pJ2F7oR6gG9Ghlv2/iZwf2bGtwDe
Vgy8DoS27SxqQWgHWGwDrpUsHoDQ7r+xOC8GbjlYdoF7cwni90FoH1jsAa7p
f7TQfXYP4AeR4ZaDxV+IukPeA5B/H80HCKFuG+kSKWpu0PyRFO0hf8XtLA58
Fu4+XQt1T11JdSuE5AulLMDsrtpUFoRu76JfyMU/YFw87ncpLODQriLuZIHj
uuc3R+bhcEduyhVVwbx8o2L/RpMjWAh3SsZ9VelfhXtVr8ak20+tEV4wXzIL
vVIo4NVMTs7kRW6lHJ3nsHmsBVyVz165hzWruaH19o7+bpa0gzo3QIhODdHh
YQdwUU6QpYHvAy5uTm5J4QGXQku8+BffGoCj60xJ4QF/osL+ldwBXIu5z0oK
D/ifHsHdQth7lvMSxB8CfAvgAfePEVigPnsF8ERkeMBtviVexOkN3WeNAN8w
42hZJRsZHnbSynI+aQ3gnWZ8FeBdkeEBM4LqGuJbdCkUZoCwh4RhZ0J1mlsA
vhwZ3sqtQNAiMEubs7UA8D4zPg/wfjMeMNmO8IDp/SQIWa4QtHPekFAntwPo
p814J8CnzHjYJZ0Jruq4OVsvgFl0+BhXQS97hV05C1j2SrMnEuoc9QP9sBkf
YE8EDQKzWXOj+9lswQz1AU+Nh13ETXE5dAh764c+YS8Q6kajvuwx4yr9iu4G
UAdXJmtu9HNQYgCeZE+61MMTRwIIE4DTFirHanKlDQh1U9FJHD2FEOcKHphb
0cgl6icbNnhHgwm/VvZrEm5xD6h7duPDKTXMnZDwUOOOf+5AbtEjJdVcvU/E
vuFWqic+7shvZxS6xfMvIXC3YPyoSWk9LvTLdnPCjbukHR+A+cWN5V5XydeF
rwSaBmOVF32vB4m4Pp8UokGi7DcvXcOf\
\>"],
  ImageRangeCache->{{{0, 205}, {205, 0}} -> {-1, -1, 0, 0}}],
 "       ",
 StyleBox["\n",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t    Figure 6.32  ",
 "The simply connected domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " shown in Examples 6.19 and 6.20."
}], "Text",
 CellChangeTimes->{{3.50676116234375*^9, 3.506761179140625*^9}}],

Cell[TextData[{
 StyleBox["Example 6.20.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox[" ",
  FontWeight->"Bold"],
 " Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], 
    RowBox[{
     FractionBox["1", "z"], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], " ", "=", " ", 
   RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]"}]}]]],
 ",  where ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is the unit circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", " ", 
    RowBox[{"|", "z", "|"}]}], "=", "1"}]]],
 ",  taken with positive orientation."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  We let ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " be that circle with the point ",
 StyleBox["-1",
  FontFamily->"Courier New"],
 " omitted, as shown in Figure 6.32(b).  The contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is contained in the simply connected domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " of Example 6.19.  We know that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", "z"]}]]],
 "  is analytic in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", and has an antiderivative  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"Log", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ",  for all  ",
 Cell[BoxData[
  RowBox[{"z\[Epsilon]", " ", "D"}]]],
 ".  Therefore, if we let ",
 Cell[BoxData[
  SubscriptBox["z", "2"]]],
 " approach ",
 StyleBox["-1",
  FontFamily->"Courier New"],
 " on ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " through the upper half-plane and ",
 Cell[BoxData[
  SubscriptBox["z", "1"]]],
 " approach ",
 StyleBox["-1",
  FontFamily->"Courier New"],
 " on ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " through the lower half-plane,  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{
      FractionBox["1", "z"], 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", " ", 
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["lim", " "], 
      UnderscriptBox[
       RowBox[{
        SubscriptBox["z", "2"], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["z", "2"], "\[Epsilon]", " ", "C"}], ",", 
           RowBox[{
            RowBox[{"Im", " ", 
             SubscriptBox["z", "2"]}], ">", "0"}]}], ")"}]}]}], 
       RowBox[{
        SubscriptBox["z", "1"], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["z", "1"], "\[Epsilon]", " ", "C"}], ",", 
           RowBox[{
            RowBox[{"Im", " ", 
             SubscriptBox["z", "1"]}], "<", "0"}]}], ")"}]}]}]]], " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       SubscriptBox["z", "1"], 
       SubscriptBox["z", "2"]], " ", 
      RowBox[{
       FractionBox["1", "z"], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox[
       UnderscriptBox["lim", " "], 
       RowBox[{
        SubscriptBox["z", "2"], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["z", "2"], "\[Epsilon]", " ", "C"}], ",", 
           RowBox[{
            RowBox[{"Im", " ", 
             SubscriptBox["z", "2"]}], ">", "0"}]}], ")"}]}]}]], 
      RowBox[{"Log", 
       RowBox[{"(", 
        SubscriptBox["z", "2"], ")"}]}]}], "  ", "-", "   ", 
     RowBox[{
      UnderscriptBox[
       UnderscriptBox["lim", " "], 
       RowBox[{
        SubscriptBox["z", "1"], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["z", "1"], "\[Epsilon]", " ", "C"}], ",", 
           RowBox[{
            RowBox[{"Im", " ", 
             SubscriptBox["z", "1"]}], "<", "0"}]}], ")"}]}]}]], 
      RowBox[{"Log", 
       RowBox[{"(", 
        SubscriptBox["z", "1"], ")"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "  ", "-", "  ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Pi]"}], ")"}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{"=", "  ", 
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]}]}]}]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"6.20", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506704997984375*^9, 3.506704997984375*^9}}],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox["1", "z"]}]],
  AspectRatioFixed->True],
 ". "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g", ",", "path", ",", "val1", ",", "val2"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox["1", "z"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "0"], "=", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "0.0208"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], "=", 
     RowBox[{
      RowBox[{"-", "1"}], "-", 
      RowBox[{"\[ImaginaryI]", " ", "0.0208"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"z", "[", "\[Theta]_", "]"}], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"lim2", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"g", "[", 
        RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], ",", 
       RowBox[{"\[Theta]", "\[Rule]", "\[Pi]"}], ",", 
       RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"lim1", " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"g", "[", 
        RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], ",", 
       RowBox[{"\[Theta]", "\[Rule]", 
        RowBox[{"-", "\[Pi]"}]}], ",", 
       RowBox[{"Direction", "\[Rule]", 
        RowBox[{"-", "1"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[z] = \[Integral]\>\"", ",", "\"\<(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)\[DifferentialD]z = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(limit\), \(2\)]\) = \!\(\*UnderscriptBox[\(lim\
\), \(\[Theta] \[Rule] \[Pi]\)]\) \
Log[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\[Theta]\)]\)] = \
\>\"", ",", "lim2"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(limit\), \(1\)]\) = \!\(\*UnderscriptBox[\(lim\
\), \(\[Theta] \[Rule] \(-\[Pi]\)\)]\) Log[\!\(\*SuperscriptBox[\(\
\[ExponentialE]\), \(\[ImaginaryI]\[Theta]\)]\)] = \>\"", ",", "lim1"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[\>\"", ",", 
      RowBox[{"Re", "[", 
       SubscriptBox["Z", "1"], "]"}], ",", 
      "\"\<+ \[ImaginaryI] \!\(\*SuperscriptBox[\(0\), \(+\)]\)] = \>\"", ",",
       "lim2", ",", "\"\<,      g[\>\"", ",", 
      RowBox[{"Re", "[", 
       SubscriptBox["Z", "0"], "]"}], ",", 
      "\"\<+ \[ImaginaryI] \!\(\*SuperscriptBox[\(0\), \(-\)]\)] = \>\"", ",",
       "lim1"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"path", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "0"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "0"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"Dashing", "[", 
           RowBox[{"{", 
            RowBox[{"0.031", ",", "0.031"}], "}"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "1", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.125"}], ",", "3.125"}], "}"}]}], "]"}]}], 
         "\[IndentingNewLine]", "}"}]}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"path", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*UnderscriptBox[\(\[Integral]\), \(C\)]\)(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<)\[DifferentialD]z = \!\(\*SubscriptBox[\(limit\), \(2\)]\) - \!\(\
\*SubscriptBox[\(limit\), \(1\)]\) = (\>\"", ",", "lim2", ",", 
      "\"\<) - (\>\"", ",", "lim1", ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
     RowBox[{"f", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", ",", 
     RowBox[{"lim2", "-", "lim1"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The contour is the unit circle  C: |z| = 1.\>\"", 
     "]"}], ";"}], " "}]}]], "Input",
 CellChangeTimes->{{3.3993086521875*^9, 3.399308656078125*^9}, {
  3.399882911921875*^9, 3.399882912359375*^9}},
 AspectRatioFixed->True],

Cell["\<\

Another approach is to parameterize the integrand.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], 
      RowBox[{
       RowBox[{"z", "'"}], "[", "\[Theta]", "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "\[Theta]_", "]"}], "  ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{"w", " ", 
       RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      RowBox[{"G", "[", "\[Pi]", "]"}], " ", "-", " ", 
      RowBox[{"G", "[", 
       RowBox[{"-", "\[Pi]"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<         z[\[Theta]] = \>\"", ",", " ", 
      RowBox[{"z", "[", "\[Theta]", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<        z'[\[Theta]] = \>\"", ",", " ", 
      RowBox[{
       RowBox[{"z", "'"}], "[", "\[Theta]", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<         f[z] = \>\"", ",", " ", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], " ", ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z[\[Theta]]]z'[\[Theta]] = \>\"", ",", " ", "w"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  G[\[Theta]] = \[Integral]f[z[\[Theta]]]z'[\[Theta]]\
\[DifferentialD]\[Theta] = \[Integral](\>\"", ",", "w", ",", 
      "\"\<)\[DifferentialD]\[Theta] = \>\"", " ", ",", 
      RowBox[{"G", "[", "\[Theta]", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  G[\[Pi]] = \>\"", ",", " ", 
      RowBox[{"G", "[", "\[Pi]", "]"}], ",", " ", "\"\<,  G[-\[Pi]] = \>\"", 
      ",", 
      RowBox[{"G", "[", 
       RowBox[{"-", "\[Pi]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*UnderscriptBox[\(\[Integral]\), \(C\)]\)(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<)\[DifferentialD]z = G[\[Pi]] - G[-\[Pi]] = (\>\"", ",", 
      RowBox[{"G", "[", "\[Pi]", "]"}], ",", "\"\<) - (\>\"", ",", 
      RowBox[{"G", "[", 
       RowBox[{"-", "\[Pi]"}], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
     RowBox[{"f", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", ",",
      "val"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The contour is the unit circle C: |z| = 1.\>\"", "]"}],
     ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399308664453125*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", 
     RowBox[{"2", " ", "+", " ", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "4"]}]], 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "z"], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], ")"}], " ", 
      SuperscriptBox["\[ExponentialE]", "2"]}], 
     SqrtBox["2"]], " ", "-", " ", "1"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.454545 0.0833333 0.833333 [
[.5 .07083 -3 -9 ]
[.5 .07083 3 0 ]
[.95455 .07083 -3 -9 ]
[.95455 .07083 3 0 ]
[1.025 .08333 0 -6.28125 ]
[1.025 .08333 10 6.28125 ]
[.03295 .41058 -16.1875 -9.125 ]
[.03295 .41058 0 9.125 ]
[.03295 .73783 -16.1875 -9.09375 ]
[.03295 .73783 0 9.09375 ]
[.04545 1.025 -5 0 ]
[.04545 1.025 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.5 .08333 m
.5 .08958 L
s
[(1)] .5 .07083 0 1 Mshowa
.95455 .08333 m
.95455 .08958 L
s
[(2)] .95455 .07083 0 1 Mshowa
0 .08333 m
1 .08333 L
s
gsave
1.025 .08333 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.04545 .41058 m
.0517 .41058 L
s
gsave
.03295 .41058 -77.1875 -13.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.25 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 9.313 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.750 15.125 moveto
(\\200\\200) show
69.000 15.125 moveto
(\\200) show
71.063 15.125 moveto
(\\200) show
66.063 21.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.04545 .73783 m
.0517 .73783 L
s
gsave
.03295 .73783 -77.1875 -13.0938 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26.1875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
66.063 9.313 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.750 15.125 moveto
(\\200\\200) show
69.000 15.125 moveto
(\\200) show
71.063 15.125 moveto
(\\200) show
66.063 21.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.04545 0 m
.04545 1 L
s
gsave
.04545 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto fill
-15. 3.75 moveto 0 0 lineto
-15. -3.75 lineto
-15. 3.75 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 0 1 r
.035 w
.04545 .08333 Mdot
1 0 0 r
.95455 .73783 Mdot
0 1 0 r
.5 Mabswid
[ .03 .03 ] 0 setdash
.04545 .08333 m
.95455 .73783 L
s
% Start of user PostScript
0 0 2. 0.785398 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{172, 172},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztmGtPE0EUhod2S4vFCwWiIpoa4yUaNRqvUYQYbTVYNF7iNWhTL0WDkFKj
RmPRDyqJop+E+Bv4j2PPzHayXd4z3V32m2yys9OZZ855Z850ZjKlcr36bLpc
n6qU88VaebY6VZnLF2ZqzaJklxBihd68oLxsZt1kRUgpqZL/5NQnKRTfzNG7
FKlqhNIUlaicQ7kBHh/lTPjKBsOZuADKQqpAZf1ROuK0ldmHQ+lOUMmYyVm6
3jlEffShGrmsC7a04iMXjYdmU1eaehz9K2simVBTKemZVFIsULbb55ielMdP
0teQCw0avF5Q5vg75dpu1f/o0KUcCogUfyKNsNMq8wj4zeMpgP/i8W6AL/J4
GuA/I3UrCywt8HgvwL/z+EaAf+PxTQD/GqlbOWDpC4/3A/wzjw8AfJ7HBwHe
iNQtS9V24OQDjw+5/x0rNAxsvotbeB44qfP4biPcAu0xUC1uufuB3GkeP2CU
WKCDBnoVt9wjQO5zHj9qlFigYwZ6uha5adeMED0AOgmEP9YN9WK5aqPNACun
gJXJ0FZOmw5PBpF+Fjh9GNppoFE6D1zd40d+BOB3Na52UC2sfTNVvv1bP72t
04sxgTyOAY+3I82aS8DSDR6/DPDrGk8BPAHKEFcAZidCx7YIrJQ88fYdsjpN
jwD4OPB41aNbnfz8xui9Bhpe4Ye9BPAij08AvBBpeliqbgInF3n8lpnXFugO
sDkat/D7wMk5Hn9ghFugR8DmmbiFPwFOTvB42Qi3QBUDHY9b7gsg9zCPV40S
C/TSQIfilvsayN3H4zMA38vjs0Z4yuR28bg+YDlt1qXaSaTYyTd7Q2kqCNRN
0DAPqWNghqAdGlLLX5Jbz+Yo3UD4kMbRtoq2O9UwSw31UbvDulk3+DYPHmx7
eEtpD7XdqrGgq/x7StOehhk3hBj/aIKQoPBZbio+mZgq0r0ZCX9maGg9UrVQ
U0bo13LX0tAqpRWa10G398L9T61l/18KHcyQG3U03D4Xoy0z61XrVf9pVYA7
dHXjqda5v7qgD5hb7ujJ34oe793t6jXGrd1MH92ufe0N3gXbR3T9Az4a/1Y=
\
\>"],
  ImageRangeCache->{{{0, 171}, {171, 0}} -> {0, 0, 0, 0}}],
 "        "
}], "Text",
 CellChangeTimes->{{3.506761185234375*^9, 3.506761186140625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{
  "Explore", " ", "Solution", " ", "for", " ", "Extra", " ", "Example", " ", 
   "1."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670500534375*^9, 3.50670500534375*^9}}],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   SuperscriptBox["\[ExponentialE]", "z"]}]],
  AspectRatioFixed->True],
 "  and the initial point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["Z", "0"], "=", "0"}]],
  AspectRatioFixed->True],
 "  and terminal point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["Z", "1"], "=", 
   RowBox[{"2", "+", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "4"]}]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g", ",", "path", ",", "val1", ",", "val2"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", "z"]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "0"], "=", "0"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], "=", 
     RowBox[{"2", "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "4"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val1", " ", "=", " ", 
     RowBox[{
      RowBox[{"g", "[", 
       SubscriptBox["Z", "1"], "]"}], " ", "-", " ", 
      RowBox[{"g", "[", 
       SubscriptBox["Z", "0"], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val2", " ", "=", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       SubscriptBox["Z", "0"], 
       SubscriptBox["Z", "1"]], 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"path", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.035", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "0"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "0"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.035", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"Dashing", "[", 
           RowBox[{"{", 
            RowBox[{"0.03", ",", "0.03"}], "}"}], "]"}], ",", 
          RowBox[{"Arrowheads", "[", 
           RowBox[{"{", 
            RowBox[{"0.0", ",", "0.05"}], "}"}], "]"}], ",", 
          RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                SubscriptBox["Z", "0"], "]"}], ",", 
               RowBox[{"Im", "[", 
                SubscriptBox["Z", "0"], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                SubscriptBox["Z", "1"], "]"}], ",", 
               RowBox[{"Im", "[", 
                SubscriptBox["Z", "1"], "]"}]}], "}"}]}], "}"}], "]"}]}], 
         "}"}]}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"path", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "2.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          FractionBox["\[Pi]", "4"], ",", 
          FractionBox["\[Pi]", "8"]}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[z] = \[Integral]\>\"", ",", "\"\<(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)\[DifferentialD]z = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"g", "[", 
       SubscriptBox["Z", "1"], "]"}], ",", "\"\<,      g[\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"g", "[", 
       SubscriptBox["Z", "0"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<It is permissible to use the straight line path.\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral]\>\"", 
       SubscriptBox["Z", "0"], 
       SubscriptBox["Z", "1"]], ",", "\"\<(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)\[DifferentialD]z = g[\>\"", 
      ",", 
      SubscriptBox["Z", "1"], ",", "\"\<] - g[\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<]\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      = (\>\"", ",", 
      RowBox[{"g", "[", 
       SubscriptBox["Z", "1"], "]"}], " ", ",", "\"\<) - (\>\"", ",", " ", 
      RowBox[{"g", "[", 
       SubscriptBox["Z", "0"], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      = (\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"g", "[", 
        SubscriptBox["Z", "1"], "]"}], "]"}], " ", ",", "\"\<) - (\>\"", ",", 
      " ", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"g", "[", 
        SubscriptBox["Z", "0"], "]"}], "]"}], ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", "val1", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral]\>\"", 
       SubscriptBox["Z", "0"], 
       SubscriptBox["Z", "1"]], ",", "\"\<(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)\[DifferentialD]z = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", "val2", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral]\>\"", 
       SubscriptBox["Z", "0"], 
       SubscriptBox["Z", "1"]], ",", "\"\<(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)\[DifferentialD]z = (\>\"", 
      ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Re", "[", "val2", "]"}], "]"}], ",", 
      "\"\<) + \[ImaginaryI](\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Im", "[", "val2", "]"}], "]"}], ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral]\>\"", 
       SubscriptBox["Z", "0"], 
       SubscriptBox["Z", "1"]], ",", "\"\<(\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<)\[DifferentialD]z = \>\"", ",", 
      RowBox[{"N", "[", "val2", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39930867459375*^9, 3.3993086761875*^9}, {
  3.399882917984375*^9, 3.39988291815625*^9}, {3.39988331915625*^9, 
  3.39988332759375*^9}, {3.399883360453125*^9, 3.399883360875*^9}},
 AspectRatioFixed->True],

Cell["\<\
The integral could be computed parametrically as suggested in the textbook.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "t", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "t_", "]"}], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "+", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "4"]}], ")"}], 
      RowBox[{"\[Integral]", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"2", "t"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", 
           RowBox[{"t", "/", "4"}]}]}]], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Fun", "=", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"2", "t"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", 
        RowBox[{"t", "/", "4"}]}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<F[t] = (2+\!\(\*FractionBox[\(\[ImaginaryI]\\\ \[Pi]\), \(4\)]\))\
\[Integral](\>\"", ",", "Fun", ",", "\"\<\[DifferentialD]t = \>\"", ",", 
      RowBox[{"F", "[", "t", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Val", "=", 
     RowBox[{
      RowBox[{"F", "[", "1", "]"}], "-", 
      RowBox[{"F", "[", "0", "]"}]}]}], " ", ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[1]-F[0] = (\>\"", ",", 
      RowBox[{"F", "[", "1", "]"}], ",", "\"\<) - (\>\"", ",", 
      RowBox[{"F", "[", "0", "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[1]-F[0] = \>\"", ",", "Val"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[1]-F[0] = \>\"", ",", 
      RowBox[{"Simplify", "[", "Val", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<(2+\!\(\*FractionBox[\(\[ImaginaryI]\\\ \[Pi]\), \(4\)]\))\>\"", 
      ",", "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)\>\"",
       ",", "Fun", ",", "\"\<\[DifferentialD]t = \>\"", ",", 
      RowBox[{"Simplify", "[", "Val", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<(2+\!\(\*FractionBox[\(\[ImaginaryI]\\\ \[Pi]\), \(4\)]\))\>\"", 
      ",", "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)\>\"",
       ",", "Fun", ",", "\"\<\[DifferentialD]t = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Simplify", "[", "Val", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<(2+\!\(\*FractionBox[\(\[ImaginaryI]\\\ \[Pi]\), \(4\)]\))\>\"", 
      ",", "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)\>\"",
       ",", "Fun", ",", "\"\<\[DifferentialD]t = (\>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{"ComplexExpand", "[", 
        RowBox[{"Re", "[", "Val", "]"}], "]"}], "]"}], ",", 
      "\"\<) + \[ImaginaryI](\>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{"ComplexExpand", "[", 
        RowBox[{"Im", "[", "Val", "]"}], "]"}], "]"}], ",", "\"\<)\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<(2+\!\(\*FractionBox[\(\[ImaginaryI]\\\ \[Pi]\), \(4\)]\))\>\"", 
      ",", "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(1\)]\)\>\"",
       ",", "Fun", ",", "\"\<\[DifferentialD]t = \>\"", ",", 
      RowBox[{"N", "[", "Val", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399308682140625*^9, 3.3993086840625*^9}}]
}, Closed]]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{914, 644},
WindowMargins->{{17, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 198, 3, 29, "Text"],
Cell[1749, 51, 1257, 38, 83, "Text",
 Evaluatable->False],
Cell[3009, 91, 1504, 56, 126, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[4538, 151, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[4682, 157, 170, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[4867, 164, 1811, 52, 105, "Text"],
Cell[CellGroupData[{
Cell[6703, 220, 190, 5, 37, "Subsection"],
Cell[6896, 227, 493, 20, 29, "Text"],
Cell[7392, 249, 7273, 197, 693, "Input"]
}, Closed]],
Cell[14680, 449, 239, 7, 26, "Text"],
Cell[14922, 458, 1184, 48, 108, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[16131, 510, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[16275, 516, 170, 4, 29, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[16460, 523, 384, 6, 65, "Text"],
Cell[16847, 531, 1463, 53, 85, "Text",
 Evaluatable->False],
Cell[18313, 586, 5358, 238, 188, "Text"],
Cell[23674, 826, 3062, 109, 206, "Text"],
Cell[CellGroupData[{
Cell[26761, 939, 230, 6, 37, "Subsection"],
Cell[26994, 947, 553, 23, 41, "Text"],
Cell[27550, 972, 7203, 197, 712, "Input"]
}, Closed]],
Cell[34768, 1172, 902, 33, 30, "Text",
 Evaluatable->False],
Cell[35673, 1207, 7434, 323, 190, "Text"],
Cell[43110, 1532, 2340, 70, 265, "Text"],
Cell[CellGroupData[{
Cell[45475, 1606, 230, 6, 37, "Subsection"],
Cell[45708, 1614, 444, 18, 29, "Text"],
Cell[46155, 1634, 7411, 201, 716, "Input"]
}, Closed]],
Cell[53581, 1838, 1958, 77, 114, "Text",
 Evaluatable->False],
Cell[55542, 1917, 4787, 185, 241, "Text"],
Cell[60332, 2104, 669, 26, 35, "Text",
 Evaluatable->False],
Cell[61004, 2132, 4138, 143, 268, "Text"],
Cell[CellGroupData[{
Cell[65167, 2279, 232, 6, 37, "Subsection"],
Cell[65402, 2287, 179, 8, 35, "Text"],
Cell[65584, 2297, 6809, 181, 680, "Input"],
Cell[72396, 2480, 121, 5, 47, "Text",
 Evaluatable->False],
Cell[72520, 2487, 3113, 80, 422, "Input"]
}, Closed]],
Cell[75648, 2570, 722, 25, 51, "Text",
 Evaluatable->False],
Cell[76373, 2597, 7038, 312, 189, "Text"],
Cell[CellGroupData[{
Cell[83436, 2913, 258, 7, 37, "Subsection"],
Cell[83697, 2922, 529, 21, 38, "Text"],
Cell[84229, 2945, 8448, 229, 799, "Input"],
Cell[92680, 3176, 99, 2, 29, "Text"],
Cell[92782, 3180, 3968, 101, 462, "Input"]
}, Closed]]
}
]
*)

(* End of internal cache information *)
