(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     95242,       2895]
NotebookOptionsPosition[     92289,       2797]
NotebookOutlinePosition[     92709,       2815]
CellTagsIndexPosition[     92666,       2812]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[StyleBox["Chapter 7  Taylor and Laurent Series",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.53270943475*^9, 3.532709435046875*^9}}],

Cell[TextData[{
 StyleBox["Overview",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tThroughout this book we have compared and contrasted properties of \
complex functions with functions whose domain and range lie entirely within \
the real numbers.  There are many similarities, such as the standard \
differentiation formulas.  However, there are also some surprises, and in \
this chapter you will encounter one of the hallmarks that distinguishes \
complex functions from their real counterparts:  It is possible for a \
function defined on the real numbers to be differentiable everywhere and yet \
not be expressible as a power series (see Exercise 20, Section 7.2).  For a \
complex function, however, things are much simpler!  You will soon learn that \
if a complex function is analytic in the disk ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "r"], 
   RowBox[{"(", "\[Alpha]", ")"}]}]]],
 ", its ",
 ButtonBox["Taylor",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Taylor.\
html"], None}],
 " series about ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 " converges to the function at every point in this disk.  Thus, analytic \
functions are locally nothing more than glorified polynomials.  "
}], "Text"],

Cell[TextData[StyleBox["7.1  Uniform Convergence",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell["\<\
\tComplex functions are the key to unlocking many of the mysteries \
encountered when power series are first introduced in a calculus course.  We \
begin by discussing an important property associated with power \
series-uniform convergence.\
\>", "Text"],

Cell[TextData[{
 "\tRecall that, for a function ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " defined on a set ",
 StyleBox["T",
  FontFamily->"Courier New"],
 ", the sequence of functions  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["S", "n"], 
    RowBox[{"(", "z", ")"}]}], "}"}]]],
 "  converges to the function ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " at the point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], " ", "\[Epsilon]", " ", "T"}]]],
 "  provided that   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
    RowBox[{"S", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}]}], " ", "=", " ", 
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 ".  Thus, for the particular point  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ",  we know that for each  ",
 Cell[BoxData[
  RowBox[{"\[Epsilon]", ">", "0"}]]],
 ",  there exists a positive integer  ",
 Cell[BoxData[
  SubscriptBox["N", 
   RowBox[{"\[Element]", 
    RowBox[{",", 
     SubscriptBox["z", "0"]}]}]]]],
 "  (which depends on both   ",
 Cell[BoxData[
  RowBox[{"\[Epsilon]", "  ", "and", "  ", 
   SubscriptBox["z", "0"]}]]],
 ")  such that\n\n",
 StyleBox["(7-1)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\tif  ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", 
   SubscriptBox["N", 
    RowBox[{"\[Element]", 
     RowBox[{",", 
      SubscriptBox["z", "0"]}]}]]}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], " ", "-", " ", 
    RowBox[{"f", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}]}], "|", 
   RowBox[{"<", " ", "\[Epsilon]"}]}]]],
 ".  \n\t\nIf ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "n"], 
   RowBox[{"(", "z", ")"}]}]]],
 " is the  ",
 Cell[BoxData[
  SuperscriptBox["n", "th"]]],
 "  partial sum of the series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "o"}], "\[Infinity]"], 
   RowBox[{
    SubscriptBox["c", "k"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "\[Alpha]"}], ")"}], "k"]}]}]]],
 ",  Statement ",
 StyleBox["(7-1)",
  FontColor->RGBColor[0, 0, 1]],
 " becomes  \n\n\t\t\tif  ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", 
   SubscriptBox["N", 
    RowBox[{"\[Element]", 
     RowBox[{",", 
      SubscriptBox["z", "0"]}]}]]}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], 
      RowBox[{"n", "-", "1"}]], 
     RowBox[{
      SubscriptBox["c", "k"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["z", "0"], "-", "\[Alpha]"}], ")"}], "k"]}]}], " ", "-",
     " ", 
    RowBox[{"f", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}]}], "|", 
   RowBox[{"<", " ", "\[Epsilon]"}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tFor a given value of  ",
 Cell[BoxData["\[Epsilon]"]],
 ",  the integer  ",
 Cell[BoxData[
  SubscriptBox["N", 
   RowBox[{"\[Element]", 
    RowBox[{",", 
     SubscriptBox["z", "0"]}]}]]]],
 "  needed to satisfy Statement ",
 StyleBox["(7-1)",
  FontColor->RGBColor[0, 0, 1]],
 " often depends on our choice of ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  This is not the case if the sequence ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["S", "n"], 
    RowBox[{"(", "z", ")"}]}], "}"}]]],
 " converges uniformly.  For a uniformly convergent sequence, it is possible \
to find an integer  ",
 Cell[BoxData[
  SubscriptBox["N", "\[Element]"]]],
 "  (depending only on ",
 Cell[BoxData["\[Epsilon]"]],
 ") that guarantees Statement  ",
 StyleBox["(7-1)",
  FontColor->RGBColor[0, 0, 1]],
 "  no matter what value for  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "\[Element]", "T"}]]],
 "  we pick.  In other words, if n is large enough, the function ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "n"], 
   RowBox[{"(", "z", ")"}]}]]],
 " is uniformly close to the function ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " for all  ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", "T"}]]],
 ".  Formally, we have the following definition."
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 7.1 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Uniform Convergence",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/UniformConvergence.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox["),.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The sequence ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["S", "n"], 
    RowBox[{"(", "z", ")"}]}], "}"}]]],
 " converges uniformly to f(z) on the set  ",
 StyleBox["T",
  FontFamily->"Courier New"],
 "  if for every  ",
 Cell[BoxData[
  RowBox[{"\[Epsilon]", ">", "0"}]]],
 ",  there exists a positive integer  ",
 Cell[BoxData[
  SubscriptBox["N", "\[Epsilon]"]]],
 "  (depending only on ",
 Cell[BoxData["\[Epsilon]"]],
 ")  such that \n\n",
 StyleBox["(7-2)\t",
  FontColor->RGBColor[0, 0, 1]],
 "\t\tif  ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", "N"}]]],
 ",  then ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "n"], 
     RowBox[{"(", "z", ")"}]}], "-", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}]}], "|", 
   RowBox[{"<", "\[Element]"}]}]]],
 "   for all   ",
 Cell[BoxData[
  RowBox[{"z", " ", "\[Epsilon]", " ", "T"}]]],
 ".\n\nIf  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "n"], 
   RowBox[{"(", "z", ")"}]}]]],
 "  is the ",
 Cell[BoxData[
  SuperscriptBox["n", "th"]]],
 "  partial sum of the series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "0"}], "\[Infinity]"], 
   RowBox[{
    SubscriptBox["c", "k"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "\[Alpha]"}], ")"}], "k"]}]}]]],
 ",  we say that the series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "0"}], "\[Infinity]"], 
   RowBox[{
    SubscriptBox["c", "k"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "\[Alpha]"}], ")"}], "k"]}]}]]],
 "  converges uniformly to  f(z)  on the set  ",
 StyleBox["T",
  FontFamily->"Courier New"],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 7.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The sequence ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["S", "n"], 
     RowBox[{"(", "z", ")"}]}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "z"], "+", 
     FractionBox["1", "n"]}], "}"}]}]]],
 " converges uniformly to the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", " ", 
   SuperscriptBox["\[ExponentialE]", "z"]}]]],
 "  on the entire complex plane because for any ",
 Cell[BoxData[
  RowBox[{"\[Epsilon]", ">", "0"}]]],
 ", statement ",
 StyleBox["(7-2)",
  FontColor->RGBColor[0, 0, 1]],
 " is satisfied for all ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " for ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", 
   SubscriptBox["N", "\[Epsilon]"]}]]],
 ", where ",
 Cell[BoxData[
  SubscriptBox["N", "\[Epsilon]"]]],
 " is any integer greater than ",
 Cell[BoxData[
  FractionBox["1", "\[Epsilon]"]]],
 ".  We leave the details of showing this result as an exercise."
}], "Text"],

Cell[TextData[{
 "\tA good example of a sequence of functions that does not converge \
uniformly is the sequence of partial sums comprising the geometric series.  \
Recall that the geometric series has ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["S", "n"], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "0"}], "n"], 
    SuperscriptBox["z", "k"]}]}]]],
 " converging to ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", "z"}]]}]]],
 " for all ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", 
   RowBox[{
    SubscriptBox["D", "1"], 
    RowBox[{"(", "0", ")"}]}]}]]],
 ".  Because the real numbers are a subset of the complex numbers, we can \
show statement ",
 StyleBox["(7-2)",
  FontColor->RGBColor[0, 0, 1]],
 " is not satisfied by demonstrating it does not hold when we restrict our \
attention to the real numbers.  In that context, ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 " becomes the open interval (-1,1), and the inequality, ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "n"], 
     RowBox[{"(", "z", ")"}]}], "-", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}]}], "|", 
   RowBox[{"<", "\[Element]"}]}]]],
 ", becomes ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "n"], 
     RowBox[{"(", "x", ")"}]}], "-", 
    RowBox[{"f", 
     RowBox[{"(", "x", ")"}]}]}], "|", 
   RowBox[{"<", "\[Element]"}]}]]],
 ", which for real variables is equivalent to ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "x", ")"}]}], "-"}], "\[Element]", 
   RowBox[{"<", 
    RowBox[{
     SubscriptBox["S", "n"], 
     RowBox[{"(", "x", ")"}]}], "<", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "x", ")"}]}], "+"}]}], "\[Element]"}]]],
 ".  If Statement ",
 StyleBox["(7-2)",
  FontColor->RGBColor[0, 0, 1]],
 " were to be satisfied, then given ",
 Cell[BoxData[
  RowBox[{"\[Epsilon]", ">", "0"}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "n"], 
   RowBox[{"(", "x", ")"}]}]]],
 "would be within an ",
 Cell[BoxData["\[Epsilon]"]],
 "-bandwidth of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "x", ")"}]}]]],
 " for all x in the interval ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], ",", "1"}], ")"}]]],
 " provided n were large enough.  Figure 7.1 illustrates that there is an  \
such that, no matter how large ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " is, we can find ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "0"], "\[Element]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "1"}], ")"}]}]]],
 " such that ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "n"], 
   RowBox[{"(", 
    SubscriptBox["x", "0"], ")"}]}]]],
 " lies outside this bandwidth.  In other words, Figure 7.1 illustrates the \
negation of Statement ",
 StyleBox["(7-2)",
  FontColor->RGBColor[0, 0, 1]],
 ", which in technical terms we state as:  \n\n ",
 StyleBox["(7-3)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\tThere exists ",
 Cell[BoxData[
  RowBox[{"\[Epsilon]", ">", "0"}]]],
 ", such that for all positive integers N, \n\t\t\tthere is some ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", "N"}]]],
 " and some ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "\[Element]", "T"}]]],
 " \n\t\t\tsuch that ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "n"], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "-", 
    RowBox[{"f", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}]}], "|", 
   RowBox[{"\[GreaterEqual]", "\[Element]"}]}]]],
 ".  \n\nIn the exercises, we ask you to use Statement ",
 StyleBox["(7-3)",
  FontColor->RGBColor[0, 0, 1]],
 " to show that the partial sums of the geometric series do not converge \
uniformly to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", "z"}]]}]]],
 "  for  ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", 
   RowBox[{
    SubscriptBox["D", "1"], 
    RowBox[{"(", "0", ")"}]}]}]]],
 ". "
}], "Text",
 CellChangeTimes->{{3.399365314828125*^9, 3.399365340203125*^9}}],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0280925 0.0561849 [
[.02381 .01559 -8.1875 -13 ]
[.02381 .01559 8.1875 0 ]
[.2619 .01559 -12.3125 -13 ]
[.2619 .01559 12.3125 0 ]
[.7381 .01559 -8.875 -13 ]
[.7381 .01559 8.875 0 ]
[.97619 .01559 -4.75 -13 ]
[.97619 .01559 4.75 0 ]
[.4875 .14046 -9.5 -6.5 ]
[.4875 .14046 0 6.5 ]
[.4875 .25283 -9.5 -6.5 ]
[.4875 .25283 0 6.5 ]
[.4875 .3652 -9.5 -6.5 ]
[.4875 .3652 0 6.5 ]
[.4875 .47757 -9.5 -6.5 ]
[.4875 .47757 0 6.5 ]
[.4875 .58994 -15 -6.5 ]
[.4875 .58994 0 6.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .02809 m
.02381 .03434 L
s
gsave
.02381 .01559 -69.1875 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .02809 m
.2619 .03434 L
s
gsave
.2619 .01559 -73.3125 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .02809 m
.7381 .03434 L
s
gsave
.7381 .01559 -69.875 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .02809 m
.97619 .03434 L
s
gsave
.97619 .01559 -65.75 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .02809 m
1 .02809 L
s
.5 .14046 m
.50625 .14046 L
s
gsave
.4875 .14046 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .25283 m
.50625 .25283 L
s
gsave
.4875 .25283 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 .3652 m
.50625 .3652 L
s
gsave
.4875 .3652 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.5 .47757 m
.50625 .47757 L
s
gsave
.4875 .47757 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.5 .58994 m
.50625 .58994 L
s
gsave
.4875 .58994 -76 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .05619 m
.06245 .05737 L
.10458 .05879 L
.14416 .06025 L
.18221 .06179 L
.22272 .0636 L
.26171 .06554 L
.30316 .06784 L
.34309 .07035 L
.3815 .07308 L
.42237 .0764 L
.46172 .0801 L
.49955 .08422 L
.53984 .08941 L
.57861 .09539 L
.61983 .10317 L
.65954 .11259 L
.69774 .12418 L
.73838 .1406 L
.77751 .16275 L
.79892 .17902 L
.81909 .1984 L
.83917 .22335 L
.85764 .25378 L
.87647 .29638 L
.88715 .32858 L
.89713 .36649 L
.90758 .41804 L
.91748 .4838 L
.92637 .5651 L
s
.92637 .5651 m
.93078 .61803 L
s
0 1 1 r
[ .02 .02 ] 0 setdash
.02381 .10113 m
.06245 .10232 L
.10458 .10374 L
.14416 .1052 L
.18221 .10674 L
.22272 .10855 L
.26171 .11049 L
.30316 .11279 L
.34309 .1153 L
.3815 .11803 L
.42237 .12135 L
.46172 .12504 L
.49955 .12917 L
.53984 .13435 L
.57861 .14033 L
.61983 .14812 L
.65954 .15753 L
.69774 .16912 L
.73838 .18554 L
.77751 .2077 L
.79892 .22397 L
.81909 .24334 L
.83917 .2683 L
.85764 .29873 L
.87647 .34133 L
.88715 .37353 L
.89713 .41144 L
.90758 .46299 L
.91748 .52875 L
.92637 .61005 L
s
.92637 .61005 m
.92703 .61803 L
s
.02381 .01124 m
.06245 .01242 L
.10458 .01384 L
.14416 .0153 L
.18221 .01684 L
.22272 .01865 L
.26171 .02059 L
.30316 .0229 L
.34309 .0254 L
.3815 .02813 L
.42237 .03145 L
.46172 .03515 L
.49955 .03928 L
.53984 .04446 L
.57861 .05044 L
.61983 .05822 L
.65954 .06764 L
.69774 .07923 L
.73838 .09565 L
.77751 .11781 L
.79892 .13407 L
.81909 .15345 L
.83917 .1784 L
.85764 .20883 L
.87647 .25143 L
.88715 .28363 L
.89713 .32155 L
.90758 .37309 L
.91748 .43885 L
.92637 .52015 L
.93139 .58035 L
s
.93139 .58035 m
.93392 .61803 L
s
1 0 0 r
[ ] 0 setdash
.02381 .08428 m
.04262 .08018 L
.06245 .07655 L
.08426 .0733 L
.10458 .07091 L
.12297 .06921 L
.14264 .06783 L
.15286 .06728 L
.16394 .0668 L
.17442 .06645 L
.18408 .06621 L
.18874 .06612 L
.19375 .06605 L
.19618 .06602 L
.19848 .066 L
.20075 .06598 L
.20281 .06596 L
.20529 .06595 L
.20664 .06594 L
.20792 .06594 L
.20911 .06594 L
.2102 .06594 L
.2114 .06594 L
.21267 .06594 L
.21395 .06594 L
.21467 .06594 L
.21533 .06594 L
.2166 .06594 L
.2178 .06595 L
.2205 .06596 L
.22344 .06598 L
.22828 .06603 L
.23283 .06609 L
.24321 .06626 L
.25332 .06648 L
.26422 .06679 L
.28426 .0675 L
.30536 .06843 L
.34346 .07054 L
.38402 .07331 L
.42307 .07647 L
.46457 .08039 L
.50455 .08482 L
.54301 .08986 L
.58393 .09629 L
.62334 .10383 L
.66122 .11266 L
.70156 .12419 L
.74039 .13783 L
.78166 .15567 L
Mistroke
.82142 .17674 L
.85967 .20126 L
.90036 .2327 L
.93955 .26898 L
.97619 .30901 L
Mfstroke
0 1 0 r
[ .02 .02 ] 0 setdash
.97619 .02809 m
.97619 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1, -1, 0, 0}}],
 StyleBox["       \n\t\t\tFigure 7.1",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The geometric series does not converge uniformly on (-1,1).  "
}], "Text",
 CellChangeTimes->{{3.506761664078125*^9, 3.506761678828125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Exploration", "."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.50670518378125*^9, 3.50670518378125*^9}},
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "x_", "]"}], "=", 
     FractionBox["1", 
      RowBox[{"1", "-", "x"}]]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Rlines", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Green", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", 
              RowBox[{"-", "2"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "8"}], "}"}]}], "}"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"Red", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", 
              RowBox[{"-", "2"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "8"}], "}"}]}], "}"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Green", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"-", "2"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "8"}], "}"}]}], "}"}], "]"}]}], "}"}]}], 
      "}"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Cpoint", "=", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Magenta", ",", 
        RowBox[{"PointSize", "[", "0.025", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"f", "[", "0", "]"}]}], "}"}], "]"}]}], "}"}], "}"}]}], 
    ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ydot", "=", 
     RowBox[{"Graphics", "[", "Cpoint", "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Rends", "=", 
     RowBox[{"Graphics", "[", "Rlines", "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "25"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"T", "[", "x_", "]"}], " ", "=", " ", 
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"f", "[", "x", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", "i"}], "}"}]}], "]"}], "]"}]}], ";", 
      "  ", "\[IndentingNewLine]", 
      RowBox[{"graph1", "=", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"f", "[", "x", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"-", "1.5"}], ",", "0.99999"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", "Red", "}"}]}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2"}], ",", "8"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"Ticks", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{
              RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.5"}], "]"}], ",", 
            RowBox[{"Range", "[", 
             RowBox[{
              RowBox[{"-", "2"}], ",", "8", ",", "2"}], "]"}]}], "}"}]}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"graph2", "=", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"T", "[", "x", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", "Blue", "}"}]}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2"}], ",", "8"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"Ticks", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{
              RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.5"}], "]"}], ",", 
            RowBox[{"Range", "[", 
             RowBox[{
              RowBox[{"-", "2"}], ",", "8", ",", "2"}], "]"}]}], "}"}]}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"figure", "=", 
       RowBox[{"Show", "[", 
        RowBox[{"graph1", ",", "graph2", ",", "ydot", ",", "Rends"}], "]"}]}],
       ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "figure", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<Approximation of \!\(\*FractionBox[\(1\), \(1 - x\)]\) with \>\"",
         ",", 
        SubscriptBox["\"\<S\>\"", "i"], ",", "\"\<[x],\>\""}], "]"}], ";"}]}],
     "  ", "]"}], "  "}]}]], "Input",
 CellChangeTimes->{{3.399365353375*^9, 3.399365368828125*^9}, {
  3.399893727203125*^9, 3.399893727390625*^9}, {3.39989391171875*^9, 
  3.39989403515625*^9}, {3.4002675853125*^9, 3.400267595640625*^9}}]
}, Closed]],

Cell[TextData[{
 "\tA useful procedure known as the ",
 StyleBox[ButtonBox["Weierstrass M-test",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/\
Weierstrass.html"], None}],
  FontFamily->"Times New Roman",
  FontVariations->{"Underline"->True}],
 " can help determine whether an infinite series is uniformly convergent."
}], "Text",
 CellChangeTimes->{{3.39932265325*^9, 3.39932266378125*^9}, {
  3.399322705984375*^9, 3.399322705984375*^9}, {3.399322746140625*^9, 
  3.399322751265625*^9}}],

Cell[TextData[{
 StyleBox["Theorem 7.1.  (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Weierstrass M-Test",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/WeierstrassM-Test.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[")",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose the infinite series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "0"}], "\[Infinity]"], 
   RowBox[{
    SubscriptBox["u", "k"], 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  has the property that for each  ",
 StyleBox["k",
  FontFamily->"Courier New"],
 ",  we have  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    SubscriptBox["u", "k"], 
    RowBox[{"(", "z", ")"}]}], "|", 
   RowBox[{"\[LessEqual]", " ", 
    SubscriptBox["M", "k"]}]}]]],
 "  for all  ",
 Cell[BoxData[
  RowBox[{"z", " ", "\[Epsilon]", " ", "T"}]]],
 ".  If  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "0"}], "\[Infinity]"], 
   SubscriptBox["M", "k"]}]]],
 "  converges,  then  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "0"}], "\[Infinity]"], 
   RowBox[{
    SubscriptBox["u", "k"], 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  converges uniformly on   ",
 StyleBox["T",
  FontFamily->"Courier New"],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.1 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tTheorem 7.2 gives an interesting application of the Weierstrass M-test.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Theorem 7.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose the power series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "0"}], "\[Infinity]"], 
   RowBox[{
    SubscriptBox["c", "k"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "\[Alpha]"}], ")"}], "k"]}]}]]],
 "  has radius of convergence  ",
 Cell[BoxData[
  RowBox[{"\[Rho]", ">", "0"}]]],
 ".  Then for each   ",
 StyleBox["r",
  FontFamily->"Courier New"],
 ",  (where  ",
 Cell[BoxData[
  RowBox[{"0", "<", "r", "<", "\[Rho]"}]]],
 "),  the series converges uniformly on the closed disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    OverscriptBox[
     SubscriptBox["D", "r"], "_"], 
    RowBox[{"(", "\[Alpha]", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", 
     RowBox[{"|", 
      RowBox[{"z", "-", "\[Alpha]"}], "|", 
      RowBox[{"\[LessEqual]", "r"}]}]}], "}"}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.2 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell["\tAn immediate consequence of Theorem 7.2 is Corollary 7.1.", "Text"],

Cell[TextData[{
 StyleBox["Corollary 7.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  For each   ",
 StyleBox["r",
  FontFamily->"Courier New"],
 ",  (where  ",
 Cell[BoxData[
  RowBox[{"0", "<", "r", "<", "1"}]]],
 "),  the geometric series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "0"}], "\[Infinity]"], 
   SuperscriptBox["z", "n"]}]]],
 "  converges uniformly on the closed disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    OverscriptBox[
     SubscriptBox["D", "r"], "_"], 
    RowBox[{"(", "0", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", 
     RowBox[{"|", "z", "|", 
      RowBox[{"\[LessEqual]", "r"}]}]}], "}"}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Corollary 7.1 is mentioned in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tTheorem 7.3 gives important properties of uniformly convergent sequences.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Theorem 7.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["S", "k"], 
    RowBox[{"(", "z", ")"}]}], "}"}]]],
 " is a sequence of continuous functions defined on a set   ",
 StyleBox["T",
  FontFamily->"Courier New"],
 "  containing the contour   ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ".   \nIf  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["S", "k"], 
    RowBox[{"(", "z", ")"}]}], "}"}]]],
 "  converges uniformly to  ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 "  on the set  ",
 StyleBox["T",
  FontFamily->"Courier New"],
 ",  then ",
 StyleBox[" \n\n(i)",
  FontColor->RGBColor[0, 0, 1]],
 "  \t\t",
 Cell[BoxData[
  RowBox[{"f", 
   StyleBox[
    RowBox[{"(", "z", ")"}],
    FontSize->12]}]]],
 "   is continuous on  ",
 StyleBox["T",
  FontFamily->"Courier New"],
 ",  and  \n\t\n",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 "  \t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"k", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{
      SubscriptBox["S", "k"], 
      RowBox[{"(", "z", ")"}], 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"k", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
      RowBox[{
       SubscriptBox["S", "k"], 
       RowBox[{"(", "z", ")"}], " ", 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "=", "  ", 
    RowBox[{
     SubscriptBox["\[Integral]", "C"], 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}], 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]]],
 ".   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.3 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Corollary 7.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If the series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "o"}], "\[Infinity]"], 
   RowBox[{
    SubscriptBox["c", "n"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]]],
 "  converges uniformly to  ",
 Cell[BoxData[
  RowBox[{"f", 
   StyleBox[
    RowBox[{"(", "z", ")"}],
    FontSize->12]}]]],
 "  on the set  ",
 StyleBox["T",
  FontFamily->"Courier New"],
 ",  and  ",
 StyleBox["C",
  FontFamily->"Courier New"],
 "  is a contour contained in  ",
 StyleBox["T",
  FontFamily->"Courier New"],
 ",  then  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["\[Integral]", "C"], 
     RowBox[{
      SubscriptBox["c", "n"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"], 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       SubscriptBox["c", "n"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"], " ", 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "=", "  ", 
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}], 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]]],
 ".   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Corollary 7.2 is mentioned in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 7.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", " ", "Log"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", "z"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    FractionBox[
     SuperscriptBox["z", "n"], "n"]}]}]]],
 "   for all   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "\[Element]", 
    RowBox[{
     SubscriptBox["D", "1"], 
     RowBox[{"(", "0", ")"}]}]}], "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", 
     RowBox[{"|", "z", "|", 
      RowBox[{"<", " ", "1"}]}]}], "}"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{599, 464},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  For  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "\[Element]", 
   RowBox[{
    SubscriptBox["D", "1"], 
    RowBox[{"(", "0", ")"}]}]}]]],
 ",  we choose r and R so that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"0", "\[LessEqual]"}], "|", 
   SubscriptBox["z", "0"], "|", 
   RowBox[{"<", "r", "<", "R", "<", "1"}]}]]],
 ",  thus ensuring that  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "\[Element]", 
   RowBox[{
    OverscriptBox[
     SubscriptBox["D", "r"], "_"], 
    RowBox[{"(", "0", ")"}]}]}]]],
 "  and that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    OverscriptBox[
     SubscriptBox["D", "r"], "_"], 
    RowBox[{"(", "0", ")"}]}], "\[Subset]", 
   RowBox[{
    SubscriptBox["D", "R"], 
    RowBox[{"(", "0", ")"}]}]}]]],
 ".  By Corollary 7.1, the geometric series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "o"}], "\[Infinity]"], 
   SuperscriptBox["z", "n"]}]]],
 "  converges uniformly to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"1", "-", "z"}]]}]]],
 "  on  ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox[
    SubscriptBox["D", "r"], "_"], 
   RowBox[{"(", "0", ")"}]}]]],
 ".  If  ",
 StyleBox["C",
  FontFamily->"Courier New"],
 "  is any contour contained in  ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox[
    SubscriptBox["D", "r"], "_"], 
   RowBox[{"(", "0", ")"}]}]]],
 ",  Corollary 7.2 gives  \n\n ",
 StyleBox["(7-4)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"1", "-", "z"}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{
      SuperscriptBox["z", "n"], 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Clearly, the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"1", "-", "z"}]]}]]],
 "  is analytic in the simply connected domain  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "R"], 
   RowBox[{"(", "0", ")"}]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", "Log"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", "z"}], ")"}]}]}]]],
 "  is an antiderivative of f(z) for all  ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", 
   RowBox[{
    SubscriptBox["D", "R"], 
    RowBox[{"(", "0", ")"}]}]}]]],
 ",  where Log is the principal branch of the logarithm.  Likewise,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", "n"]}]]],
 "  is analytic in the simply connected domain  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "R"], 
   RowBox[{"(", "0", ")"}]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"G", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"n", "+", "1"}]], 
    SuperscriptBox["z", 
     RowBox[{"n", "+", "1"}]]}]}]]],
 "  is an antiderivative of g(z) for all  ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", 
   RowBox[{
    SubscriptBox["D", "R"], 
    RowBox[{"(", "0", ")"}]}]}]]],
 ".  Hence, if ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is the straight-line segment joining ",
 Cell[BoxData[
  RowBox[{"0", " ", 
   StyleBox["to",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SubscriptBox["z", "0"]}]]],
 ", we can apply Theorem 6.9 to Equation  ",
 StyleBox["(7-4)",
  FontColor->RGBColor[0, 0, 1]],
 " to get  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "Log"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}]}], 
    UnderoverscriptBox["\[VerticalSeparator]", 
     RowBox[{"z", "=", "0"}], 
     RowBox[{"z", "=", 
      SubscriptBox["z", "0"]}]]}], "  ", "=", "  ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{"n", "+", "1"}]], 
       SuperscriptBox["z", 
        RowBox[{"n", "+", "1"}]]}], 
      UnderoverscriptBox["\[VerticalSeparator]", 
       RowBox[{"z", "=", "0"}], 
       RowBox[{"z", "=", 
        SubscriptBox["z", "0"]}]]}], ")"}]}]}]]],
 ",  \n\nwhich becomes \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", " ", "Log"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SubscriptBox["z", "0"]}], ")"}]}], " ", "+", " ", 
    RowBox[{"Log", 
     RowBox[{"(", "1", ")"}]}]}], "  ", "=", "  ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     FractionBox["1", 
      RowBox[{"n", "+", "1"}]], 
     SubsuperscriptBox["z", "0", 
      RowBox[{"n", "+", "1"}]]}]}]}]]],
 ",  \n\t\t\t\nwhich can be written as \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", " ", "Log"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SubscriptBox["z", "0"]}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    RowBox[{
     FractionBox["1", "n"], 
     SubsuperscriptBox["z", "0", "n"]}]}]}]]],
 ".   \n\nThe point ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "\[Element]", 
   RowBox[{
    SubscriptBox["D", "1"], 
    RowBox[{"(", "0", ")"}]}]}]]],
 " was arbitrary, so we are done."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"7.2", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.50670519090625*^9, 3.50670519090625*^9}},
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"z", "=", "0"}], ";", 
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "n", ",", "S17", ",", "S", ",", "S\[Infinity]"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"1", "-", "z"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "17"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(17\)]\)[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399365420796875*^9},
 AspectRatioFixed->True],

Cell["\<\
Sum up infinitely many terms to verify that we have things right.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S17", "[", "z_", "]"}], "   ", "=", 
     RowBox[{"-", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "1"}], "17"], " ", 
       FractionBox[
        SuperscriptBox["z", "n"], "n"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S\[Infinity]", "[", "z_", "]"}], " ", "=", 
     RowBox[{"-", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "1"}], "\[Infinity]"], " ", 
       FractionBox[
        SuperscriptBox["z", "n"], "n"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(17\)]\)[z] = \>\"", ",", 
      RowBox[{"S17", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(\[Infinity]\)]\)[z] = \
-\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(\[Infinity]\)]\) \
\!\(\*FractionBox[SuperscriptBox[\(z\), \(n\)], \(n\)]\) = \>\"", ",", 
      RowBox[{"S\[Infinity]", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3993654269375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate how well the series is \"converging\" for real numbers."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"f", "[", "x", "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1.25"}], ",", "0.9999999"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"S17", "[", "x", "]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1.25"}], ",", "1.2"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.25"}], ",", "1.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<s\>\""}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "2", ",", "2"}], "]"}]}], "}"}]}]}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<s = \!\(\*SubscriptBox[\(S\), \(17\)]\)[z]              blue\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<s = \!\(\*SubscriptBox[\(S\), \(\[Infinity]\)]\)[z] = \>\"", ",", 
      RowBox[{"S\[Infinity]", "[", "z", "]"}], ",", "\"\<   red\>\""}], "]"}],
     ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399365434078125*^9, 3.39936543734375*^9}, {
  3.3998937331875*^9, 3.39989373334375*^9}, {3.400267602203125*^9, 
  3.400267612484375*^9}}],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate how well the complex series is \"converging\" in the \
complex plane."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"S17", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.9", ",", "0.15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "0.8"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2.4", "3.3"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", 
      RowBox[{"S17", "[", "z", "]"}], ",", 
      "\"\<,  where |z| \[LessEqual] 0.9\>\""}], "]"}], ";", " ", 
    RowBox[{"PolarMap", "[", 
     RowBox[{"f", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.9", ",", "0.15"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
        FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2.5"}], ",", "0.8"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", 
       FractionBox["2.4", "3.3"]}], ",", "\[IndentingNewLine]", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<,  where |z| \[LessEqual] 0.9\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399365441828125*^9, 3.399365470984375*^9}, {
  3.39989373909375*^9, 3.39989373928125*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"S17", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.99", ",", "0.165"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4.8"}], ",", "0.8"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.7"}], ",", "1.7"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["3.4", "5.6"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", 
      RowBox[{"S17", "[", "z", "]"}], ",", 
      "\"\<,  where |z| \[LessEqual] 0.99\>\""}], "]"}], ";", " ", 
    RowBox[{"PolarMap", "[", 
     RowBox[{"f", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.99", ",", "0.165"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
        FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "4.8"}], ",", "0.8"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.7"}], ",", "1.7"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", 
       FractionBox["3.4", "5.6"]}], ",", "\[IndentingNewLine]", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<,  where |z| \[LessEqual] 0.99\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39936548340625*^9, 3.399365501640625*^9}, {
  3.39989379434375*^9, 3.399893794640625*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"S17", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.999", ",", "0.1665"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4.8"}], ",", "0.8"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.8"}], ",", "1.8"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["3.6", "5.6"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", 
      RowBox[{"S17", "[", "z", "]"}], ",", 
      "\"\<,  where |z| \[LessEqual] 0.999\>\""}], "]"}], ";", " ", 
    RowBox[{"PolarMap", "[", 
     RowBox[{"f", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.999", ",", "0.1665"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
        FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "4.8"}], ",", "0.8"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.8"}], ",", "1.8"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", 
       FractionBox["3.6", "5.6"]}], ",", "\[IndentingNewLine]", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<,  where |z| \[LessEqual] 0.999\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3993655118125*^9, 3.39936552771875*^9}, {
  3.3998938011875*^9, 3.399893801390625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Our second exploration is on the disk ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"\[LessEqual]", 
    FractionBox["9", "10"]}]}]]],
 ". \nIt is an animation of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", " ", "=", " ", 
    RowBox[{
     SubscriptBox["S", "1"], "[", "z", "]"}]}], ",", 
   RowBox[{
    SubscriptBox["S", "2"], "[", "z", "]"}], ",", "...", ",", 
   RowBox[{
    SubscriptBox["S", "17"], "[", "z", "]"}], ",", " ", 
   RowBox[{"and", "  ", 
    RowBox[{"Log", "[", 
     RowBox[{"1", "-", "z"}], "]"}]}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"1", "-", "z"}], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"m", "=", "1"}], ",", 
      RowBox[{"m", "\[LessEqual]", "17"}], ",", 
      RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"S", "[", "z_", "]"}], "   ", "=", 
        RowBox[{"-", 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"n", "=", "1"}], "m"], " ", 
          FractionBox[
           SuperscriptBox["z", "n"], "n"]}]}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"g0", "=", 
        RowBox[{"PolarMap", "[", 
         RowBox[{"S", " ", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0.9", ",", "0.1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
            FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "2.35"}], ",", "0.95"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1.3"}], ",", "1.3"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", 
           FractionBox["2.6", "3.3"]}], ",", "\[IndentingNewLine]", 
          RowBox[{"Ticks", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}], ",", 
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}]}], "}"}]}], 
          ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "g0", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<w = \>\"", ",", 
         SubscriptBox["\"\<S\>\"", "m"], ",", "\"\<[z],  where |z| < 0.9\>\"",
          ",", "\"\<\\n\>\""}], "]"}], ";"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", " ", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.9", ",", "0.1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
         FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.35"}], ",", "0.95"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.3"}], ",", "1.3"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        FractionBox["2.6", "3.3"]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "g1", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<,  where |z| < 0.9\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The images of the disk |z| \[LessEqual] 0.9 under the mappings\>\"",
      "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<w = \!\(\*SubscriptBox[\(S\), \(1\)]\)[z],\!\(\*SubscriptBox[\(S\), \
\(2\)]\)[z],...,\!\(\*SubscriptBox[\(S\), \(17\)]\)[z], and  Log[1-z]\>\"", 
     "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399365538140625*^9, 3.399365571515625*^9}, {
  3.399365618640625*^9, 3.39936562428125*^9}, {3.39989380609375*^9, 
  3.399893806265625*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",
 InitializationCell->True]
}, Closed]]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{907, 633},
WindowMargins->{{28, Automatic}, {Automatic, 0}},
CellLabelAutoDelete->True,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 186, 3, 29, "Text"],
Cell[1737, 51, 1310, 29, 155, "Text"],
Cell[3050, 82, 112, 2, 29, "Text"],
Cell[3165, 86, 265, 5, 47, "Text"],
Cell[3433, 93, 2990, 117, 183, "Text"],
Cell[6426, 212, 1313, 46, 86, "Text"],
Cell[7742, 260, 2118, 81, 119, "Text"],
Cell[9863, 343, 1117, 41, 61, "Text"],
Cell[10983, 386, 4336, 156, 259, "Text"],
Cell[15322, 544, 10033, 454, 213, "Text"],
Cell[CellGroupData[{
Cell[25380, 1002, 237, 7, 37, "Subsection",
 Evaluatable->False],
Cell[25620, 1011, 5329, 149, 350, "Input"]
}, Closed]],
Cell[30964, 1163, 555, 13, 26, "Text"],
Cell[31522, 1178, 1409, 53, 47, "Text"],
Cell[CellGroupData[{
Cell[32956, 1235, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[33100, 1241, 170, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[33285, 1248, 97, 2, 26, "Text"],
Cell[33385, 1252, 969, 36, 47, "Text"],
Cell[CellGroupData[{
Cell[34379, 1292, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[34523, 1298, 170, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[34708, 1305, 75, 0, 26, "Text"],
Cell[34786, 1307, 717, 28, 29, "Text"],
Cell[CellGroupData[{
Cell[35528, 1339, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[35672, 1345, 173, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[35860, 1352, 99, 2, 26, "Text"],
Cell[35962, 1356, 1852, 72, 123, "Text"],
Cell[CellGroupData[{
Cell[37839, 1432, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[37983, 1438, 170, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[38168, 1445, 1658, 61, 66, "Text"],
Cell[CellGroupData[{
Cell[39851, 1510, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[39995, 1516, 173, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[40183, 1523, 752, 30, 36, "Text",
 Evaluatable->False],
Cell[40938, 1555, 23478, 388, 478, "Text",
 Evaluatable->False],
Cell[64419, 1945, 2046, 81, 95, "Text"],
Cell[66468, 2028, 3781, 140, 323, "Text"],
Cell[CellGroupData[{
Cell[70274, 2172, 276, 8, 37, "Subsection",
 Evaluatable->False],
Cell[70553, 2182, 1311, 38, 192, "Input"],
Cell[71867, 2222, 136, 4, 29, "Text",
 Evaluatable->False],
Cell[72006, 2228, 1334, 37, 232, "Input"],
Cell[73343, 2267, 167, 5, 29, "Text"],
Cell[73513, 2274, 2200, 63, 172, "Input"],
Cell[75716, 2339, 181, 6, 29, "Text"],
Cell[75900, 2347, 3273, 88, 283, "Input"],
Cell[79176, 2437, 3279, 88, 283, "Input"],
Cell[82458, 2527, 3283, 88, 283, "Input"],
Cell[85744, 2617, 572, 20, 53, "Text"],
Cell[86319, 2639, 4939, 128, 482, "Input"]
}, Closed]],
Cell[91273, 2770, 435, 8, 26, "Text"],
Cell[CellGroupData[{
Cell[91733, 2782, 407, 7, 29, "Text"],
Cell[92143, 2791, 130, 3, 31, "Input",
 InitializationCell->True]
}, Closed]]
}
]
*)

(* End of internal cache information *)
