(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    128894,       4082]
NotebookOptionsPosition[    123432,       3901]
NotebookOutlinePosition[    123852,       3919]
CellTagsIndexPosition[    123809,       3916]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[StyleBox["7.2  Taylor Series Representations",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.5327094425625*^9, 3.532709443421875*^9}}],

Cell[TextData[{
 "\tIn Section 4.4 we showed that functions defined by power series have \
derivatives of all orders (Theorem 4.16).  In Section 6.5 we demonstrated \
that analytic functions also have derivatives of all orders (Corollary 6.2).  \
It seems natural, therefore, that there would be some connection between \
analytic functions and power series.  As you might guess, the connection \
exists via the ",
 StyleBox[ButtonBox["Taylor",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Taylor.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " and ",
 StyleBox[ButtonBox["Maclaurin",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Maclaurin.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " series  of analytic functions."
}], "Text"],

Cell[TextData[{
 StyleBox["Definition  7.2  (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Taylor Series",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/TaylorSeries.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If  ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 "  is analytic at ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ", then the series \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "\[Alpha]", ")"}]}], "+", 
     RowBox[{
      RowBox[{"f", "'"}], 
      RowBox[{"(", "\[Alpha]", ")"}], 
      RowBox[{"(", 
       RowBox[{"z", "-", "\[Alpha]"}], ")"}]}], " ", "+", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["f", 
         RowBox[{"(", "2", ")"}]], 
        RowBox[{"(", "\[Alpha]", ")"}]}], 
       RowBox[{"2", "!"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "\[Alpha]"}], ")"}], "2"]}], "+", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["f", 
         RowBox[{"(", "2", ")"}]], 
        RowBox[{"(", "\[Alpha]", ")"}]}], 
       RowBox[{"3", "!"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "\[Alpha]"}], ")"}], "3"]}], " ", "+"}], "..."}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"=", "  ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["f", 
        RowBox[{"(", "k", ")"}]], 
       RowBox[{"(", "\[Alpha]", ")"}]}], 
      RowBox[{"k", "!"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "\[Alpha]"}], ")"}], "k"]}]}]}]}]],
 "\n\t\nis called the Taylor series for ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " centered at ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ".  When the center is  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "=", "0"}]]],
 ", the series is called the Maclaurin series for ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["\<\
\tTo investigate when these series converge we will need the following lemma.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Lemma 7.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If  ",
 Cell[BoxData[
  RowBox[{"z", ",", 
   RowBox[{
    SubscriptBox["z", "0"], "  ", "and", "  ", "\[Alpha]"}]}]]],
 "  are complex numbers  with  ",
 Cell[BoxData[
  RowBox[{"z", "\[NotEqual]", 
   SubscriptBox["z", "0"]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{"z", "\[NotEqual]", "\[Alpha]"}]]],
 ",  then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    RowBox[{"z", " ", "-", " ", 
     SubscriptBox["z", "0"]}]], " ", "=", " ", 
   InterpretationBox[
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{"z", " ", "-", " ", "\[Alpha]"}]], "+", 
       FractionBox[
        RowBox[{
         SubscriptBox["z", "0"], " ", "-", " ", "\[Alpha]"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", " ", "-", " ", "\[Alpha]"}], ")"}], "2"]], "+", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["z", "0"], " ", "-", " ", "\[Alpha]"}], ")"}], "2"], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", " ", "-", " ", "\[Alpha]"}], ")"}], "3"]], "+"}], 
      "..."}], "+", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["z", "0"], " ", "-", " ", "\[Alpha]"}], ")"}], "n"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "\[Alpha]"}], ")"}], 
       RowBox[{"n", "+", "1"}]]], "+", " ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"z", "-", 
        SubscriptBox["z", "0"]}]], 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["z", "0"], " ", "-", " ", "\[Alpha]"}], ")"}], 
        RowBox[{"n", "+", "1"}]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", " ", "-", " ", "\[Alpha]"}], ")"}], 
        RowBox[{"n", "+", "1"}]]]}]}],
    SeriesData[
    z0, \[Alpha], {(z - \[Alpha])^(-1), (z - \[Alpha])^(-2), (
       z - \[Alpha])^(-3), (z - \[Alpha])^(-4), (z - \[Alpha])^(-5)}, 0, 5, 
     1]]}]]],
 "  \n\nwhere n is a positive integer.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Proof of ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 StyleBox["Lemma 7.1",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 StyleBox[" is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell["\tWe are now ready for the main result of this section.", "Text"],

Cell[TextData[{
 StyleBox["Theorem 7.4 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Taylor's Theorem",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/TaylorsTheorem.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 " Suppose ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is analytic in a domain ",
 StyleBox["G",
  FontFamily->"Courier New"],
 ", and that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["D", "R"], 
    RowBox[{"(", "\[Alpha]", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", 
     RowBox[{"|", 
      RowBox[{"z", "-", "\[Alpha]"}], "|", 
      RowBox[{"<", "R"}]}]}], "}"}]}]]],
 " is any disk contained in ",
 StyleBox["G",
  FontFamily->"Courier New"],
 ".  Then the Taylor series for ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " converges to ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " for all z in ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "R"], 
   RowBox[{"(", "\[Alpha]", ")"}]}]]],
 ";  that is, \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["f", 
        RowBox[{"(", "k", ")"}]], 
       RowBox[{"(", "\[Alpha]", ")"}]}], 
      RowBox[{"k", "!"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "\[Alpha]"}], ")"}], "k"]}]}]}]]],
 "   for all   ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", 
   RowBox[{
    SubscriptBox["D", "R"], 
    RowBox[{"(", "\[Alpha]", ")"}]}]}]]],
 ".  \n\nFurthermore, for any r, 0<r<R, the convergence is uniform on the \
closed subdisk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    OverscriptBox[
     SubscriptBox["D", "r"], "_"], 
    RowBox[{"(", "\[Alpha]", ")"}]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"z", ":", 
       RowBox[{"|", 
        RowBox[{"z", "-", "\[Alpha]"}], "|", 
        RowBox[{"\[LessEqual]", "r"}]}]}], "}"}], "  ", "for", "  ", "0"}], 
    " ", "<", " ", "r", " ", "<", " ", "R"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.4 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\n\tA singular point of a function is a point at which the function fails \
to be analytic.  You will see in Section 7.4 that singular points of a \
function can be classified according to how badly the function behaves at \
those points.  Loosely speaking, a nonremovable singular point of a function \
has the property that it is impossible to redefine the value of the function \
at that point so as to make it analytic there.  For example, the function ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", "z"}]]}]]],
 " has a nonremovable singularity at ",
 Cell[BoxData[
  RowBox[{"z", "=", "1"}]],
  CellChangeTimes->{3.399322829078125*^9}],
 ".  We give a formal definition of this concept in Section 7.4, but with \
this language we can nuance Taylor's theorem a bit."
}], "Text",
 CellChangeTimes->{{3.399322833421875*^9, 3.39932283803125*^9}}],

Cell[TextData[{
 StyleBox["Corollary 7.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 "  is analytic in the domain ",
 StyleBox["G",
  FontFamily->"Courier New"],
 " that contains the point  ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ".  Let  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  be a nonremovable singular point of minimum distance to the point  ",
 Cell[BoxData[
  RowBox[{"z", "=", "\[Alpha]"}]]],
 ".  If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[VerticalSeparator]", 
    RowBox[{
     RowBox[{
      SubscriptBox["z", "0"], "-", "\[Alpha]"}], "\[VerticalSeparator]"}]}], 
   "=", " ", "R"}]]],
 ",  then\n\n\t",
 StyleBox["(i)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["  ",
  FontWeight->"Bold"],
 "the Taylor series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "0"}], "\[Infinity]"], 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["f", 
       RowBox[{"(", "n", ")"}]], 
      RowBox[{"(", "\[Alpha]", ")"}]}], 
     RowBox[{"n", "!"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]]],
 "  converges to ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " on all of  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "R"], 
   RowBox[{"(", "\[Alpha]", ")"}]}]]],
 ",  \nand\n\t",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["  ",
  FontWeight->"Bold"],
 "if ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[VerticalSeparator]", 
    RowBox[{
     SubscriptBox["z", "1"], "-", "\[Alpha]"}], "\[VerticalSeparator]"}], "=", 
   RowBox[{"S", ">", " ", "R"}]}]]],
 ",  the series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "0"}], "\[Infinity]"], 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["f", 
       RowBox[{"(", "n", ")"}]], 
      RowBox[{"(", "\[Alpha]", ")"}]}], 
     RowBox[{"n", "!"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "1"], "-", "\[Alpha]"}], ")"}], "n"]}]}]]],
 "  does not converges to ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", 
    SubscriptBox["z", "1"], ")"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 7.3 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 7.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", "z"}], ")"}], "2"]], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"n", "+", "1"}], ")"}], " ", 
     SuperscriptBox["z", "n"]}]}]}]]],
 "  is valid for all  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "\[Element]", 
    RowBox[{
     SubscriptBox["D", "1"], 
     RowBox[{"(", "0", ")"}]}]}], "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", 
     RowBox[{"|", "z", "|", 
      RowBox[{"<", "1"}]}]}], "}"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Solution.  In Example 4.24 we established this identity with the use of \
Theorem 4.17.  We now do so via Theorem 7.4.  If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", "z"}], ")"}], "2"]]}]]],
 ",  then a standard induction argument (which we leave as an exercise) will \
show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", "n", ")"}],
      Derivative],
     MultilineFunction->None], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"n", "+", "1"}], ")"}], "!"}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", "z"}], ")"}], 
     RowBox[{"n", "+", "2"}]]]}]]],
 "  for  ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", 
   RowBox[{
    SubscriptBox["D", "1"], 
    RowBox[{"(", "0", ")"}]}]}]]],
 ".  Thus  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", "n", ")"}],
      Derivative],
     MultilineFunction->None], 
    RowBox[{"(", "0", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"n", "+", "1"}], ")"}], "!"}]}]]],
 ",  and Taylor's theorem gives  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", " ", "-", " ", "z"}], ")"}], "2"]], " ", "=", " ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["f", 
          RowBox[{"(", "n", ")"}]], 
         RowBox[{"(", "0", ")"}]}], 
        RowBox[{"n", "!"}]], 
       SuperscriptBox["z", "n"]}]}], " ", "=", "  ", 
     RowBox[{
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"n", "+", "1"}], ")"}], "!"}], 
         RowBox[{"n", "!"}]], 
        SuperscriptBox["z", "n"]}]}], " ", "=", "  ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "+", "1"}], ")"}], 
        SuperscriptBox["z", "n"]}]}]}]}]}]}]]],
 ",  \n\nand since",
 " ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " ",
 "is analytic in ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 ", this series expansion is valid for all ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", 
   RowBox[{
    SubscriptBox["D", "1"], 
    RowBox[{"(", "0", ")"}]}]}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"7.3", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506705234859375*^9, 3.506705234859375*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", "z"}], ")"}], "2"]]}]]],
 " and find the first few terms of the Maclaurin series."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"z", "=", "0"}], ";", " ", 
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "n", ",", "S17", ",", "S\[Infinity]"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "z"}], ")"}], "2"]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S17", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "17"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(17\)]\)[z] = \>\"", ",", 
      RowBox[{"S17", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"S17", "[", "z", "]"}], ",", "\"\< + ...\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399365703640625*^9}],

Cell["Sum up the terms to verify that we have things right.", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S17", "[", "z_", "]"}], "   ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "17"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "+", "1"}], ")"}], " ", 
       SuperscriptBox["z", "n"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S\[Infinity]", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "+", "1"}], ")"}], 
       SuperscriptBox["z", "n"]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(17\)]\)[z] = \>\"", ",", 
      RowBox[{"S17", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(\[Infinity]\)]\)[z] =  \
\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)(n+1)\!\(\*SuperscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      RowBox[{"S\[Infinity]", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39936570890625*^9}],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to plot some partial sums for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", "z"}], ")"}], "2"]]}]]],
 ".  Since convergence will be more rapid in a smaller disk  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", " ", "r"}]}]]],
 "  we will use the disk  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", " ", "0.6"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "j", ",", "m", ",", "n", ",", "s", ",", "z"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "z"}], ")"}], "2"]]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", " ", "[", 
     RowBox[{
      RowBox[{"j", "=", "2"}], ",", 
      RowBox[{"j", "\[LessEqual]", "4"}], ",", 
      RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"m", "=", 
        RowBox[{"4", " ", "j"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"s", "[", "z_", "]"}], "=", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "0"}], "m"], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"n", "+", "1"}], ")"}], 
          SuperscriptBox["z", "n"]}]}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"g0", "=", 
        RowBox[{"PolarMap", "[", 
         RowBox[{"s", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0.6", ",", "0.05"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"2", "\[Pi]"}], ",", 
            FractionBox["\[Pi]", "16"]}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "4"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
          RowBox[{"Ticks", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{"0", ",", "4", ",", "1"}], "]"}], ",", 
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], 
          ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "g0", "]"}], ";", "  ", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<w = \>\"", ",", 
         SubscriptBox["\"\<S\>\"", "m"], ",", "\"\<[z] = \>\"", ",", 
         RowBox[{"s", "[", "z", "]"}], ",", "\"\<\\n\>\"", ",", 
         "\"\<\\n\>\""}], "]"}], ";"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.6", ",", "0.05"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"2", "\[Pi]"}], ",", 
         FractionBox["\[Pi]", "16"]}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "4"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "4", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "g1", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  The mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399365712984375*^9, 3.399365746671875*^9}, {
  3.399365794078125*^9, 3.399365898140625*^9}, {3.39991470409375*^9, 
  3.399914704375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 7.4",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox[".",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that, for  ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", 
   RowBox[{
    SubscriptBox["D", "1"], 
    RowBox[{"(", "0", ")"}]}]}]]],
 ",   \n\n",
 StyleBox["(7-12)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", 
     SuperscriptBox["z", "2"]}]], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    SuperscriptBox["z", 
     RowBox[{"2", "n"}]]}]}]]],
 "    and    ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", " ", "+", " ", 
     SuperscriptBox["z", "2"]}]], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"], 
     SuperscriptBox["z", 
      RowBox[{"2", "n"}]]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  For the real variable case we have the following series approximations \
that were studied in calculus. Observe that their interval of convergence is \
the open interval ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], ",", "1"}], ")"}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztnft71bYZx83xOSE3QggJIQRyOwkQQkhLCCltodwKBRoC49bu2bOnrOtK
t97WdmNru/3c/QHtv3t2JFuvZPsrHzmSnXMSJcV1ZPl9vx/dbMuWtPXyh1ef
ffXyhy8+fTl397uX37764tPv5+588107KDwQBLXHQXDg67mA7beCQGxa7f+i
zRO2YcFdGvAL+189Ut7eW6U/f1WOB2EQYbWif2x7ARz4LTpnMT4Ux+T/jojo
LRn9ITDRoHMDCn8Gzj0CfLxy7GMjwmkCV2Mg+l1KuzpwWlecijDkdAx4+7w0
bwURt2Ljqqv2T8PQ21Hg5i/u3cRQC8DbURCdF5Eac9Bn6GAcWP7MieVY+jxw
MA6iP3cs2NReLHMOmJ2wMDsB7P25+2QeA/Y+tZc5C8we6z6ZM8DspIXZSWDv
T/YyTwGzx7tP5klgdsrC7HFg76W9zBPsfzVm86SFsSmy4kDSFEWXpDbipoG9
P9rLnCTmWQtjJ8mKA0moYbARN0Pi/mAvbpyMLVgYQ03+x/bixkjcooWxebLi
QBK6EbYR1yRxL+zFHSZjZyyMLZEVdLSgpENkbNnC2Bmy8sRe0jDIQhtxyyTu
sb24g+x/DXYPW4vMiicOvqfWUfET0oFUZLnXBBoMzqgJ+4q3hVx9J3paffQU
FwwImYo/ni3ZR6R5EdxKBDdx7H4cvAD45gtZQA3QojnFtHnUvQEc6jN6EITN
FoIeAhbk9bEjMTodXZoRLhI/ZRivpyEPxIZD4YD/KJU6GZ2XKn6UP7ZE8qLu
jhS+EqGGUQbIFmqnNPzypCVDail5nBTtObScBrgfhBVrjJDVAi0ROt20GULi
UaO75yDj+ihzmFdeHifNFf8sgqgIYAHEayoKhFlk70R3yYkT6S2QzqY3jz9b
nLvh3Xv3u+qeP5CdD6K6oN6uP4/DlKC2nWy8FbZZcmJlUJGUaszQM+IyiHcO
0KN4yN45EK/ZRVr6u6LAePc7NfGIbUdZX4V1x/IYszJoL+kTth1mxkYtrIyw
7ZAEs5L0JRlrWFgJycoZe0mv2bbBjIkD8S/vx3oCrDzKPeNiOUVZMn8ArLyf
m64l1S7eZI2wE68DK1fZlnfeDbPQwep01aP8aQfwPtI+tvc2sLce1Y92wBCd
0VedzFCEBS0K4280+nlQsht1DThaJbo6i3k8SvDoz+og2vvzlJCngSn1K5og
/sdVy5cjtfjPIqqfifIVoP79tFa2swaE8LSeJlPTIMoA28qvhCL77NimXtxT
tmW5QomrEycMcmPcMcr+w2SPv7kZUIt03ATxvy7rJd1j28G4jAcROC839wyz
+ibbHiEDfO92sTy7SgWlFpHyAtyKn2P5Ac59DZz7E8B9SgbU8iqSNEfIJlUd
LmSCkncieeAKOPdHUBSea/Ob7eQIeTPpj16PRi9K5YF1QyEvtLWigxD6YC7y
h/ql5kjSGjDwb76tJ5qz9u5H2sYl3fPSuqRXJ++2Zb1cBpZPE8VK1RLPRhVY
ca3aW84BUK38i28bCYkib/U6GwkbIrfX9WKXSOwFYHQFiEXvPXcmNmmDWn3F
xht64fQCKt1CIo5VwIH6Tl8DDehqZHqhLMg0T0zrwAG6ajUrgEC3J2t6iFmC
2AAOLtLReXDuP4GrsDrp6hdW4pTLwNUl1Wwcb6b7cE5SWr8FHGzQUST9H8AV
ups0lV4H9i7opVP/Mbxf3wTpP919EFNAJsJ5C8Q70X04x4FMXp35Ow70KfMV
ykUbnK1cHwisASyv6sEmARjdZimu0CfPMj9lk4E+yvwBSEJP6FuGfh1gH1Oj
B0qjkHKPBhe8A7DRJ7Om2DaDGgpiT6jRg3SDkq0daqq/C7DRB82m2NuGfh1g
j6vRE9c2o1EJVwE5+uL8e6AKdaVYDojoA27O6+GPqtEDpdXVDmW4RmGSF41X
MOUtPnCiIOIYQLxRAZjpxcYGp6XHeQ/goCExrnEOAnsrepwjavT4lJsWON8B
9werwxkFOLeAq+sAB43C6hGcGwAHDQPcZZzDAOd2F+H0A3vnDHFaepybAAe9
7/o7sNdfHc4IyJ33exfnEMC5A1zdAjiHPU7JOMMA5y5wdRvgjFSAMwDsLVeH
8y1wP1AdzlA6evtX+1I3hXPI41SJE5+yD3DuAJzhCnAGgb2zepxM9CB+s7l/
cLixAON8A9yjLy9KwsmUzfbv/b2PcxfgDHmcknHkCCYZvf3bTUSZS2NLvEjN
IUpm0AMtTp1wYiSk9GugAJHvMpG8IskM8jhl42Q6GNq/HwJX9wAOukh6nLJx
+E0nC4LvC1yDbed6Q4jDwPLpYoh3KEzGC4H7CDbTCKLHUlPeR4auHZD3xepT
Fy/ev9BIp7jQUwD5KyAH3WFt5Tp0BprM4tsEHygc8C1QWcg7fwflgP99CguE
d+j+PoZHnbCm8Ok3rhWT88pdq5B3O9ehA8oGlaZERd6qBs/00nMI2FvyUPlQ
jQRUDAZfH3qyksjqsdwgJZf9IrwHuDTuL7IvgRLUM1kqWaY0PtRC4dKIPpzx
ZCWRhTml0ePtNbwPRWlOtiVVkI0Ae4uuyXDGoY9MPV6ZeGgcRI1ctVJYewAV
5+Q2cFkU729ADnq17fE8niO8ZB3V2WAnoltpj7dzPDycrw5koyeFHsULgWz9
NdDjebyd4KGvSpvu8LZAPDkHYAJt75KhWzH0kaQzsswwbdRUeqhegZIvOdGg
mRLwtnIdugFF9ewOyVajwjcVZVHv/D1YZUkgDqEkCFMi2AkO+cWhkvkLlXVr
ZLcFXUZnO6g63yUT0iwqZA/BuekehCKwnQaXVoEd6mpUKbBabyUhoocr12Cm
l55RYG+hOhz0hG8z616FOGqDImz+1eM4wBGHPY7H8Tjl4mzn4Sjuv/A4DnDE
IY+zn3BeAfdo5LgpzhFgb97j7G8c4W6XcdDD+qPewFHnSROnoNzxOB7H43ic
HeJwB4HH6W6cz4F7NBeTKQ6aoWsu8nY5dYid1vA4PYbDx65qp6xzDVZ8gjwH
iGL8dKC4CnDPuWtey5du1cCLQ7sALw4VhP8fFSMevEZ//hYd/wV75jur+Niv
ZpZ5KN886fkAnkr1ZMLUlbT4hTJAphTfXgAH4vRRV/8Qh9Dl1GYqWLR0+O9B
YUFjfm385gzobgJJqErcpTRGa46aDrseA94+BuJQArhR4CApLJvGo8DNR0AV
SgNL1zkTlywAVWhmz+LXwXFgGfGieSeKe8tBnAdC0NSypvcwNmAOppqZA+7R
lMemriaAvRe9i3MM2HvuGCdnirNZ4B5NxW2Dg3KnpBnbZoB7NKG6qatJYA/l
Tkk4p4B7NC1+j+CcBO6nLFwdB/aeOcbJmSk0Xl2j5WCJSm4F5URJk5xOkQl5
yAZiGth74hgnZ/rmSUrDWQsHtFhYq0LpqMG0gZghiN8BpyVNnz1OThcsHKBL
67ZjiJz588cIAi0kb+pgnqw8Aq5KmvofPbDZQDQJ4mF1EIfJKVobzdTBElnZ
Aq5sVsnNWSnkEDlFa9CZOjhDVh5UJ32YTMhDNhDLBHGvOgjeIvBZt2qRe/H0
zffUNkn8hHQgFVnuNYEugzNqwr7ibSFX34nco9MAu77rRGjRq+lcjugM5fYw
fWXJdBfMi+BWIriJY/fj4AXAPF/IAmpIF80pps2j0vJemazuykRAZeAUhXWk
DfUFYhCEzRZKiCFgQd5fdEwFdDq6tUHlAImfKhxPJmnYjeAhEDoDzkWQB2Jn
oXDKf5RGIhmdl0h+lBeuSHJ0MUgliRKhhvEGyBZqCzVpIk9Ci52iIiAlj5Oi
fDR6+ApSKdJFpKZ5Lqly2vx+EFaswUdWCzR06HTTph6JR+08iqfmtAijPOwm
cDTbzKwhZFy1ZUng7QCPk87k+GcRREVQCyBeU1EgzCJ7J0CYSXaUJFFbn1Ln
xomJvqo0vXeuaBnsHpVT6jrmpYmQp7OdDXsFP6bKY35uiOeBKMyB+58U9yL8
heG5sXv+MHs+iCqN+rjyPA5Tgtp2svFW2GapiJWnIl6smv2cp/obKNPfSrXo
+XoZxDsH6FE8ZO8ciNfscG60sdNyFuTiCojXb19gfsZ18Rk4Pd2hyw5uulKA
26WnwMZjtuUrOaOV5B3UoZ9BGLqOPwb2UH9lSTK5q1HmB710CCmVkEx61w7n
V+QPUGPM8qC9zE/YdpgZQ4OMGiREOykWP4q6q/nENEMyAaxkfknGUIpw9zxX
0bSA90kmekkWkuWcdRVMZb5m22iOt/hA/Ms7H6VMtF4TDf6PJujVWrlYThXi
6TDIHPDrM1pn8hbb1uOExDlRUv0eidKGO22HXgem+Drj/XG7g0tzSeL4660+
duLbwMp6Uhd6tV2SLl7tBtiJbwIrq6SaT+o6U52upajGtQNOAyvqx39B/K+P
ku90MZlcEjtRfqDRQdyazv0pMjUNovBkfqOYuKdRdWoF8vuEDuI2dZ6PkKkx
nf53iom7T4WnjwXzPW71nqFW3liMkoExtnermAa+APkwR0i+vOmLym4rftAf
puJxzVDcEzKQc6eNJF1h2waQdJRyQDYHqSibhuLyy0WOuHXyTK/5o040pOZN
QzX5VShHzSooifzypu2s4+m6ZqjLtAXKUbhMTs8CY6cj8GzKnatOIdcQ5mhQ
bZ+lyBUqpA6jqAJeABZXKMrZ6nQtJHW9ASyuUnqhnuCSdM3pShW6Rkd1oZ6o
QgH+AKUkubMiLNLK/7oEzF6kMKl0rjqZpyhVN4GxSylx7C90v1OSONT9imRe
JohT1Ymj/mJ485q+4WB/TVcnLvGqMHaPZF4BKYw+uixJ5nEgk1cI/l4CjQh4
GwhGTwZI8Fau5YLSJ4H0dQqT8dA3/zInZOEoBGHgoyDOMYCzAVyh0TrvABz0
XTXCsRkRlIMzAXA2gSs04uZdgIO+ekc424Y+CuKMA5zLsXHVlaZoXwVEaFiC
vrzteLRODtRRAMXjacfKXAMcaPCLtqAVGoWTI30MSL/RQXCUcOaCHTSvaAwn
kvkeSFc0bqokmYlB+7H7mx1kitSsUOYokHkLmL0OZKIheCXJzEw1Gog1QJNm
bwCZaKxoFTJjCV0ocwTIRD28N4FM1JNakszMGlaBXNs3KzOzGBWaC7YKpbEK
pFTWLJmgFcrMLEwaqAvbp2VmEhStLVCF0lgFUiorl0zQCmVmxiwH6srtaZmZ
BEWrS+2yUtkMyAStUGZmGGqgrkmelplJULT65i4rlc2ATNCulZlJUDTUvSSl
A7GCQFHQwu9Gu0VsMlnv97RS2brKclqhTPkRfiL39UozaYqGi3ux6liEhNgH
vS72AywWfdThxYrutIxY9IWMbHJlU9DNSjPJigYuVytWLkCEOsosZW/nGi8I
0Ii3CYAIgu5d1G6yUMuDF7NE34IhqEeGvhzi8cecRjodhQAXUFu5HnaEkilq
tyk4UDTCvkxnSKV0neatZy8eS4RXncv7OYRoELdJ730FeLyi1cqE2s714BAF
rSfqAsBBWy2aE1U2WkwaXcD3DEIyHvpSOvQ4O8TJc98J50FOAUOf1nYtQucc
QZ/YV4hjun68x3GPgweOoElm9xFCKOymq377v/92h+yiiy7vd9mZIVp9XnHp
ilGpMF3ePhQmg4Ta/SlWHmI7qCB4pV5pZ6Xp6XKcVv/okDCNqhNa2tzL3Icy
0SLYqkzh7j/uq5CX6WVSmHwrYLpUu6ng4suyd+zeSwoRL7IDxaymMxFxmPZg
lN27XBhKHCoZShxyBVWokBXi2EkhQ6tU6ReWCRMJhbIeLTxcN4To9G2+a5xQ
V36tIbSWHUg3Xe45OS2nXnDBBtXL9DK9TCuZlxWZPKAVwGe5ncjk9gIv00ym
6RpoXqaX2T0yMx2WP+0npRvCsuItwJ1hXqwLsfbLonqxZYnF7+B+3I+KLwnz
istYtZftZXvZXrahbDmthjSNvlsJrRGS9tD3Mq93F8d+vfAiYDueM8EG0fF6
4UV43XSplwwvDu0CvDiUA99Ta4MHB/4P4O1b7Q==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{593, 366},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["CompressedBitmap", "\<\
eJy9mc1qFEEQx3t3ZjfJ7hpN/Nho/NgQjWJAEC9GiQgxKsR4lBxEWEIgEcQQ
c/DiQT2IimdfQe+efACfwFfwOdbp7klPZubXbc8HNnG6qeqq+ld1VU/Nuj7c
3956Mdzf2RwOHuwNd7d3Nl8N7r/ci0hBQ4jmihCiPxByPYqW8WMU/enHqnxI
cjQ9VetA6C2KJP5o/pKcWpLRUYQwtSkai3LRlKtmRoscATHkvxvlxD4ZOCFw
g1ohbpQTW9ZbbtvwhQa90n1eribVtpZRfgi8aIPxhTJCXwBRMx3P8ojWygjd
sYeqmw6+Yp6GfR1Qaz2uOGkO0RfqV0lhpmQN/4+Ha/WrdByb1tzOnX48nwWR
CZOCYwDhcmEJ3/gHdUN9VFjCEchjQDsDtHGb0YypKxVkKaJ141uvIBuH8ZYp
qGkQnAXaCaDNAO2Ip+znWhCQ20eBNge0nqeNbDa6beROR45zsP2aCQAp++Gp
hWhTQBsYa5PApQK2ahHisTWaYQpwNCgdZgyWpllRjRDSPsh+rQaHck3dzdbe
aQJAULjIGhW+21oHrOmUEc8yXsaeWoOe3zrlPIE+C33zN0vuUuFZHc+bmXYW
DrUFvga7bFBHRtyU06wkZIHFg+AkuX7Jmc3vyygnX5MutVXEaytEuuOL2+hl
6sSWueRlEiTqQE8Z7nd/leRUoSSxwulX0JwL0q5/SV60hSa/9WfNVWMpU0JU
Oe7W4lwxKUldML01ki+JIE3LyB53Jl1xfW+cSIvdl+lopK06eJX9L5YuLpRw
sfjibMhVQ69UDqyCRqrRgSfSaFA/eMFf/K0nIuq/ukALrLScaRIv4CQ1RRUR
+SaIyQ08UHpHZT90Rgcl6geMMnzc5Brd6BZFdNy+eOkrKOkzrT+K+IW5lOPE
LYWI+kILIsfB0/ukHT8zWg5mOjplIbT59w+FlFSJwnf1oF40CilwlfBfNcL0
bZWoDuzHMA80+kKm6z170chBr5IxtxcnQc3HmqEu1QM1+3OVHLpfEvdMKVGO
0A8bajO1UJTnVgW0+UM5LMtVsZACfTmK53LqSQYdz3Un95eT+8TJfajNv5aT
4tw1sfltaFuGFm9XsuoR/1+RaPwFQb660w==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{579, 23},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  For ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", 
   RowBox[{
    SubscriptBox["D", "1"], 
    RowBox[{"(", "0", ")"}]}]}]]],
 ",\n\n",
 StyleBox["(7-13)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", "z"}]], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    SuperscriptBox["z", "n"]}]}]]],
 ". \n\nIf we let ",
 Cell[BoxData[
  SuperscriptBox["z", "2"]]],
 " take the role of z in ",
 StyleBox["(7-13)",
  FontColor->RGBColor[0, 0, 1]],
 ", we get that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", 
     SuperscriptBox["z", "2"]}]], "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"1", " ", "-", " ", 
      RowBox[{"(", 
       SuperscriptBox["z", "2"], ")"}]}]], " ", "=", " ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["z", "2"], ")"}], "n"]}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      SuperscriptBox["z", 
       RowBox[{"2", "n"}]]}]}]}]}]]],
 ",  \n\nfor  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "2"], "\[Element]", 
   RowBox[{
    SubscriptBox["D", "1"], 
    RowBox[{"(", "0", ")"}]}]}]]],
 ".  But  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "2"], "\[Element]", 
   RowBox[{
    SubscriptBox["D", "1"], 
    RowBox[{"(", "0", ")"}]}]}]]],
 "  iff  ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", 
   RowBox[{
    SubscriptBox["D", "1"], 
    RowBox[{"(", "0", ")"}]}]}]]],
 ",  thus we have proven that  ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", 
     SuperscriptBox["z", "2"]}]], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    SuperscriptBox["z", 
     RowBox[{"2", "n"}]]}]}]]],
 "  for  ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", 
   RowBox[{
    SubscriptBox["D", "1"], 
    RowBox[{"(", "0", ")"}]}]}]]],
 ".\n\nNext, let  ",
 Cell[BoxData[
  RowBox[{"-", 
   SuperscriptBox["z", "2"]}]]],
 "  take the role of z in Equation ",
 StyleBox["(7-13)",
  FontColor->RGBColor[0, 0, 1]],
 ", we get that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", " ", "+", " ", 
     SuperscriptBox["z", "2"]}]], "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"1", " ", "-", " ", 
      RowBox[{"(", 
       RowBox[{"-", 
        SuperscriptBox["z", "2"]}], ")"}]}]], " ", "=", " ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", 
         SuperscriptBox["z", "2"]}], ")"}], "n"]}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"], 
       SuperscriptBox["z", 
        RowBox[{"2", "n"}]]}]}]}]}]}]]],
 "\n\t\t\t\n gives the second part of Equations ",
 StyleBox["(7-12)",
  FontColor->RGBColor[0, 0, 1]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Real", " ", "Solution", " ", "7.4", " ", 
   RowBox[{
    RowBox[{"(", "a", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506705241640625*^9, 3.506705241640625*^9}},
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "x_", "]"}], "=", 
     FractionBox["1", 
      RowBox[{"1", "-", 
       SuperscriptBox["x", "2"]}]]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Rlines", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Green", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", 
              RowBox[{"-", "2"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "8"}], "}"}]}], "}"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"Red", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", 
              RowBox[{"-", "2"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "8"}], "}"}]}], "}"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Green", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"-", "2"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "8"}], "}"}]}], "}"}], "]"}]}], "}"}]}], 
      "}"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Cpoint", "=", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Magenta", ",", 
        RowBox[{"PointSize", "[", "0.025", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"f", "[", "0", "]"}]}], "}"}], "]"}]}], "}"}], "}"}]}], 
    ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ydot", "=", 
     RowBox[{"Graphics", "[", "Cpoint", "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Rends", "=", 
     RowBox[{"Graphics", "[", "Rlines", "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "15"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"2", "i"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"T", "[", "x_", "]"}], " ", "=", " ", 
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"f", "[", "x", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", "m"}], "}"}]}], "]"}], "]"}]}], ";", 
      "  ", "\[IndentingNewLine]", 
      RowBox[{"graph1", "=", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"f", "[", "x", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"-", "0.99999"}], ",", "0.99999"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", "Red", "}"}]}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2"}], ",", "8"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"Ticks", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{
              RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.5"}], "]"}], ",", 
            RowBox[{"Range", "[", 
             RowBox[{
              RowBox[{"-", "2"}], ",", "8", ",", "2"}], "]"}]}], "}"}]}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"graph2", "=", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"T", "[", "x", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", "Blue", "}"}]}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2"}], ",", "8"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"Ticks", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{
              RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.5"}], "]"}], ",", 
            RowBox[{"Range", "[", 
             RowBox[{
              RowBox[{"-", "2"}], ",", "8", ",", "2"}], "]"}]}], "}"}]}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"figure", "=", 
       RowBox[{"Show", "[", 
        RowBox[{"graph1", ",", "graph2", ",", "ydot", ",", "Rends"}], "]"}]}],
       ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "figure", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<Approximation of \!\(\*FractionBox[\(1\), \(1 - \*SuperscriptBox[\
\(x\), \(2\)]\)]\) with \>\"", ",", "\"\<\\n\>\"", ",", 
        SubscriptBox["\"\<S\>\"", "m"], ",", "\"\<[x] = \>\"", ",", 
        RowBox[{"T", "[", "x", "]"}], ",", "\"\<\\n\>\"", ",", 
        "\"\<\\n\>\""}], "]"}], ";"}]}], "  ", "]"}], "  ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39936593703125*^9, 3.39936595846875*^9}, {
  3.399365997046875*^9, 3.399365997296875*^9}, {3.399914710609375*^9, 
  3.399914711*^9}, {3.399914807515625*^9, 3.39991490803125*^9}, {
  3.400267747328125*^9, 3.40026775628125*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Complex", " ", "Solution", " ", "7.4", " ", 
   RowBox[{
    RowBox[{"(", "a", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506705243953125*^9, 3.506705243953125*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", 
     SuperscriptBox["z", "2"]}]], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    SuperscriptBox["z", 
     RowBox[{"2", "n"}]]}]}]]],
 "  is valid for all ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", "1"}]}]]],
 ".  \n",
 "\n",
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", 
     SuperscriptBox["z", "2"]}]]}]]],
 " and find the first few terms of the Maclaurin series."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "n", ",", "S50", ",", "S\[Infinity]"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox["1", 
      RowBox[{"1", "-", 
       SuperscriptBox["z", "2"]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S50", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "50"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(50\)]\)[z] = \>\"", ",", 
      RowBox[{"S50", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"S50", "[", "z", "]"}], ",", "\"\< + ...\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399366008734375*^9}],

Cell["\<\
Sum up infinitely many terms to verify that we have things right.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S50", "[", "z_", "]"}], "   ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "25"], 
      SuperscriptBox["z", 
       RowBox[{"2", "n"}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S\[Infinity]", "[", "z_", "]"}], " ", "=", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      SuperscriptBox["z", 
       RowBox[{"2", "n"}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(50\)]\)[z] = \>\"", ",", 
      RowBox[{"S50", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(\[Infinity]\)]\)[z] = \
\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*SuperscriptBox[\(z\), \(2  n\)]\) = \>\"", ",", 
      RowBox[{"S\[Infinity]", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399366012921875*^9}],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to plot some partial sums for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", 
     SuperscriptBox["z", "2"]}]]}]]],
 ".  Since convergence will be more rapid in a smaller disk  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", " ", "r"}]}]]],
 "  we will use the half disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"Im", "[", "z", "]"}], ">", 
    RowBox[{"0", "  ", "and"}]}], "  ", "|", "z", "|", 
   RowBox[{"<", " ", "0.9"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "j", ",", "m", ",", "n", ",", "s", ",", "z"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", " ", 
     FractionBox["1", 
      RowBox[{"1", "-", 
       SuperscriptBox["z", "2"]}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", " ", "[", 
     RowBox[{
      RowBox[{"j", "=", "3"}], ",", 
      RowBox[{"j", "\[LessEqual]", "5"}], ",", 
      RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"m", "=", 
        RowBox[{"4", " ", "j"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"s", "[", "z_", "]"}], "=", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "0"}], "m"], 
         SuperscriptBox["z", 
          RowBox[{"2", "n"}]]}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"g0", "=", 
        RowBox[{"PolarMap", "[", 
         RowBox[{"s", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0.9", ",", "0.05"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "\[Pi]", ",", 
            FractionBox["\[Pi]", "24"]}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "4"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
          RowBox[{"Ticks", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{"0", ",", "4", ",", "1"}], "]"}], ",", 
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], 
          ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";", "  ", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "g0", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<w = \>\"", ",", 
         SubscriptBox["\"\<S\>\"", 
          RowBox[{"2", "m"}]], ",", "\"\<[z] = \>\"", ",", 
         RowBox[{"s", "[", "z", "]"}], ",", "\"\<\\n\>\"", ",", 
         "\"\<\\n\>\""}], "]"}], ";"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.9", ",", "0.05"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[Pi]", ",", 
         FractionBox["\[Pi]", "24"]}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "4"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "4", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "g1", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  The mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399366017375*^9, 3.399366050078125*^9}, {
  3.399914716453125*^9, 3.399914716765625*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Real", " ", "Solution", " ", "7.4", " ", 
   RowBox[{
    RowBox[{"(", "b", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506705246578125*^9, 3.506705246578125*^9}},
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "x_", "]"}], "=", 
     FractionBox["1", 
      RowBox[{"1", "+", 
       SuperscriptBox["x", "2"]}]]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Rlines", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Green", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", 
              RowBox[{"-", "2"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "8"}], "}"}]}], "}"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"Red", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", 
              RowBox[{"-", "2"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "8"}], "}"}]}], "}"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Green", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"-", "2"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "8"}], "}"}]}], "}"}], "]"}]}], "}"}]}], 
      "}"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Cpoint", "=", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.025", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"f", "[", "0", "]"}]}], "}"}], "]"}]}], "}"}], "}"}]}], 
    ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ydot", "=", 
     RowBox[{"Graphics", "[", "Cpoint", "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Rends", "=", 
     RowBox[{"Graphics", "[", "Rlines", "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "15"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"2", "i"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"T", "[", "x_", "]"}], " ", "=", " ", 
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"f", "[", "x", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", "m"}], "}"}]}], "]"}], "]"}]}], ";", 
      "  ", "\[IndentingNewLine]", 
      RowBox[{"graph", "=", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"f", "[", "x", "]"}], ",", 
           RowBox[{"T", "[", "x", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Magenta", ",", "Blue"}], "}"}]}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2"}], ",", "8"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"Ticks", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{
              RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.5"}], "]"}], ",", 
            RowBox[{"Range", "[", 
             RowBox[{
              RowBox[{"-", "2"}], ",", "8", ",", "2"}], "]"}]}], "}"}]}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"figure", "=", 
       RowBox[{"Show", "[", 
        RowBox[{"graph", ",", "ydot", ",", "Rends"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "figure", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<Approximation of \!\(\*FractionBox[\(1\), \(1 + \*SuperscriptBox[\
\(x\), \(2\)]\)]\) with \>\"", ",", "\"\<\\n\>\"", ",", 
        SubscriptBox["\"\<S\>\"", "m"], ",", "\"\<[x] = \>\"", ",", 
        RowBox[{"T", "[", "x", "]"}], ",", "\"\<\\n\>\"", ",", 
        "\"\<\\n\>\""}], "]"}], ";"}]}], "  ", "]"}], "  ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39936606759375*^9, 3.39936609690625*^9}, {
  3.399914722515625*^9, 3.399914722796875*^9}, {3.40026776196875*^9, 
  3.400267768953125*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Complex", " ", "Solution", " ", "7.4", " ", 
   RowBox[{
    RowBox[{"(", "b", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506705248*^9, 3.506705248*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", " ", "+", " ", 
     SuperscriptBox["z", "2"]}]], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"], 
     SuperscriptBox["z", 
      RowBox[{"2", "n"}]]}]}]}]]],
 " is valid for all ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", "1"}]}]]],
 ".  \n",
 "\n",
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox["1", 
    RowBox[{"1", " ", "+", " ", 
     SuperscriptBox["z", "2"]}]]}]]],
 " and find the first few terms of the Maclaurin series."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "n", ",", "S50", ",", "S\[Infinity]"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox["1", 
      RowBox[{"1", "+", 
       SuperscriptBox["z", "2"]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S50", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "50"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(50\)]\)[z] = \>\"", ",", 
      RowBox[{"S50", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"S50", "[", "z", "]"}], ",", "\"\< + ...\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399366136609375*^9}],

Cell["\<\
Sum up infinitely many terms to verify that we have things right.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S50", "[", "z_", "]"}], "   ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "25"], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"], 
       SuperscriptBox["z", 
        RowBox[{"2", "n"}]]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S\[Infinity]", "[", "z_", "]"}], " ", "=", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"], 
       SuperscriptBox["z", 
        RowBox[{"2", "n"}]]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(25\)]\)[z] = \>\"", ",", 
      RowBox[{"S50", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(\[Infinity]\)]\)[z] = \
\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)(-1\!\(\*SuperscriptBox[\()\), \
\(n\)]\)\!\(\*SuperscriptBox[\(z\), \(2  n\)]\) =  \>\"", ",", 
      RowBox[{"S\[Infinity]", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399366141484375*^9}],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to plot some partial sums for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox["1", 
    RowBox[{"1", " ", "+", " ", 
     SuperscriptBox["z", "2"]}]]}]]],
 ".  Since convergence will be more rapid in a smaller disk  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", " ", "r"}]}]]],
 "  we will use the half disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"Im", "[", "z", "]"}], ">", 
    RowBox[{"0", "  ", "and"}]}], "  ", "|", "z", "|", 
   RowBox[{"<", " ", "0.9"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "j", ",", "m", ",", "n", ",", "s", ",", "z"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", " ", 
     FractionBox["1", 
      RowBox[{"1", "+", 
       SuperscriptBox["z", "2"]}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", " ", "[", 
     RowBox[{
      RowBox[{"j", "=", "2"}], ",", 
      RowBox[{"j", "\[LessEqual]", "5"}], ",", 
      RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"m", "=", 
        RowBox[{"4", " ", "j"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"s", "[", "z_", "]"}], "=", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "0"}], "m"], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "n"], 
          SuperscriptBox["z", 
           RowBox[{"2", "n"}]]}]}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"g0", "=", 
        RowBox[{"PolarMap", "[", 
         RowBox[{"s", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0.9", ",", "0.05"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "\[Pi]", ",", 
            FractionBox["\[Pi]", "24"]}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "4"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
          RowBox[{"Ticks", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{"0", ",", "4", ",", "1"}], "]"}], ",", 
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], 
          ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";", "  ", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "g0", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<w = \>\"", ",", 
         SubscriptBox["\"\<S\>\"", 
          RowBox[{"2", "m"}]], ",", "\"\<[z] = \>\"", ",", 
         RowBox[{"s", "[", "z", "]"}], ",", "\"\<\\n\>\"", ",", 
         "\"\<\\n\>\""}], "]"}], ";"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.9", ",", "0.05"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[Pi]", ",", 
         FractionBox["\[Pi]", "24"]}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "4"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "4", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "g1", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  The mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399366145296875*^9, 3.3993661734375*^9}, 
   3.399366218921875*^9, {3.39991472815625*^9, 3.3999147285*^9}}],

Cell[TextData[{
 StyleBox["Question.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Why do the graph of  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["f", "1"], "[", "z", "]"}], "=", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"1", " ", "-", " ", 
        SuperscriptBox["z", "2"]}]], "   ", "and", "   ", "w"}], "=", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", "2"], "[", "z", "]"}], "=", 
      FractionBox["1", 
       RowBox[{"1", " ", "+", " ", 
        SuperscriptBox["z", "2"]}]]}]}]}]}]]],
 " \"appear\" to be the same ?"
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Remark 7.1",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Corollary 7.3 clears up what often seems to be a mystery when series are \
first introduced in calculus.  The calculus analog of Equations ",
 StyleBox["(7-12)",
  FontColor->RGBColor[0, 0, 1]],
 " is  \n\n",
 StyleBox["(7-14)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", 
     SuperscriptBox["x", "2"]}]], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    SuperscriptBox["x", 
     RowBox[{"2", "n"}]]}]}]]],
 "    and    ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", " ", "+", " ", 
     SuperscriptBox["x", "2"]}]], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"], 
     SuperscriptBox["x", 
      RowBox[{"2", "n"}]]}]}]}]]],
 "   for   ",
 Cell[BoxData[
  RowBox[{"x", "\[Element]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "1"}], ")"}]}]]],
 ".  \n\nFor many students, it makes sense that the first series in Equations \
",
 StyleBox["(7-14)",
  FontColor->RGBColor[0, 0, 1]],
 " converges only on the interval  ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], ",", "1"}], ")"}]]],
 "  because ",
 Cell[BoxData[
  FractionBox["1", 
   RowBox[{"1", " ", "-", " ", 
    SuperscriptBox["x", "2"]}]]]],
 " is undefined at the points  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{"\[PlusMinus]", "1"}]}]]],
 ".  It seems unclear as to why this should also be the case for the series \
representing ",
 Cell[BoxData[
  FractionBox["1", 
   RowBox[{"1", " ", "+", " ", 
    SuperscriptBox["x", "2"]}]]]],
 ", since the real-valued function ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "x", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"1", " ", "+", " ", 
     SuperscriptBox["x", "2"]}]]}]]],
 " is defined everywhere.  The explanation, of course, comes from the complex \
domain.  The complex function ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"1", " ", "+", " ", 
     SuperscriptBox["z", "2"]}]]}]]],
 " is not defined everywhere.  In fact, the singularities of  ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 "  are at the points  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}]}]]],
 ",  and the distance between them and the point  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"\[Alpha]", "=", "0"}]}]]],
 "  equals ",
 StyleBox["1",
  FontFamily->"Courier New"],
 ".According to Corollary 7.3, therefore, Equations ",
 StyleBox["(7-14)",
  FontColor->RGBColor[0, 0, 1]],
 " are valid only for ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", 
   RowBox[{
    SubscriptBox["D", "1"], 
    RowBox[{"(", "0", ")"}]}]}]]],
 ", and thus Equations ",
 StyleBox["(7-14)",
  FontColor->RGBColor[0, 0, 1]],
 " are valid only for the real numbers  ",
 Cell[BoxData[
  RowBox[{"x", "\[Element]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "1"}], ")"}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tAlas, there is a potential fly in this ointment: Corollary 7.3 applies to \
Taylor series.  To form the Taylor series of a function, we must compute its \
derivatives.  We didn't get the series in Equations ",
 StyleBox["(7-12)",
  FontColor->RGBColor[0, 0, 1]],
 " by computing derivatives, so how do we know that they are indeed the \
Taylor series centered at  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"\[Alpha]", "=", "0"}]}]]],
 "?  Perhaps the Taylor series would give completely different expressions \
from those given by Equations ",
 StyleBox["(7-12)",
  FontColor->RGBColor[0, 0, 1]],
 ".  Fortunately, Theorem 7.5 removes this possibility.  "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 7.5  (Uniqueness of Power Series).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose that in some disk ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "r"], 
   RowBox[{"(", "\[Alpha]", ")"}]}]]],
 " we have  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      SubscriptBox["a", "n"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}], "  ", "=", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      SubscriptBox["b", "n"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]}]}]]],
 ".  \n\nThen  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["a", "n"], "=", 
    RowBox[{
     RowBox[{
      SubscriptBox["b", "n"], "   ", 
      StyleBox["for",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "   ", "n"}], "=", "0"}]}], ",", "1", ",", 
   "2", ",", "..."}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.5 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 7.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the Maclaurin series for ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["sin", "3"], "z"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Solution.  Computing derivatives for",
 " ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " ",
 "would be an onerous task. Fortunately, we can make use of the trigonometric \
identity  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["sin", "3"], "z"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox["3", "4"], "sin", " ", "z"}], "   ", "-", "  ", 
    RowBox[{
     FractionBox["1", "4"], "sin", " ", "3", "z"}]}]}]]],
 ".  \n\nRecall that the series for sin z (valid for all z) is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"sin", " ", "z"}], "  ", "=", "  ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]], " ", 
     SuperscriptBox["z", 
      RowBox[{
       RowBox[{"2", "n"}], "+", "1"}]]}]}]}]]],
 ".  Using the identity for  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["sin", "3"], "z"}]]],
 ",  we obtain  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["sin", "3"], "z"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["3", "4"], 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "n"], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]], " ", 
        SuperscriptBox["z", 
         RowBox[{
          RowBox[{"2", "n"}], "+", "1"}]]}]}]}], "   ", "-", "  ", 
     RowBox[{
      FractionBox["1", "4"], 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "n"], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"3", "z"}], ")"}], 
         RowBox[{
          RowBox[{"2", "n"}], "+", "1"}]]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["3", "4"], 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "n"], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]], " ", 
        SuperscriptBox["z", 
         RowBox[{
          RowBox[{"2", "n"}], "+", "1"}]]}]}]}], "   ", "-", "  ", 
     RowBox[{
      FractionBox["3", "4"], 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "n"], 
          SuperscriptBox["9", "n"]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]], " ", 
        SuperscriptBox["z", 
         RowBox[{
          RowBox[{"2", "n"}], "+", "1"}]]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], 
      FractionBox[
       RowBox[{"3", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["9", "n"]}], ")"}]}], 
       RowBox[{"4", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]}]], " ", 
      SuperscriptBox["z", 
       RowBox[{
        RowBox[{"2", "n"}], "+", "1"}]], " "}]}]}]}]}]],
 "\n\nBy the uniqueness of power series, this last expression is the \
Maclaurin series for  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["sin", "3"], "z"}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"7.5", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.50670525296875*^9, 3.50670525296875*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 "First, we can let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " verify the trigonometric identity  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["sin", "3"], "z"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox["3", "4"], "sin", " ", "z"}], "   ", "-", "  ", 
    RowBox[{
     FractionBox["1", "4"], "sin", " ", "3", "z"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(3\), \(4\)]\)Sin[z] - \!\(\*FractionBox[\(1\), \
\(4\)]\)Sin[3z]  =  \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{
         FractionBox["3", "4"], 
         RowBox[{"Sin", "[", "z", "]"}]}], "-", 
        RowBox[{
         FractionBox["1", "4"], 
         RowBox[{"Sin", "[", 
          RowBox[{"3", "z"}], "]"}]}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "  ", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"Sin", "[", "z", "]"}], ")"}], "3"], "  ", "\[Equal]", "  ", 
       RowBox[{
        RowBox[{
         FractionBox["3", "4"], 
         RowBox[{"Sin", "[", "z", "]"}]}], "-", 
        RowBox[{
         FractionBox["1", "4"], 
         RowBox[{"Sin", "[", 
          RowBox[{"3", "z"}], "]"}]}]}]}], "]"}], "  ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399366255125*^9}],

Cell[TextData[{
 "Then we could let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " calculate the sum of the proposed series."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)(-1\!\(\*SuperscriptBox[\()\), \
\(n\)]\)\!\(\*FractionBox[\(3 \((1 - \*SuperscriptBox[\(9\), \(n\)])\)\), \(4 \
\(\((2  n + 1)\)!\)\)]\) \!\(\*SuperscriptBox[\(z\), \(2  n + 1\)]\)  =  \
\>\"", ",", 
      RowBox[{"FullSimplify", "[", " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "0"}], "\[Infinity]"], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "n"], 
         FractionBox[
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SuperscriptBox["9", "n"]}], ")"}]}], 
          RowBox[{"4", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]}]], " ", 
         SuperscriptBox["z", 
          RowBox[{
           RowBox[{"2", "n"}], "+", "1"}]]}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{
      RowBox[{"FullSimplify", "[", " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "0"}], "\[Infinity]"], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "n"], 
         FractionBox[
          RowBox[{"3", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SuperscriptBox["9", "n"]}], ")"}]}], 
          RowBox[{"4", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]}]], " ", 
         SuperscriptBox["z", 
          RowBox[{
           RowBox[{"2", "n"}], "+", "1"}]]}]}], "]"}], " ", "\[Equal]", "  ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"Sin", "[", "z", "]"}], ")"}], "3"]}], "  ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39936626046875*^9}],

Cell[TextData[{
 "Or we could supply more details if you prefer. \n\nEnter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "z", "]"}], "3"]}]]],
 "  and find the first few terms of the Maclaurin series."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "f1", ",", "f2", ",", "n", ",", "S27"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "z", "]"}], "3"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S27", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "27"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(27\)]\)[z] = \>\"", ",", 
      RowBox[{"S27", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"S27", "[", "z", "]"}], ",", "\"\< + ...\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399366268140625*^9}],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The Maclaurin polynomial  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "27"], "[", "z", "]"}]]],
 " of degree n=27  is ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " equal to the cube of  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "9"], "[", "z", "]"}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"S9", "[", "z_", "]"}], " ", "=", " ", 
    RowBox[{"Normal", "[", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0", ",", "9"}], "}"}]}], "]"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(S\), \(9\)]\)[z] = \>\"", ",", 
      RowBox[{"S9", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<(\!\(\*SubscriptBox[\(S\), \(9\)]\)[z]\!\(\*SuperscriptBox[\()\), \
\(3\)]\) = \>\"", ",", 
      SuperscriptBox[
       RowBox[{"S9", "[", "z", "]"}], "3"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<(\!\(\*SubscriptBox[\(S\), \(9\)]\)[z]\!\(\*SuperscriptBox[\()\), \
\(3\)]\) = \>\"", ",", 
      RowBox[{"Expand", "[", 
       SuperscriptBox[
        RowBox[{"S9", "[", "z", "]"}], "3"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Warning (\!\(\*SubscriptBox[\(S\), \(9\)]\)[z]\!\(\*SuperscriptBox[\
\()\), \(3\)]\) \[NotEqual] \!\(\*SubscriptBox[\(S\), \(27\)]\)[z].\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(27\)]\)[z] = \>\"", ",", 
      RowBox[{"S27", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39936627284375*^9}],

Cell["\<\
Sum up infinitely many terms to verify that we have things right.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], " ", "=", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "n"], " ", "3"}], 
         RowBox[{"4", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]}]], " ", 
        SuperscriptBox["z", 
         RowBox[{
          RowBox[{"2", "n"}], "+", "1"}]]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f2", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "n"]}], " ", "3", " ", 
          SuperscriptBox["9", "n"]}], 
         RowBox[{"4", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], "!"}]}]], " ", 
        SuperscriptBox["z", 
         RowBox[{
          RowBox[{"2", "n"}], "+", "1"}]]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Factor", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"f1", "[", "z", "]"}], " ", "+", " ", 
        RowBox[{"f2", "[", "z", "]"}]}], ",", " ", 
       RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(f\), \(1\)]\)[z] = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(\*SuperscriptBox[\((\(-1\))\), \(n\)]\\\
\ 3\), \(4 \(\((2  n + 1)\)!\)\)]\) \!\(\*SuperscriptBox[\(z\), \(2  n + 1\)]\
\) =  \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(f\), \(2\)]\)[z] = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(n = 0\), \(\[Infinity]\)]\)\!\(\*FractionBox[\(\(-\\\ \
\*SuperscriptBox[\((\(-1\))\), \(n\)]\)\\\ 3\\\ \*SuperscriptBox[\(9\), \
\(n\)]\), \(4 \(\((2  n + 1)\)!\)\)]\) \!\(\*SuperscriptBox[\(z\), \(2  n + 1\
\)]\) =  \>\"", ",", 
      RowBox[{"f2", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< f[z] = \!\(\*SubscriptBox[\(f\), \(1\)]\)[z] + \!\(\*SubscriptBox[\
\(f\), \(2\)]\)[z] = \>\"", ",", " ", 
      RowBox[{
       RowBox[{"f1", "[", "z", "]"}], " ", "+", " ", 
       RowBox[{"f2", "[", "z", "]"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39936627734375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to plot some partial sums for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "z", "]"}], "3"]}]]],
 ".  For illustration we use the portion of the  disk  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", " ", "1.2"}]}]]],
 "  that lies in the sector ",
 Cell[BoxData[
  RowBox[{"0", "<", 
   RowBox[{"Arg", "[", "z", "]"}], "<", 
   FractionBox[
    RowBox[{"23", "\[Pi]"}], "36"]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "j", ",", "m", ",", "n", ",", "s", ",", "z"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "z", "]"}], "3"]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", " ", "[", 
     RowBox[{
      RowBox[{"j", "=", "1"}], ",", 
      RowBox[{"j", "\[LessEqual]", "5"}], ",", 
      RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"m", "=", 
        RowBox[{
         RowBox[{"2", "j"}], "+", "1"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"s", "[", "z_", "]"}], "=", 
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"f", "[", "z", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"z", ",", "0", ",", "m"}], "}"}]}], "]"}], "]"}]}], ";", 
       " ", "\[IndentingNewLine]", 
       RowBox[{"g0", "=", 
        RowBox[{"PolarMap", "[", 
         RowBox[{"s", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1.2", ",", "0.1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            FractionBox[
             RowBox[{"23", "\[Pi]"}], "36"], ",", 
            FractionBox["\[Pi]", "36"]}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "3.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
          RowBox[{"Ticks", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{"0", ",", "4", ",", "1"}], "]"}], ",", 
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], 
          ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";", "  ", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "g0", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<w = \>\"", ",", 
         SubscriptBox["\"\<S\>\"", "m"], ",", "\"\<[z] = \>\"", ",", 
         RowBox[{"s", "[", "z", "]"}], ",", "\"\<\\n\>\"", ",", 
         "\"\<\\n\>\""}], "]"}], ";"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1.2", ",", "0.1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         FractionBox[
          RowBox[{"23", "\[Pi]"}], "36"], ",", 
         FractionBox["\[Pi]", "36"]}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "4", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "g1", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  The mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399366283765625*^9, 3.3993663139375*^9}, {
  3.3999147335625*^9, 3.399914733890625*^9}}]
}, Closed]],

Cell["\<\
\t In the preceding argument we used some obvious results of power series \
representations that we haven't yet formally stated.  The requisite results \
are part of Theorem 7.6.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Theorem 7.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " have the power series representations  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      SubscriptBox["a", "n"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"], "   ", "for", "  ", 
      "z"}]}], "\[Element]", 
    RowBox[{
     SubscriptBox["D", 
      SubscriptBox["r", "1"]], 
     RowBox[{"(", "\[Alpha]", ")"}]}]}]}]]],
 ", \nand \n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      SubscriptBox["b", "n"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"], "   ", "for", "  ", 
      "z"}]}], "\[Element]", 
    RowBox[{
     SubscriptBox["D", 
      SubscriptBox["r", "2"]], 
     RowBox[{"(", "\[Alpha]", ")"}]}]}]}]]],
 ".  \n\nIf  ",
 Cell[BoxData[
  RowBox[{"r", "=", 
   RowBox[{"min", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["r", "1"], ",", 
      SubscriptBox["r", "2"]}], "}"}], "  ", "and", "  ", "\[Beta]"}]}]]],
 "  is any complex constant, then\n\n",
 StyleBox["(7-15)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\t\t\t",
  FontWeight->"Bold"],
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Beta]f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      SubscriptBox["\[Beta]a", "n"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"], "   ", "for", "  ", 
      "z"}]}], "\[Element]", 
    RowBox[{
     SubscriptBox["D", 
      SubscriptBox["r", "1"]], 
     RowBox[{"(", "\[Alpha]", ")"}]}]}]}]]],
 ",  \n\n",
 StyleBox["(7-16)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\t\t\t",
  FontWeight->"Bold"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "+", 
    RowBox[{"g", 
     RowBox[{"(", "z", ")"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "n"], "+", 
        SubscriptBox["b", "n"]}], ")"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"], "   ", "for", "  ", 
      "z"}]}], "\[Element]", 
    RowBox[{
     SubscriptBox["D", "r"], 
     RowBox[{"(", "\[Alpha]", ")"}]}]}]}]]],
 ",  and  \n\n",
 StyleBox["(7-17)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\t\t\t",
  FontWeight->"Bold"],
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}], "*", "g", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      SubscriptBox["c", "n"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"], "   ", "for", "  ", 
      "z"}]}], "\[Element]", 
    RowBox[{
     SubscriptBox["D", "r"], 
     RowBox[{"(", "\[Alpha]", ")"}]}]}]}]]],
 ",   where \n\n",
 StyleBox["(7-18)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\t\t\t",
  FontWeight->"Bold"],
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "n"], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "0"}], "n"], 
    RowBox[{
     SubscriptBox["a", "k"], 
     SubscriptBox["b", 
      RowBox[{"n", "-", "k"}]]}]}]}]]],
 ". \n\nIdentity ",
 StyleBox["(7-17)",
  FontColor->RGBColor[0, 0, 1]],
 " is known as the ",
 StyleBox[ButtonBox["Cauchy",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cauchy.\
html"], None}],
  FontFamily->"Times New Roman",
  FontVariations->{"Underline"->True}],
 " product of the series for ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 ".  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.399322878296875*^9, 3.399322924609375*^9}, {
  3.441730035453125*^9, 3.441730040390625*^9}},
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.6 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 7.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the Cauchy product of series to show that \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", "z"}], ")"}], "2"]], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"n", "+", "1"}], ")"}], " ", 
     SuperscriptBox["z", "n"]}]}]}]]],
 "   for   ",
 Cell[BoxData[
  RowBox[{"z", " ", "\[Epsilon]", " ", 
   SubscriptBox["D", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Solution.  We let  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"g", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    FractionBox["1", 
     RowBox[{"1", " ", "-", " ", "z"}]]}]}]]],
 ",  for ",
 Cell[BoxData[
  RowBox[{"z", " ", "\[Epsilon]", " ", 
   SubscriptBox["D", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 ".   In terms of Theorem 7.6, we have  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "n"], " ", "=", " ", 
   RowBox[{
    SubscriptBox["b", "n"], " ", "=", " ", "1"}]}]]],
 ",  for all n, and thus Equation ",
 StyleBox["(7-17)",
  FontColor->RGBColor[0, 0, 1]],
 " gives  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", " ", "-", " ", "z"}], ")"}], "2"]], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"h", 
      RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}], "g", 
      RowBox[{"(", "z", ")"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                ", 
   RowBox[{"=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "0"}], "n"], 
        RowBox[{
         SubscriptBox["a", "k"], 
         SubscriptBox["b", 
          RowBox[{"n", "-", "k"}]]}]}], ")"}], 
      SuperscriptBox["z", "n"]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                ", 
   RowBox[{"=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "0"}], "n"], " ", "1"}], ")"}], 
      SuperscriptBox["z", "n"]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                ", 
   RowBox[{"=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"n", "+", "1"}], ")"}], " ", 
      SuperscriptBox["z", "n"]}]}]}]}]}]],
 " "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"7.6", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.50670525746875*^9, 3.50670525746875*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 "Use the following fact that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"g", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"1", " ", "-", " ", "z"}]], "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       SuperscriptBox["z", "n"], "   ", "for", "  ", "z", " ", "\[Epsilon]", 
       " ", 
       SubscriptBox["D", "1"], 
       RowBox[{"(", "0", ")"}]}]}]}]}]}]]],
 ". \nEnter the coefficients ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "n"], "=", 
   RowBox[{
    RowBox[{"1", "   ", "and", "   ", 
     SubscriptBox["b", "n"]}], "=", "1"}]}]]],
 "  and let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " carry out the computations."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"b", "=", 
      RowBox[{"c", "=", 
       RowBox[{"z", "=", "0"}]}]}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g", ",", "h", ",", "k", ",", "n"}], "]"}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "n_"], "=", "1"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["b", "n_"], "=", "1"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "n_"], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "0"}], "n"], 
       RowBox[{
        SubscriptBox["a", "k"], 
        SubscriptBox["b", 
         RowBox[{"n", "-", "k"}]]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        SubscriptBox["a", "n"], 
        SuperscriptBox["z", "n"]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        SubscriptBox["b", "n"], 
        SuperscriptBox["z", "n"]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", "z_", "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        SubscriptBox["c", "n"], 
        SuperscriptBox["z", "n"]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(a\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["a", "n"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(b\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["b", "n"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*SubscriptBox[\(a\), \
\(n\)]\)\!\(\*SuperscriptBox[\(z\), \(n\)]\) = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(n = 0\), \(\[Infinity]\)]\)(\>\"", ",", 
      SubscriptBox["a", "k"], ",", 
      "\"\<)\!\(\*SuperscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<g[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*SubscriptBox[\(b\), \
\(n\)]\)\!\(\*SuperscriptBox[\(z\), \(n\)]\) = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(n = 0\), \(\[Infinity]\)]\)(\>\"", ",", 
      SubscriptBox["b", 
       RowBox[{"n", "-", "k"}]], ",", 
      "\"\<)\!\(\*SuperscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubscriptBox[\(c\), \(n\)]\) = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(k = 0\), \(n\)]\)\!\(\*SubscriptBox[\(a\), \
\(k\)]\)\!\(\*SubscriptBox[\(b\), \(n - k\)]\)\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(c\), \(n\)]\) = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(k = 0\), \(n\)]\)(\>\"", ",", 
      SubscriptBox["a", "k"], ",", "\"\<)(\>\"", ",", 
      SubscriptBox["b", 
       RowBox[{"n", "-", "k"}]], ",", "\"\<) = \>\"", ",", 
      "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \(n\)]\)(\>\"", 
      ",", 
      RowBox[{
       SubscriptBox["a", "k"], 
       SubscriptBox["b", 
        RowBox[{"n", "-", "k"}]]}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \(n\)]\)(\>\"", ",", 
      RowBox[{
       SubscriptBox["a", "k"], 
       SubscriptBox["b", 
        RowBox[{"n", "-", "k"}]]}], ",", "\"\<) = \>\"", ",", 
      SubscriptBox["c", "n"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(c\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["c", "n"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<h[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*SubscriptBox[\(c\), \
\(n\)]\)\!\(\*SuperscriptBox[\(z\), \(n\)]\) = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(n = 0\), \(\[Infinity]\)]\)(\>\"", ",", 
      SubscriptBox["c", "n"], ",", 
      "\"\<)\!\(\*SuperscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      RowBox[{"h", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399366338390625*^9, 3.39936634040625*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the Cauchy product of series to show that \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox["z", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "1"}], ")"}], "4"]], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     FractionBox[
      RowBox[{"n", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "n"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", "n"}], ")"}]}], "6"], 
     SuperscriptBox["z", "n"]}]}]}]]],
 "   for   ",
 Cell[BoxData[
  RowBox[{"z", " ", "\[Epsilon]", " ", 
   SubscriptBox["D", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{
  "Explore", " ", "Solution", " ", "for", " ", "Extra", " ", "Example", " ", 
   "1."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506705260140625*^9, 3.506705260140625*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 "Use the following facts ",
 Cell[BoxData[
  RowBox[{
   FractionBox["z", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "1"}], ")"}], "2"]], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{"n", " ", 
     SuperscriptBox["z", "n"], "   ", "for", "  ", "z", " ", "\[Epsilon]", 
     " ", 
     SubscriptBox["D", "1"], 
     RowBox[{"(", "0", ")"}]}]}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "1"}], ")"}], "2"]], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"n", "+", "1"}], ")"}], " ", 
     SuperscriptBox["z", "n"], "   ", "for", "  ", "z", " ", "\[Epsilon]", 
     " ", 
     SubscriptBox["D", "1"], 
     RowBox[{"(", "0", ")"}]}]}]}]]],
 ". \nEnter the coefficients ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "n"], "=", 
   RowBox[{
    RowBox[{"n", "   ", "and", "   ", 
     SubscriptBox["b", "n"]}], "=", 
    RowBox[{"n", "+", "1"}]}]}]]],
 "  and let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " carry out the computations."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g", ",", "h", ",", "k", ",", "n"}], "]"}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "n_"], "=", "n"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["b", "n_"], "=", 
     RowBox[{"n", "+", "1"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "n_"], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "0"}], "n"], 
       RowBox[{
        SubscriptBox["a", "k"], 
        SubscriptBox["b", 
         RowBox[{"n", "-", "k"}]]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        SubscriptBox["a", "n"], 
        SuperscriptBox["z", "n"]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        SubscriptBox["b", "n"], 
        SuperscriptBox["z", "n"]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", "z_", "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        SubscriptBox["c", "n"], 
        SuperscriptBox["z", "n"]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(a\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["a", "n"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(b\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["b", "n"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<f[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*SubscriptBox[\(a\), \
\(n\)]\)\!\(\*SuperscriptBox[\(z\), \(n\)]\) = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(n = 0\), \(\[Infinity]\)]\)(\>\"", ",", 
      SubscriptBox["a", "k"], ",", 
      "\"\<)\!\(\*SuperscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<g[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*SubscriptBox[\(b\), \
\(n\)]\)\!\(\*SuperscriptBox[\(z\), \(n\)]\) = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(n = 0\), \(\[Infinity]\)]\)(\>\"", ",", 
      SubscriptBox["b", 
       RowBox[{"n", "-", "k"}]], ",", 
      "\"\<)\!\(\*SuperscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubscriptBox[\(c\), \(n\)]\) = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(k = 0\), \(n\)]\)\!\(\*SubscriptBox[\(a\), \
\(k\)]\)\!\(\*SubscriptBox[\(b\), \(n - k\)]\)\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(c\), \(n\)]\) = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(k = 0\), \(n\)]\)(\>\"", ",", 
      SubscriptBox["a", "k"], ",", "\"\<)(\>\"", ",", 
      SubscriptBox["b", 
       RowBox[{"n", "-", "k"}]], ",", "\"\<) = \>\"", ",", 
      "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \(n\)]\)(\>\"", 
      ",", 
      RowBox[{
       SubscriptBox["a", "k"], 
       SubscriptBox["b", 
        RowBox[{"n", "-", "k"}]]}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \(n\)]\)(\>\"", ",", 
      RowBox[{
       SubscriptBox["a", "k"], 
       SubscriptBox["b", 
        RowBox[{"n", "-", "k"}]]}], ",", "\"\<) = \>\"", ",", 
      SubscriptBox["c", "n"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(c\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["c", "n"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<h[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*SubscriptBox[\(c\), \
\(n\)]\)\!\(\*SuperscriptBox[\(z\), \(n\)]\) = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(n = 0\), \(\[Infinity]\)]\)(\>\"", ",", 
      SubscriptBox["c", "n"], ",", 
      "\"\<)\!\(\*SuperscriptBox[\(z\), \(n\)]\) = \>\"", ",", 
      RowBox[{"h", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399366355453125*^9, 3.39936635759375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   FractionBox["z", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", "z"}], ")"}], "2"]], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], " ", 
    RowBox[{"n", " ", 
     SuperscriptBox["z", "n"]}]}]}]]],
 "   for   ",
 Cell[BoxData[
  RowBox[{"z", " ", "\[Epsilon]", " ", 
   SubscriptBox["D", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Solution.  Use the result of Example 7.6 and ",
 StyleBox["(7-16)",
  FontColor->RGBColor[0, 0, 1]],
 " and obtain \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    FractionBox["z", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", " ", "-", " ", "z"}], ")"}], "2"]], " ", "=", "  ", 
    FractionBox[
     RowBox[{"z", "-", "1", " ", "+", " ", "1"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", " ", "-", " ", "z"}], ")"}], "2"]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", " ", "-", " ", "z"}], ")"}], "2"]], "  ", "+", "  ", 
     FractionBox[
      RowBox[{"-", "1"}], 
      RowBox[{"(", 
       RowBox[{"1", " ", "-", " ", "z"}], ")"}]]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "+", "1"}], ")"}], " ", 
       SuperscriptBox["z", "n"]}]}], "   ", "-", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], " ", 
      SuperscriptBox["z", "n"]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], " ", 
     RowBox[{"n", " ", 
      SuperscriptBox["z", "n"]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], " ", 
     RowBox[{"n", " ", 
      SuperscriptBox["z", "n"]}]}]}]}]}]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{
  "Explore", " ", "Solution", " ", "for", " ", "Extra", " ", "Example", " ", 
   "2."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506705263546875*^9, 3.5067052635625*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 "We could let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " calculate the sum of the proposed series."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(\[Infinity]\)]\) \
n \!\(\*SuperscriptBox[\(z\), \(n\)]\)  =  \>\"", ",", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "1"}], "\[Infinity]"], " ", 
       RowBox[{"n", " ", 
        SuperscriptBox["z", "n"]}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399366367859375*^9, 3.39936636878125*^9}}]
}, Closed]],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",
 InitializationCell->True]
}, Closed]]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{901, 616},
WindowMargins->{{28, Automatic}, {Automatic, 0}},
CellLabelAutoDelete->True,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 186, 3, 29, "Text"],
Cell[1737, 51, 887, 21, 65, "Text"],
Cell[2627, 74, 2297, 82, 161, "Text",
 Evaluatable->False],
Cell[4927, 158, 101, 2, 29, "Text"],
Cell[5031, 162, 2181, 71, 116, "Text"],
Cell[CellGroupData[{
Cell[7237, 237, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[7381, 243, 313, 12, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[7709, 258, 71, 0, 26, "Text"],
Cell[7783, 260, 2314, 87, 130, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[10122, 351, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[10266, 357, 170, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[10451, 364, 955, 20, 105, "Text"],
Cell[11409, 386, 2314, 92, 141, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[13748, 482, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[13892, 488, 172, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[14079, 495, 820, 32, 35, "Text",
 Evaluatable->False],
Cell[14902, 529, 2868, 106, 169, "Text"],
Cell[CellGroupData[{
Cell[17795, 639, 278, 8, 37, "Subsection",
 Evaluatable->False],
Cell[18076, 649, 341, 12, 38, "Text",
 Evaluatable->False],
Cell[18420, 663, 1617, 47, 251, "Input"],
Cell[20040, 712, 116, 2, 29, "Text",
 Evaluatable->False],
Cell[20159, 716, 1355, 38, 232, "Input"],
Cell[21517, 756, 561, 21, 56, "Text"],
Cell[22081, 779, 4494, 119, 429, "Input"]
}, Closed]],
Cell[26590, 901, 1085, 44, 70, "Text",
 Evaluatable->False],
Cell[27678, 947, 375, 12, 47, "Text"],
Cell[28056, 961, 6247, 105, 380, "Text",
 Evaluatable->False],
Cell[34306, 1068, 1301, 24, 37, "Text",
 Evaluatable->False],
Cell[35610, 1094, 3317, 125, 320, "Text"],
Cell[CellGroupData[{
Cell[38952, 1223, 326, 9, 37, "Subsection",
 Evaluatable->False],
Cell[39281, 1234, 5650, 155, 393, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[44968, 1394, 329, 9, 29, "Subsection",
 Evaluatable->False],
Cell[45300, 1405, 735, 29, 81, "Text"],
Cell[46038, 1436, 1548, 45, 249, "Input"],
Cell[47589, 1483, 136, 4, 29, "Text",
 Evaluatable->False],
Cell[47728, 1489, 1235, 34, 232, "Input"],
Cell[48966, 1525, 633, 23, 55, "Text"],
Cell[49602, 1550, 4327, 113, 427, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[53966, 1668, 326, 9, 29, "Subsection",
 Evaluatable->False],
Cell[54295, 1679, 4642, 130, 353, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[58974, 1814, 317, 9, 29, "Subsection",
 Evaluatable->False],
Cell[59294, 1825, 879, 35, 81, "Text",
 Evaluatable->False],
Cell[60176, 1862, 1548, 45, 249, "Input"],
Cell[61727, 1909, 136, 4, 29, "Text",
 Evaluatable->False],
Cell[61866, 1915, 1491, 43, 232, "Input"],
Cell[63360, 1960, 633, 23, 55, "Text"],
Cell[63996, 1985, 4464, 117, 427, "Input"],
Cell[68463, 2104, 626, 22, 37, "Text"]
}, Closed]],
Cell[69104, 2129, 3286, 118, 202, "Text"],
Cell[72393, 2249, 695, 16, 65, "Text"],
Cell[73091, 2267, 1421, 51, 101, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[74537, 2322, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[74681, 2328, 170, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[74866, 2335, 344, 14, 26, "Text",
 Evaluatable->False],
Cell[75213, 2351, 4424, 152, 300, "Text"],
Cell[CellGroupData[{
Cell[79662, 2507, 276, 8, 37, "Subsection",
 Evaluatable->False],
Cell[79941, 2517, 450, 17, 35, "Text",
 Evaluatable->False],
Cell[80394, 2536, 1106, 34, 124, "Input"],
Cell[81503, 2572, 191, 7, 29, "Text",
 Evaluatable->False],
Cell[81697, 2581, 2071, 61, 143, "Input"],
Cell[83771, 2644, 338, 10, 65, "Text",
 Evaluatable->False],
Cell[84112, 2656, 1530, 44, 232, "Input"],
Cell[85645, 2702, 388, 16, 29, "Text"],
Cell[86036, 2720, 1823, 51, 220, "Input"],
Cell[87862, 2773, 136, 4, 29, "Text",
 Evaluatable->False],
Cell[88001, 2779, 3145, 88, 294, "Input"],
Cell[91149, 2869, 568, 21, 53, "Text"],
Cell[91720, 2892, 4571, 121, 388, "Input"]
}, Closed]],
Cell[96306, 3016, 202, 4, 44, "Text"],
Cell[96511, 3022, 4551, 167, 326, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[101087, 3193, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[101231, 3199, 170, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[101416, 3206, 719, 26, 71, "Text",
 Evaluatable->False],
Cell[102138, 3234, 2286, 78, 196, "Text"],
Cell[CellGroupData[{
Cell[104449, 3316, 276, 8, 37, "Subsection",
 Evaluatable->False],
Cell[104728, 3326, 905, 33, 54, "Text",
 Evaluatable->False],
Cell[105636, 3361, 5328, 143, 731, "Input"]
}, Closed]],
Cell[110979, 3507, 830, 30, 71, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[111834, 3541, 307, 9, 37, "Subsection",
 Evaluatable->False],
Cell[112144, 3552, 1312, 47, 56, "Text",
 Evaluatable->False],
Cell[113459, 3601, 5250, 140, 731, "Input"]
}, Closed]],
Cell[118724, 3744, 630, 24, 35, "Text",
 Evaluatable->False],
Cell[119357, 3770, 1979, 63, 237, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[121361, 3837, 305, 9, 37, "Subsection",
 Evaluatable->False],
Cell[121669, 3848, 186, 7, 29, "Text",
 Evaluatable->False],
Cell[121858, 3857, 543, 14, 98, "Input"]
}, Closed]],
Cell[122416, 3874, 435, 8, 26, "Text"],
Cell[CellGroupData[{
Cell[122876, 3886, 407, 7, 29, "Text"],
Cell[123286, 3895, 130, 3, 31, "Input",
 InitializationCell->True]
}, Closed]]
}
]
*)

(* End of internal cache information *)
