(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    160769,       5267]
NotebookOptionsPosition[    154217,       5065]
NotebookOutlinePosition[    154637,       5083]
CellTagsIndexPosition[    154594,       5080]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[StyleBox["7.3  Laurent Series Representations",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.5327094490625*^9, 3.53270944996875*^9}}],

Cell[TextData[{
 "\tSuppose ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is not analytic in  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "R"], 
   RowBox[{"(", "\[Alpha]", ")"}]}]]],
 ",  but is analytic in  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["D", "R", "*"], 
    RowBox[{"(", "\[Alpha]", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", "  ", 
     RowBox[{
      RowBox[{"0", " ", "<"}], " ", "|", 
      RowBox[{"z", "-", "\[Alpha]"}], "|", " ", 
      RowBox[{"<", " ", "R"}]}]}], "}"}]}]]],
 ".   For example, the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox["z", "3"]], 
    SuperscriptBox["\[ExponentialE]", "z"]}]}]]],
 "  is not analytic when  ",
 Cell[BoxData[
  RowBox[{"z", "=", " ", "0"}]]],
 "  but is analytic for ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{">", " ", "0"}]}]]],
 ".  Clearly, this function does not have a ",
 StyleBox[ButtonBox["Maclaurin series",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/MaclaurinSeries.html"], None}],
  FontVariations->{"Underline"->True}],
 " representation.  If we use the ",
 StyleBox[ButtonBox["Maclaurin",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Maclaurin.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " series for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["\[ExponentialE]", "z"]}]]],
 ",  however, and formally divide each term in that series by  ",
 Cell[BoxData[
  SuperscriptBox["z", "3"]]],
 ", we obtain the representation  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["z", "3"]], 
     SuperscriptBox["\[ExponentialE]", "z"]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["z", "3"]], "+", 
        FractionBox["1", 
         SuperscriptBox["z", "2"]], "+", 
        FractionBox["1", 
         RowBox[{
          RowBox[{"2", "!"}], " ", "z"}]], "+", 
        FractionBox["1", 
         RowBox[{"3", "!"}]], "+", 
        FractionBox["z", 
         RowBox[{"4", "!"}]], "+", 
        FractionBox[
         SuperscriptBox["z", "2"], 
         RowBox[{"5", "!"}]], "+", 
        FractionBox[
         SuperscriptBox["z", "3"], 
         RowBox[{"6", "!"}]]}],
       SeriesData[z, 0, {1, 1, 
         Rational[1, 2], 
         Rational[1, 6], 
         Rational[1, 24], 
         Rational[1, 120], 
         Rational[1, 720], 
         Rational[1, 5040], 
         Rational[1, 40320], 
         Rational[1, 362880]}, -3, 7, 1]], "+"}], "..."}]}]}]]],
 "  \n\nthat is valid for all ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "  such that  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{">", " ", "0"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to find the series for ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    SuperscriptBox["\[ExponentialE]", "z"], 
    SuperscriptBox["z", "3"]]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{
  "Explore", " ", "Solution", " ", "for", " ", "Extra", " ", "Example", " ", 
   "1."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.50670529634375*^9, 3.50670529634375*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    SuperscriptBox["\[ExponentialE]", "z"], 
    SuperscriptBox["z", "3"]]}]]],
 " and find the first few terms of the series in the punctured plane  ",
 Cell[BoxData[
  RowBox[{"0", "<", "z"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"z", "=", "0"}], ";", " ", 
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "L", ",", "S", ",", "S9", ",", "S11", ",", "S12", ",", "S21", 
      ",", "S22", ",", "S\[Infinity]"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      SuperscriptBox["\[ExponentialE]", "z"], 
      SuperscriptBox["z", "3"]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "z"], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "9"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"L", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "6"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = (\>\"", ",", 
      RowBox[{"S", "[", "z", "]"}], ",", "\"\< + ... )/(\>\"", ",", 
      SuperscriptBox["z", "3"], ",", "\"\<)\>\""}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<L[z] = \>\"", ",", 
      RowBox[{"L", "[", "z", "]"}], ",", "\"\< + ...\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399366441859375*^9},
 AspectRatioFixed->True],

Cell["\<\
The latter is a series is valid for 0 < |z|.  Sum up infinitely many terms to \
verify that we have things right.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S9", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "9"], 
      FractionBox[
       SuperscriptBox["z", 
        RowBox[{"n", "-", "3"}]], 
       RowBox[{"n", "!"}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S\[Infinity]", "[", "z_", "]"}], " ", "=", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      FractionBox[
       SuperscriptBox["z", 
        RowBox[{"n", "-", "3"}]], 
       RowBox[{"n", "!"}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(9\)]\)[z] = \>\"", ",", 
      RowBox[{"S9", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(\[Infinity]\)]\)[z] = \
\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(n - 3\)], \(n!\)]\
\) =  \>\"", ",", 
      RowBox[{"S\[Infinity]", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399366448234375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate how well the series is \"converging\" for real numbers."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"S9", "[", "x", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0.1", ",", "8"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "8"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "10"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "8", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "10", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<s\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<s = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\<  and  s = \!\(\*SubscriptBox[\(S\), \(9\)]\)[x]\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(9\)]\)[x] = \>\"", ",", 
      RowBox[{"S9", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39936645540625*^9, 3.39936645884375*^9}, {
  3.3999150739375*^9, 3.399915074125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate how well the complex series is \"converging\" in the \
complex plane.\nBut, we need to stay away from  z=0.  For convenience we use \
the disk  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", "1"}], "|", " ", 
   RowBox[{"<", " ", "0.999"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], "=", 
     RowBox[{"f", "[", 
      RowBox[{"z", "+", "1"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "z_", "]"}], "=", 
     RowBox[{"S9", "[", 
      RowBox[{"z", "+", "1"}], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"G", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.999", ",", "0.1665"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \!\(\*SubscriptBox[\(S\), \(9\)]\)[1+z] =  \>\"", ",", 
      RowBox[{"S9", "[", 
       RowBox[{"1", "+", "z"}], "]"}], ",", "\"\<,  where |z| < 0.999\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"F", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.999", ",", "0.1665"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[1+z] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"1", "+", "z"}], "]"}], ",", "\"\<,  where |z| < 0.999\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399366464140625*^9, 3.39936646859375*^9}, {
  3.3999150789375*^9, 3.399915079328125*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"S9", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0.2", ",", "2.2", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", " ", "1", ",", " ", "0.1"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \!\(\*SubscriptBox[\(S\), \(9\)]\)[z] =  \>\"", ",", 
      RowBox[{"S9", "[", "z", "]"}], ",", 
      "\"\<,  where 0.2 \[LessEqual] x \[LessEqual] 2.2, -1 \[LessEqual] y \
\[LessEqual] 1\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{"0.2", ",", "2.2", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", " ", "1", ",", " ", "0.1"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<,  where 0.2 \[LessEqual] x \[LessEqual] 2.2, -1 \[LessEqual] y \
\[LessEqual] 1\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399366475609375*^9, 3.399366479859375*^9}, {
  3.399915084296875*^9, 3.399915084515625*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tThis example raises the question as to whether it might be possible to \
generalize the ",
 StyleBox[ButtonBox["Taylor",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Taylor.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " series method to functions analytic in an annulus  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"A", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", ",", "r", ",", "R"}], ")"}]}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"z", ":", " ", 
       RowBox[{"r", " ", "\[LessEqual]"}]}], "\[VerticalSeparator]", 
      RowBox[{"z", "-", "\[Alpha]"}], "\[VerticalSeparator]", 
      RowBox[{"\[LessEqual]", " ", "R"}]}], "}"}]}]}]]],
 ".   \n\nPerhaps we can represent these functions with a series that employs \
negative powers of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " in some way as we did with ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox["z", "3"]], 
    SuperscriptBox["\[ExponentialE]", "z"]}]}]]],
 ".  As you will see shortly, we can indeed.  We begin by defining a series \
that allows for negative powers of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Definition 7.3 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Laurent Series",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/LaurentSeries.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  SubscriptBox["c", "n"]]],
 "  be a complex number for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"n", "=", "0"}], ",", 
   RowBox[{"\[PlusMinus]", "1"}], ",", 
   RowBox[{"\[PlusMinus]", "2"}], ",", 
   RowBox[{"\[PlusMinus]", "3"}], ",", "..."}]]],
 ".  The doubly infinite series  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", 
     RowBox[{"-", "\[Infinity]"}]}], "\[Infinity]"], 
   RowBox[{
    SubscriptBox["c", "n"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]]],
 ",  called a ",
 StyleBox[ButtonBox["Laurent",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Laurent_\
Pierre.html"], None}],
  FontVariations->{"Underline"->True}],
 " series, is defined by \n\n",
 StyleBox["(7-21)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", 
      RowBox[{"-", "\[Infinity]"}]}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     RowBox[{
      SubscriptBox["c", 
       RowBox[{"-", "n"}]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "\[Alpha]"}], ")"}], 
       RowBox[{"-", "n"}]]}]}], " ", "+", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      SubscriptBox["c", "n"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]}]}]]],
 ",  \n\nprovided the series on the right-hand side of this equation converge."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Remark 7.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Recall that  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", "0"}], "\[Infinity]"], 
   RowBox[{
    SubscriptBox["c", "n"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]]],
 "  is a simplified expression for the sum  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "n0"], " ", "+", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]}]]],
 ".  At times it will be convenient to write  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", 
     RowBox[{"-", "\[Infinity]"}]}], "\[Infinity]"], 
   RowBox[{
    SubscriptBox["c", "n"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]]],
 "  as  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", 
      RowBox[{"-", "\[Infinity]"}]}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", 
       RowBox[{"-", "\[Infinity]"}]}], 
      RowBox[{"-", "1"}]], 
     RowBox[{
      SubscriptBox["c", "n"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}], " ", "+", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      SubscriptBox["c", "n"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]}]}]]],
 ", \n\nrather than using the expression given in Equation ",
 StyleBox["(7-21)",
  FontColor->RGBColor[0, 0, 1]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 7.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Given  ",
 Cell[BoxData[
  RowBox[{"0", " ", "\[LessEqual]", "r", "<", " ", "R"}]]],
 ",  we define the annulus centered at  ",
 Cell[BoxData["\[Alpha]"]],
 "  with radii ",
 StyleBox["r",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["R",
  FontFamily->"Courier New"],
 " by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", 
     RowBox[{"\[Alpha]", ",", "r", ",", "R"}], ")"}]}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", ":", " ", 
      RowBox[{"r", " ", "<"}]}], "\[VerticalSeparator]", 
     RowBox[{
      RowBox[{"z", "-", "\[Alpha]"}], "\[VerticalSeparator]", 
      RowBox[{"<", " ", "R"}]}]}], "}"}]}]]],
 ".  \n\nThe closed annulus centered at  with radii ",
 StyleBox["r",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["R",
  FontFamily->"Courier New"],
 " is denoted by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    OverscriptBox[
     RowBox[{" ", "A"}], "_"], 
    RowBox[{"(", 
     RowBox[{"\[Alpha]", ",", "r", ",", "R"}], ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", ":", " ", 
      RowBox[{"r", " ", "\[LessEqual]"}]}], "\[VerticalSeparator]", 
     RowBox[{"z", "-", "\[Alpha]"}], "\[VerticalSeparator]", 
     RowBox[{"\[LessEqual]", " ", "R"}]}], "}"}]}]]],
 ". \n\t\t\nFigure 7.3 illustrates these terms."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "Figure 7.3  The closed annulus ",
 Cell[BoxData[
  RowBox[{
   OverscriptBox[
    RowBox[{" ", "A"}], "_"], 
   RowBox[{"(", 
    RowBox[{"\[Alpha]", ",", "r", ",", "R"}], ")"}]}]]],
 ". The shaded portion is the open annulus ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"A", 
    RowBox[{"(", 
     RowBox[{"\[Alpha]", ",", "r", ",", "R"}], ")"}]}]}]]],
 "."
}], "Text",
 CellChangeTimes->{{3.510075663046875*^9, 3.51007567909375*^9}}],

Cell[TextData[{
 StyleBox["Theorem 7.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "Suppose that the Laurent series",
 "  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"n", "=", 
     RowBox[{"-", "\[Infinity]"}]}], "\[Infinity]"], 
   RowBox[{
    SubscriptBox["c", "n"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]]],
 "  converges on an annulus  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", 
     RowBox[{"\[Alpha]", ",", "r", ",", "R"}], ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", ":", " ", 
      RowBox[{"r", " ", "<"}]}], "\[VerticalSeparator]", 
     RowBox[{
      RowBox[{"z", "-", "\[Alpha]"}], "\[VerticalSeparator]", 
      RowBox[{"<", " ", "R"}]}]}], "}"}]}]]],
 ".  Then the series converges uniformly on any closed subannulus  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    OverscriptBox[
     RowBox[{" ", "A"}], "_"], 
    RowBox[{"(", 
     RowBox[{"\[Alpha]", ",", "s", ",", "t"}], ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", ":", " ", 
      RowBox[{"s", " ", "\[LessEqual]"}]}], "\[VerticalSeparator]", 
     RowBox[{
      RowBox[{"z", "-", "\[Alpha]"}], "\[VerticalSeparator]", 
      RowBox[{"\[LessEqual]", " ", "t"}]}]}], "}"}]}]]],
 " where  ",
 Cell[BoxData[
  RowBox[{"r", " ", "<", "s", "<", "t", "<", " ", "R"}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.7 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tThe main result of this section specifies how functions analytic in an \
annulus can be expanded in a ",
 StyleBox[ButtonBox["Laurent",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Laurent_\
Pierre.html"], None}],
  FontVariations->{"Underline"->True}],
 " series.  In it, we will use symbols of the form  ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["C", "\[Rho]", "+"], 
   RowBox[{"(", "\[Alpha]", ")"}]}]]],
 ",  which - we remind you - designate the positively oriented circle with \
radius  ",
 Cell[BoxData["\[Rho]"]],
 "  and center  ",
 Cell[BoxData["\[Alpha]"]],
 ".  That is,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["C", "\[Rho]", "+"], 
    RowBox[{"(", "\[Alpha]", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", ":"}], " ", "\[VerticalSeparator]", 
     RowBox[{"z", "-", "\[Alpha]"}], "\[VerticalSeparator]", 
     RowBox[{"<", " ", "\[Rho]"}]}], "}"}]}]]],
 ",  oriented counterclockwise."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Theorem 7.8  (Laurent's Theorem).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose  ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "r", "<", "R"}]]],
 ",  and that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is analytic in the annulus ",
 Cell[BoxData[
  RowBox[{"A", "=", 
   RowBox[{
    RowBox[{"A", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", ",", "r", ",", "R"}], ")"}]}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"z", ":", " ", 
       RowBox[{"r", " ", "<"}]}], "\[VerticalSeparator]", 
      RowBox[{
       RowBox[{"z", "-", "\[Alpha]"}], "\[VerticalSeparator]", 
       RowBox[{"<", " ", "R"}]}]}], "}"}]}]}]]],
 "  shown in Figure 7.3.  If  ",
 Cell[BoxData["\[Rho]"]],
 "  is any number such that ",
 Cell[BoxData[
  RowBox[{"r", " ", "<", "\[Rho]", "<", " ", "R"}]]],
 ", then for all ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], " ", "\[Epsilon]", " ", "A", 
   RowBox[{"(", 
    RowBox[{"\[Alpha]", ",", "r", ",", "R"}], ")"}]}]]],
 " the function value ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 " has the Laurent series representation \n\n",
 StyleBox["(7-22)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", 
       RowBox[{"-", "\[Infinity]"}]}], "\[Infinity]"], 
     RowBox[{
      SubscriptBox["c", "n"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["z", "0"], "-", "\[Alpha]"}], ")"}], "n"]}]}], "  ", 
    "=", "  ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      RowBox[{
       SubscriptBox["c", 
        RowBox[{"-", "n"}]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["z", "0"], "-", "\[Alpha]"}], ")"}], 
        RowBox[{"-", "n"}]]}]}], " ", "+", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       SubscriptBox["c", "n"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["z", "0"], "-", "\[Alpha]"}], ")"}], "n"]}]}]}]}]}]]],
 ",  \n\nwhere for ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"n", "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "1", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "2", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "..."}]]],
 ", the coefficients ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", 
    RowBox[{"-", "n"}]], "  ", "and", "  ", 
   SubscriptBox["c", "n"]}]]],
 " are given by \n\n",
 StyleBox["(7-23)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", 
    RowBox[{"-", "n"}]], "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
    RowBox[{
     SubscriptBox["\[Integral]", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["C", "\[Rho]"], "+"], 
       RowBox[{"(", "\[Alpha]", ")"}]}]], 
     RowBox[{
      FractionBox[
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", " ", "-", " ", "\[Alpha]"}], ")"}], 
        RowBox[{
         RowBox[{"-", "n"}], "+", "1"}]]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]]],
 "    and    ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "n"], "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
    RowBox[{
     SubscriptBox["\[Integral]", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["C", "\[Rho]"], "+"], 
       RowBox[{"(", "\[Alpha]", ")"}]}]], 
     RowBox[{
      FractionBox[
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", " ", "-", " ", "\[Alpha]"}], ")"}], 
        RowBox[{"n", "+", "1"}]]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.8 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  What happens to the Laurent series if ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is analytic in the disk ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "R"], 
   RowBox[{"(", "\[Alpha]", ")"}]}]]],
 "?  If we look at equation ",
 StyleBox["(7-23)",
  FontColor->RGBColor[0, 0, 1]],
 ", we see that the coefficient ",
 Cell[BoxData[
  SubscriptBox["c", "n"]]],
 " for the positive power ",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["z", "0"], "-", "\[Alpha]"}], ")"}], "n"]]],
 " equals ",
 Cell[BoxData[
  FractionBox[
   RowBox[{
    SuperscriptBox["f", 
     RowBox[{"(", "n", ")"}]], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], 
   RowBox[{"n", "!"}]]]],
 " by using Cauchy's integral formula for derivatives.  Hence, the series in \
equation ",
 StyleBox["(7-22)",
  FontColor->RGBColor[0, 0, 1]],
 " involving the positive powers of ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["z", "0"], "-", "\[Alpha]"}], ")"}]]],
 " is actually the \nTaylor series for ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 ".  The ",
 StyleBox[ButtonBox["Cauchy",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cauchy.\
html"], None}],
  FontVariations->{"Underline"->True}],
 StyleBox["-",
  FontSize->14,
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[ButtonBox["Goursat",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Goursat.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " theorem shows us that the coefficients for the negative powers of ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["z", "0"], "-", "\[Alpha]"}], ")"}]]],
 " equal zero.  In this case, therefore, there are no negative powers \
involved, and the Laurent series reduces to the Taylor series."
}], "Text"],

Cell["\<\
\tTheorem 7.9 delineates two important aspects of the Laurent series.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Theorem 7.9 (Uniqueness and differentiation of Laurent Series).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose that  ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 "  is analytic in the annulus  ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", 
    RowBox[{"\[Alpha]", ",", "r", ",", "R"}], ")"}]}]]],
 ",  and has the Laurent series representation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", 
      RowBox[{"-", "\[Infinity]"}]}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]}]]],
 "  for all  ",
 Cell[BoxData[
  RowBox[{"z", " ", "\[Epsilon]", " ", "A", 
   RowBox[{"(", 
    RowBox[{"\[Alpha]", ",", "r", ",", "R"}], ")"}]}]]],
 ".  \n\n",
 StyleBox["(i) ",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\tIf  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", 
      RowBox[{"-", "\[Infinity]"}]}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["b", "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "\[Alpha]"}], ")"}], "n"]}]}]}]]],
 "  for all  ",
 Cell[BoxData[
  RowBox[{"z", " ", "\[Epsilon]", " ", "A", 
   RowBox[{"(", 
    RowBox[{"\[Alpha]", ",", "r", ",", "R"}], ")"}]}]]],
 ",  then ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["b", "n"], "=", 
   SubscriptBox["c", "n"]}]]],
 " for all  ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ".  \n\t\t\t(In other words, the Laurent series for ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 "  in a given annulus is unique.)\n\n",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\t\t\t",
  FontWeight->"Bold"],
 "For all ",
 Cell[BoxData[
  RowBox[{"z", " ", "\[Epsilon]", " ", "A", 
   RowBox[{"(", 
    RowBox[{"\[Alpha]", ",", "r", ",", "R"}], ")"}]}]]],
 ", the derivatives for ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 "  may be obtained by termwise differentiation of its Laurent series. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 7.9 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tThe uniqueness of the Laurent series is an important property because the \
coefficients in the Laurent expansion of a function are seldom found by using \
 Equation ",
 StyleBox["(7-23)",
  FontColor->RGBColor[0, 0, 1]],
 ".  ",
 "The following examples illustrate some methods for finding Laurent series \
coefficients. "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 7.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find three different Laurent series representations for the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["3", 
    RowBox[{"2", " ", "+", " ", "z", " ", "-", " ", 
     SuperscriptBox["z", "2"]}]]}]],
  AspectRatioFixed->True],
 "  involving powers of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .35 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214133 0.190514 0.15 0.05 [
[.02362 .1375 -6 -9 ]
[.02362 .1375 6 0 ]
[.40465 .1375 -3 -9 ]
[.40465 .1375 3 0 ]
[.59516 .1375 -3 -9 ]
[.59516 .1375 3 0 ]
[.78568 .1375 -3 -9 ]
[.78568 .1375 3 0 ]
[.97619 .1375 -3 -9 ]
[.97619 .1375 3 0 ]
[.20163 0 -12 -4.5 ]
[.20163 0 0 4.5 ]
[.20163 .05 -12 -4.5 ]
[.20163 .05 0 4.5 ]
[.20163 .1 -12 -4.5 ]
[.20163 .1 0 4.5 ]
[.20163 .2 -6 -4.5 ]
[.20163 .2 0 4.5 ]
[.20163 .25 -6 -4.5 ]
[.20163 .25 0 4.5 ]
[.20163 .3 -6 -4.5 ]
[.20163 .3 0 4.5 ]
[.20163 .35 -6 -4.5 ]
[.20163 .35 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .35 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02362 .15 m
.02362 .15625 L
s
[(-1)] .02362 .1375 0 1 Mshowa
.40465 .15 m
.40465 .15625 L
s
[(1)] .40465 .1375 0 1 Mshowa
.59516 .15 m
.59516 .15625 L
s
[(2)] .59516 .1375 0 1 Mshowa
.78568 .15 m
.78568 .15625 L
s
[(3)] .78568 .1375 0 1 Mshowa
.97619 .15 m
.97619 .15625 L
s
[(4)] .97619 .1375 0 1 Mshowa
0 .15 m
1 .15 L
s
.21413 0 m
.22038 0 L
s
[(-3)] .20163 0 1 0 Mshowa
.21413 .05 m
.22038 .05 L
s
[(-2)] .20163 .05 1 0 Mshowa
.21413 .1 m
.22038 .1 L
s
[(-1)] .20163 .1 1 0 Mshowa
.21413 .2 m
.22038 .2 L
s
[(1)] .20163 .2 1 0 Mshowa
.21413 .25 m
.22038 .25 L
s
[(2)] .20163 .25 1 0 Mshowa
.21413 .3 m
.22038 .3 L
s
[(3)] .20163 .3 1 0 Mshowa
.21413 .35 m
.22038 .35 L
s
[(4)] .20163 .35 1 0 Mshowa
.21413 0 m
.21413 .35 L
s
0 0 m
1 0 L
1 .35 L
0 .35 L
closepath
clip
newpath
1 0 0 r
.005 w
.07638 .35 m
.08001 .33742 L
.08743 .31805 L
.09505 .3024 L
.10335 .28884 L
.1111 .27857 L
.11965 .26923 L
.13534 .25598 L
.15141 .24601 L
.16688 .23874 L
.18332 .23278 L
.19915 .22832 L
.21439 .22495 L
.2306 .22215 L
.2462 .22009 L
.25416 .21925 L
.26279 .21849 L
.2704 .21793 L
.27877 .21744 L
.28671 .21709 L
.29106 .21694 L
.29512 .21683 L
.29711 .21679 L
.29928 .21675 L
.3012 .21672 L
.30323 .2167 L
.30427 .21669 L
.30525 .21668 L
.30613 .21668 L
.30658 .21667 L
.30708 .21667 L
.30751 .21667 L
.30798 .21667 L
.30847 .21667 L
.30893 .21667 L
.30939 .21667 L
.30983 .21667 L
.31022 .21667 L
.31064 .21667 L
.31113 .21667 L
.31158 .21667 L
.31258 .21667 L
.31347 .21668 L
.31441 .21669 L
.31639 .21671 L
.31856 .21674 L
.32291 .21682 L
.32696 .21692 L
.33515 .21721 L
.34259 .21758 L
Mistroke
.35027 .21806 L
.35859 .2187 L
.37496 .22037 L
.39073 .22254 L
.40446 .22496 L
Mfstroke
0 0 1 r
.05409 .35 m
.05609 .34599 L
.07191 .31986 L
.08712 .29908 L
.10331 .28098 L
.11889 .26688 L
.13546 .25488 L
.15142 .24572 L
.16677 .23872 L
.1831 .23284 L
.19883 .2284 L
.21395 .22504 L
.23006 .22223 L
.24555 .22017 L
.25343 .21934 L
.26203 .21859 L
.27026 .21802 L
.2779 .21764 L
.28212 .21749 L
.2842 .21743 L
.2861 .21738 L
.28784 .21735 L
.28967 .21733 L
.29063 .21732 L
.29152 .21731 L
.29203 .21731 L
.29249 .21731 L
.29275 .21731 L
.29303 .2173 L
.29354 .2173 L
.29403 .2173 L
.29447 .2173 L
.29496 .21731 L
.29548 .21731 L
.29593 .21731 L
.29635 .21731 L
.2973 .21732 L
.29835 .21733 L
.2993 .21735 L
.30144 .21739 L
.30352 .21745 L
.30576 .21752 L
.30984 .2177 L
.31362 .21792 L
.31778 .21822 L
.32619 .21904 L
.33397 .22007 L
.34232 .22152 L
.35021 .22325 L
.35881 .22558 L
Mistroke
.37471 .23131 L
.39097 .23944 L
.40446 .2483 L
Mfstroke
1 0 0 r
.40484 .22504 m
.41255 .22666 L
.42096 .22866 L
.42886 .23079 L
.43646 .2331 L
.44455 .23588 L
.45233 .23891 L
.46061 .24259 L
.46858 .24666 L
.47625 .25115 L
.48441 .25668 L
.49226 .2629 L
.49982 .26991 L
.50786 .27878 L
.5156 .28909 L
.52383 .30258 L
.53176 .31898 L
.53938 .33924 L
s
.53938 .33924 m
.54241 .35 L
s
0 1 0 r
.40484 .24975 m
.40859 .24632 L
.41255 .24357 L
.41657 .24152 L
.41884 .24064 L
.42096 .23998 L
.42306 .23946 L
.42504 .23907 L
.42682 .23882 L
.42782 .2387 L
.42875 .23862 L
.42968 .23855 L
.43019 .23852 L
.43068 .2385 L
.43113 .23848 L
.43137 .23848 L
.43162 .23847 L
.43186 .23847 L
.43207 .23846 L
.43228 .23846 L
.43249 .23846 L
.43272 .23846 L
.43299 .23846 L
.43312 .23846 L
.43326 .23846 L
.43352 .23846 L
.43377 .23846 L
.43401 .23847 L
.43446 .23848 L
.435 .2385 L
.43549 .23852 L
.4366 .23858 L
.43753 .23864 L
.43853 .23873 L
.44033 .23892 L
.44444 .23953 L
.44844 .24033 L
.45266 .24137 L
.46026 .24371 L
.46836 .24683 L
.47616 .2504 L
.48444 .25481 L
.49242 .2597 L
.5001 .26503 L
.50827 .27144 L
.51614 .27839 L
.5237 .28589 L
.53176 .29483 L
.53951 .30448 L
.54775 .316 L
Mistroke
.55568 .32847 L
.56332 .34188 L
Mfstroke
.56332 .34188 m
.56744 .35 L
s
1 0 0 r
.65298 0 m
.659 .01577 L
.66728 .03271 L
.67493 .04521 L
.69026 .06412 L
.70596 .07799 L
.72106 .08799 L
.73713 .09625 L
.7526 .10256 L
.76906 .108 L
.7849 .11231 L
.80014 .1158 L
.81636 .11895 L
.83197 .12156 L
.84857 .12396 L
.86455 .12597 L
.87994 .12767 L
.8963 .12928 L
.91206 .13066 L
.92721 .13185 L
.94334 .133 L
.95886 .13399 L
.97537 .13495 L
.97619 .135 L
s
0 1 1 r
.62076 0 m
.62765 .01298 L
.64347 .03554 L
.65869 .05249 L
.67489 .06677 L
.69048 .07775 L
.70706 .0872 L
.72302 .09463 L
.73839 .10058 L
.75473 .1059 L
.77046 .11022 L
.78559 .11378 L
.8017 .11706 L
.81721 .11979 L
.83369 .12233 L
.84957 .12447 L
.86484 .12629 L
.8811 .12801 L
.89674 .12949 L
.91337 .1309 L
.92939 .13211 L
.94481 .13317 L
.9612 .1342 L
.97619 .13505 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{546.75, 191.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 545.75}, {190.375, 0}} -> {-1, -3, 0, 0}}],
 " "
}], "Text"],

Cell[TextData[{
 "Solution.  The function ",
 StyleBox["f(z)",
  FontFamily->"Courier"],
 " has singularities at  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "=", 
    RowBox[{"-", "1"}]}], ",", "2"}]]],
 "  and is analytic in the disk  ",
 Cell[BoxData[
  RowBox[{"D", ":", 
   RowBox[{"|", "z", "|", 
    RowBox[{"<", "1"}]}]}]]],
 ",  in the annulus  ",
 Cell[BoxData[
  StyleBox[
   RowBox[{"A", ":", 
    RowBox[{
     RowBox[{"1", "<"}], "|", "z", "|", 
     RowBox[{"<", "2"}]}]}],
   FontWeight->"Plain"]], "Input"],
 ",  and in the region  ",
 Cell[BoxData[
  RowBox[{"R", ":", 
   RowBox[{"|", "z", "|", 
    RowBox[{">", "2"}]}]}]]],
 ".  We want to find a different Laurent series for ",
 StyleBox["f(z)",
  FontFamily->"Courier"],
 " in each of the three domains ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", ",
 StyleBox["A",
  FontFamily->"Courier New"],
 ", and ",
 StyleBox["R",
  FontFamily->"Courier New"],
 ".  We start by writing ",
 StyleBox["f(z)",
  FontFamily->"Courier"],
 " in its partial fraction form:  \n\n",
 StyleBox["(7-30)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox["3", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "z"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"2", "-", "z"}], ")"}]}]], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"1", "+", "z"}]], "  ", "+", 
      FractionBox["1", 
       RowBox[{"2", "-", "z"}]]}], "  ", "=", "  ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"1", "+", "z"}]], "  ", "+", 
      RowBox[{
       FractionBox["1", "2"], 
       FractionBox["1", 
        RowBox[{"1", "-", 
         FractionBox["z", "2"]}]]}]}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "We use Theorem 4.12 and Corollary 4.1 to obtain the following \
representations for the terms on the right side of Equation ",
 StyleBox["(7-30)",
  FontColor->RGBColor[0, 0, 1]],
 ":  \n\n",
 Cell[BoxData[GridBox[{
    {
     StyleBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "-", "31"}], ")"}], "             "}],
      FontWeight->"Plain",
      FontColor->RGBColor[0, 0, 1]], 
     StyleBox[
      RowBox[{"          ", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"1", "+", "z"}]], "  ", "=", "  ", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "0"}], "\[Infinity]"], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "n"], 
          SuperscriptBox["z", "n"]}]}]}]}],
      FontWeight->"Plain"], 
     StyleBox[
      RowBox[{"   ", 
       RowBox[{
        RowBox[{
         StyleBox[
          RowBox[{"valid", " ", "for"}],
          FontFamily->"Times New Roman",
          FontSize->12,
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "   ", "|", "z", "|", 
         RowBox[{"<", "1"}]}], " ", 
        StyleBox[",",
         FontFamily->"Times New Roman"]}]}],
      FontWeight->"Plain"]},
    {
     StyleBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "-", "32"}], ")"}], "             "}],
      FontWeight->"Plain",
      FontColor->RGBColor[0, 0, 1]], 
     StyleBox[
      RowBox[{"          ", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"1", "+", "z"}]], "  ", "=", "  ", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "1"}], "\[Infinity]"], 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{"n", "+", "1"}]], 
          SuperscriptBox["z", "n"]], " "}]}]}],
      FontWeight->"Plain"], 
     StyleBox[
      RowBox[{"   ", 
       RowBox[{
        RowBox[{
         StyleBox[
          RowBox[{"valid", " ", "for"}],
          FontFamily->"Times New Roman",
          FontSize->12,
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "   ", "|", "z", "|", 
         RowBox[{">", "1"}]}], " ", 
        StyleBox[",",
         FontFamily->"Times New Roman"]}]}],
      FontWeight->"Plain"]},
    {
     StyleBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "-", "33"}], ")"}], "             "}],
      FontWeight->"Plain",
      FontColor->RGBColor[0, 0, 1]], 
     StyleBox[
      RowBox[{" ", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], 
         FractionBox["1", 
          RowBox[{"1", "-", 
           FractionBox["z", "2"]}]]}], "  ", "=", "  ", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "0"}], "\[Infinity]"], 
         FractionBox[
          SuperscriptBox["z", "n"], 
          SuperscriptBox["2", 
           RowBox[{"n", "+", "1"}]]], "    "}]}]}],
      FontWeight->"Plain"], 
     StyleBox[
      RowBox[{"   ", 
       RowBox[{
        RowBox[{
         StyleBox[
          RowBox[{"valid", " ", "for"}],
          FontFamily->"Times New Roman",
          FontSize->12,
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "   ", "|", "z", "|", 
         RowBox[{"<", "2"}]}], " ", 
        StyleBox[",",
         FontFamily->"Times New Roman"]}]}],
      FontWeight->"Plain"]},
    {
     StyleBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "-", "34"}], ")"}], "             "}],
      FontWeight->"Plain",
      FontColor->RGBColor[0, 0, 1]], 
     StyleBox[
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], 
        FractionBox["1", 
         RowBox[{"1", "-", 
          FractionBox["z", "2"]}]]}], "  ", "=", "  ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "1"}], "\[Infinity]"], 
        FractionBox[
         RowBox[{"-", " ", 
          SuperscriptBox["2", 
           RowBox[{"n", "-", "1"}]]}], 
         SuperscriptBox["z", "n"]]}]}],
      FontWeight->"Plain"], 
     StyleBox[
      RowBox[{"   ", 
       RowBox[{
        StyleBox[
         RowBox[{"valid", " ", "for"}],
         FontFamily->"Times New Roman",
         FontSize->12,
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "   ", "|", "z", "|", 
        RowBox[{">", 
         RowBox[{"2", " ", 
          StyleBox[".",
           FontFamily->"Times New Roman"]}]}]}]}],
      FontWeight->"Plain"]}
   }]], "Input"],
 "  "
}], "Text"],

Cell[TextData[{
 "Representations ",
 StyleBox["(7-31)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(7-33)",
  FontColor->RGBColor[0, 0, 1]],
 " are both valid in the disk  ",
 Cell[BoxData[
  RowBox[{"D", ":", 
   RowBox[{"|", "z", "|", 
    RowBox[{"<", "1"}]}]}]]],
 ",  and thus we have  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"], 
       SuperscriptBox["z", "n"]}]}], " ", "+", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      FractionBox[
       SuperscriptBox["z", "n"], 
       SuperscriptBox["2", 
        RowBox[{"n", "+", "1"}]]]}]}], "  ", "=", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "n"], "+", 
        FractionBox["1", 
         SuperscriptBox["2", 
          RowBox[{"n", "+", "1"}]]]}], ")"}], 
      SuperscriptBox["z", "n"]}]}]}]}]]],
 "   valid for   ",
 Cell[BoxData[
  StyleBox[
   RowBox[{"|", "z", "|", 
    RowBox[{"<", "1", " "}]}],
   FontWeight->"Plain"]]],
 ",  \n\nwhich is a Laurent series that reduces to a Maclaurin series. "
}], "Text"],

Cell[TextData[{
 "In the annulus  ",
 Cell[BoxData[
  StyleBox[
   RowBox[{"A", ":", 
    RowBox[{
     RowBox[{"1", "<"}], "|", "z", "|", 
     RowBox[{"<", "2"}]}]}],
   FontWeight->"Plain"]], "Input"],
 ",  representations ",
 StyleBox["(7-32)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(7-33)",
  FontColor->RGBColor[0, 0, 1]],
 " are valid; hence we get  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"n", "+", "1"}]], 
      SuperscriptBox["z", "n"]]}], "  ", "+", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     FractionBox[
      SuperscriptBox["z", "n"], 
      SuperscriptBox["2", 
       RowBox[{"n", "+", "1"}]]]}]}]}]]],
 "   valid for   ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    RowBox[{"1", "<"}], "|", "z", "|", 
    RowBox[{"<", "2"}]}],
   FontWeight->"Plain"]], "Input"],
 ".  "
}], "Text"],

Cell[TextData[{
 "Finally, in the region  ",
 Cell[BoxData[
  RowBox[{"R", ":", 
   RowBox[{"|", "z", "|", 
    RowBox[{">", "2"}]}]}]]],
 "   we use Representations ",
 StyleBox["(7-32)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(7-34)",
  FontColor->RGBColor[0, 0, 1]],
 " to obtain   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"n", "+", "1"}]], 
       SuperscriptBox["z", "n"]]}], "  ", "+", "   ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      FractionBox[
       RowBox[{"-", " ", 
        SuperscriptBox["2", 
         RowBox[{"n", "-", "1"}]]}], 
       SuperscriptBox["z", "n"]]}]}], "  ", "=", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"n", "+", "1"}]], "-", " ", 
       SuperscriptBox["2", 
        RowBox[{"n", "-", "1"}]]}], 
      SuperscriptBox["z", "n"]]}]}]}]]],
 "   valid for   ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{">", "2"}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"7.7", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506705304125*^9, 3.506705304125*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 "We could let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " sum up the various series, and note when they are valid. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)(-1\!\(\*SuperscriptBox[\()\), \
\(n\)]\)\!\(\*SuperscriptBox[\(z\), \(n\)]\) = \>\"", ",", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "n"], 
        SuperscriptBox["z", "n"]}]}], " ", ",", 
      "\"\<  valid for  |z|<1\>\""}], " ", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((\(-1\))\), \(n + 1\)], \
SuperscriptBox[\(z\), \(n\)]]\) = \>\"", ",", " ", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "1"}], "\[Infinity]"], 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], 
          RowBox[{"n", "+", "1"}]], 
         SuperscriptBox["z", "n"]]}], "]"}], ",", 
      "\"\<  valid for  |z|>1\>\""}], " ", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(n\)], \
SuperscriptBox[\(2\), \(n + 1\)]]\) = \>\"", ",", " ", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "0"}], "\[Infinity]"], 
        FractionBox[
         SuperscriptBox["z", "n"], 
         SuperscriptBox["2", 
          RowBox[{"n", "+", "1"}]]]}], "]"}], ",", 
      "\"\<  valid for  |z|<2\>\""}], " ", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(-\*SuperscriptBox[\(2\), \(n - 1\)]\), \
SuperscriptBox[\(z\), \(n\)]]\) = \>\"", ",", " ", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "1"}], "\[Infinity]"], 
        FractionBox[
         RowBox[{"-", " ", 
          SuperscriptBox["2", 
           RowBox[{"n", "-", "1"}]]}], 
         SuperscriptBox["z", "n"]]}], "]"}], ",", 
      "\"\<  valid for  |z|>2\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3993665079375*^9}],

Cell["Combining the above representations we get:", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)(-1\!\(\*SuperscriptBox[\()\), \
\(n\)]\)\!\(\*SuperscriptBox[\(z\), \(n\)]\) + \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(n\)], \
SuperscriptBox[\(2\), \(n + 1\)]]\) = \>\"", ",", " ", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "0"}], "\[Infinity]"], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "n"], 
          SuperscriptBox["z", "n"]}]}], " ", "+", " ", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "0"}], "\[Infinity]"], 
         FractionBox[
          SuperscriptBox["z", "n"], 
          SuperscriptBox["2", 
           RowBox[{"n", "+", "1"}]]]}]}], "]"}], ",", 
      "\"\<  valid for  |z|<1\>\""}], " ", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)((-1\!\(\*SuperscriptBox[\()\), \(n\)]\)+\!\(\*FractionBox[\
\(1\), SuperscriptBox[\(2\), \(n + 1\)]]\))\!\(\*SuperscriptBox[\(z\), \(n\)]\
\) = \>\"", ",", " ", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "0"}], "\[Infinity]"], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "n"], "+", 
           FractionBox["1", 
            SuperscriptBox["2", 
             RowBox[{"n", "+", "1"}]]]}], ")"}], 
         SuperscriptBox["z", "n"]}]}], "]"}], ",", 
      "\"\<  valid for  |z|<1\>\""}], " ", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(\[Infinity]\)]\)\
\!\(\*FractionBox[SuperscriptBox[\((\(-1\))\), \(n + 1\)], SuperscriptBox[\(z\
\), \(n\)]]\) + \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\[Infinity]\
\)]\)\!\(\*FractionBox[SuperscriptBox[\(z\), \(n\)], SuperscriptBox[\(2\), \
\(n + 1\)]]\) = \>\"", ",", " ", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "1"}], "\[Infinity]"], 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{"n", "+", "1"}]], 
          SuperscriptBox["z", "n"]]}], "  ", "+", "  ", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "0"}], "\[Infinity]"], 
         FractionBox[
          SuperscriptBox["z", "n"], 
          SuperscriptBox["2", 
           RowBox[{"n", "+", "1"}]]]}]}], "]"}], ",", 
      "\"\<  valid for  1<|z|<2\>\""}], " ", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[SuperscriptBox[\((\(-1\))\), \(n + 1\)], \
SuperscriptBox[\(z\), \(n\)]]\) + \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = \
1\), \(\[Infinity]\)]\)\!\(\*FractionBox[\(-\*SuperscriptBox[\(2\), \(n - \
1\)]\), SuperscriptBox[\(z\), \(n\)]]\) = \>\"", ",", " ", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "1"}], "\[Infinity]"], 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{"n", "+", "1"}]], 
          SuperscriptBox["z", "n"]]}], " ", "+", " ", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "1"}], "\[Infinity]"], 
         FractionBox[
          RowBox[{"-", " ", 
           SuperscriptBox["2", 
            RowBox[{"n", "-", "1"}]]}], 
          SuperscriptBox["z", "n"]]}]}], "]"}], ",", 
      "\"\<  valid for  2<|z|\>\""}], " ", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(\*SuperscriptBox[\((\(-1\))\), \(n + \
1\)] - \*SuperscriptBox[\(2\), \(n - 1\)]\), SuperscriptBox[\(z\), \(n\)]]\) \
= \>\"", ",", " ", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "1"}], "\[Infinity]"], 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], 
           RowBox[{"n", "+", "1"}]], "-", " ", 
          SuperscriptBox["2", 
           RowBox[{"n", "-", "1"}]]}], 
         SuperscriptBox["z", "n"]]}], "]"}], ",", 
      "\"\<  valid for  2<|z|\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3993665141875*^9}],

Cell[TextData[{
 "If more details are desired then we can proceed here they are.\n\nEnter the \
function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox["3", 
    RowBox[{"2", " ", "+", " ", "z", " ", "-", " ", 
     SuperscriptBox["z", "2"]}]]}]]],
 " and find the first few terms of the various Laurent series."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"z", "=", "0"}], ";", " ", 
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "A", ",", "f", ",", "f1", ",", "f2", ",", "L1", ",", "L2", ",", "L3", 
      ",", "L4", ",", "S0", ",", "S11", ",", "S12", ",", "S21", ",", "S22", 
      ",", "SI"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox["3", 
      RowBox[{"2", " ", "+", " ", "z", " ", "-", " ", 
       SuperscriptBox["z", "2"]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3993665203125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 " easily finds the Maclaurin series involving positive powers of  z."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S0", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "7"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(0\)]\)[z] = \>\"", ",", 
      RowBox[{"S0", "[", "z", "]"}], ",", "\"\< + ...\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39936652446875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "The above series converges for  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", " ", "1"}]}]]],
 ",  this requires looking at the sum of the two \"geometric series\" that \
form the parts of  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "0"], "[", "z", "]"}]],
  AspectRatioFixed->True],
 ".  ",
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 " can also find \"the other series\" that involves negative powers of  z, \
this involves the mental thinking that you substitute  ",
 Cell[BoxData[
  RowBox[{"Z", "=", 
   FractionBox["1", "z"]}]]],
 "  in the original series to get a new function of  Z, then expand it about  \
Z = 0  and then substitute  ",
 Cell[BoxData[
  RowBox[{"Z", "=", 
   FractionBox["1", "z"]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"SI", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "\[Infinity]", ",", "10"}], "}"}]}], "]"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(\[Infinity]\)]\)[z] = \>\"", ",", 
      "\"\<... \>\"", ",", 
      RowBox[{"SI", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399366529140625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "The above series converges for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"2", " ", "<"}], " ", "|", "z", "|"}]]],
 ",  this requires looking at the sum of the two \"geometric series that form \
the parts of ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "\[Infinity]"], "[", "z", "]"}]]],
 ".\nThis leaves an unresolved question: \"What happens in the annulus  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"1", " ", "<"}], " ", "|", "z", "|", 
   RowBox[{"<", " ", "2"}]}]]],
 " ?  This requires a little work.  First split up the functions up into \
their partial fraction form, and then do expansions about  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"0", "  ", "and", "  ", "z"}], "=", "\[Infinity]"}]}]]],
 "  for each part."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"A", " ", "=", " ", 
     RowBox[{"MapAll", "[", 
      RowBox[{"Cancel", ",", 
       RowBox[{"Apart", "[", 
        RowBox[{"f", "[", "z", "]"}], "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], " ", "=", " ", 
     SubscriptBox["A", 
      RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f2", "[", "z_", "]"}], " ", "=", " ", 
     SubscriptBox["A", 
      RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< = \>\"", ",", "A"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(f\), \(1\)]\)[z] = \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(f\), \(2\)]\)[z] = \>\"", ",", 
      RowBox[{"f2", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399366532953125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "The singularity of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["f", "1"], "[", "z", "]"}], "  ", "is", "  ", "z"}], " ", 
   "=", " ", 
   RowBox[{"-", "1"}]}]],
  AspectRatioFixed->True],
 ",  and the singularity of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["f", "2"], "[", "z", "]"}], "  ", "is", "  ", "z"}], " ", 
   "=", " ", "2"}]],
  AspectRatioFixed->True],
 ".  Next we form Laurent expansions for the two parts  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["f", "1"], "[", "z", "]"}], "  ", "and", "  ", 
   RowBox[{
    SubscriptBox["f", "2"], "[", "z", "]"}]}]],
  AspectRatioFixed->True],
 ",  there are two expansions for each function. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S11", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f1", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "12"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S12", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f1", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "\[Infinity]", ",", "11"}], "}"}]}], "]"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S21", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f2", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "12"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S22", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f2", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "\[Infinity]", ",", "12"}], "}"}]}], "]"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(f\), \(1\)]\)[z] = \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(11\)]\)[z] = \>\"", ",", 
      RowBox[{"S11", "[", "z", "]"}], ",", "\"\< - ...\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<  for  |z| < 1\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(12\)]\)[z] = \>\"", ",", 
      "\"\<... + \>\"", ",", 
      RowBox[{"S12", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<  for  |z| > 1\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(f\), \(2\)]\)[z] = \>\"", ",", 
      RowBox[{"f2", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(21\)]\)[z] = \>\"", ",", 
      RowBox[{"S21", "[", "z", "]"}], ",", "\"\< + ...\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<  for  |z| < 2\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(22\)]\)[z] = \>\"", ",", 
      "\"\<... + \>\"", ",", 
      RowBox[{"S22", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<  for  |z| > 2\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399366536796875*^9},
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Laurent Series (i).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  The first Laurent series  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["L", "1"], "[", "z", "]"}], " ", "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "11"], "[", "z", "]"}], "+", 
    RowBox[{
     SubscriptBox["S", "21"], "[", "z", "]"}]}]}]]],
 "  is valid for  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", " ", "1"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"L1", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"S11", "[", "z", "]"}], " ", "+", " ", 
      RowBox[{"S21", "[", "z", "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< = \>\"", ",", "A"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(L\), \(1\)]\)[z] = \>\"", ",", 
      RowBox[{"L1", "[", "z", "]"}], ",", "\"\< - ...\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399366540703125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"L1", "[", "x", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "0.999999"}], ",", "0.999999"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "8"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "8", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<s\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<s = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\<  and  s = \!\(\*SubscriptBox[\(L\), \(1\)]\)[x]\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(L\), \(1\)]\)[x] = \>\"", ",", 
      RowBox[{"L1", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399366544671875*^9, 3.399366547609375*^9}, {
  3.399915089328125*^9, 3.399915089515625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate how well the complex Laurent series is \"converging\" in \
the complex plane.\nFor the first series we need to be close to  ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 ".  For convenience we use the disk  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", " ", "0.6"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"L1", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.6", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"1", ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \!\(\*SubscriptBox[\(L\), \(1\)]\)[x] = \>\"", ",", 
      RowBox[{"L1", "[", "z", "]"}], ",", "\"\<,  where |z| < 0.6\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.6", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"1", ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<,  where |z| < 0.6\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39936655090625*^9, 3.399366554703125*^9}, {
   3.39991509525*^9, 3.399915095515625*^9}, 3.441831716953125*^9}],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  If ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " is ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " chosen close enough to ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 " then the series ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["L", "1"], "[", "z", "]"}]]],
 " will not converge rapidly near the circle.  More terms are needed to get \
convergence near the circle  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", " ", "1"}]}]]],
 ".  We can see what is happening in the disk  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", " ", "0.9"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"L1", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.9", ",", "0.15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"1", ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \!\(\*SubscriptBox[\(L\), \(1\)]\)[x] = \>\"", ",", 
      RowBox[{"L1", "[", "z", "]"}], ",", "\"\<,  where |z| < 0.9\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399366560703125*^9, 3.3993665625*^9}, {
  3.39991510234375*^9, 3.3999151025*^9}, {3.44183173015625*^9, 
  3.441831732875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Laurent Series (ii).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  The second Laurent series  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["L", "2"], "[", "z", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "12"], "[", "z", "]"}], "+", 
    RowBox[{
     SubscriptBox["S", "21"], "[", "z", "]"}]}]}]]],
 "  is valid for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"1", " ", "<"}], " ", "|", "z", "|", 
   RowBox[{"<", " ", "2"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"L2", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"S12", "[", "z", "]"}], " ", "+", " ", 
      RowBox[{"S21", "[", "z", "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< = \>\"", ",", "A"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(L\), \(2\)]\)[z] = ... + \>\"", ",", " ", 
      RowBox[{"S12", "[", "z", "]"}], " ", ",", "\"\< + \>\"", ",", 
      RowBox[{"S21", "[", "z", "]"}], ",", "\"\< + ...\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39936656859375*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"L2", "[", "x", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "1.0001", ",", "1.9999"}], "}"}], ",", "\n", "  ", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "7"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"1", ",", "2", ",", "0.2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "7", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Green"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<s\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<s = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\<  and  s = \!\(\*SubscriptBox[\(L\), \(2\)]\)[x]\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(L\), \(2\)]\)[x] = \>\"", ",", 
      RowBox[{"L2", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39936657240625*^9, 3.399366574046875*^9}, {
  3.399915107484375*^9, 3.3999151076875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate how well the complex Laurent series is \"converging\" in \
the complex plane.\nFor the second series we need to be in the middle of the \
annulus  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"1", " ", "<"}], " ", "|", "z", "|", 
   RowBox[{"<", " ", "2"}]}]]],
 ".   For convenience we choose  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"1.3", " ", "<"}], " ", "|", "z", "|", 
   RowBox[{"<", " ", "1.6"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"L2", ",", 
     RowBox[{"{", 
      RowBox[{"1.3", ",", "1.6", ",", "0.05"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0.63", ",", "2.93"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.15"}], ",", "1.15"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"1", ",", "3", ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \!\(\*SubscriptBox[\(L\), \(2\)]\)[x] = \>\"", ",", 
      RowBox[{"L2", "[", "z", "]"}], ",", 
      "\"\<,  where 1.3 < |z| < 1.6\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{"1.3", ",", "1.6", ",", "0.05"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0.63", ",", "2.93"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.15"}], ",", "1.15"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"1", ",", "3", ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<,  where 1.3 < |z| < 1.6\>\""}],
      "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399366576828125*^9, 3.39936658115625*^9}, {
   3.399915113078125*^9, 3.39991511325*^9}, 3.441831748828125*^9}],

Cell[TextData[{
 "Hence ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["L", "2"], "[", "z", "]"}]]],
 " is an approximation to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   RowBox[{
    FractionBox["3", 
     RowBox[{"2", " ", "+", " ", "z", " ", "-", " ", 
      SuperscriptBox["z", "2"]}]], "=", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"z", " ", "+", " ", "1"}]], "-", 
     FractionBox["1", 
      RowBox[{"z", " ", "-", " ", "2"}]]}]}]}]]],
 "  valid for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"1", " ", "<"}], " ", "|", "z", "|", 
   RowBox[{"<", " ", "2"}]}]]],
 ".   \nNotice that the first series  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["L", "1"], "[", "z", "]"}]]],
 "  is ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " a good approximation in  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"1", " ", "<"}], " ", "|", "z", "|", 
   RowBox[{"<", " ", "2"}]}]]],
 ",  for illustration, it is ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " accurate at  ",
 Cell[BoxData[
  RowBox[{"z", "=", "1.5"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[1.5] = \>\"", ",", 
      RowBox[{"f", "[", "1.5", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(L\), \(1\)]\)[1.5] = \>\"", ",", 
      RowBox[{"L1", "[", "1.5", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[1.5] = \>\"", ",", 
      RowBox[{"f", "[", "1.5", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(L\), \(2\)]\)[1.5] = \>\"", ",", 
      RowBox[{"L2", "[", "1.5", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3993665869375*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Laurent Series (iii).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  The third Laurent series  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["L", "3"], "[", "z", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "12"], "[", "z", "]"}], "+", 
    RowBox[{
     SubscriptBox["S", "22"], "[", "z", "]"}]}]}]]],
 "  is valid for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"2", " ", "<"}], " ", "|", "z", "|"}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"L3", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"S12", "[", "z", "]"}], " ", "+", " ", 
      RowBox[{"S22", "[", "z", "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< = \>\"", ",", "A"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(L\), \(3\)]\)[z] = ... \>\"", ",", 
      RowBox[{"L3", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39936659075*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"L3", "[", "x", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "2.0001", ",", "5.0"}], "}"}], ",", "\n", "  ", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "0"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"2", ",", "5", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "0", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Cyan"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<s\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<s = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\<  and  s = \!\(\*SubscriptBox[\(L\), \(3\)]\)[x], for 2 < x \
\[LessEqual] 5\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(L\), \(3\)]\)[x] = \>\"", ",", 
      RowBox[{"L3", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399366594171875*^9, 3.399366595546875*^9}, {
  3.399915118609375*^9, 3.39991511878125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate how well the complex Laurent series is \"converging\" in \
the complex plane.\nFor the third series z must satisfy  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"2", " ", "<"}], " ", "|", "z", "|"}]]],
 ".  For convenience we choose  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"3", " ", "<"}], " ", "|", "z", "|"}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"PolarMap", "[", 
    RowBox[{"L3", ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.8"}], ",", "0.4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.6"}], ",", "0.6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"1", ",", "2", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \!\(\*SubscriptBox[\(L\), \(3\)]\)[x] = \>\"", ",", 
      RowBox[{"L3", "[", "z", "]"}], ",", "\"\<,  where 3 < |z| < 5\>\""}], 
     "]"}], ";", " ", 
    RowBox[{"PolarMap", "[", 
     RowBox[{"f", ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "5", ",", "0.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
        FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.8"}], ",", "0.4"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.6"}], ",", "0.6"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "2", ",", "0.5"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<,  where 3 < |z| < 5\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39936659796875*^9, 3.399366601078125*^9}, {
   3.399915123296875*^9, 3.399915128609375*^9}, 3.4418317680625*^9}],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " If z is ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " large enough to then the series ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["L", "3"], "[", "z", "]"}]]],
 " will not converge rapidly.  More terms are needed to get convergence near  \
",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "=", " ", "2"}]]],
 ".    We can see what is happening in the annulus  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"2.2", "  ", "<"}], " ", "|", "z", "|", " ", 
   RowBox[{"<", "  ", "4"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"L3", ",", 
     RowBox[{"{", 
      RowBox[{"2.2", ",", "4", ",", "0.2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.8"}], ",", "0.4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.6"}], ",", "0.6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"1", ",", "2", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \!\(\*SubscriptBox[\(L\), \(3\)]\)[x] = \>\"", ",", 
      RowBox[{"L3", "[", "z", "]"}], ",", "\"\<,  where 2.2 < |z| < 4\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399366606109375*^9, 3.3993666089375*^9}, {
   3.399915133984375*^9, 3.3999151341875*^9}, 3.44183177665625*^9}],

Cell[TextData[{
 "So  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["L", "3"], "[", "z", "]"}]]],
 "  is an approximation to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   RowBox[{
    FractionBox["3", 
     RowBox[{"2", " ", "+", " ", "z", " ", "-", " ", 
      SuperscriptBox["z", "2"]}]], "=", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"z", " ", "+", " ", "1"}]], "-", 
     FractionBox["1", 
      RowBox[{"z", " ", "-", " ", "2"}]]}]}]}]]],
 "  valid for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"2", " ", "<"}], " ", "|", "z", "|"}]]],
 ".  \nNotice that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["L", "1"], "[", "z", "]"}], "  ", "and", "  ", 
   RowBox[{
    SubscriptBox["L", "2"], "[", "z", "]"}]}]]],
 " are ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " good approximations for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"2", " ", "<"}], " ", "|", "z", "|"}]]],
 ",  for illustration they are ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " accurate at  z = 4.0"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[4.0] = \>\"", ",", 
      RowBox[{"f", "[", "4.0", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(L\), \(1\)]\)[4.0] = \>\"", ",", 
      RowBox[{"L1", "[", "4.0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[4.0] = \>\"", ",", 
      RowBox[{"f", "[", "4.0", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(L\), \(2\)]\)[4.0] = \>\"", ",", 
      RowBox[{"L2", "[", "4.0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[4.0] = \>\"", ",", 
      RowBox[{"f", "[", "4.0", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(L\), \(3\)]\)[4.0] = \>\"", ",", 
      RowBox[{"L3", "[", "4.0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39936661315625*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Divergent Series Combination (iv).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 StyleBox["  ",
  FontColor->RGBColor[0, 1, 0]],
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The fourth possibility  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["S", "11"], "[", "z", "]"}], "+", 
   RowBox[{
    SubscriptBox["S", "22"], "[", "z", "]"}]}]]],
 "  does ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " converge for any values of z and should ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " be considered, however you could write down a few terms and think about \
why this series ",
 StyleBox["diverges",
  FontColor->RGBColor[1, 0, 1]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"L4", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"S11", "[", "z", "]"}], " ", "+", " ", 
      RowBox[{"S22", "[", "z", "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(L\), \(4\)]\)[z] = \>\"", ",", "\"\<... \>\"", 
      ",", 
      RowBox[{"S22", "[", "z", "]"}], ",", "\"\< + \>\"", ",", 
      RowBox[{"S11", "[", "z", "]"}], ",", "\"\< - ...\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39936661746875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "In the above series, when  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", " ", 
    FractionBox["1", "2"]}]}]]],
 "  the portion of the series with positive exponents will converge but the \
portion with negative exponents will diverge. Similarly, when  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{">", " ", "1"}]}]]],
 "  the portion of the series with negative exponents will converge, but the \
portion of the series with positive exponents will diverge.   Hence, the \
series diverges for all  z.  It does ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " approximate  f[z]  at any of the values x = 0.5, 1.5, 4.0"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[0.5] = \>\"", ",", 
      RowBox[{"f", "[", "0.5", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(L\), \(4\)]\)[0.5] = \>\"", ",", 
      RowBox[{"L4", "[", "0.5", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[1.5] = \>\"", ",", 
      RowBox[{"f", "[", "1.5", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(L\), \(4\)]\)[1.5] = \>\"", ",", 
      RowBox[{"L4", "[", "1.5", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[4.0] = \>\"", ",", 
      RowBox[{"f", "[", "4.0", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(L\), \(4\)]\)[4.0] = \>\"", ",", 
      RowBox[{"L4", "[", "4.0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3993666206875*^9}]
}, Open  ]],

Cell["We can summarize the above findings.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"graph1", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"f", "[", "x", "]"}], ",", 
        RowBox[{"L1", "[", "x", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "0.999999"}], ",", "0.999999"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "8"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1", ",", "0.5"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "8", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Red", ",", "Blue"}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<x\>\"", ",", "\"\<s\>\""}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<s = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\<  and  s = \!\(\*SubscriptBox[\(L\), \(1\)]\)[x]\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(L\), \(1\)]\)[x] = \>\"", ",", 
      RowBox[{"L1", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"graph2", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"f", "[", "x", "]"}], ",", 
        RowBox[{"L2", "[", "x", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "1.0001", ",", "1.9999"}], "}"}], ",", "\n", "  ", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "7"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "2", ",", "0.2"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "7", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Red", ",", "Green"}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<x\>\"", ",", "\"\<s\>\""}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<s = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\<  and  s = \!\(\*SubscriptBox[\(L\), \(2\)]\)[x]\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(L\), \(2\)]\)[x] = \>\"", ",", 
      RowBox[{"L2", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"graph3", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"f", "[", "x", "]"}], ",", 
        RowBox[{"L3", "[", "x", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "2.0001", ",", "5.0"}], "}"}], ",", "\n", "  ", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "6"}], ",", "0"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"2", ",", "5", ",", "0.5"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "6"}], ",", "0", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Red", ",", "Cyan"}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<x\>\"", ",", "\"\<s\>\""}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<s = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\<  and  s = \!\(\*SubscriptBox[\(L\), \(3\)]\)[x], for 2 < x \
\[LessEqual] 5\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(L\), \(3\)]\)[x] = \>\"", ",", 
      RowBox[{"L3", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", "graph3", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "10"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "5", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<s = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\<  and  s = \!\(\*SubscriptBox[\(L\), \(3\)]\)[x], \
\!\(\*SubscriptBox[\(L\), \(2\)]\)[x], \!\(\*SubscriptBox[\(L\), \
\(3\)]\)[x]\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399366624203125*^9, 3.399366656140625*^9}, {
  3.399915139765625*^9, 3.3999151399375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 7.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the Laurent series representation for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{"cos", 
      RowBox[{"(", "z", ")"}]}], " ", "-", " ", "1"}], 
    SuperscriptBox["z", "4"]]}]],
  AspectRatioFixed->False],
 "  that involves powers of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Solution.  We know that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", " ", "z"}], "  ", "=", "  ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], 
      SuperscriptBox["z", 
       RowBox[{"2", "n"}]]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "n"}], ")"}], "!"}]]}]}]]],
 ",  and hence the Maclaurin series for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", " ", "z"}], " ", "-", " ", "1"}]]],
 "  is\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"cos", " ", "z"}], " ", "-", " ", "1"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"], 
       SuperscriptBox["z", 
        RowBox[{"2", "n"}]]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "n"}], ")"}], "!"}]]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        SuperscriptBox["z", "2"], 
        RowBox[{"2", "!"}]]}], "+", 
      FractionBox[
       SuperscriptBox["z", "4"], 
       RowBox[{"4", "!"}]], "-", 
      FractionBox[
       SuperscriptBox["z", "6"], 
       RowBox[{"6", "!"}]], "+", 
      FractionBox[
       SuperscriptBox["z", "8"], 
       RowBox[{"8", "!"}]], "-", 
      FractionBox[
       SuperscriptBox["z", "10"], 
       RowBox[{"10", "!"}]], "+"}], "..."}]}]}]]],
 ",   \nthen we can write \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["z", "4"]], 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "n"], 
        SuperscriptBox["z", 
         RowBox[{"2", "n"}]]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", "n"}], ")"}], "!"}]]}]}], "  ", "=", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"], 
       SuperscriptBox["z", 
        RowBox[{
         RowBox[{"2", "n"}], "-", "4"}]]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "n"}], ")"}], "!"}]]}]}]}]]],
 "\n\nor in another way we can write\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"cos", " ", "z"}], "  ", "-", "  ", "1"}], 
     SuperscriptBox["z", "4"]], "  ", "=", "  ", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", " ", 
        FractionBox[
         SuperscriptBox["z", "2"], 
         RowBox[{"2", "!"}]]}], " ", "+", " ", 
       FractionBox[
        SuperscriptBox["z", "4"], 
        RowBox[{"4", "!"}]], " ", "-", " ", 
       FractionBox[
        SuperscriptBox["z", "6"], 
        RowBox[{"6", "!"}]], " ", "+", " ", 
       FractionBox[
        SuperscriptBox["z", "8"], 
        RowBox[{"8", "!"}]], " ", "-", " ", 
       FractionBox[
        SuperscriptBox["z", "10"], 
        RowBox[{"10", "!"}]], " ", "+"}], " ", "..."}], 
     SuperscriptBox["z", "4"]]}]}]]],
 "\n\nWe formally divide each term by ",
 Cell[BoxData[
  SuperscriptBox["z", "4"]]],
 " to obtain the Laurent series \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", " ", 
        FractionBox["1", 
         RowBox[{"2", "!"}]]}], 
       FractionBox["1", 
        SuperscriptBox["z", "2"]]}], " ", "+", " ", 
      FractionBox["1", 
       RowBox[{"4", "!"}]], " ", "-", " ", 
      FractionBox[
       SuperscriptBox["z", "2"], 
       RowBox[{"6", "!"}]], " ", "+", " ", 
      FractionBox[
       SuperscriptBox["z", "4"], 
       RowBox[{"8", "!"}]], " ", "-", " ", 
      FractionBox[
       SuperscriptBox["z", "6"], 
       RowBox[{"10", "!"}]], " ", "+"}], " ", "..."}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SuperscriptBox["z", "2"]}]]}], "+", 
      FractionBox["1", "24"], "-", 
      FractionBox[
       SuperscriptBox["z", "2"], "720"], "+", 
      FractionBox[
       SuperscriptBox["z", "4"], "40320"], "-", 
      FractionBox[
       SuperscriptBox["z", "6"], "3628800"], "+"}], "..."}]}]}]}]],
 " "
}], "Text",
 CellChangeTimes->{3.399322968953125*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"7.8", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506705307546875*^9, 3.506705307546875*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{"Cos", "[", "z", "]"}], " ", "-", " ", "1"}], 
    SuperscriptBox["z", "4"]]}]]],
 " and find the first few terms of the Laurent series in the punctured plane  \
",
 Cell[BoxData[
  RowBox[{"0", "<", "z"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "L", ",", "S", ",", "S10", ",", "S\[Infinity]"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"Cos", "[", "z", "]"}], " ", "-", " ", "1"}], 
      SuperscriptBox["z", "4"]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", "z", "]"}], "-", "1"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "14"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"L", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "10"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = (\>\"", ",", 
      RowBox[{"S", "[", "z", "]"}], ",", "\"\< - ... )/(\>\"", ",", 
      SuperscriptBox["z", "4"], ",", "\"\<)\>\""}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<L[z] = \>\"", ",", 
      RowBox[{"L", "[", "z", "]"}], ",", "\"\< + ...\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399366718*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "The latter Laurent series is valid for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"0", " ", "<"}], "|", "z", "|"}]]],
 ".  \n\nSum up an infinite number of terms to verify that we have things \
right."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S10", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "7"], 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "n"], 
        SuperscriptBox["z", 
         RowBox[{
          RowBox[{"2", "n"}], "-", "4"}]]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", "n"}], ")"}], "!"}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S\[Infinity]", "[", "z_", "]"}], " ", "=", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "n"], 
        SuperscriptBox["z", 
         RowBox[{
          RowBox[{"2", "n"}], "-", "4"}]]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", "n"}], ")"}], "!"}]]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(10\)]\)[z] = \>\"", ",", 
      RowBox[{"S10", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(\[Infinity]\)]\)[z]  =  \>\"", ",", 
      RowBox[{"S\[Infinity]", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(\[Infinity]\)]\)[z]  =  \>\"", ",", 
      RowBox[{"Together", "[", 
       RowBox[{"Expand", "[", 
        RowBox[{"S\[Infinity]", "[", "z", "]"}], "]"}], "]"}]}], "]"}], ";"}],
    " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.39936672284375*^9, {3.441831801515625*^9, 3.441831807203125*^9}, {
   3.44183187896875*^9, 3.441831897234375*^9}, {3.4418319353125*^9, 
   3.441831963375*^9}, {3.44183200184375*^9, 3.441832053125*^9}, {
   3.441832294875*^9, 3.441832306875*^9}, {3.441832415203125*^9, 
   3.441832434671875*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"f[z] = \"\>", "\[InvisibleSpace]", 
   RowBox[{"f", "[", "z", "]"}]}],
  SequenceForm["f[z] = ", 
   $CellContext`f[$CellContext`z]],
  Editable->False]], "Print",
 CellChangeTimes->{3.441832405421875*^9, 3.44183243834375*^9}],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{3.441832405421875*^9, 3.44183243834375*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(S\\), \\(10\\)]\\)[z] = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "24"], "-", 
    FractionBox["1", 
     RowBox[{"2", " ", 
      SuperscriptBox["z", "2"]}]], "-", 
    FractionBox[
     SuperscriptBox["z", "2"], "720"], "+", 
    FractionBox[
     SuperscriptBox["z", "4"], "40320"], "-", 
    FractionBox[
     SuperscriptBox["z", "6"], "3628800"], "+", 
    FractionBox[
     SuperscriptBox["z", "8"], "479001600"], "-", 
    FractionBox[
     SuperscriptBox["z", "10"], "87178291200"]}]}],
  SequenceForm[
  "\!\(\*SubscriptBox[\(S\), \(10\)]\)[z] = ", Rational[1, 24] + 
   Rational[-1, 2] $CellContext`z^(-2) + Rational[-1, 720] $CellContext`z^2 + 
   Rational[1, 40320] $CellContext`z^4 + 
   Rational[-1, 3628800] $CellContext`z^6 + 
   Rational[1, 479001600] $CellContext`z^8 + 
   Rational[-1, 87178291200] $CellContext`z^10],
  Editable->False]], "Print",
 CellChangeTimes->{3.441832405421875*^9, 3.44183243834375*^9}],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{3.441832405421875*^9, 3.44183243834375*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(S\\), \\(\[Infinity]\\)]\\)[z]  =  \"\
\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"Cos", "[", "z", "]"}]}], 
    SuperscriptBox["z", "4"]]}],
  SequenceForm[
  "\!\(\*SubscriptBox[\(S\), \(\[Infinity]\)]\)[z]  =  ", $CellContext`z^(-4) \
(-1 + Cos[$CellContext`z])],
  Editable->False]], "Print",
 CellChangeTimes->{3.441832405421875*^9, 3.441832438359375*^9}],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{3.441832405421875*^9, 3.441832438359375*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(S\\), \\(\[Infinity]\\)]\\)[z]  =  \"\
\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"Cos", "[", "z", "]"}]}], 
    SuperscriptBox["z", "4"]]}],
  SequenceForm[
  "\!\(\*SubscriptBox[\(S\), \(\[Infinity]\)]\)[z]  =  ", $CellContext`z^(-4) \
(-1 + Cos[$CellContext`z])],
  Editable->False]], "Print",
 CellChangeTimes->{3.441832405421875*^9, 3.441832438359375*^9}]
}, Open  ]],

Cell[TextData[{
 "See how closely the series  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "10"], "[", "z", "]"}]]],
 "  approximates the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{"Cos", "[", "z", "]"}], " ", "-", " ", "1"}], 
    SuperscriptBox["z", "4"]]}]],
  AspectRatioFixed->False],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[0.2]= \>\"", ",", 
      RowBox[{"f", "[", "0.2", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<L[0.2]= \>\"", ",", 
      RowBox[{"L", "[", "0.2", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[2.0]= \>\"", ",", 
      RowBox[{"f", "[", "2.0", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<L[2.0]= \>\"", ",", 
      RowBox[{"L", "[", "2.0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399366727953125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"L", "[", "x", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0.0001", ",", "15"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "15"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "0.1"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "15", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "10"}], ",", "0", ",", "2"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<s\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<s = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\<  and  s = \!\(\*SubscriptBox[\(S\), \(10\)]\)[x]\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(10\)]\)[x] = \>\"", ",", 
      RowBox[{"L", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399366731*^9, 3.399366733578125*^9}, {
  3.39991514734375*^9, 3.39991514809375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate how well the complex Laurent series is \"converging\" in \
the complex plane."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"S10", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0.2", ",", "2.2", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", " ", "1", ",", " ", "0.1"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "7"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \!\(\*SubscriptBox[\(S\), \(10\)]\)[z] =  \>\"", ",", 
      RowBox[{"S10", "[", "z", "]"}], ",", 
      "\"\<,  where 0.2 \[LessEqual] x \[LessEqual] 2.2, -1 \[LessEqual] y \
\[LessEqual] 1\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{"0.2", ",", "2.2", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", " ", "1", ",", " ", "0.1"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "7"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<,  where 0.2 \[LessEqual] x \[LessEqual] 2.2, -1 \[LessEqual] y \
\[LessEqual] 1\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399366736640625*^9, 3.3993667405625*^9}, {
  3.399915155390625*^9, 3.399915156140625*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], "=", 
     RowBox[{"f", "[", 
      RowBox[{"z", "+", "1"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "z_", "]"}], "=", 
     RowBox[{"S10", "[", 
      RowBox[{"z", "+", "1"}], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"G", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.999", ",", "0.1665"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["6", "7"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \!\(\*SubscriptBox[\(S\), \(9\)]\)[1+z] =  \>\"", ",", 
      RowBox[{"S9", "[", 
       RowBox[{"1", "+", "z"}], "]"}], ",", "\"\<,  where |z| < 0.999\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"F", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.999", ",", "0.1665"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "\[Pi]"}], ",", " ", "\[Pi]", ",", " ", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["6", "7"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[1+z] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"1", "+", "z"}], "]"}], ",", "\"\<,  where |z| < 0.999\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399366745484375*^9, 3.399366748953125*^9}, {
  3.39991516134375*^9, 3.39991516159375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 7.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the Laurent series for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"exp", 
    RowBox[{"(", 
     FractionBox[
      RowBox[{"-", "1"}], 
      SuperscriptBox["z", "2"]], ")"}]}]}]],
  AspectRatioFixed->False],
 "  centered at  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "=", "0"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Solution.  The Maclaurin series for  ",
 StyleBox["exp z",
  FontFamily->"Courier New"],
 "  is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"exp", " ", "z"}], "  ", "=", "  ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     FractionBox["1", 
      RowBox[{"n", "!"}]], 
     SuperscriptBox["z", "n"]}]}]}]]],
 ", which is valid for all ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ".  We let  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"-", "1"}], 
   SuperscriptBox["z", "2"]]]],
 "  take the role of z in this equation to get\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"exp", 
    RowBox[{"(", 
     FractionBox[
      RowBox[{"-", "1"}], 
      SuperscriptBox["z", "2"]], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      FractionBox["1", 
       RowBox[{"n", "!"}]], 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"-", "1"}], 
         SuperscriptBox["z", "2"]], ")"}], "n"]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       FractionBox["1", 
        RowBox[{"n", "!"}]], 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "n"], 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox["z", "2"], ")"}], "n"]]}]}], "  ", "=", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"], 
       RowBox[{
        RowBox[{"n", "!"}], 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox["z", "2"], ")"}], "n"]}]]}]}]}]}]]],
 ",\n\nwhich is valid for ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{">", "0"}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"7.9", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506705311953125*^9, 3.506705311953125*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   SuperscriptBox["\[ExponentialE]", 
    FractionBox[
     RowBox[{"-", "1"}], 
     SuperscriptBox["z", "2"]]]}]]],
 " and find the first few terms of the Laurent series in the punctured plane  \
",
 Cell[BoxData[
  RowBox[{"0", "<", "z"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "L", ",", "L1", ",", "S1"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{"-", "1"}], 
       SuperscriptBox["z", "2"]]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"L", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "\[Infinity]", ",", "20"}], "}"}]}], "]"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<L[z] = ... + \>\"", ",", 
      RowBox[{
       RowBox[{"L", "[", "z", "]"}], "-", "1"}], ",", "\"\< + \>\"", ",", 
      "1"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3993667583125*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "Note that we had to expand the function about ",
 Cell[BoxData["\[Infinity]"]],
 " in order to get the negative powers of  z. Also, we can get the Laurent \
expansion by series substitution:"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S1", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "z"], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", "10"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"L1", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"S1", "[", 
      FractionBox[
       RowBox[{"-", "1"}], 
       SuperscriptBox["z", "2"]], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(Z\)]\) = \>\"", ",", 
      RowBox[{"S1", "[", "\"\<Z\>\"", "]"}], ",", "\"\< + ...\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Use the change of variable Z = \!\(\*FractionBox[\(-1\), \
SuperscriptBox[\(z\), \(2\)]]\).\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(L\), \(1\)]\)[z] = ... + \>\"", ",", 
      RowBox[{
       RowBox[{"L1", "[", "z", "]"}], "-", "1"}], ",", "\"\< + \>\"", ",", 
      "1"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.399366761328125*^9, {3.40026820109375*^9, 3.40026820375*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 "The above Laurent series is valid for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"0", " ", "<"}], " ", "|", "z", "|"}]]],
 ".  \n\nWe can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate how well the Laurent series is \"converging\" for real \
numbers."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"L1", "[", "x", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0.3", ",", "2.0"}], "}"}], ",", "\n", "  ", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "0.2"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<s\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<s = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\<  and  s = \!\(\*SubscriptBox[\(S\), \(1\)]\)[x]\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(1\)]\)[x] = \>\"", ",", 
      RowBox[{"L1", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399366764359375*^9, 3.3993667659375*^9}, {
  3.39991516675*^9, 3.399915166921875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate how well the complex Laurent series is \"converging\" in \
the complex plane.\nBut, we need to stay away from  z=0.  For convenience we \
use the disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"0.3", " ", "<"}], " ", "|", "z", "|", 
   RowBox[{"<", "0.9"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"L1", " ", ",", 
     RowBox[{"{", 
      RowBox[{"0.3", ",", "0.9", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"-", " ", "\[Pi]"}], "2"], ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "2"], ",", " ", 
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "12"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \!\(\*SubscriptBox[\(S\), \(1\)]\)[1+z] =  \>\"", ",", 
      RowBox[{"S9", "[", 
       RowBox[{"1", "+", "z"}], "]"}], ",", 
      "\"\<,  where 0.3 < |z| < 0.9\>\""}], "]"}], ";", " ", 
    RowBox[{"PolarMap", "[", 
     RowBox[{"f", ",", 
      RowBox[{"{", 
       RowBox[{"0.3", ",", "0.9", ",", "0.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        FractionBox[
         RowBox[{"-", " ", "\[Pi]"}], "2"], ",", " ", 
        FractionBox[
         RowBox[{" ", "\[Pi]"}], "2"], ",", " ", 
        FractionBox[
         RowBox[{" ", "\[Pi]"}], "12"]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "5"}], ",", "5", ",", "1"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "5"}], ",", "5", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[1+z] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"1", "+", "z"}], "]"}], ",", 
      "\"\<,  where 0.3 < |z| < 0.9\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399366768171875*^9, 3.39936677184375*^9}, {
  3.3999151719375*^9, 3.3999151721875*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",
 InitializationCell->True]
}, Closed]]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{901, 635},
WindowMargins->{{28, Automatic}, {Automatic, 4}},
CellLabelAutoDelete->True,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 186, 3, 29, "Text"],
Cell[1737, 51, 3108, 109, 157, "Text",
 Evaluatable->False],
Cell[4848, 162, 457, 19, 40, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[5330, 185, 305, 9, 37, "Subsection",
 Evaluatable->False],
Cell[5638, 196, 384, 14, 40, "Text",
 Evaluatable->False],
Cell[6025, 212, 1936, 55, 255, "Input"],
Cell[7964, 269, 184, 5, 29, "Text",
 Evaluatable->False],
Cell[8151, 276, 1389, 40, 234, "Input"],
Cell[9543, 318, 167, 5, 29, "Text"],
Cell[9713, 325, 1618, 45, 132, "Input"],
Cell[11334, 372, 370, 12, 47, "Text"],
Cell[11707, 386, 3590, 96, 314, "Input"],
Cell[15300, 484, 3278, 86, 232, "Input"]
}, Closed]],
Cell[18593, 573, 1381, 42, 123, "Text",
 Evaluatable->False],
Cell[19977, 617, 2304, 78, 119, "Text",
 Evaluatable->False],
Cell[22284, 697, 2056, 72, 119, "Text"],
Cell[24343, 771, 1477, 51, 173, "Text",
 Evaluatable->False],
Cell[25823, 824, 529, 19, 29, "Text"],
Cell[26355, 845, 1466, 51, 47, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[27846, 900, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[27990, 906, 170, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[28175, 913, 1093, 33, 64, "Text",
 Evaluatable->False],
Cell[29271, 948, 4668, 168, 164, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[33964, 1120, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[34108, 1126, 170, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[34293, 1133, 2027, 69, 112, "Text"],
Cell[36323, 1204, 93, 2, 29, "Text"],
Cell[36419, 1208, 2299, 82, 173, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[38743, 1294, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[38887, 1300, 170, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[39072, 1307, 355, 9, 44, "Text"],
Cell[39430, 1318, 527, 19, 37, "Text",
 Evaluatable->False],
Cell[39960, 1339, 8512, 420, 209, "Text"],
Cell[48475, 1761, 1809, 72, 96, "Text"],
Cell[50287, 1835, 4873, 162, 173, "Text"],
Cell[55163, 1999, 1528, 54, 112, "Text"],
Cell[56694, 2055, 1165, 45, 77, "Text"],
Cell[57862, 2102, 1455, 53, 76, "Text"],
Cell[CellGroupData[{
Cell[59342, 2159, 272, 8, 37, "Subsection",
 Evaluatable->False],
Cell[59617, 2169, 156, 5, 29, "Text"],
Cell[59776, 2176, 2793, 73, 298, "Input"],
Cell[62572, 2251, 59, 0, 29, "Text"],
Cell[62634, 2253, 5185, 133, 324, "Input"],
Cell[67822, 2388, 408, 12, 73, "Text",
 Evaluatable->False],
Cell[68233, 2402, 887, 24, 150, "Input"],
Cell[69123, 2428, 194, 6, 29, "Text",
 Evaluatable->False],
Cell[69320, 2436, 921, 26, 132, "Input"],
Cell[70244, 2464, 823, 27, 77, "Text",
 Evaluatable->False],
Cell[71070, 2493, 702, 21, 92, "Input"],
Cell[71775, 2516, 822, 24, 65, "Text",
 Evaluatable->False],
Cell[72600, 2542, 1385, 38, 192, "Input"],
Cell[73988, 2582, 801, 29, 47, "Text",
 Evaluatable->False],
Cell[74792, 2613, 3196, 89, 352, "Input"],
Cell[CellGroupData[{
Cell[78013, 2706, 534, 21, 29, "Text",
 Evaluatable->False],
Cell[78550, 2729, 850, 22, 132, "Input"],
Cell[79403, 2753, 177, 6, 29, "Text"],
Cell[79583, 2761, 1712, 48, 132, "Input"],
Cell[81298, 2811, 404, 13, 47, "Text"],
Cell[81705, 2826, 3059, 79, 274, "Input"],
Cell[84767, 2907, 698, 27, 47, "Text"],
Cell[85468, 2936, 1753, 45, 193, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87258, 2986, 528, 20, 29, "Text"],
Cell[87789, 3008, 937, 24, 132, "Input"],
Cell[88729, 3034, 177, 6, 29, "Text"],
Cell[88909, 3042, 1626, 45, 152, "Input"],
Cell[90538, 3089, 521, 17, 47, "Text"],
Cell[91062, 3108, 3185, 83, 319, "Input"],
Cell[94250, 3193, 1128, 44, 55, "Text",
 Evaluatable->False],
Cell[95381, 3239, 903, 24, 152, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[96321, 3268, 499, 19, 29, "Text"],
Cell[96823, 3289, 828, 22, 132, "Input"],
Cell[97654, 3313, 177, 6, 29, "Text"],
Cell[97834, 3321, 1699, 47, 152, "Input"],
Cell[99536, 3370, 427, 14, 47, "Text"],
Cell[99966, 3386, 3047, 79, 253, "Input"],
Cell[103016, 3467, 610, 22, 47, "Text"],
Cell[103629, 3491, 1743, 44, 173, "Input"],
Cell[105375, 3537, 1097, 42, 55, "Text",
 Evaluatable->False],
Cell[106475, 3581, 1326, 35, 212, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[107838, 3621, 799, 29, 47, "Text",
 Evaluatable->False],
Cell[108640, 3652, 661, 18, 92, "Input"],
Cell[109304, 3672, 724, 19, 71, "Text",
 Evaluatable->False],
Cell[110031, 3693, 1300, 34, 212, "Input"]
}, Open  ]],
Cell[111346, 3730, 52, 0, 29, "Text"],
Cell[111401, 3732, 5756, 158, 372, "Input"]
}, Closed]],
Cell[117172, 3893, 537, 21, 33, "Text",
 Evaluatable->False],
Cell[117712, 3916, 4910, 171, 388, "Text"],
Cell[CellGroupData[{
Cell[122647, 4091, 278, 8, 37, "Subsection",
 Evaluatable->False],
Cell[122928, 4101, 422, 16, 36, "Text",
 Evaluatable->False],
Cell[123353, 4119, 1799, 52, 232, "Input"],
Cell[125155, 4173, 275, 9, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[125455, 4186, 2551, 74, 287, "Input"],
Cell[128009, 4262, 275, 7, 23, "Print"],
Cell[128287, 4271, 97, 1, 23, "Print"],
Cell[128387, 4274, 1028, 27, 44, "Print"],
Cell[129418, 4303, 97, 1, 23, "Print"],
Cell[129518, 4306, 491, 13, 40, "Print"],
Cell[130012, 4321, 98, 1, 23, "Print"],
Cell[130113, 4324, 491, 13, 40, "Print"]
}, Open  ]],
Cell[130619, 4340, 390, 15, 36, "Text"],
Cell[131012, 4357, 831, 24, 152, "Input"],
Cell[131846, 4383, 177, 6, 29, "Text"],
Cell[132026, 4391, 1718, 49, 152, "Input"],
Cell[133747, 4442, 189, 6, 29, "Text"],
Cell[133939, 4450, 3279, 86, 232, "Input"],
Cell[137221, 4538, 3642, 98, 344, "Input"]
}, Closed]],
Cell[140878, 4639, 514, 21, 35, "Text",
 Evaluatable->False],
Cell[141395, 4662, 2019, 74, 123, "Text"],
Cell[CellGroupData[{
Cell[143439, 4740, 278, 8, 37, "Subsection",
 Evaluatable->False],
Cell[143720, 4750, 416, 16, 41, "Text",
 Evaluatable->False],
Cell[144139, 4768, 1351, 39, 207, "Input"],
Cell[145493, 4809, 268, 7, 29, "Text",
 Evaluatable->False],
Cell[145764, 4818, 1525, 43, 209, "Input"],
Cell[147292, 4863, 352, 12, 65, "Text",
 Evaluatable->False],
Cell[147647, 4877, 1646, 46, 152, "Input"],
Cell[149296, 4925, 378, 12, 47, "Text"],
Cell[149677, 4939, 3509, 96, 253, "Input"]
}, Closed]],
Cell[153201, 5038, 435, 8, 26, "Text"],
Cell[CellGroupData[{
Cell[153661, 5050, 407, 7, 29, "Text"],
Cell[154071, 5059, 130, 3, 31, "Input",
 InitializationCell->True]
}, Closed]]
}
]
*)

(* End of internal cache information *)
