(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    230830,       6946]
NotebookOptionsPosition[    224229,       6742]
NotebookOutlinePosition[    224640,       6760]
CellTagsIndexPosition[    224597,       6757]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[StyleBox["Chapter 8  Residue Theory",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[StyleBox["8.1  The Residue Theorem",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.532709495109375*^9, 3.532709495953125*^9}}],

Cell[TextData[{
 StyleBox["Overview",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tWe now have the necessary machinery to see some amazing applications \
of the tools we developed in the last few chapters.  You will learn how \
Laurent expansions can give useful information concerning seemingly unrelated \
properties of complex functions.  You will also learn how the ideas of \
complex analysis make the solution of very complicated integrals of \
real-valued functions as easy - literally - as the computation of residues.  \
We begin with a theorem relating residues to the evaluation of complex \
integrals. "
}], "Text"],

Cell[TextData[{
 "\tThe ",
 StyleBox[ButtonBox["Cauchy",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cauchy.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " ",
 StyleBox[ButtonBox["integral formulae",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/CauchyIntegralFormula.html"], None}],
  FontVariations->{"Underline"->True}],
 " in Section 6.5 are useful in evaluating contour integrals over a simple \
closed contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " where the integrand has the form  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"z", " ", "-", " ", 
      SubscriptBox["z", "0"]}], ")"}], "k"]]]],
 "  and  f  is an analytic function.  In this case, the singularity of the \
integrand is at worst a pole of order ",
 StyleBox["k",
  FontFamily->"Courier New"],
 " at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  We begin this section by extending this result to integrals that have a \
finite number of isolated singularities inside the contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ".  This new method can be used in cases where the integrand has an \
essential singularity at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " and is an important extension of the previous method."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Definition 8.1 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Residue",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/ResidueComplexAnalysis.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " have a nonremovable isolated singularity at the point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  Then ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has the Laurent series representation for all z in some disk ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["D", "R", "*"], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 "given by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", 
      RowBox[{"-", "\[Infinity]"}]}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["a", "n"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["z", "0"]}], ")"}], "n"]}]}]}]]],
 ".  \n\nThe coefficient  ",
 Cell[BoxData[
  SubscriptBox["a", 
   RowBox[{"-", "1"}]]]],
 "  of  ",
 Cell[BoxData[
  FractionBox["1", 
   RowBox[{"z", " ", "-", " ", 
    SubscriptBox["z", "0"]}]]]],
 "  is called the residue of ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " and we use the notation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{"f", ",", 
     SubscriptBox["z", "0"]}], "]"}], "=", 
   SubscriptBox["a", 
    RowBox[{"-", "1"}]]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 8.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   SuperscriptBox["\[ExponentialE]", 
    FractionBox["2", "z"]]}]],
  AspectRatioFixed->False],
 ",  then the Laurent series of f about the point ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 " has the form   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"1", " ", "+", " ", 
     RowBox[{"2", 
      FractionBox["1", "z"]}], " ", "+", " ", 
     FractionBox[
      SuperscriptBox["2", "2"], 
      RowBox[{
       RowBox[{"2", "!"}], 
       SuperscriptBox["z", "2"]}]], " ", "+", " ", 
     FractionBox[
      SuperscriptBox["2", "3"], 
      RowBox[{
       RowBox[{"3", "!"}], " ", 
       SuperscriptBox["z", "3"]}]], " ", "+", " ", 
     FractionBox[
      SuperscriptBox["2", "4"], 
      RowBox[{
       RowBox[{"4", "!"}], " ", 
       SuperscriptBox["z", "4"]}]], " ", "+", " ", 
     FractionBox[
      SuperscriptBox["2", "5"], 
      RowBox[{
       RowBox[{"5", "!"}], " ", 
       SuperscriptBox["z", "5"]}]], " ", "+"}], "..."}]}]]],
 ",  and\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{"f", ",", "0"}], "]"}], "  ", "=", "  ", 
   RowBox[{
    SubscriptBox["a", 
     RowBox[{"-", "1"}]], "  ", "=", "  ", "2"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"8.1", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506705466671875*^9, 3.506705466671875*^9}}],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   SuperscriptBox["\[ExponentialE]", 
    FractionBox["2", "z"]]}]],
  AspectRatioFixed->False],
 "  and construct the Laurent series about ",
 " z = 0. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"z", "=", "0"}], ";", " ", 
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Res", ",", "S"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox["2", "z"]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "\[Infinity]", ",", "5"}], "}"}]}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39997177240625*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "The coefficient of  ",
 Cell[BoxData[
  FractionBox["1", "z"]]],
 "  is  2  so the residue is Res[f, 0] = 2."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        SubscriptBox["a", "n"], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "0", ",", 
          RowBox[{"-", "5"}], ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}], ",", "\"\<  =  \>\"", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{
          RowBox[{"f", "[", "z", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"z", ",", "\[Infinity]", ",", "n"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "0", ",", 
          RowBox[{"-", "5"}], ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"k", "=", 
       RowBox[{"-", "5"}]}], ",", 
      RowBox[{"k", "\[LessEqual]", "0"}], ",", 
      RowBox[{"k", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Print", "[", " ", 
        RowBox[{
         SubscriptBox["\"\<a\>\"", "k"], ",", "\"\<  =  \>\"", ",", 
         RowBox[{"SeriesCoefficient", "[", 
          RowBox[{
           RowBox[{"f", "[", "z", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"z", ",", "\[Infinity]", ",", "k"}], "}"}]}], "]"}]}], 
        "]"}], ";"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Looking at this list of coefficients, we see that\>\"",
      "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(a\), \(-1\)]\) = \>\"", ",", 
      RowBox[{"SeriesCoefficient", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "\[Infinity]", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39997180103125*^9, 3.399971883953125*^9}, {
   3.399971926390625*^9, 3.399971927703125*^9}, {3.399972001296875*^9, 
   3.39997200346875*^9}, {3.39997203740625*^9, 3.3999721041875*^9}, {
   3.39997261478125*^9, 3.399972627078125*^9}, {3.399978563109375*^9, 
   3.399978685015625*^9}, 3.39997872603125*^9, {3.39997878790625*^9, 
   3.39997881203125*^9}, {3.399979041875*^9, 3.399979046171875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Res", " ", "=", " ", 
     RowBox[{"SeriesCoefficient", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "\[Infinity]", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,0] = Res[\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<,0] = \!\(\*SubscriptBox[\(a\), \(-1\)]\) = \>\"", ",", "Res"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.399972115828125*^9, {3.399979464046875*^9, 3.399979483625*^9}, {
   3.399981728625*^9, 3.399981732578125*^9}}],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can verify this computation with ",
 StyleBox["Mathematica'",
  FontSlant->"Italic"],
 "s built in \"Residue\" procedure. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Res", "=", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0"}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,0] = Res[\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<,0] = \>\"", ",", "Res"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Res", " ", "=", " ", 
      RowBox[{"SeriesCoefficient", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "\[Infinity]", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";"}], " ", ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,0] = Res[\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<,0] = \>\"", ",", "Res"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399966904640625*^9, 3.399966917375*^9}, {
  3.399972129984375*^9, 3.399972130703125*^9}, {3.399979500921875*^9, 
  3.399979513484375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 8.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find  ",
 Cell[BoxData[
  RowBox[{"Res", "[", 
   RowBox[{"g", ",", 
    SubscriptBox["z", "0"]}], "]"}]]],
 "  if  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["3", 
    RowBox[{
     RowBox[{"2", "z"}], " ", "+", " ", 
     SuperscriptBox["z", "2"], " ", "-", " ", 
     SuperscriptBox["z", "3"]}]]}]],
  AspectRatioFixed->False],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Solution.  Using Example 7.7, we find that ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " has three Laurent series representations involving powers of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ".  The Laurent series valid in the punctured disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["D", "1", "*"], 
    RowBox[{"(", "0", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", 
     RowBox[{
      RowBox[{"0", "<"}], "|", "z", "|", 
      RowBox[{"<", "1"}]}]}], "}"}]}]]],
 "  is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "n"], "+", 
        FractionBox["1", 
         SuperscriptBox["2", 
          RowBox[{"n", "+", "1"}]]]}], ")"}], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], "  ", "=", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "n"], 
         SuperscriptBox["2", 
          RowBox[{"n", "+", "1"}]]}], " ", "+", " ", "1"}], 
       SuperscriptBox["2", 
        RowBox[{"n", "+", "1"}]]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}]}]}]]],
 ".  \n\nComputing the first few coefficients, we obtain  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "0"], 
        SuperscriptBox["2", "1"]}], "+", "1"}], "2"], 
     FractionBox["1", "z"]}], " ", "+", " ", 
    FractionBox[
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "1"], 
       SuperscriptBox["2", "2"]}], "+", "1"}], 
     SuperscriptBox["2", "2"]], " ", "+", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "2"], 
        SuperscriptBox["2", "3"]}], "+", "1"}], 
      SuperscriptBox["2", "3"]], "z"}], " ", "+", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "3"], 
        SuperscriptBox["2", "4"]}], "+", "1"}], 
      SuperscriptBox["2", "4"]], 
     SuperscriptBox["z", 
      RowBox[{"2", " "}]]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"                   ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"+", " ", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "4"], 
          SuperscriptBox["2", "5"]}], "+", "1"}], 
        SuperscriptBox["2", "5"]]}], 
      SuperscriptBox["z", "3"]}], "+", " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "5"], 
         SuperscriptBox["2", "6"]}], "+", "1"}], 
       SuperscriptBox["2", "6"]], 
      SuperscriptBox["z", "4"]}], " ", "+", " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "n"], 
         SuperscriptBox["2", 
          RowBox[{"n", "+", "1"}]]}], " ", "+", " ", "1"}], 
       SuperscriptBox["2", 
        RowBox[{"n", "+", "1"}]]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], " ", "+"}], " ", "..."}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["3", "2"], 
       FractionBox["1", "z"]}], " ", "-", " ", 
      FractionBox["3", 
       SuperscriptBox["2", "2"]], " ", "+", " ", 
      RowBox[{
       FractionBox["9", 
        SuperscriptBox["2", "3"]], "z"}], " ", "-", " ", 
      RowBox[{
       FractionBox["15", 
        SuperscriptBox["2", "4"]], 
       SuperscriptBox["z", "2"]}], " ", "+", " ", 
      RowBox[{
       FractionBox["33", 
        SuperscriptBox["2", "5"]], 
       SuperscriptBox["z", "3"]}], " ", "-", " ", 
      RowBox[{
       FractionBox["63", 
        SuperscriptBox["2", "6"]], 
       SuperscriptBox["z", "4"]}], "  ", "+"}], " ", "..."}]}]}]}]],
 "\n\nTherefore,   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{"f", ",", "0"}], "]"}], "  ", "=", "  ", 
   RowBox[{
    SubscriptBox["a", 
     RowBox[{"-", "1"}]], "  ", "=", "  ", 
    FractionBox["3", "2"]}]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"8.2", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506705471015625*^9, 3.506705471015625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"z", "=", "0"}], ";", " ", 
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "n"], "+", 
         FractionBox["1", 
          SuperscriptBox["2", 
           RowBox[{"n", "+", "1"}]]]}], ")"}], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)((-1\!\(\*SuperscriptBox[\()\), \(n\)]\)+\!\(\*FractionBox[\
\(1\), SuperscriptBox[\(2\), \(n + 1\)]]\))\!\(\*SuperscriptBox[\(z\), \(n - \
1\)]\)  = \>\"", ",", " ", 
      RowBox[{"g", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], " ", "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"g", "[", "z", "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)((-1\!\(\*SuperscriptBox[\()\), \(n\)]\)+\!\(\*FractionBox[\
\(1\), SuperscriptBox[\(2\), \(n + 1\)]]\))\!\(\*SuperscriptBox[\(z\), \(n - \
1\)]\)  = \>\"", ",", " ", 
      RowBox[{"g", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], " ", "=", 
     RowBox[{
      RowBox[{"Numerator", "[", 
       RowBox[{"g", "[", "z", "]"}], "]"}], "/", 
      RowBox[{"Expand", "[", 
       RowBox[{"Denominator", "[", 
        RowBox[{"FullSimplify", "[", 
         RowBox[{"g", "[", "z", "]"}], "]"}], "]"}], "]"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)((-1\!\(\*SuperscriptBox[\()\), \(n\)]\)+\!\(\*FractionBox[\
\(1\), SuperscriptBox[\(2\), \(n + 1\)]]\))\!\(\*SuperscriptBox[\(z\), \(n - \
1\)]\)  = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399972134890625*^9, 3.399972136921875*^9}}],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", "[", "z", "]"}], "=", 
   FractionBox["3", 
    RowBox[{
     RowBox[{"2", "z"}], " ", "+", " ", 
     SuperscriptBox["z", "2"], " ", "-", " ", 
     SuperscriptBox["z", "3"]}]]}]],
  AspectRatioFixed->False],
 "  and construct the Laurent series about  z = 0. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"g", ",", "Res", ",", "S", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox["3", 
      RowBox[{
       RowBox[{"2", "z"}], " ", "+", " ", 
       SuperscriptBox["z", "2"], " ", "-", " ", 
       SuperscriptBox["z", "3"]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"g", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0", ",", "6"}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[z] = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39997214253125*^9, 3.399972145625*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 "The coefficient of  ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", "z"], "  ", "is", "  ", 
   FractionBox["3", "2"]}]]],
 "  so the residue is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{"g", ",", "0"}], "]"}], "=", 
   FractionBox["3", "2"]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        SubscriptBox["a", "n"], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", 
          RowBox[{"-", "1"}], ",", "6", ",", "1"}], "}"}]}], "]"}], ",", 
      "\"\<  =  \>\"", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{
          RowBox[{"g", "[", "z", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"z", ",", "0", ",", "n"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", 
          RowBox[{"-", "1"}], ",", "6", ",", "1"}], "}"}]}], "]"}]}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"k", "=", "6"}], ",", 
      RowBox[{"k", "\[GreaterEqual]", 
       RowBox[{"-", "1"}]}], ",", 
      RowBox[{"k", "--"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Print", "[", " ", 
        RowBox[{
         SubscriptBox["\"\<a\>\"", "k"], ",", "\"\<  =  \>\"", ",", 
         RowBox[{"SeriesCoefficient", "[", 
          RowBox[{
           RowBox[{"g", "[", "z", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"z", ",", "0", ",", "k"}], "}"}]}], "]"}]}], "]"}], 
       ";"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Looking at this list of coefficients, we see that\>\"",
      "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(a\), \(-1\)]\) = \>\"", ",", 
      RowBox[{"SeriesCoefficient", "[", 
       RowBox[{
        RowBox[{"g", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39997180103125*^9, 3.399971883953125*^9}, {
   3.399971926390625*^9, 3.399971927703125*^9}, {3.399972001296875*^9, 
   3.39997200346875*^9}, {3.39997203740625*^9, 3.3999721041875*^9}, {
   3.39997261478125*^9, 3.399972627078125*^9}, {3.399978563109375*^9, 
   3.399978685015625*^9}, 3.39997872603125*^9, {3.39997878790625*^9, 
   3.39997881203125*^9}, {3.39997885446875*^9, 3.39997885796875*^9}, {
   3.39997889609375*^9, 3.399978922765625*^9}, {3.39997898590625*^9, 
   3.399978988015625*^9}, {3.39997906775*^9, 3.39997909425*^9}, {
   3.39998177009375*^9, 3.399981790484375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Res", " ", "=", " ", 
     RowBox[{"SeriesCoefficient", "[", 
      RowBox[{
       RowBox[{"g", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[g,0] = Res[\>\"", ",", 
      RowBox[{"g", "[", "z", "]"}], ",", " ", 
      "\"\<,0] = \!\(\*SubscriptBox[\(a\), \(-1\)]\) = \>\"", ",", "Res"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.399972150203125*^9, 3.39997956171875*^9, {3.39998181775*^9, 
   3.39998184809375*^9}}],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can verify this computation with ",
 StyleBox["Mathematica'",
  FontSlant->"Italic"],
 "s built in \"Residue\" procedure. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Res", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"g", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0"}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[g,0] = Res[\>\"", ",", 
      RowBox[{"g", "[", "z", "]"}], ",", "\"\<,0] = \>\"", ",", "Res"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.39997958375*^9, {3.399981864234375*^9, 3.39998187678125*^9}}]
}, Closed]],

Cell[TextData[{
 "\tRecall that, for a function ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " analytic in ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["D", "R", "*"], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 " and for any r with ",
 Cell[BoxData[
  RowBox[{"0", "<", "r", "<", "R"}]]],
 ", the Laurent series coefficients of ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " are given by  \n\n",
 StyleBox["(8-1)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "n"], "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
    RowBox[{
     SubscriptBox["\[Integral]", 
      RowBox[{
       SubsuperscriptBox["C", "r", "+"], 
       RowBox[{"(", 
        SubscriptBox["z", "0"], ")"}]}]], 
     RowBox[{
      FractionBox[
       RowBox[{"f", 
        RowBox[{"(", "\[Xi]", ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"\[Xi]", " ", "-", " ", 
          SubscriptBox["z", "0"]}], ")"}], 
        RowBox[{"n", "+", "1"}]]], 
      RowBox[{"\[DifferentialD]", "\[Xi]"}]}]}]}]}]]],
 "    for    ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"n", "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"\[PlusMinus]", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"\[PlusMinus]", "2"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "..."}]]],
 ",  \n  \n  where ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["C", "r", "+"], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 " denotes the circle ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["C", "r", "+"], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", ":", " ", 
      RowBox[{"|", 
       RowBox[{"z", "-", 
        SubscriptBox["z", "0"]}], "|"}]}], "=", "r"}], "}"}]}]]],
 " with positive orientation.  This gives us an important fact concerning  ",
 Cell[BoxData[
  RowBox[{"Res", "[", 
   RowBox[{"f", ",", 
    SubscriptBox["z", "0"]}], "]"}]]],
 ".  If we set  ",
 Cell[BoxData[
  RowBox[{"n", "=", 
   RowBox[{"-", "1"}]}]]],
 "  in Equation ",
 StyleBox["(8-1)",
  FontColor->RGBColor[0, 0, 1]],
 " and replace ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["C", "r", "+"], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 " with any positively oriented simple closed contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " containing ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", provided ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " is the still only singularity of ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " that lies inside ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", then we obtain  \n\n",
 StyleBox["(8-2)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
     SubscriptBox["a", 
      RowBox[{"-", "1"}]]}], "  ", "=", "  ", 
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
     RowBox[{"Res", "[", 
      RowBox[{"f", ",", 
       SubscriptBox["z", "0"]}], "]"}]}]}]}]]],
 ".  \n\nIf we are able to find the Laurent series expansion for ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 ", then above equation gives us an important tool for evaluating contour \
integrals.  "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 8.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Evaluate  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Integral]", 
    RowBox[{" ", 
     RowBox[{
      SubsuperscriptBox["C", "1", "+"], 
      RowBox[{"(", "0", ")"}]}]}]], " ", 
   RowBox[{"exp", 
    RowBox[{"(", 
     FractionBox["2", "z"], ")"}], 
    RowBox[{"\[DifferentialD]", "z"}]}]}]]],
 "  where ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["C", "1", "+"], 
   RowBox[{"(", "0", ")"}]}]]],
 " denotes the circle ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["C", "1", "+"], 
    RowBox[{"(", "0", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", ":", " ", 
      RowBox[{"|", "z", "|"}]}], "=", "1"}], "}"}]}]]],
 " with positive orientation.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{305, 195},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  In Example 8.1 we showed that the residue of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   SuperscriptBox["\[ExponentialE]", 
    FractionBox["2", "z"]]}]],
  AspectRatioFixed->False],
 "  at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 "  is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{"f", ",", "0"}], "]"}], " ", "=", " ", "2"}]]],
 ".  Using Equation ",
 StyleBox["(8-2)",
  FontColor->RGBColor[0, 0, 1]],
 ", we get  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", 
     RowBox[{" ", 
      RowBox[{
       SubsuperscriptBox["C", "1", "+"], 
       RowBox[{"(", "0", ")"}]}]}]], " ", 
    RowBox[{"exp", 
     RowBox[{"(", 
      FractionBox["2", "z"], ")"}], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
     RowBox[{"Res", "[", 
      RowBox[{"f", ",", "0"}], "]"}]}], "  ", "=", "  ", 
    RowBox[{"4", "\[Pi]", " ", "\[ImaginaryI]"}]}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"8.3", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506705474703125*^9, 3.506705474703125*^9}}],

Cell["From Example 8.1  we have  Res[f,0]  =  2.", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"z", "=", "0"}], ";", " ", 
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Res", ",", "val"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox["2", "z"]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Res", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0"}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,0] = Res[\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<,0] = \>\"", ",", "Res"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Res", "=", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"Series", "[", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          FractionBox["2", "z"]], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "\[Infinity]", ",", "5"}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0"}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,0] = Res[\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<,0] = \>\"", ",", "Res"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399966985359375*^9, 3.399966986203125*^9}, 
   3.39997226225*^9},
 AspectRatioFixed->True],

Cell["\<\
Thus the value of the contour integral is given by the following computation.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "Res"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], "=", "0"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,0] = Res[\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<,0] = \>\"", ",", "Res"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Red", ",", 
         RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "1"], "]"}], ",", 
            RowBox[{"Im", "[", 
             SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"center", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            SubscriptBox["Z", "1"], "]"}], ",", 
           RowBox[{
            RowBox[{"Im", "[", 
             SubscriptBox["Z", "1"], "]"}], "+", "0.05"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dot", ",", "center", ",", "contour", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", 
          FractionBox["1", "2"]}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) \>\"", ",", 
     RowBox[{"f", "[", "z", "]"}], ",", 
     "\"\< \[DifferentialD]z = 2\[Pi]\[ImaginaryI] Res[\>\"", ",", 
     RowBox[{"f", "[", "z", "]"}], ",", "\"\<,0] = \>\"", ",", "val"}], "]"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The contour is the unit circle  C:|z| = 1,\>\"", "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<with positive orientation.\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399966246375*^9, 3.39996624675*^9}, {
   3.399967004671875*^9, 3.399967004921875*^9}, 3.399972273796875*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Theorem 8.1 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Cauchy's Residue Theorem",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/ResidueTheorem.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " be a simply connected domain, and let ",
 StyleBox["C",
  FontFamily->"Courier New"],
 "  be a simple closed positively oriented contour that lies in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  If ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is analytic inside ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " and on ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ",  except at the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "n"]}]]],
 "  that lie inside ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "1"}], "n"], 
     RowBox[{"Res", "[", 
      RowBox[{"f", ",", 
       SubscriptBox["z", "k"]}], "]"}]}]}]}]]],
 ".  \n\nThe situation is illustrated in Figure 8.1."
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{3.39946385946875*^9},
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 8.1 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{486, 245},
  ImageMargins->0],
 StyleBox[" \n",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\t Figure 8.1 ",
 "The domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " and contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " and the singular points ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "n"]}]]],
 " in the statement of Cauchy's residue theorem."
}], "Text",
 CellChangeTimes->{
  3.399463682328125*^9, {3.399463806703125*^9, 3.39946381471875*^9}, {
   3.50676213909375*^9, 3.506762142109375*^9}}],

Cell[TextData[{
 "\tThe calculation of a ",
 StyleBox[ButtonBox["Laurent",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Laurent_\
Pierre.html"], None}],
  FontVariations->{"Underline"->True}],
 " ",
 StyleBox[ButtonBox["series",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/LaurentSeries.html"], None}],
  FontVariations->{"Underline"->True}],
 " expansion is tedious in most circumstances.  Since the residue at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " involves only the coefficient ",
 Cell[BoxData[
  SubscriptBox["a", 
   RowBox[{"-", "1"}]]]],
 " in the Laurent expansion, we seek a method to calculate the residue from \
special information about the nature of the singularity at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".\n\n\tIf ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has a removable singularity at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", then  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", 
    RowBox[{"-", "1"}]], "=", "0"}]]],
 "  for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"n", "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "2", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "..."}]]],
 ".  Therefore,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{"f", ",", 
     SubscriptBox["z", "0"]}], "]"}], "=", "0"}]]],
 ".  Theorem 8.2 gives methods for evaluating residues at poles."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Theorem 8.2 (Residues at Poles).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n",
  FontColor->RGBColor[1, 0, 1]],
 "\n",
 StyleBox["(i)  ",
  FontColor->RGBColor[0, 0, 1]],
 "\tIf ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has a simple pole at  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{"f", ",", 
     SubscriptBox["z", "0"]}], "]"}], " ", "=", " ", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", " ", "\[Rule]", " ", 
      SubscriptBox["z", "0"]}]], " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "-", 
       SubscriptBox["z", "0"]}], ")"}], "f", 
     RowBox[{"(", "z", ")"}]}]}]}]]],
 ".  \n\n",
 StyleBox["(ii) ",
  FontColor->RGBColor[0, 0, 1]],
 "\tIf ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has a pole of order ",
 StyleBox["2",
  FontFamily->"Courier New"],
 " at  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{"f", ",", 
     SubscriptBox["z", "0"]}], "]"}], " ", "=", " ", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", " ", "\[Rule]", " ", 
      SubscriptBox["z", "0"]}]], " ", 
    RowBox[{
     FractionBox["d", "dz"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SubscriptBox["z", "0"]}], ")"}], "2"], "f", 
       RowBox[{"(", "z", ")"}]}], ")"}]}]}]}]]],
 ".  \n\n",
 StyleBox["(iii)",
  FontColor->RGBColor[0, 0, 1]],
 " \tIf ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has a pole of order ",
 StyleBox["3",
  FontFamily->"Courier New"],
 " at  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{"f", ",", 
     SubscriptBox["z", "0"]}], "]"}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "!"}]], 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "0"]}]], " ", 
     RowBox[{
      FractionBox[
       SuperscriptBox["d", "2"], 
       SuperscriptBox["dz", "2"]], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", 
           SubscriptBox["z", "0"]}], ")"}], "3"], "f", 
        RowBox[{"(", "z", ")"}]}], ")"}]}]}]}]}]]],
 ".  \n\n",
 StyleBox["(v) ",
  FontColor->RGBColor[0, 0, 1]],
 "\tIf ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has a pole of order ",
 StyleBox["k",
  FontFamily->"Courier New"],
 " at  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{"f", ",", 
     SubscriptBox["z", "0"]}], "]"}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"k", "-", "1"}], ")"}], "!"}]], 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "0"]}]], " ", 
     RowBox[{
      FractionBox[
       SuperscriptBox["d", 
        RowBox[{"k", "-", "1"}]], 
       SuperscriptBox["dz", 
        RowBox[{"k", "-", "1"}]]], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", 
           SubscriptBox["z", "0"]}], ")"}], "k"], "f", 
        RowBox[{"(", "z", ")"}]}], ")"}]}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Proof of Theorem 8.2",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 StyleBox[" is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 8.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the residue of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{"\[Pi]", " ", "cot", " ", 
     RowBox[{"(", 
      RowBox[{"\[Pi]", " ", "z"}], ")"}]}], 
    SuperscriptBox["z", "2"]]}]]],
 "  at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Solution.  We write  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"\[Pi]", " ", "cot", " ", 
      RowBox[{"(", 
       RowBox[{"\[Pi]", " ", "z"}], ")"}]}], 
     SuperscriptBox["z", "2"]], " ", "=", " ", 
    FractionBox[
     RowBox[{"\[Pi]", " ", "cos", " ", 
      RowBox[{"(", 
       RowBox[{"\[Pi]", " ", "z"}], ")"}]}], 
     RowBox[{
      SuperscriptBox["z", "2"], "sin", " ", 
      RowBox[{"(", 
       RowBox[{"\[Pi]", " ", "z"}], ")"}]}]]}]}]]],
 ".  Because  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "2"], "sin", " ", 
   RowBox[{"(", 
    RowBox[{"\[Pi]", " ", "z"}], ")"}]}]]],
 "  has a zero of order ",
 StyleBox["3",
  FontFamily->"Courier New"],
 " at ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 " and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Pi]", " ", "cot", " ", 
    RowBox[{"(", 
     RowBox[{"\[Pi]", " ", "z"}], ")"}]}], "\[NotEqual]", "0"}]]],
 ".  Thus ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has a pole of order ",
 StyleBox["3",
  FontFamily->"Courier New"],
 " at ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 ".  By part ",
 StyleBox["(iii)",
  FontColor->RGBColor[0, 0, 1]],
 " of Theorem 8.2, we have  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", "0"}], "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "!"}]], 
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
       RowBox[{
        FractionBox[
         SuperscriptBox["d", "2"], 
         SuperscriptBox["dz", "2"]], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "3"], "f", 
          RowBox[{"(", "z", ")"}]}], ")"}]}]}]}], " ", "=", " ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "!"}]], 
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
       RowBox[{
        FractionBox[
         SuperscriptBox["d", "2"], 
         SuperscriptBox["dz", "2"]], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "3"], 
          FractionBox[
           RowBox[{"\[Pi]", " ", "cot", " ", 
            RowBox[{"(", 
             RowBox[{"\[Pi]", " ", "z"}], ")"}]}], 
           SuperscriptBox["z", "2"]]}], ")"}]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "!"}]], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      RowBox[{
       FractionBox[
        SuperscriptBox["d", "2"], 
        SuperscriptBox["dz", "2"]], 
       RowBox[{"(", 
        RowBox[{"\[Pi]", " ", "z", " ", "cot", " ", 
         RowBox[{"(", 
          RowBox[{"\[Pi]", " ", "z"}], ")"}]}], ")"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "!"}]], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      RowBox[{
       FractionBox["d", "dz"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Pi]", " ", "cot", 
          RowBox[{"(", 
           RowBox[{"\[Pi]", " ", "z"}], ")"}]}], " ", "-", " ", 
         RowBox[{
          SuperscriptBox["\[Pi]", "2"], " ", "z", " ", 
          SuperscriptBox["csc", "2"], 
          RowBox[{"(", 
           RowBox[{"\[Pi]", " ", "z"}], ")"}]}]}], ")"}]}]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "!"}]], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[Pi]", "2"]}], " ", 
         SuperscriptBox["csc", "2"], 
         RowBox[{"(", 
          RowBox[{"\[Pi]", " ", "z"}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["\[Pi]", "2"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["csc", "2"], 
            RowBox[{"(", 
             RowBox[{"\[Pi]", " ", "z"}], ")"}]}], "-", 
           RowBox[{"2", "\[Pi]", " ", "z", " ", 
            SuperscriptBox["csc", "2"], 
            RowBox[{"(", 
             RowBox[{"\[Pi]", " ", "z"}], ")"}], "cot", 
            RowBox[{"(", 
             RowBox[{"\[Pi]", " ", "z"}], ")"}]}]}], ")"}]}]}], ")"}]}]}]}], 
   " ", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "!"}]], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["\[Pi]", "3"], " ", "z", " ", "cot", 
         RowBox[{"(", 
          RowBox[{"\[Pi]", " ", "z"}], ")"}], " ", 
         SuperscriptBox["csc", "2"], 
         RowBox[{"(", 
          RowBox[{"\[Pi]", " ", "z"}], ")"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Pi]", "2"], " ", 
         SuperscriptBox["csc", "2"], 
         RowBox[{"(", 
          RowBox[{"\[Pi]", " ", "z"}], ")"}]}]}], ")"}]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", " ", 
    RowBox[{
     SuperscriptBox["\[Pi]", "2"], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Pi]", " ", "z", " ", "cot", 
         RowBox[{"(", 
          RowBox[{"\[Pi]", " ", "z"}], ")"}], " ", 
         SuperscriptBox["csc", "2"], 
         RowBox[{"(", 
          RowBox[{"\[Pi]", " ", "z"}], ")"}]}], "-", " ", 
        RowBox[{
         SuperscriptBox["csc", "2"], 
         RowBox[{"(", 
          RowBox[{"\[Pi]", " ", "z"}], ")"}]}]}], ")"}]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", " ", 
    RowBox[{
     SuperscriptBox["\[Pi]", "2"], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Pi]", " ", "z", " ", "cot", 
          RowBox[{"(", 
           RowBox[{"\[Pi]", " ", "z"}], ")"}]}], "-", "1"}], ")"}], " ", 
       SuperscriptBox["csc", "2"], 
       RowBox[{"(", 
        RowBox[{"\[Pi]", " ", "z"}], ")"}]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", " ", 
    RowBox[{
     SuperscriptBox["\[Pi]", "2"], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Pi]", " ", "z", " ", "cot", 
           RowBox[{"(", 
            RowBox[{"\[Pi]", " ", "z"}], ")"}]}], "-", "1"}], ")"}], " ", 
        "sin", 
        RowBox[{"(", 
         RowBox[{"\[Pi]", " ", "z"}], ")"}]}], 
       RowBox[{" ", 
        RowBox[{
         SuperscriptBox["sin", "3"], 
         RowBox[{"(", 
          RowBox[{"\[Pi]", " ", "z"}], ")"}]}]}]]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", " ", 
    RowBox[{
     SuperscriptBox["\[Pi]", "2"], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"\[Pi]", " ", "z", " ", "cos", 
         RowBox[{"(", 
          RowBox[{"\[Pi]", " ", "z"}], ")"}]}], "-", 
        RowBox[{"sin", 
         RowBox[{"(", 
          RowBox[{"\[Pi]", " ", "z"}], ")"}], " "}]}], 
       RowBox[{" ", 
        RowBox[{
         SuperscriptBox["sin", "3"], 
         RowBox[{"(", 
          RowBox[{"\[Pi]", " ", "z"}], ")"}]}]}]], "  "}]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "This last limit involves an indeterminate form, which we evaluate by using \
L'H\[OHat]pital's rule:  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", "0"}], "]"}], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["\[Pi]", "2"], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"\[Pi]", " ", "z", " ", "cos", 
         RowBox[{"(", 
          RowBox[{"\[Pi]", " ", "z"}], ")"}]}], " ", "-", " ", 
        RowBox[{"sin", 
         RowBox[{"(", 
          RowBox[{"\[Pi]", " ", "z"}], ")"}], " "}]}], 
       RowBox[{" ", 
        RowBox[{
         SuperscriptBox["sin", "3"], 
         RowBox[{"(", 
          RowBox[{"\[Pi]", " ", "z"}], ")"}]}]}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"  ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SuperscriptBox["\[Pi]", "2"], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[Pi]", "2"]}], " ", "z", " ", "sin", 
         RowBox[{"(", 
          RowBox[{"\[Pi]", " ", "z"}], ")"}]}], " ", "+", " ", 
        RowBox[{"\[Pi]", " ", "cos", 
         RowBox[{"(", 
          RowBox[{"\[Pi]", " ", "z"}], ")"}]}], " ", "-", " ", 
        RowBox[{"\[Pi]", " ", "cos", 
         RowBox[{"(", 
          RowBox[{"\[Pi]", " ", "z"}], ")"}]}]}], 
       RowBox[{"3", " ", "\[Pi]", " ", "cos", 
        RowBox[{"(", 
         RowBox[{"\[Pi]", " ", "z"}], ")"}], " ", 
        SuperscriptBox["sin", "2"], 
        RowBox[{"(", 
         RowBox[{"\[Pi]", " ", "z"}], ")"}]}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"  ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SuperscriptBox["\[Pi]", "2"], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Pi]", "2"]}], " ", "z", " ", "sin", 
        RowBox[{"(", 
         RowBox[{"\[Pi]", " ", "z"}], ")"}]}], 
       RowBox[{"3", " ", "\[Pi]", " ", "cos", 
        RowBox[{"(", 
         RowBox[{"\[Pi]", " ", "z"}], ")"}], " ", 
        SuperscriptBox["sin", "2"], 
        RowBox[{"(", 
         RowBox[{"\[Pi]", " ", "z"}], ")"}]}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"  ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SuperscriptBox["\[Pi]", "2"], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "\[Pi]"}], " ", "z"}], 
       RowBox[{"3", " ", "cos", 
        RowBox[{"(", 
         RowBox[{"\[Pi]", " ", "z"}], ")"}], " ", "sin", 
        RowBox[{"(", 
         RowBox[{"\[Pi]", " ", "z"}], ")"}]}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"  ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"-", 
       SuperscriptBox["\[Pi]", "2"]}], "3"], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      FractionBox[
       RowBox[{"\[Pi]", " ", "z"}], 
       RowBox[{"cos", 
        RowBox[{"(", 
         RowBox[{"\[Pi]", " ", "z"}], ")"}], " ", "sin", 
        RowBox[{"(", 
         RowBox[{"\[Pi]", " ", "z"}], ")"}]}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"  ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"-", 
       SuperscriptBox["\[Pi]", "2"]}], "3"], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      RowBox[{
       FractionBox[
        RowBox[{"\[Pi]", " ", "z"}], 
        RowBox[{"sin", 
         RowBox[{"(", 
          RowBox[{"\[Pi]", " ", "z"}], ")"}]}]], 
       RowBox[{
        UnderscriptBox["lim", 
         RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
        FractionBox["1", 
         RowBox[{"cos", 
          RowBox[{"(", 
           RowBox[{"\[Pi]", " ", "z"}], ")"}]}]]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"  ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"-", 
        SuperscriptBox["\[Pi]", "2"]}], "3"], 
      RowBox[{"(", "1", ")"}], 
      RowBox[{"(", "1", ")"}]}], "  ", "=", "  ", 
     RowBox[{"-", 
      FractionBox[
       SuperscriptBox["\[Pi]", "2"], "3"]}]}]}]}]}]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"8.4", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.5067054798125*^9, 3.5067054798125*^9}}],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{"\[Pi]", " ", 
     RowBox[{"Cot", "[", 
      RowBox[{"\[Pi]", " ", "z"}], "]"}]}], 
    SuperscriptBox["z", "2"]]}]],
  AspectRatioFixed->False],
 ".   "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"z", "=", "0"}], ";", " ", 
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Res", ",", "S"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"\[Pi]", " ", 
       RowBox[{"Cot", "[", 
        RowBox[{"\[Pi]", " ", "z"}], "]"}]}], 
      SuperscriptBox["z", "2"]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399972285421875*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "The function  f[z]  has a pole of order  3  at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 ".  The residue is computed using Theorem 8.2 (c)."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ResLim", "=", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "!"}]], " ", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"z", ",", "z"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "3"], " ", 
           RowBox[{"f", "[", "z", "]"}]}], ")"}]}], ",", 
        RowBox[{"z", "\[Rule]", "0"}]}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      \!\(\*SuperscriptBox[\(z\), \(3\)]\)f[z] = \>\"", ",", 
      RowBox[{
       SuperscriptBox["z", "3"], " ", 
       RowBox[{"f", "[", "z", "]"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*SubscriptBox[\(\[PartialD]\), \(z\)]\) \
(\!\(\*SuperscriptBox[\(z\), \(3\)]\)f[z]) = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "z"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "3"], 
         RowBox[{"f", "[", "z", "]"}]}], ")"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(z, z\)]\) \
(\!\(\*SuperscriptBox[\(z\), \(3\)]\)f[z]) = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"z", ",", "z"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "3"], " ", 
         RowBox[{"f", "[", "z", "]"}]}], ")"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[f,0] = \!\(\*FractionBox[\(1\), \(2!\)]\) \!\(\*UnderscriptBox[\
\(lim\), \(z \[Rule] 0\)]\) \>\"", ",", 
      "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(z, \
z\)]\)(\!\(\*SuperscriptBox[\(z\), \(3\)]\)f[z])) = \>\"", ",", "ResLim"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,0] = Res[\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<,0] = \>\"", ",", "ResLim"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399972290109375*^9, 3.399972291890625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can verify this computation with ",
 StyleBox["Mathematica'",
  FontSlant->"Italic"],
 "s built in \"Residue\" procedure. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Res", "=", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0"}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,0] = Res[\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<,0] = \>\"", ",", "Res"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399972299671875*^9}],

Cell[TextData[{
 "Which is the coefficient of  ",
 Cell[BoxData[
  FractionBox["1", "z"]]],
 " in the Laurent series expansion for  f[z]."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0", ",", "5"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        SubscriptBox["a", "n"], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", 
          RowBox[{"-", "3"}], ",", "5", ",", "1"}], "}"}]}], "]"}], ",", 
      "\"\<  =  \>\"", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{
          RowBox[{"f", "[", "z", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"z", ",", "0", ",", "n"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", 
          RowBox[{"-", "3"}], ",", "5", ",", "1"}], "}"}]}], "]"}]}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"k", "=", "5"}], ",", 
      RowBox[{"k", "\[GreaterEqual]", " ", 
       RowBox[{"-", "3"}]}], ",", 
      RowBox[{"k", "--"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Print", "[", " ", 
        RowBox[{
         SubscriptBox["\"\<a\>\"", "k"], ",", "\"\<  =  \>\"", ",", 
         RowBox[{"SeriesCoefficient", "[", 
          RowBox[{
           RowBox[{"f", "[", "z", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"z", ",", "0", ",", "k"}], "}"}]}], "]"}]}], "]"}], 
       ";"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Looking at this list of coefficients, we see that\>\"",
      "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(a\), \(-1\)]\) = \>\"", ",", 
      RowBox[{"SeriesCoefficient", "[", 
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "0", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39997180103125*^9, 3.399971883953125*^9}, {
   3.399971926390625*^9, 3.399971927703125*^9}, {3.399972001296875*^9, 
   3.39997200346875*^9}, {3.39997203740625*^9, 3.3999721041875*^9}, {
   3.39997261478125*^9, 3.399972627078125*^9}, {3.399978563109375*^9, 
   3.399978685015625*^9}, 3.39997872603125*^9, {3.39997878790625*^9, 
   3.39997881203125*^9}, {3.39997885446875*^9, 3.39997885796875*^9}, {
   3.39997889609375*^9, 3.399978922765625*^9}, {3.39997898590625*^9, 
   3.399978988015625*^9}, {3.39997906775*^9, 3.39997909425*^9}, {
   3.399979162625*^9, 3.399979168296875*^9}, {3.399979220875*^9, 
   3.3999792845625*^9}, 3.399979334375*^9, {3.3999819383125*^9, 
   3.39998195853125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0", ",", "7"}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Res", " ", "=", " ", 
     RowBox[{"SeriesCoefficient", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,0] = Res[\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<,0] = \!\(\*SubscriptBox[\(a\), \(-1\)]\) = \>\"", ",", "Res"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3999723065*^9, 3.399972308375*^9}, 3.3999793653125*^9, {
   3.399981988015625*^9, 3.399981991640625*^9}},
 AspectRatioFixed->False]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 8.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Integral]", 
    RowBox[{
     SubsuperscriptBox["C", "3", "+"], 
     RowBox[{"(", "0", ")"}]}]], 
   RowBox[{
    FractionBox[
     RowBox[{" ", "1"}], 
     RowBox[{
      SuperscriptBox["z", "4"], " ", "+", " ", 
      SuperscriptBox["z", "3"], " ", "-", " ", 
      RowBox[{"2", 
       SuperscriptBox["z", "2"]}]}]], 
    RowBox[{"\[DifferentialD]", "z"}]}]}]]],
 "  where ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["C", "3", "+"], 
   RowBox[{"(", "0", ")"}]}]]],
 " denotes the circle ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["C", "3", "+"], 
    RowBox[{"(", "0", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", ":", " ", 
      RowBox[{"|", "z", "|"}]}], "=", "3"}], "}"}]}]]],
 " with positive orientation.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{305, 195},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  We write the integrand as  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{" ", "1"}], 
     RowBox[{
      SuperscriptBox["z", "4"], " ", "+", " ", 
      SuperscriptBox["z", "3"], " ", "-", " ", 
      RowBox[{"2", 
       SuperscriptBox["z", "2"]}]}]], " ", "=", " ", 
    FractionBox[
     RowBox[{" ", "1"}], 
     RowBox[{
      SuperscriptBox["z", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"z", "+", "2"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}]}]]}]}]]],
 ".  \nThe singularities of ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " that lie inside ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["C", "3", "+"], 
   RowBox[{"(", "0", ")"}]}]]],
 " are simple poles at the points ",
 Cell[BoxData[
  RowBox[{"z", "=", "1"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"-", "2"}]}]]],
 ", and a pole of order ",
 StyleBox["2",
  FontFamily->"Courier New"],
 " at the origin.  We compute the residues as follows:  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", "0"}], "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      RowBox[{
       FractionBox["d", "dz"], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], "f", 
         RowBox[{"(", "z", ")"}]}], ")"}]}]}], "  ", "=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      RowBox[{
       FractionBox["d", "dz"], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], 
         FractionBox[
          RowBox[{" ", "1"}], 
          RowBox[{
           SuperscriptBox["z", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"z", "+", "2"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}]}]]}], ")"}]}]}]}]}], 
   "\[IndentingNewLine]", "  "}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      RowBox[{
       FractionBox["d", "dz"], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{" ", "1"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"z", "+", "2"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"z", "-", "1"}], ")"}]}]], ")"}]}]}], "  ", "=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      RowBox[{
       FractionBox["d", "dz"], 
       RowBox[{"(", 
        FractionBox["1", 
         RowBox[{
          SuperscriptBox["z", "2"], "+", "z", "-", "2"}]], ")"}]}]}]}]}], " ",
    "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "z"}], "-", "1"}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "+", "z", "-", "2"}], ")"}], "2"]]}], 
     "  ", "=", "  ", 
     RowBox[{"-", 
      FractionBox["1", "4"]}]}]}]}]}]],
 "    \n\t\t\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", "1"}], "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "1"}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], "f", 
       RowBox[{"(", "z", ")"}]}]}], "  ", "=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "1"}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       FractionBox[
        RowBox[{" ", "1"}], 
        RowBox[{
         SuperscriptBox["z", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"z", "+", "2"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"z", "-", "1"}], ")"}]}]]}]}]}]}], "\[IndentingNewLine]", 
   "  "}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "1"}]], 
      FractionBox[
       RowBox[{" ", "1"}], 
       RowBox[{
        SuperscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"z", "+", "2"}], ")"}]}]]}], "  ", "=", "  ", 
     FractionBox["1", "3"]}]}]}]}]],
 "  \n\t\t\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", 
      RowBox[{"-", "2"}]}], "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        RowBox[{"-", "2"}]}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{"(", 
          RowBox[{"-", "2"}], ")"}]}], ")"}], "f", 
       RowBox[{"(", "z", ")"}]}]}], "  ", "=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        RowBox[{"-", "2"}]}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "+", "2"}], ")"}], 
       FractionBox[
        RowBox[{" ", "1"}], 
        RowBox[{
         SuperscriptBox["z", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"z", "+", "2"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"z", "-", "1"}], ")"}]}]]}]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                         ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        RowBox[{"-", "2"}]}]], " ", 
      FractionBox[
       RowBox[{" ", "1"}], 
       RowBox[{
        SuperscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"z", "-", "1"}], ")"}]}]]}], "  ", "=", "  ", 
     RowBox[{"-", 
      FractionBox["1", "12"]}]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "Finally, the residue theorem yields \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", 
      RowBox[{
       SubsuperscriptBox["C", "3", "+"], 
       RowBox[{"(", "0", ")"}]}]], 
     RowBox[{
      FractionBox[
       RowBox[{" ", "1"}], 
       RowBox[{
        SuperscriptBox["z", "4"], " ", "+", " ", 
        SuperscriptBox["z", "3"], " ", "-", " ", 
        RowBox[{"2", 
         SuperscriptBox["z", "2"]}]}]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", "0"}], "]"}], " ", "+", " ", 
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", "1"}], "]"}], " ", "+", " ", 
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", 
         RowBox[{"-", "2"}]}], "]"}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                        ", 
   RowBox[{"=", "  ", 
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "4"]}], " ", "+", " ", 
       FractionBox["1", "3"], " ", "-", " ", 
       FractionBox["1", "12"]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                        ", 
   RowBox[{"=", "  ", "0"}]}]}]],
 "\n\nThe answer,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", 
     RowBox[{
      SubsuperscriptBox["C", "3", "+"], 
      RowBox[{"(", "0", ")"}]}]], 
    RowBox[{
     FractionBox[
      RowBox[{" ", "1"}], 
      RowBox[{
       SuperscriptBox["z", "4"], " ", "+", " ", 
       SuperscriptBox["z", "3"], " ", "-", " ", 
       RowBox[{"2", 
        SuperscriptBox["z", "2"]}]}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", "0"}]]],
 ",  is not at all obvious, and all the preceding calculations are required \
to get it."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"8.5", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506705484078125*^9, 3.506705484078125*^9}}],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{" ", "1"}], 
    RowBox[{
     SuperscriptBox["z", "4"], " ", "+", " ", 
     SuperscriptBox["z", "3"], " ", "-", " ", 
     RowBox[{"2", 
      SuperscriptBox["z", "2"]}]}]]}]],
  AspectRatioFixed->True],
 "  and ",
 "locate the",
 " singularities.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "=", "0"}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Res1", ",", "Res2", ",", "Res3", ",", "Res4"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", 
     FractionBox[
      RowBox[{" ", "1"}], 
      RowBox[{
       SuperscriptBox["z", "4"], " ", "+", " ", 
       SuperscriptBox["z", "3"], " ", "-", " ", 
       RowBox[{"2", 
        SuperscriptBox["z", "2"]}]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Denominator", "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}], 
       "]"}], "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The singularities are\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "2"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "3"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "4"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["Z", "4"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3999819985*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "Find out which singularities lie within a circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", "z", "|"}]}], "=", "3"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "3"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "4"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "1"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}], "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "2"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}], "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "3"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}], "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "4"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}], "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "3"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", "contour", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3.1"}], ",", "3.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3.1"}], ",", "3.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<, Is |\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<| < 3 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", "1"], "]"}], "]"}], "<", "3"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<,  Is |\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<| < 3 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", "2"], "]"}], "]"}], "<", "3"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<,  Is |\>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<| < 3 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", "3"], "]"}], "]"}], "<", "3"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<,  Is |\>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<| < 3 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", "4"], "]"}], "]"}], "<", "3"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39996657278125*^9, 3.399966573140625*^9}, 
   3.39998200659375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Compute the residues at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], ",", 
   SubscriptBox["z", "2"], ",", " ", 
   RowBox[{"and", "  ", 
    SubscriptBox["z", "4"]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Res1", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "1"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Res2", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "2"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Res4", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "4"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<] = \>\"", ",", "Res1"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<] = \>\"", ",", "Res2"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<] = \>\"", ",", "Res4"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399982014453125*^9},
 AspectRatioFixed->True],

Cell["The integral is computed by the residue calculus.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"val", " ", "=", 
     RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{"Res1", " ", "+", " ", "Res2", " ", "+", " ", "Res4"}], 
       ")"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<] = \>\"", ",", "Res1"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<] = \>\"", ",", "Res2"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<] = \>\"", ",", "Res4"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "4"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "1"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}], "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "2"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}], "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "4"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}], "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "3"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", "contour", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3.1"}], ",", "3.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3.1"}], ",", "3.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\< \[DifferentialD]z = 2\[Pi]\[ImaginaryI][(\>\"", ",", "Res1", " ", 
      ",", "\"\<) + (\>\"", ",", " ", "Res2", " ", ",", "\"\<) + (\>\"", ",", 
      " ", "Res4", ",", "\"\<)]\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\< \[DifferentialD]z = 2\[Pi]\[ImaginaryI]( \>\"", ",", 
      RowBox[{"Res1", " ", "+", " ", "Res2", " ", "+", " ", "Res4"}], ",", 
      "\"\< ) = \>\"", ",", "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The contour is the circle  C:|z| = 3,\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<with positive orientation.\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399966582703125*^9, 3.399966582921875*^9}, {
  3.399982019125*^9, 3.399982020921875*^9}, {3.40031078353125*^9, 
  3.40031082890625*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 8.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Integral]", 
    RowBox[{
     SubsuperscriptBox["C", "2", "+"], 
     RowBox[{"(", "1", ")"}]}]], 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      SuperscriptBox["z", "4"], " ", "+", " ", "4"}]], 
    RowBox[{"\[DifferentialD]", "z"}]}]}]]],
 "  where ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["C", "2", "+"], 
   RowBox[{"(", "1", ")"}]}]]],
 " denotes the circle ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["C", "2", "+"], 
    RowBox[{"(", "1", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", ":", " ", 
      RowBox[{"|", 
       RowBox[{"z", "-", "1"}], "|"}]}], "=", "2"}], "}"}]}]]],
 " with positive orientation.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[GraphicsData["CompressedBitmap", "\<\
eJzlmvlzFEUUxzubTdhACKAlxOwmLAmSRALKoVEpKgoYBUQ8Aa8fUhRV8IOF
QPQHUvwsWKU/eHB5cKjgyaX/37p97Jve2U9PZrMTay2nUtudft/3fW/6dU/P
vO4DM7PHj304M3vi6Ez5pdMzHx0/cfRMefrk6WpTZ4dSHVuUUt+Xla5XqlX3
U6n+VbbqH92STf1vU3Qqa8BI1Fkr+lMXeS3onAcUE+XD8DsgMuw53dKva31a
9LaF3xYXiDMHbav0b7du6JPaQd/VfB08cHO9+rdLNwxIbZ93B7mQS4Waw5X1
UpsO93R3jawyIbU9YXheQE9KbVcYnhPQdpFWRDqVpFitT4o2IO2QrKgdAtoZ
B0WWdgpohwU9kIaY4SkRPGuR96SBgv2CSCct/C5YJ8XdgNvujRLD2QWKe0Bx
m1X8A0RE8SLg3GT8HUTdQDEtPjrF30BxCSi+DLgnLMWvICoAxV7AbbYUv4Co
Byj2AW6Tpbgld9YLivtBccIq/gwiongFcBstxU8gWg4UBwD3eGYUP4KoDyhe
Bdy4pbgJohVAcRBwY5biBohWAsVrgBu1FNdBtAooXgfchsworoHoIaB4A3CP
WYofQPQwULwJuPVhCllj8An1FmiMWLKv7Byp1goAokCTgZKwPB029aUu8hq0
pBlTZnksiS4ZGI4b6AaQrKapl/9iGqNRB9Jd0TBP7sBngGWdNfW5BLknZCr4
LjEq0k1hA5+KAXqPIaOrAVcWFnJkI7CUrfnzpkj1TkWDdQ3g1qWnnAg7dgHg
rXg1DG3UV+TSWuvSZykHFg3KfsCNOLTf5jpLys1hdwKhiyYwDR7yo4mA0UD2
3TFDcBmAHg3ZNRrbQGPI0l5OSfbOolJcAtEAULwLuMF2orgIoiJQvAe40r9O
8X4Q1yYU3wTvMTXFx7owk6/kgWqXmcgU46JMnqIQDMYI4lZiFIMxp+p9IFzM
POLyznPhdB58AhqlFjwg3FBwgqiT0kv01H9EpLkWXEpui2Iy4Mek4bnbSqcU
kyijZueMH5kcDaCQ6ZJoDNXXHK7mepOz5INw+L4GEXVA+1JIqqi2stYu+xau
TulixMn9AJxTdtT6bUo15BX0ZV991WyKyb6wMZzMR+mGFYvfc+0xNjIY5P87
isVdWduDoj1eVP5b730JFO3xGp0BRXt82GRAcQVE9Jl5BHBrM6O4CiLKA2RA
cRhwZUvxLYgoX5MBxSHAuZzSdyAyKehgtjKBLOtk2ySwNCQTW8lWPgW6DelQ
ShtRlj45R5lgKuo2SsOkNRV1G5lyyekvdGH0+gDUK11EHz5jojs2j4GYIpmi
vPw4tG0AXZerT06HklHaTyjXD3bz4UNG3R5DE0nQtB4EcmrxGOtrNOwYJUGJ
YiVQ0MykJGi0e0895PaC0qY+yRGatyMhR4K4iG8sMWhrQINmWyBA46A+7hns
CtmgXcIowUkxdvuFGWx83gLRMqBI2H69DaKlzVFksHucwR52BjvpC97Fz+AE
wYJPL9wVRZpHu0Rqt9XUfWlQ0Te1LqMjGXZXTP3l2ayBpgT0nAUFT43E2hrg
yvEmnkTxnzniGBkLn6LplDCZ2vNheJeAJqS2OwwviNujAk84MLRUQMOiuNcL
ffC4lnm+mHNM/VLb7ynG4LTWm+VZbzdVzLQs6Jrd/5/nWJf5sunRoiPeYEux
HNSdMUu1vvrHzIIvLQ5k/sngCJ2cZlLn4kM+sjkXjulZ1tLXnGehsQPmvLlo
9erzWwu8T9XxDxoy2Ck=\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{305, 157},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  The singularities of the integrand  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["z", "4"], " ", "+", " ", "4"}]]}]]],
 "  that lie inside ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["C", "2", "+"], 
   RowBox[{"(", "1", ")"}]}]]],
 " are simple poles occurring at the points  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"1", "\[PlusMinus]", "\[ImaginaryI]"}]}]]],
 ",  as the points  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"-", "1"}], "\[PlusMinus]", "\[ImaginaryI]"}]}]]],
 ",  lie outside ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["C", "2", "+"], 
   RowBox[{"(", "1", ")"}]}]]],
 ".  Factoring the denominator is tedious, so we use a different approach.  \
If ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " is any one of the singularities of ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " , then we can use L'H\[OHat]pital's rule to compute ",
 Cell[BoxData[
  RowBox[{"Res", "[", 
   RowBox[{"f", ",", 
    SubscriptBox["z", "0"]}], "]"}]]],
 ": \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", 
      SubscriptBox["z", "0"]}], "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", 
        SubscriptBox["z", "0"]}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", 
         SubscriptBox["z", "0"]}], ")"}], "f", 
       RowBox[{"(", "z", ")"}]}]}], "  ", "=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", 
        SubscriptBox["z", "0"]}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", 
         SubscriptBox["z", "0"]}], ")"}], 
       FractionBox["1", 
        RowBox[{
         SuperscriptBox["z", "4"], " ", "+", " ", "4"}]]}]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                        ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", 
        SubscriptBox["z", "0"]}]], " ", 
      FractionBox[
       RowBox[{"(", 
        RowBox[{"z", "-", 
         SubscriptBox["z", "0"]}], ")"}], 
       RowBox[{
        SuperscriptBox["z", "4"], " ", "+", " ", "4"}]]}], "  ", "=", 
     RowBox[{"'", 
      RowBox[{
       FractionBox["0", "0"], "'"}]}]}]}], "    ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                        ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", 
        SubscriptBox["z", "0"]}]], " ", 
      FractionBox["1", 
       RowBox[{"4", 
        SuperscriptBox["z", "3"]}]]}], "  ", "=", "  ", 
     FractionBox["1", 
      RowBox[{"4", 
       SubsuperscriptBox["z", "0", "3"]}]]}]}]}]}]],
 "\n"
}], "Text"],

Cell[TextData[{
 "Since ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["z", "0", "4"], " ", "=", " ", 
   RowBox[{"-", "4"}]}]]],
 ",  we can simplify this expression further to yield \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{"f", ",", 
     SubscriptBox["z", "0"]}], "]"}], "  ", "=", "  ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"4", 
      SubsuperscriptBox["z", "0", "3"]}]], "  ", "=", "  ", 
    RowBox[{
     FractionBox[
      SubscriptBox["z", "0"], 
      RowBox[{"4", 
       SubsuperscriptBox["z", "0", "4"]}]], "  ", "=", "  ", 
     RowBox[{
      FractionBox[
       SubscriptBox["z", "0"], 
       RowBox[{"4", 
        RowBox[{"(", 
         RowBox[{"-", "4"}], ")"}]}]], "  ", "=", "  ", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "16"]}], 
       SubscriptBox["z", "0"]}]}]}]}]}]]],
 "\n\nWe now use the residue theorem to get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Integral]", 
      RowBox[{
       SubsuperscriptBox["C", "2", "+"], 
       RowBox[{"(", "1", ")"}]}]], 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        SuperscriptBox["z", "4"], " ", "+", " ", "4"}]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", 
         RowBox[{"1", "+", "\[ImaginaryI]"}]}], "]"}], " ", "+", " ", 
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", 
         RowBox[{"1", "-", "\[ImaginaryI]"}]}], "]"}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                              ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"1", "+", "\[ImaginaryI]"}], "16"]}], " ", "-", 
        FractionBox[
         RowBox[{"1", "-", "\[ImaginaryI]"}], "16"]}], ")"}]}], "  ", "=", 
     "  ", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "-", "\[ImaginaryI]"}], "16"], " ", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], "16"]}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                              ", 
   RowBox[{"=", "  ", 
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{"-", 
       FractionBox["1", "8"]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                              ", 
   RowBox[{"=", "  ", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "4"]}]}]}]}]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"8.6", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506705488265625*^9, 3.506705488265625*^9}}],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["z", "4"], " ", "+", " ", "4"}]]}]],
  AspectRatioFixed->True],
 "  and ",
 "locate the",
 " singularities.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "=", "0"}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Res1", ",", "Res2", ",", "Res3", ",", "Res4"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", 
     FractionBox["1", 
      RowBox[{
       SuperscriptBox["z", "4"], " ", "+", " ", "4"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Denominator", "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Denominator", "[", 
           RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}],
         "]"}], "]"}], "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The singularities are\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "2"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "3"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "4"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["Z", "4"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.399982032703125*^9, {3.40031141115625*^9, 3.4003114194375*^9}},
 AspectRatioFixed->False],

Cell[TextData[{
 "Find out which singularities lie within a circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", 
     RowBox[{"z", "-", "1"}], "|"}]}], "=", "2."}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "3"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "4"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "1"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}], "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "2"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}], "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "3"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}], "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "4"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}], "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}], ",", "2"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", "contour", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "3.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["4", "5"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<, Is |\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\< - 1| < 2 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         RowBox[{
          SubscriptBox["Z", "1"], "-", "1"}], "]"}], "]"}], "<", "2"}]}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<, Is |\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\< - 1| < 2 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         RowBox[{
          SubscriptBox["Z", "2"], "-", "1"}], "]"}], "]"}], "<", "2"}]}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<,  Is  |\>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\< - 1| < 2 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         RowBox[{
          SubscriptBox["Z", "3"], "-", "1"}], "]"}], "]"}], "<", "2"}]}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<,  Is  |\>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\< - 1| < 2 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         RowBox[{
          SubscriptBox["Z", "4"], "-", "1"}], "]"}], "]"}], "<", "2"}]}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399966589515625*^9, 3.399966589703125*^9}, 
   3.399982039484375*^9, {3.400311879078125*^9, 3.40031188028125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "\nYou must look carefully at the above list and make the proper choice. \n\
We see that we should compute the residues at  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "3"], "=", 
    RowBox[{"1", "-", "\[ImaginaryI]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    RowBox[{"and", "  ", 
     SubscriptBox["z", "4"]}], "=", 
    RowBox[{"1", "+", "\[ImaginaryI]"}]}]}]]],
 ". \n"
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.40031153525*^9, 3.40031161475*^9}, {3.4003124795625*^9, 
  3.400312490734375*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Res3", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "3"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Res4", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "4"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<] = \>\"", ",", "Res3"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<] = \>\"", ",", "Res4"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39998204584375*^9},
 AspectRatioFixed->True],

Cell["The integral is computed by the residue calculus.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"val", " ", "=", 
     RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", " ", 
       RowBox[{"Res3", " ", "+", " ", "Res4"}], ")"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<] = \>\"", ",", "Res3"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<] = \>\"", ",", "Res4"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "3"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "4"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "3"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}], "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "4"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}], "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}], ",", "2"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", "contour", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "3.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["4", "5"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\< \[DifferentialD]z = 2\[Pi]\[ImaginaryI]((\>\"", ",", " ", "Res3", 
      " ", ",", "\"\<) + (\>\"", ",", " ", "Res4", ",", "\"\<))\>\""}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\< \[DifferentialD]z = 2\[Pi]\[ImaginaryI](\>\"", ",", 
      RowBox[{"Res3", " ", "+", " ", "Res4"}], ",", "\"\<) = \>\"", ",", 
      "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The contour is the circle  C:|z-1| = 2,\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<with positive orientation.\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39996659375*^9, 3.399966593921875*^9}, {
  3.399982050953125*^9, 3.399982052859375*^9}}],

Cell[TextData[{
 StyleBox["Caveat.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  When using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", you must make sure that you choose the singularities that lie inside the \
contour.  Different versions of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " might order the list of singularities differently.  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.4003110148125*^9, 3.400311018078125*^9}, {
  3.400311147578125*^9, 3.40031124728125*^9}, {3.4003114518125*^9, 
  3.400311486921875*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\t",
 StyleBox["The theory of residues can be used to expand the quotient of two \
polynomials into its partial fraction representation.",
  FontFamily->"Times New Roman",
  FontSize->12]
}], "SmallText"],

Cell[TextData[{
 StyleBox["Example 8.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Let ",
 StyleBox["P(z)",
  FontFamily->"Courier New"],
 " be a polynomial of degree at most ",
 StyleBox["2",
  FontFamily->"Courier New"],
 ".  If ",
 StyleBox["a",
  FontFamily->"Courier New"],
 " , ",
 StyleBox["b",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["c",
  FontFamily->"Courier New"],
 " are distinct complex numbers, then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox[
     RowBox[{"P", 
      RowBox[{"(", "z", ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", " ", "-", " ", "a"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", " ", "-", " ", "b"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", " ", "-", " ", "c"}], ")"}]}]], "  ", "=", "  ", 
    RowBox[{
     FractionBox["\[DoubleStruckCapitalA]", 
      RowBox[{"z", " ", "-", " ", "a"}]], " ", "+", " ", 
     FractionBox["\[DoubleStruckCapitalB]", 
      RowBox[{"z", " ", "-", " ", "b"}]], " ", "+", " ", 
     FractionBox["\[DoubleStruckCapitalC]", 
      RowBox[{"z", " ", "-", " ", "c"}]]}]}]}]]],
 ",  \nwhere\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"\[DoubleStruckCapitalA]", " ", "=", " ", 
     RowBox[{
      RowBox[{"Res", "[", 
       RowBox[{"f", ",", "a"}], "]"}], " ", "=", " ", 
      FractionBox[
       RowBox[{"P", 
        RowBox[{"(", "a", ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", " ", "-", " ", "b"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"a", " ", "-", " ", "c"}], ")"}]}]]}]}], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"\[DoubleStruckCapitalB]", " ", "=", " ", 
     RowBox[{
      RowBox[{"Res", "[", 
       RowBox[{"f", ",", "b"}], "]"}], " ", "=", " ", 
      FractionBox[
       RowBox[{"P", 
        RowBox[{"(", "b", ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"b", " ", "-", " ", "a"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"b", " ", "-", " ", "c"}], ")"}]}]]}]}], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"\[DoubleStruckCapitalC]", " ", "=", " ", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", "c"}], "]"}], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"P", 
       RowBox[{"(", "c", ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"c", " ", "-", " ", "a"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"c", " ", "-", " ", "b"}], ")"}]}]], 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[".",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}]}]}]],
 "   "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Solution.  It will suffice to prove that  ",
 Cell[BoxData[
  RowBox[{"A", " ", "=", " ", 
   RowBox[{"Res", "[", 
    RowBox[{"f", ",", "a"}], "]"}]}]]],
 ".  We expand ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " in its Laurent series about the point ",
 Cell[BoxData[
  RowBox[{"z", "=", "a"}]]],
 " by writing the three terms ",
 Cell[BoxData[
  FractionBox["A", 
   RowBox[{"z", " ", "-", " ", "a"}]]]],
 ", ",
 Cell[BoxData[
  FractionBox["\[DoubleStruckCapitalB]", 
   RowBox[{"z", " ", "-", " ", "b"}]]]],
 ", and ",
 Cell[BoxData[
  FractionBox["\[DoubleStruckCapitalC]", 
   RowBox[{"z", " ", "-", " ", "c"}]]]],
 " in their Laurent series about the point ",
 Cell[BoxData[
  RowBox[{"z", "=", "a"}]]],
 " and adding them.  The term ",
 Cell[BoxData[
  FractionBox["\[DoubleStruckCapitalA]", 
   RowBox[{"z", " ", "-", " ", "a"}]]]],
 " is itself a one-term Laurent series about the point ",
 Cell[BoxData[
  RowBox[{"z", "=", "a"}]]],
 ".  The term ",
 Cell[BoxData[
  FractionBox["\[DoubleStruckCapitalB]", 
   RowBox[{"z", " ", "-", " ", "b"}]]]],
 " is analytic at the point ",
 Cell[BoxData[
  RowBox[{"z", "=", "a"}]]],
 ", and its Laurent series is actually a Taylor series given by  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    FractionBox["\[DoubleStruckCapitalB]", 
     RowBox[{"z", "-", "b"}]], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"(", 
      FractionBox[
       RowBox[{"-", "\[DoubleStruckCapitalB]"}], 
       RowBox[{"b", "-", "a"}]], ")"}], 
     RowBox[{"(", 
      FractionBox["1", 
       RowBox[{"1", "-", 
        FractionBox[
         RowBox[{"z", "-", "a"}], 
         RowBox[{"b", "-", "a"}]]}]], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"         ", 
   RowBox[{"=", "   ", 
    RowBox[{
     RowBox[{"(", 
      FractionBox[
       RowBox[{"-", "\[DoubleStruckCapitalB]"}], 
       RowBox[{"b", "-", "a"}]], ")"}], 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"z", "-", "a"}], 
         RowBox[{"b", "-", "a"}]], ")"}], "n"]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"         ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"(", 
      FractionBox[
       RowBox[{"-", "\[DoubleStruckCapitalB]"}], 
       RowBox[{"b", "-", "a"}]], ")"}], 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", "a"}], ")"}], "n"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"b", "-", "a"}], ")"}], "n"]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"         ", 
   RowBox[{"=", "  ", 
    RowBox[{"-", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      FractionBox[
       RowBox[{"\[DoubleStruckCapitalB]", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", "a"}], ")"}], "n"]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"b", "-", "a"}], ")"}], 
        RowBox[{"n", "+", "1"}]]]}]}]}]}]}]],
 "  \n\nwhich is valid for  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", "a"}], "|", 
   RowBox[{"<", 
    RowBox[{"|", 
     RowBox[{"b", "-", "a"}], "|"}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Likewise, the Laurent expansion of the term ",
 Cell[BoxData[
  FractionBox["\[DoubleStruckCapitalC]", 
   RowBox[{"z", " ", "-", " ", "c"}]]]],
 " is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox["\[DoubleStruckCapitalC]", 
    RowBox[{"z", " ", "-", " ", "c"}]], "  ", "="}]]],
 Cell[BoxData[
  RowBox[{"  ", 
   RowBox[{"-", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     FractionBox[
      RowBox[{"\[DoubleStruckCapitalC]", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", "a"}], ")"}], "n"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "a"}], ")"}], 
       RowBox[{"n", "+", "1"}]]]}]}]}]]],
 ",  \n\t\t\nwhich is valid for  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", "a"}], "|", 
   RowBox[{"<", 
    RowBox[{"|", 
     RowBox[{"c", "-", "a"}], "|"}]}]}]]],
 ".  Thus the Laurent series of ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " about the point ",
 Cell[BoxData[
  RowBox[{"z", "=", "a"}]]],
 " is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox["\[DoubleStruckCapitalA]", 
     RowBox[{"z", " ", "-", " ", "a"}]], " ", "-", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     FractionBox[
      RowBox[{"\[DoubleStruckCapitalB]", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", "a"}], ")"}], "n"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "a"}], ")"}], 
       RowBox[{"n", "+", "1"}]]]}], " ", "-", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], 
     FractionBox[
      RowBox[{"\[DoubleStruckCapitalC]", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", "a"}], ")"}], "n"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"c", "-", "a"}], ")"}], 
       RowBox[{"n", "+", "1"}]]]}]}]}]]],
 ", \n\nwhich is valid for  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", "a"}], "|", 
   RowBox[{"<", " ", "R"}]}]]],
 ", where  ",
 Cell[BoxData[
  RowBox[{"R", "=", 
   RowBox[{"min", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"|", 
       RowBox[{"b", "-", "a"}], "|"}], ",", 
      RowBox[{"|", 
       RowBox[{"c", "-", "a"}], "|"}]}], "}"}]}]}]]],
 ".  Therefore  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{"f", ",", "a"}], "]"}], " ", "=", " ", 
   "\[DoubleStruckCapitalA]"}]]],
 ",  and calculation reveals that \n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", "a"}], "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "a"}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "a"}], ")"}], "f", 
       RowBox[{"(", "z", ")"}]}]}], " ", "=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "a"}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "a"}], ")"}], 
       FractionBox[
        RowBox[{"P", 
         RowBox[{"(", "z", ")"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", " ", "-", " ", "a"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"z", " ", "-", " ", "b"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"z", " ", "-", " ", "c"}], ")"}]}]]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "a"}]], " ", 
      FractionBox[
       RowBox[{"P", 
        RowBox[{"(", "z", ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", " ", "-", " ", "b"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", " ", "-", " ", "c"}], ")"}]}]]}], "  ", "=", "  ", 
     FractionBox[
      RowBox[{"P", 
       RowBox[{"(", "a", ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", " ", "-", " ", "b"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"a", " ", "-", " ", "c"}], ")"}]}]]}]}]}]}]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"8.7", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506705491703125*^9, 3.506705491703125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "=", "0"}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<            \!\(\*FractionBox[\(\[DoubleStruckCapitalB]\), \(z - \
b\)]\) = \>\"", ",", 
      FractionBox["\[DoubleStruckCapitalB]", 
       RowBox[{"z", "-", "b"}]]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<(\!\(\*FractionBox[\(-\[DoubleStruckCapitalB]\), \(b - a\)]\))(\!\(\
\*FractionBox[\(1\), \(1 - \*FractionBox[\(\(-a\) + z\), \(\(-a\) + \
b\)]\)]\)) = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"(", 
         FractionBox[
          RowBox[{"-", "\[DoubleStruckCapitalB]"}], 
          RowBox[{"b", "-", "a"}]], ")"}], 
        RowBox[{"(", 
         FractionBox["1", 
          RowBox[{"1", "-", 
           FractionBox[
            RowBox[{
             RowBox[{"-", "a"}], "+", "z"}], 
            RowBox[{
             RowBox[{"-", "a"}], "+", "b"}]]}]], ")"}]}], "]"}]}], " ", "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<(\!\(\*FractionBox[\(-\[DoubleStruckCapitalB]\), \(b - \
a\)]\))\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)(\!\(\*FractionBox[\(z - a\), \(b - \
a\)]\)\!\(\*SuperscriptBox[\()\), \(n\)]\) = \>\"", ",", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"-", "\[DoubleStruckCapitalB]"}], 
         RowBox[{"b", "-", "a"}]], ")"}], 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "0"}], "\[Infinity]"], 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox[
           RowBox[{"z", "-", "a"}], 
           RowBox[{"b", "-", "a"}]], ")"}], "n"]}]}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   - \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(\[DoubleStruckCapitalB] \
\*SuperscriptBox[\((z - a)\), \(n\)]\), SuperscriptBox[\((b - a)\), \(n + \
1\)]]\) = \>\"", ",", 
      RowBox[{"-", " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "0"}], "\[Infinity]"], 
        FractionBox[
         RowBox[{"\[DoubleStruckCapitalB]", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", "a"}], ")"}], "n"]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "a"}], ")"}], 
          RowBox[{"n", "+", "1"}]]]}]}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   - \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(\[DoubleStruckCapitalB] \
\*SuperscriptBox[\((z - a)\), \(n\)]\), SuperscriptBox[\((b - a)\), \(n + \
1\)]]\) = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{"-", " ", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "0"}], "\[Infinity]"], 
         FractionBox[
          RowBox[{"\[DoubleStruckCapitalB]", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z", "-", "a"}], ")"}], "n"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "-", "a"}], ")"}], 
           RowBox[{"n", "+", "1"}]]]}]}], " ", "]"}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399982060828125*^9, 3.399982115921875*^9}],

Cell["\<\

Next evaluate.\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.399982146421875*^9, 3.399982156515625*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<            \!\(\*FractionBox[\(\[DoubleStruckCapitalC]\), \(z\\\  \
- \\\ c\)]\) = \>\"", ",", 
      FractionBox["\[DoubleStruckCapitalC]", 
       RowBox[{"z", " ", "-", " ", "c"}]]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    - \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\[Infinity]\
\)]\)\!\(\*FractionBox[\(\[DoubleStruckCapitalC] \*SuperscriptBox[\((z - \
a)\), \(n\)]\), SuperscriptBox[\((c - a)\), \(n + 1\)]]\) = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{"-", " ", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "0"}], "\[Infinity]"], 
         FractionBox[
          RowBox[{"\[DoubleStruckCapitalC]", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z", "-", "a"}], ")"}], "n"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"c", "-", "a"}], ")"}], 
           RowBox[{"n", "+", "1"}]]]}]}], " ", "]"}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399982122109375*^9, 3.39998212421875*^9}}],

Cell["\<\

Next evaluate.\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.399982146421875*^9, 3.399982156515625*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      FractionBox["\[DoubleStruckCapitalA]", 
       RowBox[{"z", "-", "a"}]], "+", 
      FractionBox["\[DoubleStruckCapitalB]", 
       RowBox[{"z", "-", "b"}]], "+", 
      FractionBox["\[DoubleStruckCapitalC]", 
       RowBox[{"z", "-", "c"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<                            f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(\[DoubleStruckCapitalA]\), \(z\\\  - \\\ \
a\)]\)- \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(\[DoubleStruckCapitalB] \
\*SuperscriptBox[\((z - a)\), \(n\)]\), SuperscriptBox[\((b - a)\), \(n + \
1\)]]\)- \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\[Infinity]\)]\)\!\
\(\*FractionBox[\(\[DoubleStruckCapitalC] \*SuperscriptBox[\((z - a)\), \
\(n\)]\), SuperscriptBox[\((c - a)\), \(n + 1\)]]\) = \>\"", ",", 
      RowBox[{
       FractionBox["\[DoubleStruckCapitalA]", 
        RowBox[{"z", " ", "-", " ", "a"}]], "-", " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "0"}], "\[Infinity]"], 
        FractionBox[
         RowBox[{"\[DoubleStruckCapitalB]", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", "a"}], ")"}], "n"]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "a"}], ")"}], 
          RowBox[{"n", "+", "1"}]]]}], "-", " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "0"}], "\[Infinity]"], 
        FractionBox[
         RowBox[{"\[DoubleStruckCapitalC]", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", "a"}], ")"}], "n"]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"c", "-", "a"}], ")"}], 
          RowBox[{"n", "+", "1"}]]]}]}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(\[DoubleStruckCapitalA]\), \(z\\\  - \\\ \
a\)]\)- \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(\[DoubleStruckCapitalB] \
\*SuperscriptBox[\((z - a)\), \(n\)]\), SuperscriptBox[\((b - a)\), \(n + \
1\)]]\)- \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\[Infinity]\)]\)\!\
\(\*FractionBox[\(\[DoubleStruckCapitalC] \*SuperscriptBox[\((z - a)\), \
\(n\)]\), SuperscriptBox[\((c - a)\), \(n + 1\)]]\) = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        FractionBox["\[DoubleStruckCapitalA]", 
         RowBox[{"z", " ", "-", " ", "a"}]], "-", " ", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "0"}], "\[Infinity]"], 
         FractionBox[
          RowBox[{"\[DoubleStruckCapitalB]", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z", "-", "a"}], ")"}], "n"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "-", "a"}], ")"}], 
           RowBox[{"n", "+", "1"}]]]}], "-", " ", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "0"}], "\[Infinity]"], 
         FractionBox[
          RowBox[{"\[DoubleStruckCapitalC]", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z", "-", "a"}], ")"}], "n"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"c", "-", "a"}], ")"}], 
           RowBox[{"n", "+", "1"}]]]}]}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39998206309375*^9, 3.39998211009375*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 8.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Express  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"3", "z"}], " ", "+", " ", "2"}], 
    RowBox[{"z", 
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "2"}], ")"}]}]]}]],
  AspectRatioFixed->True],
 "  in partial fractions.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Solution.  In Example 8.7 use  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "0"}], ",", 
   RowBox[{"b", "=", "1"}], ",", 
   RowBox[{"c", "=", "2"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"3", "z"}], "+", "2"}]}]]],
 ".  Computing the residues, we obtain  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"\[DoubleStruckCapitalA]", " ", "=", " ", 
     RowBox[{
      RowBox[{"Res", "[", 
       RowBox[{"f", ",", "0"}], "]"}], " ", "=", " ", 
      RowBox[{
       FractionBox[
        RowBox[{"P", 
         RowBox[{"(", "0", ")"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"0", " ", "-", " ", "1"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"0", " ", "-", " ", "2"}], ")"}]}]], "=", " ", 
       RowBox[{
        FractionBox["2", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", " ", "1"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"-", " ", "2"}], ")"}]}]], "=", " ", 
        RowBox[{
         FractionBox["2", "1"], " ", "=", " ", "1"}]}]}]}]}], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"\[DoubleStruckCapitalB]", " ", "=", " ", 
     RowBox[{
      RowBox[{"Res", "[", 
       RowBox[{"f", ",", "1"}], "]"}], " ", "=", " ", 
      RowBox[{
       FractionBox[
        RowBox[{"P", 
         RowBox[{"(", "1", ")"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "-", " ", "0"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"1", " ", "-", " ", "2"}], ")"}]}]], "=", " ", 
       RowBox[{
        FractionBox["5", 
         RowBox[{
          RowBox[{"(", "1", " ", ")"}], 
          RowBox[{"(", 
           RowBox[{"-", " ", "1"}], ")"}]}]], "=", " ", 
        RowBox[{
         FractionBox["5", 
          RowBox[{"-", " ", "1"}]], " ", "=", " ", 
         RowBox[{"-", "5"}]}]}]}]}]}], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"\[DoubleStruckCapitalC]", " ", "=", " ", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", "2"}], "]"}], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"P", 
       RowBox[{"(", "2", ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", " ", "-", " ", "0"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"2", " ", "-", " ", "1"}], ")"}]}]], 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "=", " ", 
     RowBox[{
      FractionBox["8", 
       RowBox[{
        RowBox[{"(", "2", ")"}], 
        RowBox[{"(", "1", ")"}]}]], "=", " ", 
      RowBox[{
       FractionBox["8", "2"], " ", "=", " ", 
       RowBox[{"4", 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[".",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}]}]}]}]}]}]}]],
 " \n\nThe formula for ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " in Example 8.7 gives us  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox["\[DoubleStruckCapitalA]", 
      RowBox[{"z", "-", "0"}]], " ", "+", " ", 
     FractionBox["\[DoubleStruckCapitalB]", 
      RowBox[{"z", "-", "1"}]], " ", "+", " ", 
     FractionBox["\[DoubleStruckCapitalC]", 
      RowBox[{"z", "-", "2"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"z", "-", "0"}]], " ", "+", " ", 
     FractionBox[
      RowBox[{"-", "5"}], 
      RowBox[{"z", "-", "1"}]], " ", "+", " ", 
     FractionBox["4", 
      RowBox[{"z", "-", "2"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", "z"], " ", "-", " ", 
     FractionBox["5", 
      RowBox[{"z", "-", "1"}]], " ", "+", " ", 
     FractionBox["4", 
      RowBox[{"z", "-", "2"}]]}]}]}]}]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"8.8", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506705494609375*^9, 3.506705494609375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "=", "0"}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"3", "z"}], "+", "2"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"3", "z"}], "+", "2"}], 
      RowBox[{"z", 
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", "2"}], ")"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"c", "=", "2"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[DoubleStruckCapitalA]", " ", "=", " ", 
     FractionBox[
      RowBox[{"P", "[", "a", "]"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "-", "b"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"a", "-", "c"}], ")"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[DoubleStruckCapitalB]", " ", "=", " ", 
     FractionBox[
      RowBox[{"P", "[", "b", "]"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"b", "-", "a"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"b", "-", "c"}], ")"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[DoubleStruckCapitalC]", " ", "=", " ", 
     FractionBox[
      RowBox[{"P", "[", "c", "]"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"c", "-", "a"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"c", "-", "b"}], ")"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], "=", 
     RowBox[{
      FractionBox["\[DoubleStruckCapitalA]", 
       RowBox[{"z", "-", "a"}]], "+", 
      FractionBox["\[DoubleStruckCapitalB]", 
       RowBox[{"z", "-", "b"}]], "+", 
      FractionBox["\[DoubleStruckCapitalC]", 
       RowBox[{"z", "-", "c"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<P[z] = \>\"", ",", 
      RowBox[{"P", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f(z) = \!\(\*FractionBox[\(P[z]\), \(\((z - a)\) \((z - b)\) \((z - \
c)\)\)]\)\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   a = \>\"", ",", "a"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   b = \>\"", ",", "b"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   c = \>\"", ",", "c"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[DoubleStruckCapitalA] = \!\(\*FractionBox[\(P[a]\), \(\((a - \
b)\) \((a - c)\)\)]\) = \>\"", ",", "\[DoubleStruckCapitalA]"}], "]"}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[DoubleStruckCapitalB] = \!\(\*FractionBox[\(P[b]\), \(\((b - \
a)\) \((b - c)\)\)]\) = \>\"", ",", "\[DoubleStruckCapitalB]"}], "]"}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \[DoubleStruckCapitalC] = \!\(\*FractionBox[\(P[c]\), \(\((c - \
a)\) \((c - b)\)\)]\) = \>\"", ",", "\[DoubleStruckCapitalC]"}], "]"}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f[z] = \!\(\*FractionBox[\(\[DoubleStruckCapitalA]\), \(z - a\)]\) \
+ \!\(\*FractionBox[\(\[DoubleStruckCapitalB]\), \(z - b\)]\) + \
\!\(\*FractionBox[\(\[DoubleStruckCapitalC]\), \(z - c\)]\)\>\"", " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = (\>\"", ",", 
      FractionBox["\[DoubleStruckCapitalA]", 
       RowBox[{"z", "-", "a"}]], ",", "\"\<) + (\>\"", ",", 
      FractionBox["\[DoubleStruckCapitalB]", 
       RowBox[{"z", "-", "b"}]], ",", "\"\<) + (\>\"", ",", 
      FractionBox["\[DoubleStruckCapitalC]", 
       RowBox[{"z", "-", "c"}]], ",", "\"\<)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399982194609375*^9}],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{"3", "z"}], " ", "+", " ", "2"}], 
    RowBox[{"z", 
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "2"}], ")"}]}]]}]],
  AspectRatioFixed->True],
 "  and find the partial fraction expansion.  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "i", ",", "p", ",", "R", ",", "solset"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"3", "z"}], " ", "+", " ", "2"}], 
      RowBox[{"z", 
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", "2"}], ")"}]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Denominator", "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}], 
       "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Z", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"Length", "[", "solset", "]"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"R", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"Length", "[", "solset", "]"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"Length", "[", "solset", "]"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\n", "   ", 
      RowBox[{
       RowBox[{
        SubscriptBox["Z", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], "=", 
        RowBox[{"ReplaceAll", "[", 
         RowBox[{"z", ",", 
          SubscriptBox["solset", 
           RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
         "]"}]}], ";", " ", "\n", "   ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"1", "\[Equal]", "i"}], ",", 
         RowBox[{"p", " ", "=", " ", "1"}]}], "]"}], ";", " ", "\n", "   ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "<", "i"}], ";", " ", 
          RowBox[{
           SubscriptBox["Z", 
            RowBox[{"\[LeftDoubleBracket]", 
             RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]], "\[Equal]", 
           SubscriptBox["Z", 
            RowBox[{
            "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}]}], ",", 
         RowBox[{"p", "=", 
          RowBox[{"p", "+", "1"}]}], ",", 
         RowBox[{"p", "=", "1"}]}], "]"}], ";", " ", "\n", "   ", 
       RowBox[{"Print", "[", 
        RowBox[{
         SubscriptBox["\"\<z\>\"", "i"], ",", "\"\< = \>\"", ",", 
         SubscriptBox["Z", 
          RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
        "]"}], ";", " ", "\n", "   ", 
       RowBox[{
        SubscriptBox["R", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Residue", "[", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z", "-", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
             ")"}], 
            RowBox[{"p", "-", "1"}]], 
           RowBox[{"f", "[", "z", "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"z", ",", 
            SubscriptBox["Z", 
             RowBox[{
             "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
           "}"}]}], "]"}]}], ";", " ", "\n", "   ", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Res[\>\"", ",", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", 
            SubscriptBox["Z", 
             RowBox[{
             "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], ")"}], 
          RowBox[{"p", "-", "1"}]], ",", "\"\< f,\>\"", ",", 
         SubscriptBox["Z", 
          RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
         ",", "\"\<] = \>\"", ",", 
         SubscriptBox["R", 
          RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
        "]"}], ";", " ", "\n", "   ", 
       RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";", " ", "\n", "   ", 
       RowBox[{
        RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
        RowBox[{
         RowBox[{"F", "[", "z", "]"}], " ", "+", " ", 
         FractionBox[
          SubscriptBox["R", 
           RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", 
             SubscriptBox["Z", 
              RowBox[{
              "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
            ")"}], "p"]]}]}], ";"}]}], " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39998220221875*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "Compare this with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s Apart  procedure for the partial fraction expansion."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"Apart", "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39998220934375*^9},
 AspectRatioFixed->True],

Cell["\<\
In a moment, we will see that our subroutine will work for complex factors \
and \"Apart\" does not.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->False]
}, Closed]],

Cell[TextData[{
 StyleBox["Remark 8.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  If a repeated root occurs, then the process is similar, and it is easy to \
show that if ",
 StyleBox["P(z)",
  FontFamily->"Courier New"],
 " has degree of at most ",
 StyleBox["2",
  FontFamily->"Courier New"],
 ", then\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox[
     RowBox[{"P", 
      RowBox[{"(", "z", ")"}]}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "a"}], ")"}], "2"], 
      RowBox[{"(", 
       RowBox[{"z", " ", "-", " ", "b"}], ")"}]}]], "  ", "=", "  ", 
    RowBox[{
     FractionBox["\[DoubleStruckCapitalA]", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "a"}], ")"}], "2"]], " ", "+", " ", 
     FractionBox["\[DoubleStruckCapitalB]", 
      RowBox[{"z", " ", "-", " ", "a"}]], " ", "+", " ", 
     FractionBox["\[DoubleStruckCapitalC]", 
      RowBox[{"z", " ", "-", " ", "b"}]]}]}]}]]],
 ",  \nwhere\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"\[DoubleStruckCapitalA]", " ", "=", " ", 
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "a"}], ")"}], "f", 
        RowBox[{"(", "z", ")"}]}], ",", "a"}], "]"}]}], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"\[DoubleStruckCapitalB]", " ", "=", " ", 
     RowBox[{"Res", "[", 
      RowBox[{"f", ",", "a"}], "]"}]}], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"\[DoubleStruckCapitalC]", " ", "=", " ", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", "b"}], "]"}], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[".",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}]}]}]],
 "   "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Example 8.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Express  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z", "2"], " ", "+", " ", 
     RowBox[{"3", "z"}], " ", "+", " ", "2"}], 
    RowBox[{
     SuperscriptBox["z", "2"], 
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "1"}], ")"}]}]]}]],
  AspectRatioFixed->True],
 "  in partial fractions.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Solution.  Using the Remark 8.1 and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "0"}], ",", 
   RowBox[{"b", "=", "1"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "2"], " ", "+", " ", 
    RowBox[{"3", "z"}], " ", "+", " ", "2"}]}]]],
 ",  we have  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox[
     RowBox[{"P", 
      RowBox[{"(", "z", ")"}]}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "0"}], ")"}], "2"], 
      RowBox[{"(", 
       RowBox[{"z", " ", "-", " ", "1"}], ")"}]}]], "  ", "=", "  ", 
    RowBox[{
     FractionBox["\[DoubleStruckCapitalA]", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "0"}], ")"}], "2"]], " ", "+", " ", 
     FractionBox["\[DoubleStruckCapitalB]", 
      RowBox[{"z", " ", "-", " ", "0"}]], " ", "+", " ", 
     FractionBox["\[DoubleStruckCapitalC]", 
      RowBox[{"z", " ", "-", " ", "1"}]]}]}]}]]],
 "\n\nwhere  \n\t\t\t",
 Cell[BoxData[{
  RowBox[{"\[DoubleStruckCapitalA]", "  ", "=", "  ", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "0"}], ")"}], "f", 
       RowBox[{"(", "z", ")"}]}], ",", "0"}], "]"}], "=", " ", 
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"z", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z", "2"], " ", "+", " ", 
         RowBox[{"3", "z"}], " ", "+", " ", "2"}], 
        RowBox[{
         SuperscriptBox["z", "2"], 
         RowBox[{"(", 
          RowBox[{"z", " ", "-", " ", "1"}], ")"}]}]]}], ",", "0"}], 
     "]"}]}]}], "\[IndentingNewLine]", 
  RowBox[{"     ", 
   RowBox[{"=", "  ", 
    RowBox[{"Res", "[", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "2"], " ", "+", " ", 
        RowBox[{"3", "z"}], " ", "+", " ", "2"}], 
       RowBox[{"z", 
        RowBox[{"(", 
         RowBox[{"z", " ", "-", " ", "1"}], ")"}]}]], ",", "0"}], 
     "]"}]}]}], "\[IndentingNewLine]", 
  RowBox[{"     ", 
   RowBox[{"=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", "0"}]], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", "0"}], ")"}], 
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "2"], " ", "+", " ", 
        RowBox[{"3", "z"}], " ", "+", " ", "2"}], 
       RowBox[{"z", 
        RowBox[{"(", 
         RowBox[{"z", " ", "-", " ", "1"}], 
         ")"}]}]]}]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"     ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["2", 
      RowBox[{"-", " ", "1"}]], "  ", "=", "  ", 
     RowBox[{"-", "2"}]}]}]}]}]],
 "    \n\t\t\t\n\t\t\t",
 Cell[BoxData[{
  RowBox[{"\[DoubleStruckCapitalB]", "  ", "=", "  ", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", "0"}], "]"}], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "=", " ", 
    RowBox[{"Res", "[", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "2"], " ", "+", " ", 
        RowBox[{"3", "z"}], " ", "+", " ", "2"}], 
       RowBox[{
        SuperscriptBox["z", "2"], 
        RowBox[{"(", 
         RowBox[{"z", " ", "-", " ", "1"}], ")"}]}]], ",", "0"}], 
     "]"}]}]}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
     RowBox[{
      FractionBox["d", "dz"], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", "0"}], ")"}], "2"], 
        FractionBox[
         RowBox[{
          SuperscriptBox["z", "2"], " ", "+", " ", 
          RowBox[{"3", "z"}], " ", "+", " ", "2"}], 
         RowBox[{
          SuperscriptBox["z", "2"], 
          RowBox[{"(", 
           RowBox[{"z", " ", "-", " ", "1"}], ")"}]}]]}], 
       ")"}]}]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
     RowBox[{
      FractionBox["d", "dz"], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         SuperscriptBox["z", "2"], " ", "+", " ", 
         RowBox[{"3", "z"}], " ", "+", " ", "2"}], 
        RowBox[{"z", " ", "-", " ", "1"}]], 
       ")"}]}]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "z"}], "+", "3"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "1"}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", "1", ")"}], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], " ", "+", " ", 
          RowBox[{"3", "z"}], " ", "+", " ", "2"}], ")"}]}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], "2"]]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", "0"}]], " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], "-", 
       RowBox[{"2", " ", "z"}], "-", "5"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], "2"]]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"-", "5"}], "1"], "  ", "=", "  ", 
     RowBox[{"-", "5"}]}]}]}]}]],
 "    \n\t\t\t\t\t\t\n\t\t\t",
 Cell[BoxData[{
  RowBox[{"\[DoubleStruckCapitalC]", "  ", "=", "  ", 
   RowBox[{"Res", "[", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], " ", "+", " ", 
       RowBox[{"3", "z"}], " ", "+", " ", "2"}], 
      RowBox[{
       SuperscriptBox["z", "2"], 
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "1"}], ")"}]}]], ",", "1"}], 
    "]"}]}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", " ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", "1"}]], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "2"], " ", "+", " ", 
        RowBox[{"3", "z"}], " ", "+", " ", "2"}], 
       RowBox[{
        SuperscriptBox["z", "2"], 
        RowBox[{"(", 
         RowBox[{"z", " ", "-", " ", "1"}], 
         ")"}]}]]}]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", " ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", "1"}]], " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], " ", "+", " ", 
       RowBox[{"3", "z"}], " ", "+", " ", "2"}], 
      SuperscriptBox["z", "2"]]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", 
    RowBox[{
     FractionBox[
      RowBox[{"1", " ", "+", " ", "3", " ", "+", " ", "2"}], "1"], "  ", "=", 
     "  ", "6"}]}]}]}]],
 "    "
}], "Text"],

Cell[TextData[{
 "Thus,  \n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], " ", "+", " ", 
       RowBox[{"3", "z"}], " ", "+", " ", "2"}], 
      RowBox[{
       SuperscriptBox["z", "2"], 
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "1"}], ")"}]}]], " ", "=", " ", 
     RowBox[{
      FractionBox["\[DoubleStruckCapitalA]", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", " ", "-", " ", "0"}], ")"}], "2"]], " ", "+", " ", 
      FractionBox["\[DoubleStruckCapitalB]", 
       RowBox[{"z", " ", "-", " ", "0"}]], " ", "+", " ", 
      FractionBox["\[DoubleStruckCapitalC]", 
       RowBox[{"z", " ", "-", " ", "1"}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"-", "2"}], 
      SuperscriptBox[
       RowBox[{"z", " "}], "2"]], " ", "+", " ", 
     FractionBox[
      RowBox[{"-", "5"}], "z"], " ", "+", " ", 
     FractionBox["6", 
      RowBox[{"z", " ", "-", " ", "1"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["2", 
       SuperscriptBox[
        RowBox[{"z", " "}], "2"]]}], " ", "-", " ", 
     FractionBox["5", "z"], " ", "+", " ", 
     FractionBox["6", 
      RowBox[{"z", " ", "-", " ", "1"}]]}]}]}]}],
  AspectRatioFixed->True],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"8.9", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670549934375*^9, 3.506705499359375*^9}}],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z", "2"], " ", "+", " ", 
     RowBox[{"3", "z"}], " ", "+", " ", "2"}], 
    RowBox[{
     SuperscriptBox["z", "2"], 
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "1"}], ")"}]}]]}]],
  AspectRatioFixed->True],
 " and find the partial fraction expansion.  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "=", "0"}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "i", ",", "p", ",", "R", ",", "solset"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], " ", "+", " ", 
       RowBox[{"3", "z"}], " ", "+", " ", "2"}], 
      RowBox[{
       SuperscriptBox["z", "2"], 
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Denominator", "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}], 
       "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Z", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"Length", "[", "solset", "]"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"R", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"Length", "[", "solset", "]"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"Length", "[", "solset", "]"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\n", "   ", 
      RowBox[{
       RowBox[{
        SubscriptBox["Z", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], "=", 
        RowBox[{"ReplaceAll", "[", 
         RowBox[{"z", ",", 
          SubscriptBox["solset", 
           RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
         "]"}]}], ";", " ", "\n", "   ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"1", "\[Equal]", "i"}], ",", 
         RowBox[{"p", " ", "=", " ", "1"}]}], "]"}], ";", " ", "\n", "   ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "<", "i"}], ";", " ", 
          RowBox[{
           SubscriptBox["Z", 
            RowBox[{"\[LeftDoubleBracket]", 
             RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]], "\[Equal]", 
           SubscriptBox["Z", 
            RowBox[{
            "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}]}], ",", 
         RowBox[{"p", "=", 
          RowBox[{"p", "+", "1"}]}], ",", 
         RowBox[{"p", "=", "1"}]}], "]"}], ";", " ", "\n", "   ", 
       RowBox[{"Print", "[", 
        RowBox[{
         SubscriptBox["\"\<z\>\"", "i"], ",", "\"\< = \>\"", ",", 
         SubscriptBox["Z", 
          RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
        "]"}], ";", " ", "\n", "   ", 
       RowBox[{
        SubscriptBox["R", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Residue", "[", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z", "-", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
             ")"}], 
            RowBox[{"p", "-", "1"}]], 
           RowBox[{"f", "[", "z", "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"z", ",", 
            SubscriptBox["Z", 
             RowBox[{
             "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
           "}"}]}], "]"}]}], ";", " ", "\n", "   ", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Res[\>\"", ",", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", 
            SubscriptBox["Z", 
             RowBox[{
             "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], ")"}], 
          RowBox[{"p", "-", "1"}]], ",", "\"\< f,\>\"", ",", 
         SubscriptBox["Z", 
          RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
         ",", "\"\<] = \>\"", ",", 
         SubscriptBox["R", 
          RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
        "]"}], ";", " ", "\n", "   ", 
       RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";", " ", "\n", "   ", 
       RowBox[{
        RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
        RowBox[{
         RowBox[{"F", "[", "z", "]"}], " ", "+", " ", 
         FractionBox[
          SubscriptBox["R", 
           RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", 
             SubscriptBox["Z", 
              RowBox[{
              "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
            ")"}], "p"]]}]}], ";"}]}], " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39998221946875*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "Compare this with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s Apart  procedure for the partial fraction expansion."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"Apart", "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3999822266875*^9},
 AspectRatioFixed->True],

Cell["\<\
In the next example we will see that our subroutine will work for complex \
factors and \"Apart\" does not.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->False]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Express  of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["z", "4"], " ", "-", " ", "1"}]]}]],
  AspectRatioFixed->True],
 "  in partial fractions.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox["Explore",
   FontWeight->"Bold",
   FontColor->RGBColor[1, 0, 1]], 
  StyleBox[" ",
   FontWeight->"Bold",
   FontColor->RGBColor[1, 0, 1]], 
  StyleBox["Solution",
   FontWeight->"Bold",
   FontColor->RGBColor[1, 0, 1]], 
  StyleBox[" ",
   FontWeight->"Bold",
   FontColor->RGBColor[1, 0, 1]], 
  StyleBox["for",
   FontWeight->"Bold",
   FontColor->RGBColor[1, 0, 1]], 
  StyleBox[" ",
   FontWeight->"Bold",
   FontColor->RGBColor[1, 0, 1]], 
  StyleBox["Extra",
   FontWeight->"Bold",
   FontColor->RGBColor[1, 0, 1]], 
  StyleBox[" ",
   FontWeight->"Bold",
   FontColor->RGBColor[1, 0, 1]], 
  StyleBox["Example",
   FontWeight->"Bold",
   FontColor->RGBColor[1, 0, 1]], 
  StyleBox[" ",
   FontWeight->"Bold",
   FontColor->RGBColor[1, 0, 1]], 
  StyleBox["1.",
   FontWeight->"Bold",
   FontColor->RGBColor[1, 0, 1]], "  "}]], "Subsection",
 CellChangeTimes->{{3.50670550246875*^9, 3.50670550246875*^9}}],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["z", "4"], " ", "-", " ", "1"}]]}]],
  AspectRatioFixed->True],
 " and find the partial fraction expansion.  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "=", "0"}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "i", ",", "p", ",", "R", ",", "solset"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox["1", 
      RowBox[{
       SuperscriptBox["z", "4"], "-", "1"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Denominator", "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}], 
       "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Z", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"Length", "[", "solset", "]"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"R", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"Length", "[", "solset", "]"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"Length", "[", "solset", "]"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\n", "   ", 
      RowBox[{
       RowBox[{
        SubscriptBox["Z", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], "=", 
        RowBox[{"ReplaceAll", "[", 
         RowBox[{"z", ",", 
          SubscriptBox["solset", 
           RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
         "]"}]}], ";", " ", "\n", "   ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"1", "\[Equal]", "i"}], ",", 
         RowBox[{"p", " ", "=", " ", "1"}]}], "]"}], ";", " ", "\n", "   ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "<", "i"}], ";", " ", 
          RowBox[{
           SubscriptBox["Z", 
            RowBox[{"\[LeftDoubleBracket]", 
             RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]], "\[Equal]", 
           SubscriptBox["Z", 
            RowBox[{
            "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}]}], ",", 
         RowBox[{"p", "=", 
          RowBox[{"p", "+", "1"}]}], ",", 
         RowBox[{"p", "=", "1"}]}], "]"}], ";", " ", "\n", "   ", 
       RowBox[{"Print", "[", 
        RowBox[{
         SubscriptBox["\"\<z\>\"", "i"], ",", "\"\< = \>\"", ",", 
         SubscriptBox["Z", 
          RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
        "]"}], ";", " ", "\n", "   ", 
       RowBox[{
        SubscriptBox["R", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Residue", "[", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z", "-", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
             ")"}], 
            RowBox[{"p", "-", "1"}]], 
           RowBox[{"f", "[", "z", "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"z", ",", 
            SubscriptBox["Z", 
             RowBox[{
             "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
           "}"}]}], "]"}]}], ";", " ", "\n", "   ", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Res[\>\"", ",", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", 
            SubscriptBox["Z", 
             RowBox[{
             "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], ")"}], 
          RowBox[{"p", "-", "1"}]], ",", "\"\< f,\>\"", ",", 
         SubscriptBox["Z", 
          RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
         ",", "\"\<] = \>\"", ",", 
         SubscriptBox["R", 
          RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
        "]"}], ";", " ", "\n", "   ", 
       RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";", " ", "\n", "   ", 
       RowBox[{
        RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
        RowBox[{
         RowBox[{"F", "[", "z", "]"}], " ", "+", " ", 
         FractionBox[
          SubscriptBox["R", 
           RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", 
             SubscriptBox["Z", 
              RowBox[{
              "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
            ")"}], "p"]]}]}], ";"}]}], " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399982236484375*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "Which is an improvement on ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s \"Apart\"  procedure."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"Apart", "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399982245515625*^9, 3.3999822465*^9}},
 AspectRatioFixed->True]
}, Closed]]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{900, 619},
WindowMargins->{{17, Automatic}, {Automatic, 1}},
Magnification->1,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 113, 2, 29, "Text"],
Cell[1664, 50, 178, 3, 29, "Text"],
Cell[1845, 55, 645, 12, 119, "Text"],
Cell[2493, 69, 1474, 45, 93, "Text",
 Evaluatable->False],
Cell[3970, 116, 1750, 67, 164, "Text"],
Cell[5723, 185, 1536, 56, 123, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[7284, 245, 231, 6, 37, "Subsection"],
Cell[7518, 253, 272, 10, 37, "Text"],
Cell[7793, 265, 1121, 33, 181, "Input"],
Cell[8917, 300, 186, 7, 35, "Text",
 Evaluatable->False],
Cell[9106, 309, 2554, 66, 172, "Input"],
Cell[11663, 377, 738, 19, 92, "Input"],
Cell[12404, 398, 279, 10, 29, "Text",
 Evaluatable->False],
Cell[12686, 410, 1205, 33, 152, "Input"]
}, Closed]],
Cell[13906, 446, 552, 23, 34, "Text",
 Evaluatable->False],
Cell[14461, 471, 4935, 169, 299, "Text"],
Cell[CellGroupData[{
Cell[19421, 644, 231, 6, 37, "Subsection"],
Cell[19655, 652, 2515, 67, 295, "Input"],
Cell[22173, 721, 357, 12, 37, "Text"],
Cell[22533, 735, 1194, 34, 190, "Input"],
Cell[23730, 771, 355, 15, 35, "Text",
 Evaluatable->False],
Cell[24088, 788, 2668, 68, 172, "Input"],
Cell[26759, 858, 709, 19, 92, "Input"],
Cell[27471, 879, 279, 10, 29, "Text",
 Evaluatable->False],
Cell[27753, 891, 589, 16, 92, "Input"]
}, Closed]],
Cell[28357, 910, 4047, 148, 220, "Text"],
Cell[32407, 1060, 859, 34, 39, "Text",
 Evaluatable->False],
Cell[33269, 1096, 2217, 39, 209, "Text",
 Evaluatable->False],
Cell[35489, 1137, 1116, 40, 83, "Text"],
Cell[CellGroupData[{
Cell[36630, 1181, 231, 6, 37, "Subsection"],
Cell[36864, 1189, 105, 2, 29, "Text",
 Evaluatable->False],
Cell[36972, 1193, 1653, 46, 216, "Input"],
Cell[38628, 1241, 148, 4, 29, "Text",
 Evaluatable->False],
Cell[38779, 1247, 3715, 102, 322, "Input"]
}, Closed]],
Cell[42509, 1352, 2324, 83, 120, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[44858, 1439, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[45002, 1445, 170, 4, 29, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[45187, 1452, 22630, 399, 280, "Text"],
Cell[67820, 1853, 1874, 65, 101, "Text",
 Evaluatable->False],
Cell[69697, 1920, 3477, 140, 209, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[73199, 2064, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[73343, 2070, 246, 9, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[73604, 2082, 512, 21, 33, "Text",
 Evaluatable->False],
Cell[74119, 2105, 8160, 265, 464, "Text"],
Cell[82282, 2372, 4522, 143, 380, "Text"],
Cell[CellGroupData[{
Cell[86829, 2519, 227, 6, 37, "Subsection"],
Cell[87059, 2527, 301, 12, 36, "Text"],
Cell[87363, 2541, 787, 23, 149, "Input"],
Cell[88153, 2566, 247, 8, 29, "Text",
 Evaluatable->False],
Cell[88403, 2576, 2368, 65, 250, "Input"],
Cell[90774, 2643, 279, 10, 29, "Text",
 Evaluatable->False],
Cell[91056, 2655, 535, 15, 92, "Input"],
Cell[91594, 2672, 196, 7, 35, "Text",
 Evaluatable->False],
Cell[91793, 2681, 3068, 79, 192, "Input"],
Cell[94864, 2762, 1277, 35, 172, "Input"]
}, Closed]],
Cell[96156, 2800, 978, 38, 34, "Text",
 Evaluatable->False],
Cell[97137, 2840, 2319, 41, 209, "Text",
 Evaluatable->False],
Cell[99459, 2883, 6079, 208, 417, "Text"],
Cell[105541, 3093, 2018, 61, 202, "Text"],
Cell[CellGroupData[{
Cell[107584, 3158, 231, 6, 37, "Subsection"],
Cell[107818, 3166, 444, 18, 37, "Text",
 Evaluatable->False],
Cell[108265, 3186, 3656, 103, 430, "Input"],
Cell[111924, 3291, 228, 9, 29, "Text",
 Evaluatable->False],
Cell[112155, 3302, 6700, 181, 272, "Input"],
Cell[118858, 3485, 266, 11, 29, "Text",
 Evaluatable->False],
Cell[119127, 3498, 1441, 43, 172, "Input"],
Cell[120571, 3543, 111, 2, 29, "Text",
 Evaluatable->False],
Cell[120685, 3547, 6304, 168, 426, "Input"]
}, Closed]],
Cell[127004, 3718, 886, 35, 34, "Text",
 Evaluatable->False],
Cell[127893, 3755, 1957, 35, 171, "Text",
 Evaluatable->False],
Cell[129853, 3792, 2938, 100, 233, "Text"],
Cell[132794, 3894, 2870, 90, 293, "Text"],
Cell[CellGroupData[{
Cell[135689, 3988, 231, 6, 37, "Subsection"],
Cell[135923, 3996, 328, 14, 37, "Text",
 Evaluatable->False],
Cell[136254, 4012, 3632, 101, 430, "Input"],
Cell[139889, 4115, 255, 10, 29, "Text",
 Evaluatable->False],
Cell[140147, 4127, 6892, 185, 295, "Input"],
Cell[147042, 4314, 611, 19, 83, "Text",
 Evaluatable->False],
Cell[147656, 4335, 1011, 30, 132, "Input"],
Cell[148670, 4367, 111, 2, 29, "Text",
 Evaluatable->False],
Cell[148784, 4371, 5173, 140, 409, "Input"],
Cell[153960, 4513, 595, 17, 47, "Text",
 Evaluatable->False]
}, Closed]],
Cell[154570, 4533, 222, 6, 25, "SmallText"],
Cell[154795, 4541, 4453, 151, 211, "Text",
 Evaluatable->False],
Cell[159251, 4694, 3443, 116, 318, "Text"],
Cell[162697, 4812, 4229, 145, 295, "Text"],
Cell[CellGroupData[{
Cell[166951, 4961, 231, 6, 37, "Subsection"],
Cell[167185, 4969, 3683, 101, 294, "Input"],
Cell[170871, 5072, 151, 6, 47, "Text",
 Evaluatable->False],
Cell[171025, 5080, 1263, 32, 134, "Input"],
Cell[172291, 5114, 151, 6, 47, "Text",
 Evaluatable->False],
Cell[172445, 5122, 3842, 95, 198, "Input"]
}, Closed]],
Cell[176302, 5220, 553, 21, 34, "Text",
 Evaluatable->False],
Cell[176858, 5243, 5886, 194, 335, "Text"],
Cell[CellGroupData[{
Cell[182769, 5441, 231, 6, 37, "Subsection"],
Cell[183003, 5449, 4740, 134, 680, "Input"],
Cell[187746, 5585, 428, 15, 37, "Text"],
Cell[188177, 5602, 5977, 166, 545, "Input"],
Cell[194157, 5770, 205, 7, 29, "Text",
 Evaluatable->False],
Cell[194365, 5779, 476, 14, 92, "Input"],
Cell[194844, 5795, 171, 5, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[195030, 5803, 3859, 129, 184, "Text",
 Evaluatable->False],
Cell[198892, 5934, 549, 21, 44, "Text",
 Evaluatable->False],
Cell[199444, 5957, 7330, 242, 590, "Text"],
Cell[206777, 6201, 1564, 50, 157, "Text"],
Cell[CellGroupData[{
Cell[208366, 6255, 230, 6, 37, "Subsection"],
Cell[208599, 6263, 433, 15, 44, "Text"],
Cell[209035, 6280, 6059, 168, 551, "Input"],
Cell[215097, 6450, 205, 7, 29, "Text",
 Evaluatable->False],
Cell[215305, 6459, 475, 14, 92, "Input"],
Cell[215783, 6475, 178, 5, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[215976, 6483, 391, 15, 34, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[216392, 6502, 949, 35, 37, "Subsection"],
Cell[217344, 6539, 282, 10, 37, "Text"],
Cell[217629, 6551, 5899, 163, 544, "Input"],
Cell[223531, 6716, 183, 7, 29, "Text",
 Evaluatable->False],
Cell[223717, 6725, 496, 14, 92, "Input"]
}, Closed]]
}
]
*)

(* End of internal cache information *)
