(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    145579,       4209]
NotebookOptionsPosition[    141982,       4097]
NotebookOutlinePosition[    142393,       4115]
CellTagsIndexPosition[    142350,       4112]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[StyleBox["8.2  Trigonometric Integrals",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.532709504015625*^9, 3.532709504796875*^9}}],

Cell["\<\
\tAs indicated at the beginning of this chapter, we can evaluate certain \
definite real integrals with the aid of the residue theorem.  One way to do \
this is by interpreting the definite integral as the parametric form of an \
integral of an analytic function along a simple closed contour.\
\>", "Text"],

Cell[TextData[{
 "\tSuppose we wish to evaluate an integral of the form  \n\n",
 StyleBox["(8-3)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", 
    RowBox[{"2", "\[Pi]"}]], "  ", 
   RowBox[{"F", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cos", " ", "\[Theta]"}], ",", 
      RowBox[{"sin", " ", "\[Theta]"}]}], ")"}], 
    RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]]],
 ",    \n\nwhere ",
 StyleBox["F(u,v)",
  FontFamily->"Courier New"],
 " is a function of the two real variables ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["v",
  FontFamily->"Courier New"],
 ".  Consider the unit circle ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "1"], 
    RowBox[{"(", "0", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", ":", 
      RowBox[{"|", "z", "|"}]}], "=", "1"}], "}"}]}]]],
 " with parametrization  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubsuperscriptBox["C", "1", "+"], 
     RowBox[{"(", "0", ")"}]}], ":", "  ", "z"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"cos", " ", "\[Theta]"}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "sin", " ", "\[Theta]"}]}], "  ", "=", 
    "  ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]}]]],
 ",    for    ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "\[Theta]", "\[LessEqual]", 
   RowBox[{"2", "\[Pi]"}]}]]],
 ";   \n\nwhich gives us the following symbolic differentials.\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[DifferentialD]", "z"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "sin"}], " ", "\[Theta]"}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "cos", " ", "\[Theta]"}]}], ")"}], 
     RowBox[{"\[DifferentialD]", "\[Theta]"}]}], "   ", "=", "  ", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], 
     RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]}]]],
 ",    and   \n",
 StyleBox["(8-4)",
  FontColor->RGBColor[0, 0, 1]],
 "\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[DifferentialD]", "\[Theta]"}], "   ", "=", "  ", 
   RowBox[{
    FractionBox[
     RowBox[{"\[DifferentialD]", "z"}], 
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]], "  ", "=", "  ", 
    FractionBox[
     RowBox[{"\[DifferentialD]", "z"}], 
     RowBox[{"\[ImaginaryI]", " ", "z"}]]}]}]]],
 ".  \n\nCombining   ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{
    RowBox[{"cos", " ", "\[Theta]"}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "sin", " ", "\[Theta]"}]}]}]]],
 "   with   ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", "z"], " ", "=", " ", 
   RowBox[{
    RowBox[{"cos", " ", "\[Theta]"}], " ", "-", " ", 
    RowBox[{"\[ImaginaryI]", " ", "sin", " ", "\[Theta]"}]}]}]]],
 ",   we can obtain  \n\n",
 StyleBox["(8-5)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", " ", "\[Theta]"}], "  ", "=", "  ", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{"z", "+", 
      FractionBox["1", "z"]}], ")"}]}]}]]],
 "    and    ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"sin", " ", "\[Theta]"}], "  ", "=", "  ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "\[ImaginaryI]"}]], 
    RowBox[{"(", 
     RowBox[{"z", "-", 
      FractionBox["1", "z"]}], ")"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Using the substitutions for  ",
 Cell[BoxData[
  RowBox[{"cos", " ", "\[Theta]"}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{"sin", " ", "\[Theta]"}]]],
 " , and  ",
 Cell[BoxData[
  RowBox[{"\[DifferentialD]", "\[Theta]"}]]],
 "  in Expression ",
 StyleBox["(8-3)",
  FontColor->RGBColor[0, 0, 1]],
 " transforms the definite integral into a contour integral \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", 
     RowBox[{"2", "\[Pi]"}]], "  ", 
    RowBox[{"F", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", " ", "\[Theta]"}], ",", 
       RowBox[{"sin", " ", "\[Theta]"}]}], ")"}], 
     RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}], "   ", "=", "  ", 
   RowBox[{
    SubscriptBox["\[ContourIntegral]", 
     RowBox[{" ", 
      RowBox[{
       SubsuperscriptBox["C", "1", "+"], 
       RowBox[{"(", "0", ")"}]}]}]], " ", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}], " ", 
     RowBox[{"\[DifferentialD]", "z"}], " "}]}]}]]],
 ",  \n\nwhere the new integrand is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "\[ImaginaryI]z"], "F", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"(", 
        RowBox[{"z", "+", 
         FractionBox["1", "z"]}], ")"}]}], ",", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", "\[ImaginaryI]"}]], 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         FractionBox["1", "z"]}], ")"}]}]}], ")"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "\tSuppose that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is analytic inside and on the unit circle ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["C", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 ", except at the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], ",", 
   SubscriptBox["z", "2"], ",", " ", "...", ",", 
   SubscriptBox["z", "n"]}]]],
 "  that lie interior to  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["C", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 ".  Then the residue theorem gives\n\n",
 StyleBox["(8-6)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", 
     RowBox[{"2", "\[Pi]"}]], "  ", 
    RowBox[{"F", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", " ", "\[Theta]"}], ",", 
       RowBox[{"sin", " ", "\[Theta]"}]}], ")"}], 
     RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}], "   ", "=", "  ", 
   RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "1"}], "n"], 
     RowBox[{"Res", "[", 
      RowBox[{"f", ",", 
       SubscriptBox["z", "k"]}], "]"}]}]}]}]]],
 ".  \n\nThe situation is illustrated in Figure 8.2."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{534, 277},
  ImageMargins->0],
 StyleBox["  \n\n",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\t  Figure 8.2  ",
 "The change of variables from a definite integral on ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"0", ",", 
    RowBox[{"2", "\[Pi]"}]}], "]"}]]],
 " to a contour integral around ",
 StyleBox["C",
  FontFamily->"Courier New"],
 "."
}], "Text",
 CellChangeTimes->{
  3.399463887625*^9, {3.399463958125*^9, 3.39946396940625*^9}, 
   3.39946404246875*^9, {3.506762252875*^9, 3.506762255734375*^9}}],

Cell[TextData[{
 "Some of these problems can be solved using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s table of integrals."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["We need to use the following substitution procedure.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"f0", ",", "F", ",", "sub", ",", "\[Theta]", ",", "z"}], "]"}], 
   ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"sub", "[", 
     RowBox[{"F_", ",", "\[Theta]_"}], "]"}], " ", ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Clear", "[", "f0", "]"}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"f0", " ", "=", " ", "F"}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"f0", " ", "=", " ", 
        RowBox[{"ReplaceAll", "[", 
         RowBox[{"f0", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Cos", "[", "\[Theta]", "]"}], "\[Rule]", 
             FractionBox[
              RowBox[{"z", "+", 
               FractionBox["1", "z"]}], "2"]}], ",", 
            RowBox[{
             RowBox[{"Sin", "[", "\[Theta]", "]"}], "\[Rule]", 
             FractionBox[
              RowBox[{"z", "-", 
               FractionBox["1", "z"]}], 
              RowBox[{"2", "\[ImaginaryI]"}]]}]}], "}"}]}], "]"}]}], ";", " ",
        "\[IndentingNewLine]", 
       RowBox[{"f0", " ", "=", " ", 
        RowBox[{"ReplaceAll", "[", 
         RowBox[{"f0", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", "\[Theta]"}], "]"}], "\[Rule]", 
             FractionBox[
              RowBox[{
               SuperscriptBox["z", "2"], "+", 
               FractionBox["1", 
                SuperscriptBox["z", "2"]]}], "2"]}], ",", 
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{"2", "\[Theta]"}], "]"}], "\[Rule]", 
             FractionBox[
              RowBox[{
               SuperscriptBox["z", "2"], "-", 
               FractionBox["1", 
                SuperscriptBox["z", "2"]]}], 
              RowBox[{"2", "\[ImaginaryI]"}]]}]}], "}"}]}], "]"}]}], ";", " ",
        "\[IndentingNewLine]", 
       RowBox[{"f0", " ", "=", " ", 
        RowBox[{"ReplaceAll", "[", 
         RowBox[{"f0", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"3", "\[Theta]"}], "]"}], "\[Rule]", 
             FractionBox[
              RowBox[{
               SuperscriptBox["z", "3"], "+", 
               FractionBox["1", 
                SuperscriptBox["z", "3"]]}], "2"]}], ",", 
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{"3", "\[Theta]"}], "]"}], "\[Rule]", 
             FractionBox[
              RowBox[{
               SuperscriptBox["z", "3"], "-", 
               FractionBox["1", 
                SuperscriptBox["z", "3"]]}], 
              RowBox[{"2", "\[ImaginaryI]"}]]}]}], "}"}]}], "]"}]}], ";", " ",
        "\[IndentingNewLine]", 
       RowBox[{"f0", " ", "=", " ", 
        FractionBox["f0", 
         RowBox[{"\[ImaginaryI]", " ", "z"}]]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"f0", " ", "=", " ", 
        RowBox[{"Together", "[", "f0", "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"f0", " ", "=", " ", 
        RowBox[{"Cancel", "[", "f0", "]"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"Return", "[", "f0", "]"}], ";"}]}], "  ", "]"}]}], ";"}], 
  " "}]}], "Input",
 InitializationCell->True,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Example 8.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "    Evaluate  ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", 
    RowBox[{"2", "\[Pi]"}]], 
   RowBox[{
    FractionBox[
     RowBox[{" ", "1"}], 
     RowBox[{"1", " ", "+", " ", 
      RowBox[{"3", " ", 
       SuperscriptBox["cos", "2"], "\[Theta]"}]}]], 
    RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]]],
 "  by using complex analysis.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztWtlOFEEUbWYGkKiEXZBtQEBZn4wP+q4PiguKu8QJLhBDwAH1AfRn3DcU
URSXEDUxxoiJ6Cf4HyNVt/p2T82pZnroQQNMyHRT59xzb1V31VTdqu7Y2MDF
odjYYH8sui8eGxkY7B+N7h2OLxaFcywrp8eyrD9RS9wnFm/VV2LxL3FUfIkS
f/e/5SVskZBErPHlQN/FJSKAyBIkDco10+cBJNVDomSCSF88HYeXCiaSBHmH
P8++PYL22Xz5rBk3kwpA2bCZniv+QTUfcdvkJkGq9lYImKEyD/fpSIjPVbME
Ch7Jqgr9okZM2LVOeajX6WaB3pWEqqZsgWsE/RSXPAGNGwoc4wnd680sdap1
aB1alZAce43DlCL9AJAHXY7OhaL8BhXIXwY1XItfP7K1LdE4H7HDSsQ1CTES
pBVMAVuosemTuIgBKZHviifVcCP7vkKGc+IiOIkSQC9iP4NE/8AF5YBewuhl
or9nkjP+I8MywLtAEu8AVAEkygGvnyRmOawqYFjBqKK/5oJqQK9kNEb0GeAY
GW4FvD6SeAWgGiBRDXjnSGKaw6oHhnncE4qZpwxfAE0kscH0vDXbM/5kjd2z
FAicJu0pAEUdNS6zO2LIA6sAWqcIfQ6gBhApmjKgGqE39CS5muSn0mQUi+jx
y07uvI5K6inwso1I5plLLTA6btZrFN/aDAdJ9JLEE5OEnPg0AfQYGT421UUa
NgNULTweAaiZg27xZ9jCrbcDoD1k+BBADt1KFluexHbAOxKYxAMAtQIJ1BaH
A5O4D6C27Ei0At4hkrgHoPbsSLQB3kGSuAugjuxItANed2ASdwDUCSQ6AO9A
YBKj4iJHwE4Xyf7IQRU9IHeZbSDJHaxX7XKgWXdp8SS7x3Hb5YhHswNrzCgR
Saq6D29dgKcqNsQ1RdPaFkbVzFMLAEbgfgSpbaVPnlTTpvx8+agyctiBVatd
bRxy9Bw36uPdshbTu1hIPb3baVYexbx/tUjs5laxnKWT+GxavvYejSc+m13v
8i7l1j0A9IGyneILTYBVjHEA6T3eT9yIx0u+LLTT//EmrFWJ7P7crTmJ7M5h
ApiMBTAlDEAigOnxCkrIrJYsqgMWPtcdcr2KVu0ZafvPOSA3Phdw6eYcapbv
KqweAKqJfUVu1KrWe0VtyEegqqDkl4cPZ7nv5CjqAU8t/DNONWSc3PBOrCDD
XrOhk+FBhiqVM2ky1Fq60SzxzBS0JtEAeCdIIt20WhTwVI5rimq7iCDDOkZ9
5iJRCktJTAOozp/ESwDVAgnUl86SRAB54hluHGRYxeh5or8BSiiJXgl4SmIW
QJVAYgvgqRT7Ww4LGZYzqrYM5K6DFEJ7DaVMv0T0OS4oBfQiFhsg+kemFwN6
IaNqg+WzuMgdF973gcNbAfOGyPArK6V75IC3fuyNpW/iUiYKKFHgd7Mrk72x
gE8urEPr0IpBcokvi0bMpEyOycgpSCRF2GvqmJeE2feW54EW46ww5DJ0DpSg
Xoq6t6qddq7FeP7FOdNiJWcqpKrpJMzaPfjyzw61+Rze/4+jbAqS/2R4LNF0
v8Dh3nK9gpr/iSVD061cLb6Am3DC1SfCqqu4O06GdbZy/gJeprwp\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{338, 228},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  Using Substitutions ",
 StyleBox["(8-4)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(8-5)",
  FontColor->RGBColor[0, 0, 1]],
 ", we transform the integral to  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[ContourIntegral]", 
     RowBox[{" ", 
      RowBox[{
       SubsuperscriptBox["C", "1", "+"], 
       RowBox[{"(", "0", ")"}]}]}]], " ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"1", "+", 
       RowBox[{"3", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox[
           RowBox[{"z", "+", 
            SuperscriptBox["z", 
             RowBox[{"-", "1"}]]}], "2"], ")"}], "2"]}]}]], 
     FractionBox["1", 
      RowBox[{"\[ImaginaryI]", " ", "z"}]], " ", 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[ContourIntegral]", 
      RowBox[{" ", 
       RowBox[{
        SubsuperscriptBox["C", "1", "+"], 
        RowBox[{"(", "0", ")"}]}]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", "z"}], 
       RowBox[{
        RowBox[{"3", 
         SuperscriptBox["z", "4"]}], "+", 
        RowBox[{"10", 
         SuperscriptBox["z", "2"]}], "+", "3"}]], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{
     SubscriptBox["\[ContourIntegral]", 
      RowBox[{" ", 
       RowBox[{
        SubsuperscriptBox["C", "1", "+"], 
        RowBox[{"(", "0", ")"}]}]}]], " ", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]]],
 "\n\nwhere  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", "z"}], 
    RowBox[{
     RowBox[{"3", 
      SuperscriptBox["z", "4"]}], "+", 
     RowBox[{"10", 
      SuperscriptBox["z", "2"]}], "+", "3"}]]}]]],
 ".  The singularities of ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " are poles located at the points where  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"3", 
     SuperscriptBox["z", "4"]}], "+", 
    RowBox[{"10", 
     SuperscriptBox["z", "2"]}], "+", "3"}], "=", "0"}]]],
 "  or equivalently, where  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"3", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["z", "2"], ")"}], "2"]}], "+", 
    RowBox[{"10", 
     SuperscriptBox["z", "2"]}], "+", "3"}], "=", "0"}]]],
 ".  Using the quadratic formula, we see that the singular points satisfy the \
relation  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "2"], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"-", "10"}], "\[PlusMinus]", 
      SqrtBox[
       RowBox[{"100", "-", "36"}]]}], "6"], " ", "=", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "5"}], "\[PlusMinus]", "4"}], "3"]}]}]]],
 "  which implies that  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "2"], " ", "=", "3"}]]],
 "  or  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "2"], "=", 
   RowBox[{"-", 
    FractionBox["1", "3"]}]}]]],
 ".  Hence the only singularities that lie inside the unit circle are simple \
poles corresponding to the solutions of  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "2"], "=", 
   RowBox[{"-", 
    FractionBox["1", "3"]}]}]]],
 ",  which are the two points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{"-", 
    FractionBox["\[ImaginaryI]", 
     SqrtBox["3"]]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   FractionBox["\[ImaginaryI]", 
    SqrtBox["3"]]}]]],
 ".  We use Theorem 8.2 and L'H\[OHat]pital's rule to get the residues at ",
 Cell[BoxData[
  SubscriptBox["z", "1"]]],
 " and ",
 Cell[BoxData[
  SubscriptBox["z", "2"]]],
 ":  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", 
      SubscriptBox["z", "k"]}], "]"}], " ", "=", " ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "k"]}]], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["z", "k"]}], ")"}], "f", 
      RowBox[{"(", "z", ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                       ", 
   RowBox[{"=", " ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "k"]}]], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["z", "k"]}], ")"}], 
      FractionBox[
       RowBox[{
        RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", "z"}], 
       RowBox[{
        RowBox[{"3", 
         SuperscriptBox["z", "4"]}], "+", 
        RowBox[{"10", 
         SuperscriptBox["z", "2"]}], "+", "3"}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{"=", " ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "k"]}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", "z", 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         SubscriptBox["z", "k"]}], ")"}]}], 
      RowBox[{
       RowBox[{"3", 
        SuperscriptBox["z", "4"]}], "+", 
       RowBox[{"10", 
        SuperscriptBox["z", "2"]}], "+", "3"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", 
        SubscriptBox["z", "k"]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "-", " ", 
          RowBox[{"z", " ", 
           SubscriptBox["z", "k"]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"3", 
         SuperscriptBox["z", "4"]}], "+", 
        RowBox[{"10", 
         SuperscriptBox["z", "2"]}], "+", "3"}]]}], "  ", "=", "  ", 
     RowBox[{"'", 
      RowBox[{
       FractionBox["0", "0"], "'"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "k"]}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "z"}], " ", "-", " ", 
         SubscriptBox["z", "k"]}], ")"}]}], 
      RowBox[{
       RowBox[{"12", 
        SuperscriptBox["z", "3"]}], "+", 
       RowBox[{"20", "z"}]}]]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "k"]}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["z", "k"]}], " ", "-", " ", 
         SubscriptBox["z", "k"]}], ")"}]}], 
      RowBox[{
       RowBox[{"12", 
        SubsuperscriptBox["z", "k", "3"]}], "+", 
       RowBox[{"20", " ", 
        SubscriptBox["z", "k"]}]}]]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{
      RowBox[{"-", " ", "\[ImaginaryI]"}], " ", "4", 
      SubscriptBox["z", "k"]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"12", 
         SubsuperscriptBox["z", "k", "2"]}], "+", "20"}], ")"}], " ", 
      SubscriptBox["z", "k"]}]]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                    ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{
      RowBox[{"-", " ", "\[ImaginaryI]"}], " ", "4"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"12", 
        SubsuperscriptBox["z", "k", "2"]}], "+", "20"}], ")"}]]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                    ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{"-", " ", "\[ImaginaryI]"}], 
     RowBox[{
      RowBox[{"3", 
       SubsuperscriptBox["z", "k", "2"]}], "+", "5"}]], "  "}]}]}]],
 "   "
}], "Text"],

Cell[TextData[{
 "\nAs  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "k"], "=", 
   RowBox[{"\[PlusMinus]", 
    FractionBox["\[ImaginaryI]", 
     SqrtBox["3"]]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["z", "k", "2"], " ", "=", " ", 
   FractionBox[
    RowBox[{"-", "1"}], "3"]}]]],
 ",  the residues are given by  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{"f", ",", 
     SubscriptBox["z", "k"]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", 
      FractionBox[
       RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}], 
       SqrtBox["3"]]}], "]"}], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"-", " ", "\[ImaginaryI]"}], 
      RowBox[{
       RowBox[{"3", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{"-", "1"}], "3"], ")"}]}], "+", "5"}]], " ", "=", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"-", " ", "\[ImaginaryI]"}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", "5"}]], "=", " ", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{" ", "\[ImaginaryI]"}], "4"]}]}]}]}]}]]],
 ".  We now use Equation ",
 StyleBox["(8-6)",
  FontColor->RGBColor[0, 0, 1]],
 " to compute the value of the integral: \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", 
      RowBox[{"2", "\[Pi]"}]], 
     RowBox[{
      FractionBox[
       RowBox[{" ", "1"}], 
       RowBox[{"1", " ", "+", " ", 
        RowBox[{"3", " ", 
         SuperscriptBox["cos", "2"], "\[Theta]"}]}]], 
      RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}], "  ", "=", "  ", 
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", 
         SubscriptBox["z", "1"]}], "]"}], " ", "+", " ", 
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", 
         SubscriptBox["z", "2"]}], "]"}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                  ", 
   RowBox[{"=", "  ", 
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", 
         FractionBox["\[ImaginaryI]", 
          SqrtBox["3"]]}], "]"}], " ", "+", " ", 
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", 
         FractionBox[
          RowBox[{"-", "\[ImaginaryI]"}], 
          SqrtBox["3"]]}], "]"}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                  ", 
   RowBox[{"=", "   ", 
    RowBox[{
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{" ", "\[ImaginaryI]"}], "4"]}], " ", "-", " ", 
        FractionBox[
         RowBox[{" ", "\[ImaginaryI]"}], "4"]}], ")"}]}], "=", "   ", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{" ", "\[ImaginaryI]"}], "2"]}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                  ", 
   RowBox[{"=", "  ", "\[Pi]"}]}]}]],
 "   "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"8.10", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.5067055405625*^9, 3.506705540578125*^9}}],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", "[", "\[Theta]", "]"}], "=", 
   FractionBox[
    RowBox[{" ", "1"}], 
    RowBox[{"1", " ", "+", " ", 
     RowBox[{"3", " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]}]],
  AspectRatioFixed->True],
 " and use substitution to obtain the complex function f[z].  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", "0"}], ";", " ", 
    RowBox[{"Remove", "[", "Z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "G", ",", "F", ",", "Res1", ",", "Res2", ",", "Res3", ",", 
      "Res4", ",", "solset", ",", "\[Theta]", ",", "val", ",", "z"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "\[Theta]_", "]"}], " ", "=", 
     FractionBox[
      RowBox[{" ", "1"}], 
      RowBox[{"1", " ", "+", " ", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"sub", "[", 
      RowBox[{
       RowBox[{"F", "[", "\[Theta]", "]"}], ",", "\[Theta]"}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\[Theta]] = \>\"", ",", 
      RowBox[{"F", "[", "\[Theta]", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399999918375*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "Locate the singularities of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{"-", " ", "4"}], " ", "\[ImaginaryI]", " ", "z"}], 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["z", "4"]}], " ", "+", " ", 
     RowBox[{"10", " ", 
      SuperscriptBox["z", "2"]}], " ", "+", " ", "3"}]]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Denominator", "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}], 
       "]"}], "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The singularities are\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "2"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "3"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "4"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["Z", "4"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399999925015625*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "Find out which singularities lie inside the unit circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", "z", "|"}]}], "=", "1"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "3"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "4"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "1"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "2"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "3"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "4"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", "contour", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<,  Is |\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<| < 1 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", "1"], "]"}], "]"}], "<", "1"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<,   Is |\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<| < 1 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", "2"], "]"}], "]"}], "<", "1"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<, Is |\>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<| < 1 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", "3"], "]"}], "]"}], "<", "1"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<,  Is |\>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<| < 1 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", "4"], "]"}], "]"}], "<", "1"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.3999932918125*^9, {3.3999999295625*^9, 3.39999993321875*^9}, 
   3.40000205684375*^9}],

Cell[TextData[{
 "\nYou must look carefully at the above list and make the proper choice. \n\
We see that we should compute the residues at  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], "=", 
    RowBox[{"-", 
     FractionBox["\[ImaginaryI]", 
      SqrtBox["3"]]}]}], ",", " ", 
   RowBox[{
    RowBox[{"and", "  ", 
     SubscriptBox["z", "2"]}], "=", 
    FractionBox["\[ImaginaryI]", 
     SqrtBox["3"]]}]}]]],
 ", \n and then use the residue calculus to compute the value of the \
integral.\n"
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.40031153525*^9, 3.40031161475*^9}, {3.40031214840625*^9,
   3.400312162203125*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Res1", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "1"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Res2", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "2"]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"val", " ", "=", 
     RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{"Res1", " ", "+", " ", "Res2"}], ")"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<] = \>\"", ",", "Res1"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<] = \>\"", ",", "Res2"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "1"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "2"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", "contour", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<) \[DifferentialD]z = 2\[Pi]\[ImaginaryI]((\>\"", ",", "Res1", " ",
       ",", "\"\<) + (\>\"", ",", " ", "Res2", " ", ",", "\"\<))\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<) \[DifferentialD]z = 2\[Pi]\[ImaginaryI](\>\"", ",", 
      RowBox[{"Res1", " ", "+", " ", "Res2"}], " ", ",", "\"\<)\>\""}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", 
      ",", "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The contour is the circle  C:|z| = 1,\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<taken with the positive orientation.\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral] \>\"", "0", 
       RowBox[{"2", "\[Pi]"}]], ",", 
      RowBox[{"F", "[", "\[Theta]", "]"}], ",", 
      "\"\< \[DifferentialD]\[Theta] = \>\"", ",", "val"}], "]"}], ";"}], " ",
    "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3999932979375*^9, 3.399993298703125*^9}, {
   3.399999940265625*^9, 3.3999999405*^9}, 3.399999999671875*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 8.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Evaluate  ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", 
    RowBox[{"2", "\[Pi]"}]], 
   RowBox[{
    FractionBox[
     RowBox[{" ", "1"}], 
     RowBox[{"1", " ", "+", " ", 
      RowBox[{"3", " ", 
       SuperscriptBox["cos", "2"], "t"}]}]], 
    RowBox[{"\[DifferentialD]", "t"}]}]}]]],
 "  by using a computer algebra system.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Solution.  We can obtain the antiderivative of ",
 Cell[BoxData[
  FractionBox[
   RowBox[{" ", "1"}], 
   RowBox[{"1", " ", "+", " ", 
    RowBox[{"3", " ", 
     SuperscriptBox["cos", "2"], "t"}]}]]]],
 " by using software such as Mathematica or MAPLE.  It is   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Integral]", 
    RowBox[{
     FractionBox[
      RowBox[{" ", "1"}], 
      RowBox[{"1", " ", "+", " ", 
       RowBox[{"3", " ", 
        SuperscriptBox["cos", "2"], "t"}]}]], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", "Arctan", 
     RowBox[{"(", " ", 
      RowBox[{"cot", " ", "t"}], ")"}]}], "  ", "=", "  ", 
    RowBox[{"g", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 ".  \nSince  ",
 Cell[BoxData[
  RowBox[{"cot", " ", "0"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"cot", " ", "2", "\[Pi]"}]]],
 "  are not defined, the computations for both ",
 Cell[BoxData[
  RowBox[{"g", 
   RowBox[{"(", "0", ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"g", 
   RowBox[{"(", 
    RowBox[{"2", "\[Pi]"}], ")"}]}]]],
 " are indeterminate.  The graph ",
 Cell[BoxData[
  RowBox[{"s", "=", 
   RowBox[{"g", 
    RowBox[{"(", "t", ")"}]}]}]]],
 "shown in Figure 8.3 reveals another problem:  \nThe integrand ",
 Cell[BoxData[
  FractionBox[
   RowBox[{" ", "1"}], 
   RowBox[{"1", " ", "+", " ", 
    RowBox[{"3", " ", 
     SuperscriptBox["cos", "2"], "t"}]}]]]],
 " is a continuous function for all ",
 StyleBox["t",
  FontFamily->"Courier New"],
 ", but the function ",
 Cell[BoxData[
  RowBox[{"g", 
   RowBox[{"(", "t", ")"}]}]]],
 " has a discontinuity at ",
 Cell[BoxData[
  RowBox[{"t", "=", "\[Pi]"}]]],
 ".  This condition appears to be a violation of the fundamental theorem of \
calculus, which asserts that the integral of a continuous function must be \
differentiable and hence continuous.  The problem is that ",
 Cell[BoxData[
  RowBox[{"g", 
   RowBox[{"(", "t", ")"}]}]]],
 " is not an antiderivative of ",
 Cell[BoxData[
  FractionBox[
   RowBox[{" ", "1"}], 
   RowBox[{"1", " ", "+", " ", 
    RowBox[{"3", " ", 
     SuperscriptBox["cos", "2"], "t"}]}]]]],
 " for all ",
 StyleBox["t",
  FontFamily->"Courier New"],
 " in the interval ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"0", ",", 
    RowBox[{"2", "\[Pi]"}]}], "]"}]]],
 ".  Oddly, it is the antiderivative at all points except ",
 Cell[BoxData["0"]],
 ", ",
 Cell[BoxData["\[Pi]"]],
 ", and ",
 Cell[BoxData[
  RowBox[{"2", "\[Pi]"}]]],
 ", which you can verify by computing ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", "'"}], 
   RowBox[{"(", "t", ")"}]}]]],
 " and showing that it equals ",
 Cell[BoxData[
  FractionBox[
   RowBox[{" ", "1"}], 
   RowBox[{"1", " ", "+", " ", 
    RowBox[{"3", " ", 
     SuperscriptBox["cos", "2"], "t"}]}]]]],
 " whenever ",
 Cell[BoxData[
  RowBox[{"g", 
   RowBox[{"(", "t", ")"}]}]]],
 " is defined."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.40005415609375*^9, 3.400054174*^9}},
 ImageSize->{344, 147},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 8.3",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/integralstrigonometric/\
IntegralsTrigFigures/mat0803.gif"], None}],
  FontWeight->"Bold"],
 "  Graph of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    RowBox[{"\[Integral]", 
     RowBox[{
      FractionBox[
       RowBox[{" ", "1"}], 
       RowBox[{"1", " ", "+", " ", 
        RowBox[{"3", " ", 
         SuperscriptBox["cos", "2"], "t"}]}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"ArcTan", "[", 
      FractionBox[
       RowBox[{"Tan", "[", "\[Theta]", "]"}], "2"], "]"}]}]}]}]]],
 "."
}], "Text",
 CellChangeTimes->{{3.399463989203125*^9, 3.399464008953125*^9}, {
  3.400054243953125*^9, 3.400054243953125*^9}}],

Cell[TextData[{
 "\tThe integration algorithm used by computer algebra systems here (the \
Risch-Norman algorithm) gives the antiderivative  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "Arctan", 
    RowBox[{"(", " ", 
     RowBox[{"cot", " ", "t"}], ")"}]}]}]]],
 ",  and we must take great care in using this information.  We get the \
proper value of the integral by using ",
 Cell[BoxData[
  RowBox[{"g", 
   RowBox[{"(", "t", ")"}]}]]],
 " on the open subintervals ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"0", ",", "\[Pi]"}], ")"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"0", ",", 
    RowBox[{"2", "\[Pi]"}]}], ")"}]]],
 " where it is continuous, and taking appropriate limits:   \n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", 
      RowBox[{"2", "\[Pi]"}]], 
     RowBox[{
      FractionBox[
       RowBox[{" ", "1"}], 
       RowBox[{"1", " ", "+", " ", 
        RowBox[{"3", " ", 
         SuperscriptBox["cos", "2"], "t"}]}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       FractionBox["\[Pi]", "2"]], 
      RowBox[{
       FractionBox[
        RowBox[{" ", "1"}], 
        RowBox[{"1", " ", "+", " ", 
         RowBox[{"3", " ", 
          SuperscriptBox["cos", "2"], "t"}]}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "+", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       FractionBox["\[Pi]", "2"], 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]], 
      RowBox[{
       FractionBox[
        RowBox[{" ", "1"}], 
        RowBox[{"1", " ", "+", " ", 
         RowBox[{"3", " ", 
          SuperscriptBox["cos", "2"], "t"}]}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "+", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"], 
       RowBox[{"2", "\[Pi]"}]], 
      RowBox[{
       FractionBox[
        RowBox[{" ", "1"}], 
        RowBox[{"1", " ", "+", " ", 
         RowBox[{"3", " ", 
          SuperscriptBox["cos", "2"], "t"}]}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                  ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox[
       UnderscriptBox[
        UnderscriptBox["lim", " "], 
        RowBox[{"t", "\[Rule]", 
         SuperscriptBox[
          FractionBox["\[Pi]", "2"], "-"]}]], 
       RowBox[{"s", "\[Rule]", 
        SuperscriptBox["0", "+"]}]], " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "s", "t"], 
       RowBox[{
        FractionBox[
         RowBox[{" ", "1"}], 
         RowBox[{"1", " ", "+", " ", 
          RowBox[{"3", " ", 
           SuperscriptBox["cos", "2"], "t"}]}]], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}], " ", "+", " ", 
     RowBox[{
      UnderscriptBox[
       UnderscriptBox[
        UnderscriptBox["lim", " "], 
        RowBox[{"t", "\[Rule]", 
         SuperscriptBox[
          FractionBox[
           RowBox[{"3", "\[Pi]"}], "2"], "-"]}]], 
       RowBox[{"s", "\[Rule]", 
        SuperscriptBox[
         FractionBox["\[Pi]", "2"], "+"]}]], " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "s", "t"], 
       RowBox[{
        FractionBox[
         RowBox[{" ", "1"}], 
         RowBox[{"1", " ", "+", " ", 
          RowBox[{"3", " ", 
           SuperscriptBox["cos", "2"], "t"}]}]], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}], " ", "+", " ", 
     RowBox[{
      UnderscriptBox[
       UnderscriptBox[
        UnderscriptBox["lim", " "], 
        RowBox[{"t", "\[Rule]", 
         RowBox[{"2", 
          SuperscriptBox["\[Pi]", "-"]}]}]], 
       RowBox[{"s", "\[Rule]", 
        SuperscriptBox[
         FractionBox[
          RowBox[{"3", "\[Pi]"}], "2"], "+"]}]], " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "s", "t"], 
       RowBox[{
        FractionBox[
         RowBox[{" ", "1"}], 
         RowBox[{"1", " ", "+", " ", 
          RowBox[{"3", " ", 
           SuperscriptBox["cos", "2"], "t"}]}]], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                  ", 
   RowBox[{"=", "   ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        UnderscriptBox["lim", 
         RowBox[{"t", "\[Rule]", 
          SuperscriptBox[
           FractionBox["\[Pi]", "2"], "-"]}]], " ", 
        RowBox[{"g", 
         RowBox[{"(", "t", ")"}]}]}], " ", "-", " ", 
       RowBox[{
        UnderscriptBox["lim", 
         RowBox[{"s", "\[Rule]", 
          SuperscriptBox["0", "+"]}]], " ", 
        RowBox[{"g", 
         RowBox[{"(", "s", ")"}]}]}]}], ")"}], "+", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        UnderscriptBox["lim", 
         RowBox[{"t", "\[Rule]", 
          SuperscriptBox[
           FractionBox[
            RowBox[{"3", "\[Pi]"}], "2"], "-"]}]], " ", 
        RowBox[{"g", 
         RowBox[{"(", "t", ")"}]}]}], " ", "-", " ", 
       RowBox[{
        UnderscriptBox["lim", 
         RowBox[{"s", "\[Rule]", 
          SuperscriptBox[
           FractionBox["\[Pi]", "2"], "+"]}]], " ", 
        RowBox[{"g", 
         RowBox[{"(", "s", ")"}]}]}]}], ")"}]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"                                     ", 
   RowBox[{"+", "  ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"t", "\[Rule]", 
         RowBox[{"2", 
          SuperscriptBox["\[Pi]", "-"]}]}]], " ", 
       RowBox[{"g", 
        RowBox[{"(", "t", ")"}]}]}], " ", "-", " ", 
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"s", "\[Rule]", 
         SuperscriptBox[
          FractionBox[
           RowBox[{"3", "\[Pi]"}], "2"], "+"]}]], " ", 
       RowBox[{"g", 
        RowBox[{"(", "s", ")"}]}]}]}], ")"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                  ", 
   RowBox[{"=", "   ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "-", " ", "0"}], ")"}], "  ", "+", 
     "  ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], "-", 
       RowBox[{"(", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "4"]}], ")"}]}], ")"}], "  ", "+", "  ", 
     RowBox[{"(", 
      RowBox[{"0", "-", 
       RowBox[{"(", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "4"]}], ")"}]}], ")"}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                  ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["\[Pi]", "4"], "  ", "+", "  ", 
      FractionBox["\[Pi]", "2"], "  ", "+", "  ", 
      FractionBox["\[Pi]", "4"]}], "   ", "=", "   ", "\[Pi]"}]}]}]}]],
 "  "
}], "Text",
 CellChangeTimes->{{3.400054278328125*^9, 3.400054530859375*^9}, {
  3.400054566*^9, 3.40005457784375*^9}, {3.400054678484375*^9, 
  3.40005469828125*^9}, {3.400055204984375*^9, 3.4000552565*^9}, {
  3.40005528928125*^9, 3.400055305765625*^9}, {3.40005534928125*^9, 
  3.400055382203125*^9}, {3.40005560325*^9, 3.40005560325*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"8.11", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670554503125*^9, 3.50670554503125*^9}}],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", "[", "\[Theta]", "]"}], "=", 
   FractionBox[
    RowBox[{" ", "1"}], 
    RowBox[{"1", " ", "+", " ", 
     RowBox[{"3", " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]}]],
  AspectRatioFixed->True],
 " and use substitution to obtain the complex function f[z].  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", "0"}], ";", " ", 
    RowBox[{"Remove", "[", "Z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "G", ",", "F", ",", "Res1", ",", "Res2", ",", "Res3", ",", 
      "Res4", ",", "solset", ",", "\[Theta]", ",", "val", ",", "z"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "\[Theta]_", "]"}], " ", "=", 
     FractionBox[
      RowBox[{" ", "1"}], 
      RowBox[{"1", " ", "+", " ", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"sub", "[", 
      RowBox[{
       RowBox[{"F", "[", "\[Theta]", "]"}], ",", "\[Theta]"}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\[Theta]] = \>\"", ",", 
      RowBox[{"F", "[", "\[Theta]", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399999991375*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "  is capable of finding some of these difficult integrals.  The function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", "[", "\[Theta]", "]"}], "=", 
   FractionBox[
    RowBox[{" ", "1"}], 
    RowBox[{"1", " ", "+", " ", 
     RowBox[{"3", " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]}]],
  AspectRatioFixed->True],
 "  can be integrated."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "\[Theta]_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"F", "[", "\[Theta]", "]"}], 
       RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"2", "\[Pi]"}]], 
      RowBox[{
       RowBox[{"F", "[", "\[Theta]", "]"}], 
       RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<G[\[Theta]] = \[Integral] \>\"", ",", 
      RowBox[{"F", "[", "\[Theta]", "]"}], ",", 
      "\"\< \[DifferentialD]\[Theta] = \>\"", ",", 
      RowBox[{"G", "[", "\[Theta]", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral] \>\"", "0", 
       RowBox[{"2", "\[Pi]"}]], ",", 
      RowBox[{"F", "[", "\[Theta]", "]"}], ",", 
      "\"\< \[DifferentialD]\[Theta] = \>\"", ",", "val"}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral] \>\"", "0", 
       RowBox[{"2", "\[Pi]"}]], ",", 
      RowBox[{"F", "[", "\[Theta]", "]"}], ",", 
      "\"\< \[DifferentialD]\[Theta] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", "val", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.400000260015625*^9}],

Cell[TextData[{
 "However, direct substitution using  ",
 Cell[BoxData[
  RowBox[{"G", "[", "\[Theta]", "]"}]]],
 "  and the endpoints of the interval seems to be ",
 StyleBox["erroneous",
  FontColor->RGBColor[1, 0, 1]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<        G[0] = \>\"", ",", 
      RowBox[{"G", "[", "0", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       G[2\[Pi]] = \>\"", ",", 
      RowBox[{"G", "[", 
       RowBox[{"2", "\[Pi]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<G[2\[Pi]] - G[0] = \>\"", ",", 
      RowBox[{
       RowBox[{"G", "[", 
        RowBox[{"2", "\[Pi]"}], "]"}], "-", 
       RowBox[{"G", "[", "0", "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.400000031546875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "This is due to the fact that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cot", 
    RowBox[{"(", "0", ")"}]}], ",", " ", 
   RowBox[{"cot", 
    RowBox[{"(", "\[Pi]", ")"}]}], ",", " ", 
   RowBox[{"and", "  ", "cot", 
    RowBox[{"(", 
     RowBox[{"2", "\[Pi]"}], ")"}]}]}]]],
 "  are undefined.  A graph of  ",
 Cell[BoxData[
  RowBox[{"G", "[", "\[Theta]", "]"}]]],
 "  reveals that it has a discontinuity at  ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "=", "\[Pi]"}]]],
 "  in the middle of the interval  ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"0", ",", 
    RowBox[{"2", "\[Pi]"}]}], "]"}]]],
 ".  This is a violation of the Fundamental Theorem of Calculus, which \
asserts that the integral of a continuous function must be continuous. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"G", "[", "\[Theta]", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]", ",", "0", ",", 
         FractionBox["\[Pi]", "2"]}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"G", "[", "\[Theta]", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]", ",", 
         FractionBox["\[Pi]", "2"], ",", 
         FractionBox[
          RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr3", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"G", "[", "\[Theta]", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]", ",", 
         FractionBox[
          RowBox[{"3", "\[Pi]"}], "2"], ",", 
         RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Green"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", "gr3", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{"2", "\[Pi]"}], ",", 
          FractionBox["\[Pi]", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "\[Pi]"}], "4"], ",", 
          FractionBox["\[Pi]", "4"], ",", 
          FractionBox["\[Pi]", "2"]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\[Theta]\>\"", ",", "\"\<s\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<s = \>\"", ",", 
      RowBox[{"G", "[", "\[Theta]", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.399993303671875*^9, {3.400000041203125*^9, 3.4000000414375*^9}, {
   3.40000210346875*^9, 3.4000021734375*^9}, {3.400311962375*^9, 
   3.40031197615625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "The indefinite integrand  ",
 Cell[BoxData[
  RowBox[{"G", "[", "\[Theta]", "]"}]]],
 "  can be used piecewise over  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"0", ",", 
     FractionBox["\[Pi]", "2"]}], ")"}], ",", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "2"], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], ")"}], "  ", "and", "  ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"], ",", 
      RowBox[{"2", "\[Pi]"}]}], ")"}]}]}]]],
 "  where it is continuous, by using the left and right hand limits at the \
endpoints. "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.400002186875*^9, 3.400002212*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"lim1", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"G", "[", "\[Theta]", "]"}], ",", 
       RowBox[{"\[Theta]", "\[Rule]", 
        FractionBox["\[Pi]", "2"]}], ",", "   ", 
       RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim2", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"G", "[", "\[Theta]", "]"}], ",", 
       RowBox[{"\[Theta]", "\[Rule]", 
        FractionBox["\[Pi]", "2"]}], ",", "    ", 
       RowBox[{"Direction", "\[Rule]", 
        RowBox[{"-", "1"}]}]}], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim3", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"G", "[", "\[Theta]", "]"}], ",", 
       RowBox[{"\[Theta]", "\[Rule]", 
        FractionBox[
         RowBox[{"3", "\[Pi]"}], "2"]}], ",", 
       RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim4", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"G", "[", "\[Theta]", "]"}], ",", 
       RowBox[{"\[Theta]", "\[Rule]", 
        FractionBox[
         RowBox[{"3", "\[Pi]"}], "2"]}], ",", "   ", 
       RowBox[{"Direction", "\[Rule]", 
        RowBox[{"-", "1"}]}]}], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"lim1", " ", "-", "lim2"}], ")"}], " ", "+", " ", 
      RowBox[{"(", 
       RowBox[{"lim3", " ", "-", " ", "lim4"}], ")"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      G[0] = \>\"", ",", 
      RowBox[{"G", "[", "0", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(\[Theta] \[Rule] \
\*SuperscriptBox[FractionBox[\(\[Pi]\), \(2\)], \(-\)]\)]\) \>\"", ",", 
      "\"\<G[\[Theta]]\>\"", ",", "\"\< = \>\"", ",", 
      "\"\< \!\(\*UnderscriptBox[\(lim\), \(\[Theta] \[Rule] \
\*SuperscriptBox[FractionBox[\(\[Pi]\), \(2\)], \(-\)]\)]\) (\>\"", ",", 
      RowBox[{"G", "[", "\[Theta]", "]"}], ",", "\"\<) = \>\"", ",", "lim1"}],
      "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(\[Theta] \[Rule] \
\*SuperscriptBox[FractionBox[\(\[Pi]\), \(2\)], \(+\)]\)]\) \>\"", ",", 
      "\"\<G[\[Theta]]\>\"", ",", "\"\< = \>\"", ",", 
      "\"\< \!\(\*UnderscriptBox[\(lim\), \(\[Theta] \[Rule] \
\*SuperscriptBox[FractionBox[\(\[Pi]\), \(2\)], \(+\)]\)]\) (\>\"", ",", 
      RowBox[{"G", "[", "\[Theta]", "]"}], ",", "\"\<) = \>\"", ",", "lim2"}],
      "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[Theta] \[Rule] \
\*SuperscriptBox[FractionBox[\(3  \[Pi]\), \(2\)], \(-\)]\)]\) \>\"", ",", 
      "\"\<G[\[Theta]]\>\"", ",", "\"\< = \>\"", ",", 
      "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[Theta] \[Rule] \
\*SuperscriptBox[FractionBox[\(3  \[Pi]\), \(2\)], \(-\)]\)]\) (\>\"", ",", 
      RowBox[{"G", "[", "\[Theta]", "]"}], ",", "\"\<) = \>\"", ",", "lim3"}],
      "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[Theta] \[Rule] \
\*SuperscriptBox[FractionBox[\(3  \[Pi]\), \(2\)], \(+\)]\)]\) \>\"", ",", 
      "\"\<G[\[Theta]]\>\"", ",", "\"\< = \>\"", ",", 
      "\"\<\!\(\*UnderscriptBox[\(lim\), \(\[Theta] \[Rule] \
\*SuperscriptBox[FractionBox[\(3  \[Pi]\), \(2\)], \(+\)]\)]\) (\>\"", ",", 
      RowBox[{"G", "[", "\[Theta]", "]"}], ",", "\"\<) = \>\"", ",", "lim4"}],
      "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     G[2\[Pi]] = \>\"", ",", 
      RowBox[{"G", "[", 
       RowBox[{"2", "\[Pi]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral] \>\"", "0", 
       RowBox[{"2", "\[Pi]"}]], ",", 
      RowBox[{"F", "[", "\[Theta]", "]"}], ",", 
      "\"\< \[DifferentialD]\[Theta]  =  \>\"", ",", 
      "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
FractionBox[\(\[Pi]\), \(2\)]]\)\>\"", " ", ",", 
      RowBox[{"F", "[", "\[Theta]", "]"}], ",", " ", 
      "\"\<\[DifferentialD]\[Theta]\>\"", ",", "\"\< + \>\"", ",", 
      "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), FractionBox[\(\[Pi]\), \
\(2\)], FractionBox[\(3  \[Pi]\), \(2\)]]\)\>\"", ",", " ", 
      RowBox[{"F", "[", "\[Theta]", "]"}], ",", " ", 
      "\"\<\[DifferentialD]\[Theta]\>\"", ",", "\"\< + \>\"", ",", 
      "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), FractionBox[\(3  \[Pi]\), \
\(2\)], \(2  \[Pi]\)]\)\>\"", ",", " ", 
      RowBox[{"F", "[", "\[Theta]", "]"}], " ", ",", 
      "\"\<\[DifferentialD]\[Theta]\>\""}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral] \>\"", "0", 
       RowBox[{"2", "\[Pi]"}]], ",", 
      RowBox[{"F", "[", "\[Theta]", "]"}], ",", 
      "\"\< \[DifferentialD]\[Theta]  =  ((\>\"", ",", "lim1", ",", 
      "\"\< - (\>\"", ",", 
      RowBox[{"G", "[", "0", "]"}], ",", "\"\<))  +  (\>\"", ",", "lim3", 
      ",", "\"\< - (\>\"", ",", "lim2", " ", ",", "\"\<))  +  (\>\"", ",", 
      RowBox[{"G", "[", 
       RowBox[{"2", " ", "\[Pi]"}], "]"}], ",", "\"\< - (\>\"", ",", "lim4", 
      ",", "\"\<))\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral] \>\"", "0", 
       RowBox[{"2", "\[Pi]"}]], ",", 
      RowBox[{"F", "[", "\[Theta]", "]"}], ",", 
      "\"\< \[DifferentialD]\[Theta]  =  (\>\"", ",", 
      RowBox[{"lim1", " ", "-", " ", 
       RowBox[{"G", "[", "0", "]"}]}], " ", ",", "\"\<)  +  (\>\"", ",", 
      RowBox[{"lim3", " ", "-", " ", "lim2"}], " ", ",", "\"\<)  +  (\>\"", 
      ",", 
      RowBox[{
       RowBox[{"G", "[", 
        RowBox[{"2", " ", "\[Pi]"}], "]"}], " ", "-", "lim4"}], ",", 
      "\"\<)\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral] \>\"", "0", 
       RowBox[{"2", "\[Pi]"}]], ",", 
      RowBox[{"F", "[", "\[Theta]", "]"}], ",", 
      "\"\< \[DifferentialD]\[Theta]  =  \>\"", ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"lim1", " ", "-", " ", 
         RowBox[{"G", "[", "0", "]"}]}], ")"}], " ", "+", " ", 
       RowBox[{"(", 
        RowBox[{"lim3", " ", "-", " ", "lim2"}], ")"}], " ", "+", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"G", "[", 
          RowBox[{"2", " ", "\[Pi]"}], "]"}], "-", "lim4"}], ")"}]}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.400000045953125*^9, {3.400000317015625*^9, 3.40000033071875*^9}, {
   3.40000037775*^9, 3.400000463734375*^9}, 3.40000109934375*^9, {
   3.40000286065625*^9, 3.40000292928125*^9}, {3.400006693734375*^9, 
   3.400006699953125*^9}, {3.400007168875*^9, 3.400007392671875*^9}, 
   3.400054990546875*^9}],

Cell[TextData[{
 "The above answer is correct too.  Limits were required because  ",
 Cell[BoxData[
  RowBox[{"G", "[", "\[Theta]", "]"}]]],
 "  is not continuous at  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Theta]", "=", 
    FractionBox["\[Pi]", "2"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], 
   StyleBox["  ",
    FontFamily->"Times New Roman"], 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman"], "   ", "\[Theta]"}], "=", 
    FractionBox[
     RowBox[{"3", "\[Pi]"}], "2"]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.400001130734375*^9, 3.400001175171875*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 8.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "    Evaluate  ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", 
    RowBox[{"2", "\[Pi]"}]], 
   RowBox[{
    FractionBox[
     RowBox[{" ", 
      RowBox[{"cos", 
       RowBox[{"(", 
        RowBox[{"2", "\[Theta]"}], ")"}]}]}], 
     RowBox[{"5", " ", "-", " ", 
      RowBox[{"4", " ", "cos", 
       RowBox[{"(", "\[Theta]", ")"}]}]}]], 
    RowBox[{"\[DifferentialD]", "\[Theta]"}], " "}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[GraphicsData["CompressedBitmap", "\<\
eJzlWllTE0EQXkKCB5TIIUeIEEDu+watUsoHePJVnylEQUUQUBQ5RVBEENHC
C5TCKssHtcrj/8XM9G6TbL7NbmCwQrkF2aG/r7/umdmQTM9c6hnr7xvsGRvo
7fF3j/QM9w/0jvq7hkaCpsQETUu4rGnall8T7UCwqb8Egj+BK+JFWPbe/iNv
iRqJSkT7dEDQN3HzCCDRmvQDQHb0FGHfJMMXcXMJZpIcLHslaZPkDZL4bOQZ
tDpL5hhLrJHEtrgJTuA45+MBjqnMWyHHjwY9kAno6YwuE32TDVmAnsnoEtHf
syEH0HclAmxbJMe37OgFjtnciwWibzDdB+heRueJ/poN+YDuY3SO6K9Ansgx
H/CmSWIdQAVAogDwpkhijdMqAo5+4DhJjqvseAY4FjKq01eAEnIsZscJcnwO
HEuAYwngjZPEMoBKgUQp4N0jiWcAKgMSZYB3lySWAFQOJMoBb0yZxFMAVQCJ
CsAbJYknAKoEEpWAN0ISiwCqAhJVgHeHJBYAVA0kqgFvmCQeA6gGSNQA3hBJ
zAOoFkjUAt5tZRKPAFQHJOoAb5Ak5gBUH5vELIAagEQ94N2KTaIB8G6SxAyA
Gg9GohHwbpDENICaYpOYAlAzkGgCvAFlEpMAagESzYDX/88lWgDvOkk8BFDr
wUi0At41ZRITAGo7jBIPANQOJNoAr+8wSrQD3lVlEvdD6BqtrzT5jR1NS5sV
WQZwi1aZWZY8xdVhk5lhR7zy/cueBTw92xFO37WPAOcArzS2vDtMvN1Q7jAe
Hmjjip6wxupyROT8WQyv1WygNHvjXUI+vIlimHzhLTTeEuUVp7FoN640+mvc
KopHeHu5lReVl27qmrjIRl9ak/QEQme4TbzoUYxWXlResmgdBaOotC9pNiOm
Zl7+h6c1PiRqaWY1UVCKFDtCM6LpT4Vrd6LDVbrCeTgUWjZYBjXZTgPbCRCj
G/C81imVc+9R3QslZ0nOiCqVCoKfZw/5meQOGT70sU/viYhPCevEPWE2na5/
/mEsC4dwOxz8C9jdZXIXl8+6n6jq4HR2zKGQbbej9ryTIL9Oq/xcNh2rBMNj
uKH/26jTqINOOmM1ZRcdxvXG/Fym2D6D4RFysEwmiNiJqYU2OcpckvEkSCyX
WxlWUSXqp0DxsVpSIBEf61cFC3EF5YD4qGvER41HQbFqBkAxlsycSkQp3M0C
KMbyoVOJKEVMp6VUBRJRqrEKasIKKtMKSuwKCv0KthsUbHookFCwe6NgD0nB
ZpiCLTkFG4N73pRcBY7FwLEI8HSJF6yJHAuBI31wai8B5AcSfsDTN2PXOTZy
zGeU/iXHurG9AQLnAceIDfQ3bED0HEb17fl3bMgF9GyQhe74gR2zgeMpRund
pm2JmxSyPMwgUXpb0KEJ6W+uB4nfiKMSO+ImD13I5ZflyjLicMZXNjj4Xh9x
OiTixMleTqw4p383BgWeH9FJyo/qyD8UHC8Kbf/inuyQ4TeIv22bmtlLXNsh
ESKXPTr603iAzIW5PfZZS/gL2r+1Kw==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{342, 157},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  For values of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " that lie on the unit circle ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["C", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 ", we have \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "2"], " ", "=", " ", 
   RowBox[{
    RowBox[{"cos", " ", "2", "\[Theta]"}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "sin", " ", "2", "\[Theta]"}]}]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", 
    RowBox[{"-", "2"}]], " ", "=", " ", 
   RowBox[{
    RowBox[{"cos", " ", "2", "\[Theta]"}], " ", "-", " ", 
    RowBox[{"\[ImaginaryI]", " ", "sin", " ", "2", "\[Theta]"}]}]}]]],
 "\n\nWe solve for  ",
 Cell[BoxData[
  RowBox[{"cos", " ", "2", "\[Theta]", "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "sin", " ", "2", "\[Theta]"}]]],
 "  to obtain the substitutions  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", " ", "2", "\[Theta]"}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z", "2"], "+", 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}], ")"}]}]}]]],
 "    and    ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"sin", " ", "2", "\[Theta]"}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "\[ImaginaryI]"}]], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z", "2"], "-", 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}], ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Using the identity for ",
 Cell[BoxData[
  RowBox[{"cos", " ", "2", "\[Theta]", " "}]]],
 " along with Substitutions ",
 StyleBox["(8-4)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(8-5)",
  FontColor->RGBColor[0, 0, 1]],
 ", we rewrite the integral as  \n\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[ContourIntegral]", 
      RowBox[{" ", 
       RowBox[{
        SubsuperscriptBox["C", "1", "+"], 
        RowBox[{"(", "0", ")"}]}]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "+", 
          SuperscriptBox["z", 
           RowBox[{"-", "2"}]]}], ")"}]}], 
       RowBox[{"5", "-", 
        RowBox[{"4", 
         RowBox[{"(", 
          FractionBox[
           RowBox[{"z", "+", 
            SuperscriptBox["z", 
             RowBox[{"-", "1"}]]}], "2"], ")"}]}]}]], 
      FractionBox["1", 
       RowBox[{"\[ImaginaryI]", " ", "z"}]], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{
     SubscriptBox["\[ContourIntegral]", 
      RowBox[{" ", 
       RowBox[{
        SubsuperscriptBox["C", "1", "+"], 
        RowBox[{"(", "0", ")"}]}]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "4"], "+", "1"}], ")"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["z", "2"]}], "-", 
          RowBox[{"5", " ", "z"}], "+", "2"}], ")"}]}]], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  "}], "\[IndentingNewLine]", 
  RowBox[{"                                                    ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[ContourIntegral]", 
       RowBox[{" ", 
        RowBox[{
         SubsuperscriptBox["C", "1", "+"], 
         RowBox[{"(", "0", ")"}]}]}]], " ", 
      RowBox[{
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "4"], "+", "1"}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox["z", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"z", "-", "2"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "z"}], "-", "1"}], ")"}]}]], " ", 
       RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
     RowBox[{
      SubscriptBox["\[ContourIntegral]", 
       RowBox[{" ", 
        RowBox[{
         SubsuperscriptBox["C", "1", "+"], 
         RowBox[{"(", "0", ")"}]}]}]], " ", 
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}], " ", 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}]}]],
 "\n\nwhere  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z", "4"], "+", "1"}], ")"}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", "2"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "z"}], "-", "1"}], ")"}]}]]}]]],
 ".  The singularities of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}]}]]],
 " lying inside ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["C", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 " are poles located at the points ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    SubscriptBox["z", "2"], "=", "0"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "3"], "=", 
   FractionBox["1", "2"]}]]],
 ".  We use Theorem 8.2 to get the residues: \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", "0"}], "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      RowBox[{
       FractionBox["d", "dz"], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], "f", 
         RowBox[{"(", "z", ")"}]}], ")"}]}]}], "  ", "=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      RowBox[{
       FractionBox["d", "dz"], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z", "4"], "+", "1"}], ")"}]}], 
          RowBox[{"2", " ", 
           SuperscriptBox["z", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"z", "-", "2"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "z"}], "-", "1"}], ")"}]}]]}], ")"}]}]}]}]}], 
   "\[IndentingNewLine]", "  "}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      RowBox[{
       FractionBox["d", "dz"], 
       RowBox[{"(", 
        RowBox[{"\[ImaginaryI]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z", "4"], "+", "1"}], 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"z", "-", "2"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "z"}], "-", "1"}], ")"}]}]]}], ")"}]}]}], "  ",
      "=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "0"}]], " ", 
      RowBox[{
       FractionBox["d", "dz"], 
       RowBox[{"(", 
        RowBox[{"\[ImaginaryI]", 
         FractionBox[
          RowBox[{
           SuperscriptBox["z", "4"], "+", "1"}], 
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["z", "2"]}], "-", 
             RowBox[{"5", " ", "z"}], "+", "2"}], ")"}]}]]}], ")"}]}]}]}]}], 
   " ", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{"=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", "0"}]], 
     RowBox[{"(", 
      RowBox[{"\[ImaginaryI]", 
       FractionBox[
        RowBox[{
         RowBox[{"4", " ", 
          SuperscriptBox["z", "3"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["z", "2"]}], "-", 
            RowBox[{"5", " ", "z"}], "+", "2"}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", "z"}], "-", "5"}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z", "4"], "+", "1"}], ")"}]}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["z", "2"]}], "-", 
            RowBox[{"5", " ", "z"}], "+", "2"}], ")"}], "2"]}]]}], ")"}]}]}], 
   "  ", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{"=", "   ", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"4", "\[Cross]", 
           SuperscriptBox["0", "3"]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "\[Cross]", 
            SuperscriptBox["0", "2"]}], "-", 
           RowBox[{"5", "\[Cross]", "0"}], "+", "2"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", "\[Cross]", "0"}], "-", "5"}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["0", "4"], "+", "1"}], ")"}]}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "\[Cross]", 
            SuperscriptBox["0", "2"]}], "-", 
           RowBox[{"5", "\[Cross]", "0"}], "+", "2"}], ")"}], "2"]}]]}], 
     "   ", "=", "   ", 
     RowBox[{"\[ImaginaryI]", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"(", "0", ")"}], "\[Cross]", 
         RowBox[{"(", "2", ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"-", "5"}], ")"}], 
         RowBox[{"(", "1", ")"}]}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", "2", ")"}], "2"]}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{"5", " ", "\[ImaginaryI]"}], "8"]}]}]}]],
 "    \n\t\t\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", 
      FractionBox["1", "2"]}], "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        FractionBox["1", "2"]}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", 
         FractionBox["1", "2"]}], ")"}], "f", 
       RowBox[{"(", "z", ")"}]}]}], "  ", "=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        FractionBox["1", "2"]}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", 
         FractionBox["1", "2"]}], ")"}], 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "4"], "+", "1"}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox["z", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"z", "-", "2"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "z"}], "-", "1"}], ")"}]}]]}]}]}]}], 
   "\[IndentingNewLine]", "  "}], "\[IndentingNewLine]", 
  RowBox[{"                       ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        FractionBox["1", "2"]}]], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", 
         FractionBox["1", "2"]}], ")"}], 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "4"], "+", "1"}], ")"}]}], 
        RowBox[{"4", " ", 
         SuperscriptBox["z", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"z", "-", "2"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"z", "-", 
           FractionBox["1", "2"]}], ")"}]}]]}]}]}], "  ", "=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", 
       FractionBox["1", "2"]}]], 
     RowBox[{"\[ImaginaryI]", 
      FractionBox[
       RowBox[{" ", 
        RowBox[{
         SuperscriptBox["z", "4"], "+", "1"}]}], 
       RowBox[{"4", " ", 
        SuperscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"z", "-", "2"}], ")"}]}]]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                       ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", 
      FractionBox[
       RowBox[{" ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", "2"], ")"}], "4"], "+", "1"}]}], 
       RowBox[{"4", "  ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "2"], ")"}], "2"], 
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", "2"], "-", "2"}], ")"}]}]]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"\[ImaginaryI]", 
       FractionBox[
        RowBox[{" ", 
         RowBox[{
          FractionBox["1", "16"], "+", "1"}]}], 
        RowBox[{"4", "  ", 
         RowBox[{"(", 
          FractionBox["1", "4"], ")"}], 
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "2"], "-", "2"}], ")"}]}]]}], "  ", "=", "  ", 
      RowBox[{"\[ImaginaryI]", 
       FractionBox[
        RowBox[{" ", 
         FractionBox["17", "16"]}], 
        RowBox[{"4", "  ", 
         RowBox[{"(", 
          FractionBox["1", "4"], ")"}], 
         RowBox[{"(", 
          FractionBox[
           RowBox[{"-", "3"}], "2"], ")"}]}]]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                       ", 
   RowBox[{"=", "  ", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"17", " ", "\[ImaginaryI]"}], "24"]}]}]}]}]],
 "   "
}], "Text"],

Cell[TextData[{
 "Therefore we conclude that  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", 
      RowBox[{"2", "\[Pi]"}]], 
     RowBox[{
      FractionBox[
       RowBox[{" ", 
        RowBox[{"cos", 
         RowBox[{"(", 
          RowBox[{"2", "\[Theta]"}], ")"}]}]}], 
       RowBox[{"5", " ", "-", " ", 
        RowBox[{"4", " ", "cos", 
         RowBox[{"(", "\[Theta]", ")"}]}]}]], 
      RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}], "  ", "=", "  ", 
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", 
         SubscriptBox["z", "1"]}], "]"}], " ", "+", " ", 
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", 
         SubscriptBox["z", "2"]}], "]"}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                    ", 
   RowBox[{"=", "  ", 
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", "0"}], "]"}], " ", "+", " ", 
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", 
         FractionBox["1", "2"]}], "]"}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                    ", 
   RowBox[{"=", "   ", 
    RowBox[{
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"5", " ", "\[ImaginaryI]"}], "8"], " ", "-", " ", 
        FractionBox[
         RowBox[{"17", " ", "\[ImaginaryI]"}], "24"]}], ")"}]}], "  ", "=", 
     "  ", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{"-", 
        FractionBox["\[ImaginaryI]", "12"]}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                    ", 
   RowBox[{"=", "  ", 
    FractionBox["\[Pi]", "6"]}]}]}]],
 "    "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"8.12", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.5067055496875*^9, 3.506705549703125*^9}}],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", "[", "\[Theta]", "]"}], "=", 
   FractionBox[
    RowBox[{" ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", "\[Theta]"}], "]"}]}], 
    RowBox[{"5", " ", "-", " ", 
     RowBox[{"4", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}]]}]],
  AspectRatioFixed->True],
 " and use substitution to obtain the complex function f[z].  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", "0"}], ";", " ", 
    RowBox[{"Remove", "[", "Z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "G", ",", "F", ",", "Res1", ",", "Res2", ",", "Res3", ",", 
      "Res4", ",", "solset", ",", "\[Theta]", ",", "val", ",", "z"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "\[Theta]_", "]"}], " ", "=", 
     FractionBox[
      RowBox[{" ", 
       RowBox[{"Cos", "[", 
        RowBox[{"2", "\[Theta]"}], "]"}]}], 
      RowBox[{"5", " ", "-", " ", 
       RowBox[{"4", " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"sub", "[", 
      RowBox[{
       RowBox[{"F", "[", "\[Theta]", "]"}], ",", "\[Theta]"}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[\[Theta]] = \>\"", ",", 
      RowBox[{"F", "[", "\[Theta]", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.400002282765625*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "Locate the singularities of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{"1", " ", "+", " ", 
       SuperscriptBox["z", "4"]}], ")"}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"2", " ", "-", " ", 
       RowBox[{"5", " ", "z"}], " ", "+", " ", 
       RowBox[{"2", " ", 
        SuperscriptBox["z", "2"]}]}], ")"}]}]]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Denominator", "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}], 
       "]"}], "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The singularities are\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "2"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "3"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "4"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["Z", "4"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.4000022880625*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "Find out which singularities lie inside the unit circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", "z", "|"}]}], "=", "1"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "3"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "4"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], "-", "0.05"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}], "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "2"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}], "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "3"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}], "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "4"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}], "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", "contour", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "2.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "3"]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<,   Is |\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<| < 1 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", "1"], "]"}], "]"}], "<", "1"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<,   Is |\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<| < 1 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", "2"], "]"}], "]"}], "<", "1"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<,  Is |\>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<| < 1 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", "3"], "]"}], "]"}], "<", "1"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<,   Is |\>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<| < 1 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", "4"], "]"}], "]"}], "<", "1"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.3999933100625*^9, {3.400002293125*^9, 3.400002293328125*^9}}],

Cell[TextData[{
 "\nYou must look carefully at the above list and make the proper choice. \n\
We see that we should compute the residues at  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], "=", "0"}], ",", " ", 
   RowBox[{
    RowBox[{"and", "  ", 
     SubscriptBox["z", "3"]}], "=", 
    FractionBox["1", "2"]}]}]]],
 ", \n and then use the residue calculus to compute the value of the \
integral.\n"
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.40031153525*^9, 3.40031161475*^9}, {3.40031214840625*^9,
    3.400312162203125*^9}, 3.400312282546875*^9, 3.400312312875*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Res1", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "1"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Res3", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "3"]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"val", " ", "=", 
     RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{"Res1", " ", "+", " ", "Res3"}], ")"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<] = \>\"", ",", "Res1"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<] = \>\"", ",", "Res3"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "3"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "1"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}], "-", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "3"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}], "-", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Show", "[", 
     RowBox[{"dots", ",", "centers", ",", "contour", ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
      RowBox[{"Axes", "\[Rule]", "True"}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<) \[DifferentialD]z = 2\[Pi]\[ImaginaryI]((\>\"", ",", "Res1", " ",
       ",", "\"\<) + (\>\"", ",", " ", "Res3", " ", ",", "\"\<))\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<) \[DifferentialD]z = 2\[Pi]\[ImaginaryI](\>\"", ",", 
      RowBox[{"Res1", " ", "+", " ", "Res3"}], " ", ",", "\"\<) = \>\"", ",", 
      "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The contour is the circle  C:|z| = 1,\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<taken with the positive orientation.\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral] \>\"", "0", 
       RowBox[{"2", "\[Pi]"}]], ",", 
      RowBox[{"F", "[", "\[Theta]", "]"}], ",", 
      "\"\< \[DifferentialD]\[Theta] = \>\"", ",", "val"}], "]"}], ";"}], 
   "  ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399993315421875*^9, 3.399993315828125*^9}, 
   3.400002297640625*^9}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "  is capable of finding some of these difficult integrals.  The function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", "[", "\[Theta]", "]"}], "=", 
   FractionBox[
    RowBox[{" ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", "\[Theta]"}], "]"}]}], 
    RowBox[{"5", " ", "-", " ", 
     RowBox[{"4", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}]]}]],
  AspectRatioFixed->True],
 "  can be integrated."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"G", "[", "\[Theta]_", "]"}], " ", "=", " ", 
    RowBox[{"\[Integral]", 
     RowBox[{
      RowBox[{"F", "[", "\[Theta]", "]"}], 
      RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"val", " ", "=", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", 
      RowBox[{"2", "\[Pi]"}]], 
     RowBox[{
      RowBox[{"F", "[", "\[Theta]", "]"}], 
      RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<G[\[Theta]] = \[Integral] \>\"", ",", 
     RowBox[{"F", "[", "\[Theta]", "]"}], ",", 
     "\"\< \[DifferentialD]\[Theta] = \>\"", ",", 
     RowBox[{"G", "[", "\[Theta]", "]"}]}], "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{
     UnderoverscriptBox["\"\<\[Integral] \>\"", "0", 
      RowBox[{"2", "\[Pi]"}]], ",", 
     RowBox[{"F", "[", "\[Theta]", "]"}], ",", 
     "\"\< \[DifferentialD]\[Theta] = \>\"", ",", "val"}], "]"}], ";"}], 
  " "}], "\[IndentingNewLine]"}], "Input"],

Cell[TextData[{
 "However, direct substitution using ",
 Cell[BoxData[
  RowBox[{"G", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 " and the endpoints of the interval seems to be ",
 StyleBox["erroneous",
  FontColor->RGBColor[1, 0, 1]],
 ".  This is due to the fact that in the interior of the interval, ",
 Cell[BoxData[
  RowBox[{"tan", 
   RowBox[{"(", 
    FractionBox["\[Pi]", "2"], ")"}]}]]],
 " is undefined. Hence ",
 Cell[BoxData[
  RowBox[{"G", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 "is discontinuous."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<        G[0] = \>\"", ",", 
      RowBox[{"G", "[", "0", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       G[2\[Pi]] = \>\"", ",", 
      RowBox[{"G", "[", 
       RowBox[{"2", "\[Pi]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<G[2\[Pi]] - G[0] = \>\"", ",", 
      RowBox[{
       RowBox[{"G", "[", 
        RowBox[{"2", "\[Pi]"}], "]"}], "-", 
       RowBox[{"G", "[", "0", "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.400002316078125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "This is due to the fact that  ",
 Cell[BoxData[
  RowBox[{"tan", 
   RowBox[{"(", 
    FractionBox["\[Pi]", "2"], ")"}]}]]],
 " is undefined.  A graph of  ",
 Cell[BoxData[
  RowBox[{"G", "[", "\[Theta]", "]"}]]],
 "  reveals that it has a discontinuity at  ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "=", "\[Pi]"}]]],
 "  in the middle of the interval  ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"0", ",", 
    RowBox[{"2", "\[Pi]"}]}], "]"}]]],
 ".  This is a violation of the Fundamental Theorem of Calculus, which \
asserts that the integral of a continuous function must be continuous. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"G", "[", "\[Theta]", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"G", "[", "\[Theta]", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]", ",", "\[Pi]", ",", 
         RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4.5"}], ",", "0.5"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{"2", "\[Pi]"}], ",", 
          FractionBox["\[Pi]", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"-", "4"}], "\[Pi]"}], "3"], ",", 
          FractionBox["\[Pi]", "3"], ",", 
          FractionBox["\[Pi]", "3"]}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\[Theta]\>\"", ",", "\"\<s\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<s = \>\"", ",", 
      RowBox[{"G", "[", "\[Theta]", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.39999332065625*^9, {3.400002328734375*^9, 3.400002332375*^9}, {
   3.400006326046875*^9, 3.4000063364375*^9}, {3.4003119840625*^9, 
   3.40031199221875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "The indefinite integrand  ",
 Cell[BoxData[
  RowBox[{"G", "[", "\[Theta]", "]"}]]],
 "  can be used piecewise over  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"0", ",", "\[Pi]"}], ")"}], "  ", "and", "  ", 
   RowBox[{"(", 
    RowBox[{"\[Pi]", ",", 
     RowBox[{"2", "\[Pi]"}]}], ")"}]}]]],
 "  where it is continuous, by using the left and right hand limits at the \
endpoints. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"lim1", "=", 
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{"G", "[", "\[Theta]", "]"}], ",", 
     RowBox[{"\[Theta]", "\[Rule]", "0"}], ",", "   ", 
     RowBox[{"Direction", "\[Rule]", 
      RowBox[{"-", "1"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"lim2", "=", 
    RowBox[{"Limit", "[", 
     RowBox[{
      RowBox[{"G", "[", "\[Theta]", "]"}], ",", 
      RowBox[{"\[Theta]", "\[Rule]", "\[Pi]"}], ",", "   ", 
      RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lim3", "=", 
    RowBox[{"Limit", "[", 
     RowBox[{
      RowBox[{"G", "[", "\[Theta]", "]"}], ",", 
      RowBox[{"\[Theta]", "\[Rule]", "\[Pi]"}], ",", "   ", 
      RowBox[{"Direction", "\[Rule]", 
       RowBox[{"-", "1"}]}]}], "]"}]}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lim4", "=", 
    RowBox[{"Limit", "[", 
     RowBox[{
      RowBox[{"G", "[", "\[Theta]", "]"}], ",", 
      RowBox[{"\[Theta]", "\[Rule]", 
       RowBox[{"2", "\[Pi]"}]}], ",", "   ", 
      RowBox[{"Direction", "\[Rule]", "1"}]}], "]"}]}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<      G[0] = \>\"", ",", 
    RowBox[{"G", "[", "0", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\< \!\(\*UnderscriptBox[\(lim\), \(\[Theta] \[Rule] \
\*SuperscriptBox[\(\[Pi]\), \(-\)]\)]\) \>\"", ",", "\"\<G[\[Theta]]\>\"", 
     ",", "\"\< = \>\"", ",", 
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(\[Theta] \[Rule] \*SuperscriptBox[\
\(\[Pi]\), \(-\)]\)]\) (\>\"", ",", 
     RowBox[{"G", "[", "\[Theta]", "]"}], ",", "\"\<) = \>\"", ",", "lim2"}], 
    "]"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\< \!\(\*UnderscriptBox[\(lim\), \(\[Theta] \[Rule] \
\*SuperscriptBox[\(\[Pi]\), \(+\)]\)]\) \>\"", ",", "\"\<G[\[Theta]]\>\"", 
     ",", "\"\< = \>\"", ",", 
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(\[Theta] \[Rule] \*SuperscriptBox[\
\(\[Pi]\), \(+\)]\)]\) (\>\"", ",", 
     RowBox[{"G", "[", "\[Theta]", "]"}], ",", "\"\<) = \>\"", ",", "lim3"}], 
    "]"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<    G[2\[Pi]] = \>\"", ",", 
    RowBox[{"G", "[", 
     RowBox[{"2", "\[Pi]"}], "]"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
    UnderoverscriptBox["\"\<\[Integral] \>\"", "0", 
     RowBox[{"2", "\[Pi]"}]], ",", 
    RowBox[{"F", "[", "\[Theta]", "]"}], ",", 
    "\"\< \[DifferentialD]\[Theta]  =  \>\"", ",", 
    "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\[Pi]\)]\)\>\"", 
    " ", ",", 
    RowBox[{"F", "[", "\[Theta]", "]"}], ",", " ", 
    "\"\<\[DifferentialD]\[Theta]\>\"", ",", "\"\< + \>\"", ",", 
    "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(\[Pi]\), \(2  \
\[Pi]\)]\)\>\"", ",", " ", 
    RowBox[{"F", "[", "\[Theta]", "]"}], " ", ",", 
    "\"\<\[DifferentialD]\[Theta]\>\""}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{
     UnderoverscriptBox["\"\<\[Integral] \>\"", "0", 
      RowBox[{"2", "\[Pi]"}]], ",", 
     RowBox[{"F", "[", "\[Theta]", "]"}], ",", 
     "\"\< \[DifferentialD]\[Theta]  =  ((\>\"", ",", "lim2", ",", 
     "\"\< - (\>\"", ",", "lim1", " ", ",", "\"\<))  +  (\>\"", ",", "lim4", 
     ",", "\"\< - (\>\"", ",", "lim3", ",", "\"\<))\>\""}], "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{
     UnderoverscriptBox["\"\<\[Integral] \>\"", "0", 
      RowBox[{"2", "\[Pi]"}]], ",", 
     RowBox[{"F", "[", "\[Theta]", "]"}], ",", 
     "\"\< \[DifferentialD]\[Theta]  =  (\>\"", ",", 
     RowBox[{"lim2", " ", "-", " ", "lim1"}], " ", ",", "\"\<)  +  (\>\"", 
     ",", 
     RowBox[{"lim4", " ", "-", " ", "lim3"}], ",", "\"\<)\>\""}], "]"}], 
   ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{
     UnderoverscriptBox["\"\<\[Integral] \>\"", "0", 
      RowBox[{"2", "\[Pi]"}]], ",", 
     RowBox[{"F", "[", "\[Theta]", "]"}], ",", 
     "\"\< \[DifferentialD]\[Theta]  =  \>\"", ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"lim2", " ", "-", " ", "lim1"}], ")"}], "  ", "+", " ", 
      RowBox[{"(", 
       RowBox[{"lim4", " ", "-", " ", "lim3"}], ")"}]}]}], "]"}], ";"}], 
  " "}]}], "Input",
 CellChangeTimes->{{3.400006575359375*^9, 3.400006629453125*^9}, {
   3.40000698565625*^9, 3.400006990484375*^9}, {3.40000752696875*^9, 
   3.40000752953125*^9}, {3.400007561375*^9, 3.400007566453125*^9}, {
   3.400007646453125*^9, 3.400007648546875*^9}, 3.4000540696875*^9}],

Cell[TextData[{
 "The above answer is correct too.  Limits were required because  ",
 Cell[BoxData[
  RowBox[{"G", "[", "\[Theta]", "]"}]]],
 "  is not continuous at  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Theta]", "=", "\[Pi]"}], " "}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{897, 645},
WindowMargins->{{23, Automatic}, {Automatic, 1}},
Magnification->1,
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 182, 3, 29, "Text"],
Cell[1733, 51, 317, 5, 47, "Text"],
Cell[2053, 58, 3642, 122, 348, "Text",
 Evaluatable->False],
Cell[5698, 182, 1616, 57, 118, "Text",
 Evaluatable->False],
Cell[7317, 241, 1295, 45, 123, "Text",
 Evaluatable->False],
Cell[8615, 288, 14423, 249, 330, "Text"],
Cell[23041, 539, 197, 7, 29, "Text",
 Evaluatable->False],
Cell[23241, 548, 187, 4, 29, "Text",
 Evaluatable->False],
Cell[23431, 554, 3458, 93, 368, "Input",
 InitializationCell->True],
Cell[26892, 649, 526, 19, 37, "Text",
 Evaluatable->False],
Cell[27421, 670, 1806, 32, 242, "Text",
 Evaluatable->False],
Cell[29230, 704, 8460, 286, 683, "Text"],
Cell[37693, 992, 3243, 104, 274, "Text"],
Cell[CellGroupData[{
Cell[40961, 1100, 230, 6, 37, "Subsection"],
Cell[41194, 1108, 395, 13, 38, "Text"],
Cell[41592, 1123, 1310, 38, 191, "Input"],
Cell[42905, 1163, 446, 16, 40, "Text",
 Evaluatable->False],
Cell[43354, 1181, 3029, 84, 352, "Input"],
Cell[46386, 1267, 235, 9, 29, "Text",
 Evaluatable->False],
Cell[46624, 1278, 6729, 182, 272, "Input"],
Cell[53356, 1462, 687, 21, 117, "Text",
 Evaluatable->False],
Cell[54046, 1485, 6372, 174, 537, "Input"]
}, Closed]],
Cell[60433, 1662, 519, 19, 34, "Text",
 Evaluatable->False],
Cell[60955, 1683, 2953, 109, 200, "Text"],
Cell[63911, 1794, 3106, 54, 161, "Text",
 Evaluatable->False],
Cell[67020, 1850, 973, 32, 42, "Text"],
Cell[67996, 1884, 7355, 225, 415, "Text"],
Cell[CellGroupData[{
Cell[75376, 2113, 230, 6, 37, "Subsection"],
Cell[75609, 2121, 395, 13, 38, "Text"],
Cell[76007, 2136, 1310, 38, 191, "Input"],
Cell[77320, 2176, 504, 17, 38, "Text",
 Evaluatable->False],
Cell[77827, 2195, 1742, 47, 270, "Input"],
Cell[79572, 2244, 286, 10, 29, "Text",
 Evaluatable->False],
Cell[79861, 2256, 729, 21, 112, "Input"],
Cell[80593, 2279, 821, 26, 47, "Text",
 Evaluatable->False],
Cell[81417, 2307, 2528, 73, 236, "Input"],
Cell[83948, 2382, 767, 26, 55, "Text",
 Evaluatable->False],
Cell[84718, 2410, 7421, 172, 650, "Input"],
Cell[92142, 2584, 667, 23, 35, "Text",
 Evaluatable->False]
}, Closed]],
Cell[92824, 2610, 586, 22, 34, "Text",
 Evaluatable->False],
Cell[93413, 2634, 1725, 31, 171, "Text",
 Evaluatable->False],
Cell[95141, 2667, 1681, 59, 144, "Text"],
Cell[96825, 2728, 12378, 402, 747, "Text"],
Cell[109206, 3132, 2013, 59, 210, "Text"],
Cell[CellGroupData[{
Cell[111244, 3195, 230, 6, 37, "Subsection"],
Cell[111477, 3203, 428, 14, 37, "Text"],
Cell[111908, 3219, 1348, 39, 190, "Input"],
Cell[113259, 3260, 569, 20, 49, "Text",
 Evaluatable->False],
Cell[113831, 3282, 3027, 84, 352, "Input"],
Cell[116861, 3368, 235, 9, 29, "Text",
 Evaluatable->False],
Cell[117099, 3379, 6738, 182, 295, "Input"],
Cell[123840, 3563, 630, 17, 107, "Text",
 Evaluatable->False],
Cell[124473, 3582, 6036, 166, 470, "Input"],
Cell[130512, 3750, 537, 18, 37, "Text",
 Evaluatable->False],
Cell[131052, 3770, 1239, 37, 186, "Input"],
Cell[132294, 3809, 570, 20, 55, "Text",
 Evaluatable->False],
Cell[132867, 3831, 729, 21, 112, "Input"],
Cell[133599, 3854, 667, 21, 55, "Text",
 Evaluatable->False],
Cell[134269, 3877, 2120, 61, 202, "Input"],
Cell[136392, 3940, 474, 16, 47, "Text",
 Evaluatable->False],
Cell[136869, 3958, 4786, 123, 365, "Input"],
Cell[141658, 4083, 308, 11, 29, "Text",
 Evaluatable->False]
}, Closed]]
}
]
*)

(* End of internal cache information *)
