(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    152465,       4309]
NotebookOptionsPosition[    148524,       4185]
NotebookOutlinePosition[    148917,       4202]
CellTagsIndexPosition[    148874,       4199]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[StyleBox["8.3  Improper Integrals of Rational Functions",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.5327095111875*^9, 3.532709511953125*^9}}],

Cell[TextData[{
 "\tAn important application of the theory of residues is the evaluation of \
certain types of improper integrals.  Let ",
 StyleBox["f(x)",
  FontFamily->"Courier New"],
 " be a continuous function of the real variable ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " on the interval  ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "x", "<", "\[Infinity]"}]]],
 ".  Recall from calculus that the improper integral of ",
 StyleBox["f(x)",
  FontFamily->"Courier New"],
 " over  [",
 Cell[BoxData[
  StyleBox[
   RowBox[{"0", ",", "\[Infinity]"}],
   FontWeight->"Plain"]]],
 ")  is defined by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "x", ")"}], 
     RowBox[{"\[DifferentialD]", "x"}]}]}], "  ", "=", "  ", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"b", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "b"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "x", ")"}], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}]}]]],
 ",  \n\t\nprovided that the limit exists.  If ",
 StyleBox["f(x)",
  FontFamily->"Courier New"],
 "  is defined for all real ",
 StyleBox["x",
  FontFamily->"Courier New"],
 ", then the integral of ",
 StyleBox["f(x)",
  FontFamily->"Courier New"],
 " over",
 StyleBox[" ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  StyleBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], ")"}],
   FontWeight->"Plain",
   FontColor->GrayLevel[0]]],
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 " is defined by \n\n",
 StyleBox["(8-7)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "x", ")"}], 
     RowBox[{"\[DifferentialD]", "x"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"a", " ", "\[Rule]", " ", 
       RowBox[{"-", "\[Infinity]"}]}]], " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "a", "0"], " ", 
      RowBox[{"f", 
       RowBox[{"(", "x", ")"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], " ", "+", " ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"b", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "b"], " ", 
      RowBox[{"f", 
       RowBox[{"(", "x", ")"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}]}]}]]],
 ",  \n\nprovided both limits exist.  If the integral in Equation ",
 StyleBox["(8-7)",
  FontColor->RGBColor[0, 0, 1]],
 " exists, we can obtain its value by taking a single limit:\n\n",
 StyleBox["(8-8)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "x", ")"}], 
     RowBox[{"\[DifferentialD]", "x"}]}]}], "  ", "=", "  ", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"R", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "R"}], "R"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "x", ")"}], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}]}]]],
 ".  \n\nFor some functions the limit on the right side of Equation ",
 StyleBox["(8-8)",
  FontColor->RGBColor[0, 0, 1]],
 " exists, but the limit on the right side of Equation ",
 StyleBox["(8-7)",
  FontColor->RGBColor[0, 0, 1]],
 " doesn't exist."
}], "Text",
 CellChangeTimes->{3.399458247046875*^9}],

Cell[TextData[{
 StyleBox["Example 8.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  ",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"R", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "R"}], "R"], " ", 
      RowBox[{"x", "  ", 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"R", " ", "\[Rule]", " ", "\[Infinity]"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Integral]", "R", "0"], " ", 
        RowBox[{"x", " ", 
         RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "+", " ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "R"], " ", 
        RowBox[{"x", " ", 
         RowBox[{"\[DifferentialD]", "x"}]}]}]}], ")"}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                  ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"R", " ", "\[Rule]", " ", "\[Infinity]"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["R", "2"], "2"]}], " ", "+", " ", 
        FractionBox[
         SuperscriptBox["R", "2"], "2"]}], ")"}]}], " ", "=", " ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"R", " ", "\[Rule]", " ", "\[Infinity]"}]], 
      RowBox[{"(", "0", ")"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                  ", 
   RowBox[{"=", "  ", "0", " "}]}]}],
  CellChangeTimes->{{3.399453464875*^9, 3.39945362746875*^9}}],
 "  \n\nbut Equation ",
 StyleBox["(8-7)",
  FontColor->RGBColor[0, 0, 1]],
 " tells us that the improper integral of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "x", ")"}]}], "=", "x"}]],
  AspectRatioFixed->True],
 "  over",
 StyleBox[" ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  StyleBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], ")"}],
   FontWeight->"Plain",
   FontColor->GrayLevel[0]]],
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  doesn't exist, because the calculation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], " ", 
    RowBox[{"x", 
     RowBox[{"\[DifferentialD]", "x"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"a", " ", "\[Rule]", " ", 
        RowBox[{"-", "\[Infinity]"}]}]], " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", "0"], " ", 
       RowBox[{"x", 
        RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "+", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"b", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "b"], " ", 
       RowBox[{"x", 
        RowBox[{"\[DifferentialD]", "x"}]}]}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      StyleBox["'",
       FontColor->GrayLevel[0]], "\[Infinity]"}], "-", 
     RowBox[{"\[Infinity]", "'"}]}]}]}]]],
 "    is undefined .  \n\nTherefore we can use Equation ",
 StyleBox["(8-8)",
  FontColor->RGBColor[0, 0, 1]],
 " to extend the notion of the value of an improper integral, as Definition \
8.2 indicates.  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.3994536399375*^9, 3.399453713734375*^9}, {
  3.399457830734375*^9, 3.399457858859375*^9}, {3.39945808665625*^9, 
  3.39945809371875*^9}},
 AspectRatioFixed->False],

Cell[GraphicsData["CompressedBitmap", "\<\
eJyt2FtPE0EYBuClLS1gU7FiEZG0nM+1cj6IpGlKRQ4iIBLEQ0WUhhAM4iFG
iTFoCAYvvNb/4j16pX/BhH+xdnbo61pm+krjhmx3Z575vt3ZafvRieTmyvJa
cjO1lAwlNpKPV1JLT0Ij6xvpJmeBYRS8NgxjN2SIYzN9eLgz03/mltiJluMd
PxUvLhFo3WpwGjKkZYxPEj0TL4UCrenRC6BVPXoJlNKjV0CP9GgLaFmP3gAt
6dFboKQebQPd1aP3QLf1aAczvqhHu0ALevQB6eb1aA9ojiCHYX7dt+QskS7I
aSLdkFNEFkFOElkCOU6kV0hrFseI9EGOEnlSSLeQI0SeEtIjZIzIMsSMElmO
ex8msgJyiMhKyEEiqzBLA0QGIfuIDCF7D5E1kF1E1kF2ENkAGSGyCTJMZAtk
G5FtkC1EhrFCGomMQNYT2YnstUR2Q1YT2QsZJLIfsorIQchKIocgK4gchiwn
Mgp5hsgY5Gki43h3+IlMQJYSeQXZfURehfQq5A2xt5ocit5uW5xxxClRSPlt
4/qrzch8HMgAkwhQpAtgNfXbxkxhjDu/pNMI4MovwCwCqCbImj5X9lXPYUwW
fy72DqvJmUlmbQF5ZlVev0RD9hSJTa5d48DWJWtC0xAx02nTPaq3bODoQBlT
3nv6Hg3rMzzntR0o5soUtUb6dFo0DaizyLOMnLLJvZxrb0bRVog4k7Y4O3gI
DvXzVJVCHoQat4X6iEu6qRhTnElkjmWP+bekJxBgNL8AXlx1InsiXbqr9mFM
nDymUsgYkX7IKJFlkMNEBiCHiDwLOUjkObF3i4Y+Is9D9hAZRPYuIqshO4is
hYwQWQ8ZJrIRso3IZsgWIluxgJuJbIdsJDKM7PVERiBrieyArCayCzJIZA9k
FZF9kJVEDkBWEHkJ6zNA5GXIMiKjyO4nMgZZSmQc0kdkAtJL5ChkCZFjkEVE
TkC6ibwG6SLyOqSDyBm8O0SHiW/TTOmhGoNaw+zXozlcQq8ezQN169ECUKce
LQJd1KM7QBf06B5Qux7dB2rVowdY/0169BCoQY9SSFenR6tANXq0hmcn6zP5
o9wtyD8LIGTrz/NHPt3xT8WFqcrqL5L/UHSpKvfPku9nbvGwfDxSKapqS1VR
7kEgj27Ytjz7phjtVLRll5diK1S47H/kxPbueKlUbblvsljRu/2fp9Sfx0Sq
4uR4/N+RQjWzOZaZbrUaBb8Bd7CZNA==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{381, 138},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"8.13", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506705587546875*^9, 3.506705587546875*^9}}],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], "=", "x"}]],
  AspectRatioFixed->True],
 "  and investigate the ",
 " Cauchy Principal Value ."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "=", "0"}], ";", " ", 
    RowBox[{"Remove", "[", "x", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "lim1", ",", "lim2", ",", "R", ",", "x"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "x_", "]"}], " ", "=", " ", "x"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "x_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"lim", " ", "=", " ", 
     RowBox[{"Limit", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"F", "[", "R", "]"}], " ", "-", " ", 
        RowBox[{"F", "[", 
         RowBox[{"-", "R"}], "]"}]}], ",", " ", 
       RowBox[{"R", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1.5"}], ",", "0"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red"}], "}"}]}]}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "1.5"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Blue"}], "}"}]}]}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g11", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "x", "]"}], ",", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", " ", 
       RowBox[{"Filling", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "2", "}"}], ",", 
            RowBox[{"{", "Pink", "}"}]}], "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g22", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "x", "]"}], ",", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", " ", 
       RowBox[{"Filling", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "2", "}"}], ",", 
            RowBox[{"{", "Cyan", "}"}]}], "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ends", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<-R\>\"", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}], "}"}]}], "]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<R\>\"", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "}"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"g11", ",", "g22", ",", "g1", ",", "g2", ",", "ends", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.25"}], ",", "1.25"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.25"}], ",", "1.25"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<   s = f[x]\>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<         f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<         F[x] = \[Integral] x \[DifferentialD]x = \>\"", ",", 
      RowBox[{"F", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) \
\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-R\), \(R\)]\) x \[DifferentialD]x \
= \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) \
(\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-R\), \(0\)]\) \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\< \[DifferentialD]x + \!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(0\), \(R\)]\) \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x) = \>\"", 
      ",", "lim"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) \
\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-R\), \(R\)]\) x \[DifferentialD]x \
= \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) ((\>\"", ",", 
      RowBox[{"F", "[", "x", "]"}], ",", "\"\<)\>\"", ",", 
      UnderoverscriptBox["\"\<|\>\"", 
       RowBox[{"-", "R"}], "0"], ",", "\"\< + (\>\"", ",", 
      RowBox[{"F", "[", "x", "]"}], ",", "\"\<)\>\"", ",", 
      UnderoverscriptBox["\"\<|\>\"", "0", "R"], ",", "\"\<) = \>\"", ",", 
      "lim"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) \
\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-R\), \(R\)]\) x \[DifferentialD]x \
= \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) ((\>\"", ",", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", 
        RowBox[{"-", "R"}], "0"], " ", 
       RowBox[{
        RowBox[{"f", "[", "x", "]"}], " ", 
        RowBox[{"\[DifferentialD]", "x"}]}]}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "R"], " ", 
       RowBox[{
        RowBox[{"f", "[", "x", "]"}], " ", 
        RowBox[{"\[DifferentialD]", "x"}]}]}], ",", "\"\<)) = \>\"", ",", 
      "lim"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) \
\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-R\), \(R\)]\) x \[DifferentialD]x \
= \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) (\>\"", ",", 
      RowBox[{"F", "[", "R", "]"}], ",", "\"\< - \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"-", "R"}], "]"}], ",", "\"\<) = \>\"", ",", "lim"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) \
\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-R\), \(R\)]\) x \[DifferentialD]x \
= \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) (\>\"", ",", 
      RowBox[{
       RowBox[{"F", "[", "R", "]"}], "-", " ", 
       RowBox[{"F", "[", 
        RowBox[{"-", "R"}], "]"}]}], ",", "\"\<) = \>\"", ",", "lim"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V. \!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\) \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "lim"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39945834165625*^9, 3.399458346125*^9}, {
  3.4000563825625*^9, 3.4000563828125*^9}, {3.400057065328125*^9, 
  3.400057077671875*^9}, {3.400057117859375*^9, 3.400057128421875*^9}, {
  3.4000572365625*^9, 3.400057250875*^9}, {3.4003128561875*^9, 
  3.40031286546875*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  ",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"R", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "R"}], "R"], 
      RowBox[{
       RowBox[{
        StyleBox["(",
         FontColor->GrayLevel[1]], 
        RowBox[{"|", "x", "|"}], 
        StyleBox[")",
         FontColor->GrayLevel[1]]}], " ", 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], " ", "=", " ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"R", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Integral]", "R", "0"], 
        RowBox[{
         RowBox[{
          StyleBox["(",
           FontColor->GrayLevel[1]], 
          RowBox[{"|", "x", 
           StyleBox["|",
            FontColor->GrayLevel[0]]}], 
          StyleBox[")",
           FontColor->GrayLevel[1]]}], " ", 
         RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "+", " ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "R"], 
        RowBox[{
         RowBox[{
          StyleBox["(",
           FontColor->GrayLevel[1]], 
          RowBox[{"|", "x", "|"}], 
          StyleBox[")",
           FontColor->GrayLevel[1]]}], 
         RowBox[{"\[DifferentialD]", "x"}]}]}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                           ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"R", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SuperscriptBox["R", "2"], "2"], " ", "+", " ", 
        FractionBox[
         SuperscriptBox["R", "2"], "2"]}], ")"}]}], "=", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"R", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
      RowBox[{"(", 
       SuperscriptBox["R", "2"], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                           ", 
   RowBox[{"=", "  ", "\[Infinity]", " "}]}]}],
  CellChangeTimes->{{3.399453464875*^9, 3.39945362746875*^9}, {
   3.399453773640625*^9, 3.399453838546875*^9}, {3.3994539673125*^9, 
   3.399453994796875*^9}}],
 "  \n\nand Equation ",
 StyleBox["(8-7)",
  FontColor->RGBColor[0, 0, 1]],
 " tells us that the improper integral of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "x", ")"}]}], "=", 
   RowBox[{"|", "x", "|"}]}]],
  AspectRatioFixed->True],
 "  over",
 StyleBox[" ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  StyleBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], ")"}],
   FontWeight->"Plain",
   FontColor->GrayLevel[0]]],
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  also diverges to ",
 Cell[BoxData[
  RowBox[{
   StyleBox["'",
    FontColor->GrayLevel[0]], 
   RowBox[{"\[Infinity]", "'"}]}]]],
 ", because  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], " ", 
    RowBox[{"|", "x", "|", 
     RowBox[{"\[DifferentialD]", "x"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"a", " ", "\[Rule]", " ", 
        RowBox[{"-", "\[Infinity]"}]}]], " ", 
      SubsuperscriptBox["\[Integral]", "a", "0"]}], " ", "|", "x", "|", 
     RowBox[{
      RowBox[{"\[DifferentialD]", "x"}], "  ", "+", "  ", 
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"b", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
       SubsuperscriptBox["\[Integral]", "0", "b"]}]}], " ", "|", "x", "|", 
     RowBox[{"\[DifferentialD]", "x"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"\[Infinity]", "+", "\[Infinity]"}], "  ", "=", "  ", 
     "\[Infinity]"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.399454004375*^9, 3.39945404878125*^9}, {
   3.399457914828125*^9, 3.399457936640625*^9}, 3.399457974453125*^9, {
   3.399458059796875*^9, 3.39945807653125*^9}},
 AspectRatioFixed->False],

Cell[GraphicsData["CompressedBitmap", "\<\
eJzt2NtXVGUYx/EXZlBAlIMc5CQDyEHkJOejgMhZUBEQzBOhBRrpMstWZbWq
1cGyi/4i76mr+ge6aK3+i4m93+Hb9PRDocVls2Rmu/fv887z7ndmzd7P7OqT
9Xubq0821lZjE49XH61vrL0XG3/4eHtXJMW5lGfOuecxF2zHtzcTT/Htf/FP
g6dgz/62/wxfIs4PFB5xP/1/aF+HXgQv4ZFUEboq9i2+UnT6Yb8NXqJ/h6L/
CG0/loRd0tEev/Ej73ttNxvu6k2KH9j7HsRALzgnagKLHO3dfdGeBs+p4a7I
zujho9D/74Pg5Y9gR7rRwaMoqY4VF3+5lRp+CSOJMeLh33KQrxTvXZiklwMd
ETqoLb4UoIrXlBqOcy15nJ3QzjmMLwbbfUnxJeLqU5X4AMQXLFuERcS8UoFX
LVwARgWMAOctnA9gNIBpAkZ3ljp+2cIrwEMCpgEvWXiZUu3KB3+HKXXOwjne
MUPAdOCshbPATAEzgBctnAFmCZgJnLFwGnhUwCPAaQunODnZAmYBpyycBOYI
eBQ4aeEEMFfAY6zjuIXjwDwBs4FjFo4BjwuYCxy18AIwX8A84HkLR4EFAuZz
ckYsHGEdCwUs4B2HLBwGFglYCDxn4RClFgt4glIHLTwHLBGwGDhg4SCwVMAS
YL+F/cyxTMBSYJ+FfcByAcuAvRb2UmqFgOXAHgt7gDEBTwK7LewGqh+aCmCX
hZ3MsUrAGB+ADgs7gNUCVgLbLWyn1BoBqym1zcI2YK2Ap4BnLWyl1DoBa4Ct
FrYA6wWsZY7NFjZTaoOAdcAmC5uAZwQ8TamNFjYCGwVsAJ6xsIE5Ngl4Bthg
4Wlgs4CNzLHewnpKbRWwCVhnYR3wrIAtlFprYS2wTcBWYI2Fp5hju4BnKbXa
wmpgh4BtwCoLqyi1S8AOSq20sBLYLWAnMGZhDNgjYBewwsIKYK+A3cyx3MKT
wD4Be4BlFpYD+wXso9RSC0tZjgEB+4ElFpYABwUcABZbeAI4JOAgcyyysAg4
LOA5YKGFhZyc8wIOU2qBhQXAUQFHgPkWHqfUCwKep9Q8C/OAYwKOAnMtzKXU
CQHHKDXHwhzgpIDjwGwLs4FTAk4Aj1l4DDgt4CRzzLLwKHBGwCngEQuzgBcF
nKHUTAszWY5ZAS8CMyzMAM4JOAtMt/Aw8LKAc8zxkIWHgFcEvARMszCNk6M6
MFcoNWphFLgg4DwwYmEqpS4KeBWYamFwG/xyK3H7H96Y697IArNN1mGpyyJO
OySeaIf8QHxFxK9RYKLZ8j3x6yK+TNz//LjnxN8Q8RWKSbS3viN+Q8SvE/c/
p74bFsZvivgNivE/2+4b4rdE/CZxf3ngviZ+W8RvEfeXIe6rxOfEuTsifpva
W3z8S+KrIn6HuL+scl9QzJqIv0kx/vLNfc7od0V8jbi/THSfEb8n4neJ+8tR
94z42yJ+j9pP+/gnxNdF/C3i/vLafcxU74v4OsX4y3j3EfEHIr5B3N8uuA8p
5h0Rv08xp3z8KfFNEX9A3N/++EZhWMxDEd+kGH+b5d4n/kjE3yVemTS68329
ndDvQLp1idvGfff997L9m6hTtdRUI0E1wp76YX8Vh1TDTTU2XjHs1s76JDqU
/2psqkaq6kkeZiDVlNvrKImqfhaHdu2gml6z6nsWJEo0c3ut22c5at9/OVd7
G+WgV1D10g5g3VT8AD64vzA1tXAH8IXb7fvtUv4CbeHRHQ==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{381, 138},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "1."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670559071875*^9, 3.50670559071875*^9}}],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], "=", 
   RowBox[{
    RowBox[{"|", "x", "|"}], " ", "=", " ", 
    RowBox[{"Abs", "[", "x", "]"}]}]}]],
  AspectRatioFixed->True],
 "  and investigate the ",
 " Cauchy Principal Value ."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "=", "0"}], ";", " ", 
    RowBox[{"Remove", "[", "x", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "lim1", ",", "lim2", ",", "R", ",", "x"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "x_", "]"}], " ", "=", " ", 
     RowBox[{"Abs", "[", "x", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "x_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"lim", " ", "=", " ", 
     RowBox[{"Limit", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubsuperscriptBox["\[Integral]", 
          RowBox[{"-", "R"}], "0"], " ", 
         RowBox[{
          RowBox[{"-", "x"}], " ", 
          RowBox[{"\[DifferentialD]", "x"}]}]}], "+", 
        RowBox[{
         SubsuperscriptBox["\[Integral]", "0", "R"], " ", 
         RowBox[{"x", " ", 
          RowBox[{"\[DifferentialD]", "x"}]}]}]}], ",", " ", 
       RowBox[{"R", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1.5"}], ",", "0"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red"}], "}"}]}]}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "1.5"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Blue"}], "}"}]}]}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g11", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "x", "]"}], ",", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", " ", 
       RowBox[{"Filling", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "2", "}"}], ",", 
            RowBox[{"{", "Pink", "}"}]}], "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g22", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "x", "]"}], ",", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", " ", 
       RowBox[{"Filling", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "2", "}"}], ",", 
            RowBox[{"{", "Cyan", "}"}]}], "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ends", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<-R\>\"", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<R\>\"", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "}"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"g11", ",", "g22", ",", "g1", ",", "g2", ",", "ends", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.25"}], ",", "1.25"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.25"}], ",", "1.25"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<   s = f[x]\>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<           F[x] = \[Integral] x \[DifferentialD]x = \>\"", ",", 
      RowBox[{"F", "[", "x", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) \
\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-R\), \(R\)]\) |x| \
\[DifferentialD]x = \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \
\[Infinity]\)]\) (\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-R\), \(0\)]\) \
\>\"", ",", 
      RowBox[{"-", "x"}], ",", 
      "\"\< \[DifferentialD]x + \!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(0\), \(R\)]\) \>\"", ",", "x", ",", "\"\< \[DifferentialD]x) = \>\"", ",", 
      "lim"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) \
\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-R\), \(R\)]\) |x| \
\[DifferentialD]x = \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \
\[Infinity]\)]\) ((\>\"", ",", 
      RowBox[{"\[Integral]", 
       RowBox[{
        RowBox[{"-", "x"}], 
        RowBox[{"\[DifferentialD]", "x"}]}]}], ",", "\"\<)\>\"", ",", 
      UnderoverscriptBox["\"\<|\>\"", 
       RowBox[{"-", "R"}], "0"], ",", "\"\< + (\>\"", ",", 
      RowBox[{"\[Integral]", 
       RowBox[{"x", 
        RowBox[{"\[DifferentialD]", "x"}]}]}], ",", "\"\<)\>\"", ",", 
      UnderoverscriptBox["\"\<|\>\"", "0", "R"], ",", "\"\<) = \>\"", ",", 
      "lim"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) \
\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-R\), \(R\)]\) |x| \
\[DifferentialD]x = \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \
\[Infinity]\)]\) ((\>\"", ",", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", 
        RowBox[{"-", "R"}], "0"], " ", 
       RowBox[{
        RowBox[{"-", "x"}], " ", 
        RowBox[{"\[DifferentialD]", "x"}]}]}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "R"], " ", 
       RowBox[{"x", " ", 
        RowBox[{"\[DifferentialD]", "x"}]}]}], ",", "\"\<)) = \>\"", ",", 
      "lim"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) \
\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-R\), \(R\)]\) |x| \
\[DifferentialD]x = \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \
\[Infinity]\)]\) (\>\"", ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Integral]", 
         RowBox[{"-", "R"}], "0"], " ", 
        RowBox[{
         RowBox[{"-", "x"}], " ", 
         RowBox[{"\[DifferentialD]", "x"}]}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "R"], " ", 
        RowBox[{"x", " ", 
         RowBox[{"\[DifferentialD]", "x"}]}]}]}], ",", "\"\<) = \>\"", ",", 
      "lim"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V. \!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\) \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "lim"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399458365984375*^9, 3.399458373359375*^9}, {
  3.400056391046875*^9, 3.40005639125*^9}, {3.400057146140625*^9, 
  3.400057225265625*^9}, {3.400312873*^9, 3.4003128811875*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Definition 8.2 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Cauchy Principal Value - P.V.",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/CauchyPrincipalValue.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 StyleBox["f(x)",
  FontFamily->"Courier New"],
 " be a continuous real valued function for all ",
 StyleBox["x",
  FontFamily->"Courier New"],
 ".  The Cauchy principal value (P.V.) of the integral  ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", 
    RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], " ", 
   RowBox[{"f", 
    RowBox[{"(", "x", ")"}], 
    RowBox[{"\[DifferentialD]", "x"}]}]}]]],
 "  is defined by \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", ".", "V", ".", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "x", ")"}], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "=", "  ", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"R", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "R"}], "R"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "x", ")"}], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}]}]]],
 ",  \n\nprovided the limit exists."
}], "Text"],

Cell[TextData[{
 "\tExample 8.13 shows that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", ".", "V", ".", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], " ", 
     RowBox[{"x", 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "=", "  ", "0"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 8.14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the Cauchy principal value of  ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", 
    RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      SuperscriptBox["x", "2"], " ", "+", " ", "1"}]], 
    RowBox[{"\[DifferentialD]", "x"}]}]}]]],
 ".   "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.3994581949375*^9, 3.399458206734375*^9}},
 AspectRatioFixed->False],

Cell[GraphicsData["CompressedBitmap", "\<\
eJzt2XtQVFUcB/DDsiwsGOKDh4K4gKKgKKCIL0SliMHANNMhUtuIWDDCkLQ0
TU3KfGSmjjWO0zTV1DRNNb3f2fthb7WX9m56TTP90V/9te05v8uX3Z3v3RaX
/2pHzr333M/vnN859+7de68N3h5fa6e3p73F6zm/27vW196yzlPb1R2oio9T
Ku6AUuqQR+l1f2DVKvyBf/6DutA1A1v/yyzilTRk9qijsezq1Quzx0HQlaTO
FzGiRJrdqhfOfuQMQYFPO4lt57RUVm5Gvx12saaqLIgPWr+D0VAv5oQNwIe9
ZWd1PLfp0mGq4vs6Np9M2dqgF3/riqSwaP3JkrUdetGl/MeOW/uVOQH9ao0u
s0i3mdEEZvxLbpGjy/9H/wm0wTq9/EGnV3LEwFSckH5E5Elj6/UiQbfljthE
irjAan5QFok60BUxMElcYLVAAjciMD5iYAICCyVws164dWAnienQZbLeLlL9
l1bDOwhv06Vbb1tXYnP5cmneRnirLl162zoIO8FbCb8cvEL4bkxzC+GrdWmG
Wil8L7iX8JVofbbwfUhmFeHNMpuBskr4fhyBZsKbwKuFH0TrTYQvRzILhB9G
7isIXwZeI/wu8IsJX4pkaoUfAb+I8CW61D8O/jrhR8GXEL4YvF743eCLCW8E
XyT8HmV+iwJrjYRfAN4g/F69MN/bBsLrMdRG4feh9UWE14FfKPx+8HrCa8GX
Cn8AvI7w85D7MuEPYmZqCa8BXy78IfBzCV8IvkL4w0imhvAFujRXrybhj2Ai
FxI+H/wS4Y+i9fmEV4M3C38MvJrweeCXCn8cycwjvAp8pfAnwKsInwu+SviT
4HMJnwO+WvhT4HMIn4V5v0z40+CzCZ8J7hX+DPgswiuRTIvwZ8FnEj4D/Arh
z4FXEl4B3ir8efAZhE8Hl3tz9QJ4BeHTwNuEvwg+nfBycJ/wl8CnEV4GLne+
6mXwcsJLweUGWL0CXkb4VPA1wo+BlxI+Bfwq4a+CTyW8BLxT+GvgUwifDH61
8NfBSwifBN4l/A3wyYQXg68V/ib4JMKLwK8R/hZ4MeETwbuFv60XDjs+AXyd
8HfAiwgvBO8J4iaZiYSPB79W+LvgE+y4fnTwrxf+HpJhfBy43E2q4+CFhBeA
Xyf8ffDxhOeDXy/8AxV0yxrg+q8g6kDTzzjC88A3Cv8QnLXuAd8k/CPwfMLH
gt8g/GPwPDsedpO9KSjQjN5DAnPRz2bhn4CPJXwM+BbhnyItxnPAbxR+AjzX
joeNYktQoElrDAnMRj9bhZ8EzyF8NPg24aeQFuOjwLcL/ww8m/AsfHks/jn4
aMIzwW8S/gX4KDtuktkh/EtyemeSwAwE9gYFmn6yCE9HWhb/Cpy1PhJcXsWo
0+AZhI8Av0X4GfB0woeD7wziZswjCR8Gfqvwr8FH2HEzM7uEfwM+nPA08N3C
vwUfRvhQJGPx78DTCE8F3yP8e/ChhJ8Dvlf4D+CphA8Bv034j6rvfnMI4Sng
+4T/BJ5CeDL47cJ/RjLJhLvB9wv/BdxNeKIuzR3hHcJ/BU8iPEGX5qHjgPDf
kLuLcCdaPyT8d71wWa8KAtwZwvvaPiz4D2Dr8mVhZZ427xT0J/INQ2briKBB
f3l8drtief8dzfoZ0rWL1BWTulxSZz3gnCa7wl+l6j8PqUsgdelRtmc9jp2Q
U0z1vUINfcvs5+9XnaS9RDRkXp/pU42+yR9AN0lo0smDEvpjQjuxHk1P2vYf
Wheep/6wuc2OInYgfbjtYm0HNgiDZXWRD2haDMNmdWzYLIMBTsCgncrsMNsf
0qi6SY5heAM85mxE7AKQE0P3iWTkyvY/5djg2fljXZJOYRLZd5BdcnMQwfba
DsCBE8CBNB39x45eru1+HVTcP2YQJ4M=\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  \n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"P", ".", "V", ".", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], " ", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         SuperscriptBox["x", "2"], " ", "+", " ", "1"}]], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"R", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "R"}], "R"], " ", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         SuperscriptBox["x", "2"], " ", "+", " ", "1"}]], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                   ", 
   RowBox[{"=", " ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"R", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"Arctan", 
        RowBox[{"(", "R", ")"}]}], "  ", "-", "  ", 
       RowBox[{"Arctan", 
        RowBox[{"(", 
         RowBox[{"-", "R"}], ")"}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                   ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"R", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
      RowBox[{"Arctan", 
       RowBox[{"(", "R", ")"}]}]}], "  ", "-", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"R", " ", "\[Rule]", " ", "\[Infinity]"}]], " ", 
      RowBox[{"Arctan", 
       RowBox[{"(", 
        RowBox[{"-", "R"}], ")"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                   ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["\[Pi]", "2"], "  ", "-", "  ", 
     FractionBox[
      RowBox[{"-", "\[Pi]"}], "2"]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                   ", 
   RowBox[{"=", "  ", "\[Pi]"}]}]}]],
 "   "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"8.14", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670559596875*^9, 3.506705595984375*^9}}],

Cell[TextData[{
 StyleBox["Method (i).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], "=", "x"}]],
  AspectRatioFixed->True],
 "  and investigate the  Cauchy Principal Value ."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "=", "0"}], ";", " ", 
    RowBox[{"Remove", "[", "x", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "lim1", ",", "lim2", ",", "R", ",", "x"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "x_", "]"}], " ", "=", " ", 
     FractionBox["1", 
      RowBox[{
       SuperscriptBox["x", "2"], "+", "1"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "x_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"lim", " ", "=", " ", 
     RowBox[{"Limit", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"F", "[", "R", "]"}], " ", "-", " ", 
        RowBox[{"F", "[", 
         RowBox[{"-", "R"}], "]"}]}], ",", " ", 
       RowBox[{"R", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "2.5"}], ",", "0"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red"}], "}"}]}]}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "2.5"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Blue"}], "}"}]}]}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g11", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "x", "]"}], ",", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "2.0"}], ",", "0"}], "}"}], ",", " ", 
       RowBox[{"Filling", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "2", "}"}], ",", 
            RowBox[{"{", "Pink", "}"}]}], "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g22", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "x", "]"}], ",", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "2.0"}], "}"}], ",", " ", 
       RowBox[{"Filling", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "2", "}"}], ",", 
            RowBox[{"{", "Cyan", "}"}]}], "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ends", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<-R\>\"", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<R\>\"", ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "}"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"g11", ",", "g22", ",", "g1", ",", "g2", ",", "ends", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<   s = f[x]\>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<         f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<         F[x] = \[Integral] x \[DifferentialD]x = \>\"", ",", 
      RowBox[{"F", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) \
\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-R\), \(R\)]\) x \[DifferentialD]x \
= \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) \
(\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-R\), \(0\)]\) \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\< \[DifferentialD]x + \!\(\*SubsuperscriptBox[\(\[Integral]\), \
\(0\), \(R\)]\) \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x) = \>\"", 
      ",", "lim"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) \
\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-R\), \(R\)]\) x \[DifferentialD]x \
= \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) ((\>\"", ",", 
      RowBox[{"F", "[", "x", "]"}], ",", "\"\<)\>\"", ",", 
      UnderoverscriptBox["\"\<|\>\"", 
       RowBox[{"-", "R"}], "0"], ",", "\"\< + (\>\"", ",", 
      RowBox[{"F", "[", "x", "]"}], ",", "\"\<)\>\"", ",", 
      UnderoverscriptBox["\"\<|\>\"", "0", "R"], ",", "\"\<) = \>\"", ",", 
      "lim"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) \
\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-R\), \(R\)]\) x \[DifferentialD]x \
= \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) ((\>\"", ",", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", 
        RowBox[{"-", "R"}], "0"], " ", 
       RowBox[{
        RowBox[{"f", "[", "x", "]"}], " ", 
        RowBox[{"\[DifferentialD]", "x"}]}]}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "R"], " ", 
       RowBox[{
        RowBox[{"f", "[", "x", "]"}], " ", 
        RowBox[{"\[DifferentialD]", "x"}]}]}], ",", "\"\<)) = \>\"", ",", 
      "lim"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) \
\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-R\), \(R\)]\) x \[DifferentialD]x \
= \!\(\*UnderscriptBox[\(lim\), \(R \[Rule] \[Infinity]\)]\) (\>\"", ",", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Integral]", 
         RowBox[{"-", "R"}], "0"], " ", 
        RowBox[{
         RowBox[{"f", "[", "x", "]"}], " ", 
         RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "+", " ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "R"], " ", 
        RowBox[{
         RowBox[{"f", "[", "x", "]"}], " ", 
         RowBox[{"\[DifferentialD]", "x"}]}]}]}], ",", "\"\<) = \>\"", ",", 
      "lim"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V. \!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\) \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "lim"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399458384875*^9, 3.39945838790625*^9}, {
  3.399458538796875*^9, 3.39945854271875*^9}, {3.39945859334375*^9, 
  3.3994585949375*^9}, {3.399458629875*^9, 3.399458631875*^9}, {
  3.399458898984375*^9, 3.39945893396875*^9}, {3.400056396609375*^9, 
  3.4000563968125*^9}, {3.400057267828125*^9, 3.400057317921875*^9}, {
  3.400312888515625*^9, 3.40031289603125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method (ii).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["z", "2"], " ", "+", " ", "1"}]]}]],
  AspectRatioFixed->True],
 "  and locate the singularities."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "=", 
      RowBox[{"x", "=", "0"}]}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"x", ",", "z", ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "g", ",", "Res1", ",", "Res2", ",", "solset", ",", "val"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox["1", 
      RowBox[{
       SuperscriptBox["z", "2"], " ", "+", " ", "1"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Denominator", "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}], 
       "]"}], "]"}]}], ";"}], " ", "\[IndentingNewLine]", " ", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The singularities are\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "2"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"]}], "]"}], ";"}], " ", "\n"}]}]], "Input",
 CellChangeTimes->{3.399458939859375*^9},
 AspectRatioFixed->False],

Cell["Determine which poles lie in the upper half plane ?", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "1"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "2"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<, Is  Im(\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<) > 0 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "1"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<,  Is  Im(\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<) > 0 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "2"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39945894834375*^9, 3.39945895171875*^9}, 
   3.40005640259375*^9, {3.40005770459375*^9, 3.400057716359375*^9}}],

Cell[TextData[{
 "Compute the residues at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", "\[ImaginaryI]"}]]],
 ", and use the residue calculus to compute the value of the integral."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Res2", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "2"]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"val", " ", "=", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", "  ", "Res2"}]}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<] = \>\"", ",", "Res2"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Magenta", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            SubscriptBox["Z", "2"], "]"}], ",", 
           RowBox[{"Im", "[", 
            SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            SubscriptBox["Z", "2"], "]"}], ",", 
           RowBox[{"Im", "[", 
            SubscriptBox["Z", "2"], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.2"}], ",", "0"}], "}"}]}], "]"}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "2", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "\[Pi]"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"segment", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", "contour", ",", "segment", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "2.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<) \[DifferentialD]z = 2\[Pi]\[ImaginaryI](\>\"", ",", "Res2", " ", 
      ",", "\"\<) = \>\"", ",", "val"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The contour is the semicircle \!\(\*SubscriptBox[\(C\), \(R\)]\) \
and interval [-R,R],\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<taken with the positive orientation.\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Let R\[Rule]\[Infinity] to obtain the Cauchy Principal Value of the \
integral.\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\< \[DifferentialD]x = 2\[Pi]\[ImaginaryI](\>\"", ",", "Res2", ",", 
      "\"\<) = \>\"", ",", "val"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399458954890625*^9, 3.39945895771875*^9}, {
  3.39945899471875*^9, 3.39945901334375*^9}, {3.4000564081875*^9, 
  3.400056408375*^9}, {3.400057368484375*^9, 3.40005736909375*^9}, {
  3.400057423828125*^9, 3.400057456734375*^9}}],

Cell[TextData[{
 "Or, we can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s integral table and evaluate the integral."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"int", "=", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}], ",", 
       RowBox[{"PrincipalValue", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "int"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39945901840625*^9}],

Cell[TextData[{
 "However, for this simple integral ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s can find the correct answer without resorting to the PrincipalValue \
option."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "x_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[x] = \[Integral]\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",", 
      RowBox[{"g", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[\[Infinity]] = \>\"", ",", 
      RowBox[{"g", "[", "\[Infinity]", "]"}], ",", 
      "\"\<,    g[-\[Infinity]] = \>\"", ",", " ", 
      RowBox[{"g", "[", 
       RowBox[{"-", "\[Infinity]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\< \[DifferentialD]x = g[\[Infinity]]-g[-\[Infinity]] = (\>\"", ",", 
      RowBox[{"g", "[", "\[Infinity]", "]"}], " ", ",", "\"\<) - (\>\"", ",", 
      " ", 
      RowBox[{"g", "[", 
       RowBox[{"-", "\[Infinity]"}], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",", 
      RowBox[{
       RowBox[{"g", "[", "\[Infinity]", "]"}], " ", "-", " ", 
       RowBox[{"g", "[", 
        RowBox[{"-", "\[Infinity]"}], "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399459021921875*^9},
 AspectRatioFixed->True],

Cell["The above answer is correct too.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tIf  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "x", ")"}]}], "=", 
   FractionBox[
    RowBox[{"P", 
     RowBox[{"(", "x", ")"}]}], 
    RowBox[{"Q", 
     RowBox[{"(", "x", ")"}]}]]}]]],
 ",  where ",
 StyleBox["P(x)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["Q(x)",
  FontFamily->"Courier New"],
 " are polynomials, then ",
 StyleBox["f(x)",
  FontFamily->"Courier New"],
 " is called a rational function.  Techniques in calculus were developed to \
integrate rational functions.  We now show how the Residue Theorem can be \
used to obtain the ",
 StyleBox[ButtonBox["Cauchy",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cauchy.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " principal value of the integral of ",
 StyleBox["f(x)",
  FontFamily->"Courier New"],
 " over  ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], ")"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 8.3 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Contour Integration for Rational Functions",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/ContourIntegration.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"P", 
     RowBox[{"(", "z", ")"}]}], 
    RowBox[{"Q", 
     RowBox[{"(", "z", ")"}]}]]}]]],
 "  where ",
 StyleBox["P(x)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["Q(x)",
  FontFamily->"Courier New"],
 " are polynomials, of degree m and n , respectively.  If ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Q", 
    RowBox[{"(", "x", ")"}]}], "\[NotEqual]", "0"}]]],
 " for all real ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " and  ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", 
   RowBox[{"m", "+", "2"}]}]]],
 ",  then the Cauchy Principal Value (P.V.) of the integral is\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", ".", "V", ".", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
     RowBox[{
      FractionBox[
       RowBox[{"P", 
        RowBox[{"(", "x", ")"}]}], 
       RowBox[{"Q", 
        RowBox[{"(", "x", ")"}]}]], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "=", "  ", 
   RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"j", "=", "1"}], "k"], 
     RowBox[{"Res", "[", 
      RowBox[{
       FractionBox["P", "Q"], ",", 
       SubscriptBox["z", "j"]}], "]"}]}]}]}]]],
 ".  \n\nwhere  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "k"]}]]],
 "  are the poles of  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"P", 
    RowBox[{"(", "z", ")"}]}], 
   RowBox[{"Q", 
    RowBox[{"(", "z", ")"}]}]]]],
 "  that lie in the upper half plane.   The situation is illustrated in \
Figure 8.4.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{387, 236},
  ImageMargins->0],
 StyleBox["  \n\n",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t  Figure 8.4  ",
 "The poles  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "k"]}]]],
 "  of  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"P", 
    RowBox[{"(", "x", ")"}]}], 
   RowBox[{"Q", 
    RowBox[{"(", "x", ")"}]}]]]],
 "  that lie in the upper half-plane. "
}], "Text",
 CellChangeTimes->{{3.399464061203125*^9, 3.399464062203125*^9}, {
  3.399464099984375*^9, 3.399464109*^9}, {3.506762342265625*^9, 
  3.506762344484375*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Proof of Theorem 8.3",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 StyleBox[" is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 8.15.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  ",
 "Evaluate",
 "  ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", 
    RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], " ", "+", " ", "1"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], " ", "+", " ", "4"}], ")"}]}]], 
    RowBox[{"\[DifferentialD]", "x"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztmtlvVFUcxy/TFi1EjTEaIpCMRoMk0I1ibSvd6AIoaxfaQqnTTVAbtJQH
Y+KLL8QXEx8k/gEuiZooQU007rghiRZ3gxpF4otEH018GOecM/3dO9PP784d
hhkx4aZzeud3vuf7/Z3fOeee5c7WxOz+yenE7IHxRLxnJvHg/gPjh+LdB2dS
prJFnhc74nneE3HP3CdTt+kkmfpzyeMmMeYiGE7bf2Wek0y6j0mP6/l/m7TC
WFrk7pAOrzRpzFj+hNw2sIWQLQXbH4XTxqQiZZB7zqTlxlJeuJQTKM+wKcx5
VuykuFnmQp6yLdYqG7CZ67w0UrvcHQ7QUiXKowpIp3rOMX4GIUh9Fhs+JTz2
5iX37URoc/gsFVLwxWBNFnDHpDLWtAJIH5KgpB2cv+KBGsXEJRv6Y+bua8Ox
BAJ+k95DbDWtyZa2tJWAi+sUL4t2ZQ7PqfQrYpO28aYANwW4tZcs7STgqi7T
Xqb9j2iPAXzyf087AbjqktNeaVL7/H+mOALhC4YiiSpzY5E8mDP/1EVEkURP
SlzTCknPLYgjr2bM51kQmMjPkVMAD1ugxFy0UtfzxRa34Xkhoso44GqcSvY6
asGCzK6JjhcuRNWJSe96NaLAGOBqnYC//KqAglSD8fwEaDQWiZbCMVY6Wrte
tKaBIgpk2fqhbN2FSC3owhV+987k6LtYkvQ0irS7y9OD1wCeABw9mLNt5iL5
dfnJD0mE/dEcda7oLVx+Dzd5echTegho6nXV1wE+DDj7bPaXBIO6ygPOw9RV
LfAqYKzKzLUlduXjzWgOH7LK1Gk+ZNlqIuKodw2FtNc9urvTQF9bgLvVEXvj
oOvTXnBPn9DdnJJ2osF+W2huVNfJRr1iFHD7ALc+2CEWDJZCglzFlNQt9uXn
7LQ0S63cqc2chaN5huRHAHe7k6fHxBsAH7lkad8E+F7A7QVcQ8lpD0vjeZnn
V+0R9fYA7g7HZEfzWQO+IquguTZCwT0gMAy4Rsdyf8TRQiMt6vi/FmwdEV2n
6bCpdK5fo7UthZ5muhD/qS+9VRzatwE+BDhaFjSXnPYdgA8Cbjfg7tRp3wX4
7tLR0mZlg077HsAHAEcTRkvhtDQNtuq07wO8v3DaDwDeBzhaHLXptCcA3gs4
Wri0F067E3AdOu2HAN9VOO1HAN8JOPtqqEx75m3UBT4G+A7A0QtTmjo7dalP
AL7dprzdTr8c9HiO7tKFPgX4NsApm2za5dJMGOKBf/pBcwX5Qnvb9H5BCUB3
DvkI00CXRDj8TS/tNVqAr0d3Kfygm5zr1KIUtjHvAqJNuld5nITTfNfJvTdr
G08jcrOT8o+pw08+6FU7TRIUM+vNZgBvcVSnuBJ5vZUnX9o5tv5b8i25fIJ6
KA1GT7EOGT3+vpsk74oiWaGpbIJiPYC7O3ew59QRlUnfDbitjp5+P/AlwLuB
lobONn3onAZ4F+A6AbddpyVvqVfToNqh0341H5gkkclvVZK9OsU3ah/PxLUB
LoT2W4C3Aa4VcH067XcAbwUcPcb7ddrvAd4CuA2AG9Bpf5AGILJmyR3SKc6A
YjPgmgAXQvsjwJsA1wi4YZ32J5NadCPkNkiFR3SKXwTUALnrJXdUpzgLTtcD
rh5wIbS/AXwd4OrExzGd7JyAiKJGcid0it8FpB5F2twpncJfX1M/o9PMtYAL
EfCXC7TYOiM+ktQakLpXlwp782ytP4vaGii+Wrrufa5o+At+Wrr8KhSrocQq
kXdH9oEfJPqLB1XKzn5+p1kFuFtE/mBAgMjC1hzUTr7urZB7s+TOOJKcP2C0
HeL8/F0yDqQrJXfWkYYtMf6Rmq8EquXi38PBuPDy2DZ4UkosB75lovZIoL7q
+/Wk1OQGyL1Och/Vu3aaYh5JZ5pXS+5jOXjsmF9qrOqeaIkxHMnBc71JrjLW
J3MgKYhPuTL2y1858m1SzJ95LzB8IS1qrSvk69Mufw48Vqt69MLDk60jHmWX
MdfRgO/KT4Rv5Lx0yc/nO3b2gbMFLtNyL2JTeYv+Bad920M=\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{648, 143},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  We write the integrand as  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], " ", "+", " ", "1"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], " ", "+", " ", "4"}], ")"}]}]], " ", "=", 
    " ", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "+", "\[ImaginaryI]"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", "+", 
        RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"2", "\[ImaginaryI]"}]}], ")"}]}]]}]}]]],
 ".  We see that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has simple poles at the points ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"\[PlusMinus]", "2"}], "\[ImaginaryI]"}]}]]],
 ",  and that the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", "\[ImaginaryI]"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "4"], "=", 
   RowBox[{"2", "\[ImaginaryI]"}]}]]],
 ",  are the only singularities of ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " in the upper half-plane.  Computing the residues, we obtain  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", "\[ImaginaryI]"}], "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", "\[ImaginaryI]"}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], "f", 
       RowBox[{"(", "z", ")"}]}]}], " ", "=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", "\[ImaginaryI]"}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], 
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "+", "\[ImaginaryI]"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"z", "+", 
           RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{"z", "-", 
           RowBox[{"2", "\[ImaginaryI]"}]}], ")"}]}]]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", "\[ImaginaryI]"}]], " ", 
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "+", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "+", 
          RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", 
          RowBox[{"2", "\[ImaginaryI]"}]}], ")"}]}]]}], "  ", "=", "  ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[ImaginaryI]", "+", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"\[ImaginaryI]", "+", 
          RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"\[ImaginaryI]", "-", 
          RowBox[{"2", "\[ImaginaryI]"}]}], ")"}]}]], "  ", "=", "  ", 
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"3", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"-", "\[ImaginaryI]"}], ")"}]}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", "  ", 
    RowBox[{"-", 
     FractionBox["\[ImaginaryI]", "6"]}]}]}]}]],
 "  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", 
      RowBox[{"2", "\[ImaginaryI]"}]}], "]"}], "  ", "=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", 
       RowBox[{"2", "\[ImaginaryI]"}]}]], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], "f", 
      RowBox[{"(", "z", ")"}]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                          ", 
   RowBox[{"=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", 
       RowBox[{"2", "\[ImaginaryI]"}]}]], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], 
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "+", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "+", 
          RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", 
          RowBox[{"2", "\[ImaginaryI]"}]}], ")"}]}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                          ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        RowBox[{"2", "\[ImaginaryI]"}]}]], " ", 
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "+", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "+", 
          RowBox[{"2", "\[ImaginaryI]"}]}], ")"}]}]]}], "  ", "=", "  ", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "\[ImaginaryI]"}], "+", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "\[ImaginaryI]"}], "-", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "\[ImaginaryI]"}], "+", 
         RowBox[{"2", "\[ImaginaryI]"}]}], ")"}]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                          ", 
   RowBox[{"=", "  ", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "\[ImaginaryI]"}], ")"}], 
      RowBox[{"(", "\[ImaginaryI]", ")"}], 
      RowBox[{"(", 
       RowBox[{"4", "\[ImaginaryI]"}], ")"}]}]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                          ", 
   RowBox[{"=", "  ", 
    FractionBox["\[ImaginaryI]", "12"]}]}]}]],
 "   "
}], "Text"],

Cell[TextData[{
 "Using Theorem 8.3, we conclude that  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], " ", "+", " ", "1"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], " ", "+", " ", "4"}], ")"}]}]], 
      RowBox[{"\[DifferentialD]", "x"}]}]}], "  ", "=", "  ", 
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", "\[ImaginaryI]"}], "]"}], " ", "+", " ", 
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", 
         RowBox[{"2", "\[ImaginaryI]"}]}], "]"}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                         ", 
   RowBox[{"=", "  ", 
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[ImaginaryI]", "6"]}], " ", "+", " ", 
       FractionBox["\[ImaginaryI]", "12"]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                         ", 
   RowBox[{"=", "  ", 
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{"-", 
       FractionBox["\[ImaginaryI]", "12"]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                         ", 
   RowBox[{"=", "  ", 
    FractionBox["\[Pi]", "6"]}]}]}]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"8.15", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506705600671875*^9, 3.5067056006875*^9}}],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z", "2"], " ", "+", " ", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z", "2"], " ", "+", " ", "4"}], ")"}]}]]}]],
  AspectRatioFixed->True],
 "  and ",
 "locate the",
 " singularities."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "=", 
      RowBox[{"x", "=", "0"}]}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"x", ",", "z", ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "g", ",", "Res1", ",", "Res2", ",", "Res3", ",", "Res4", ",", 
      "solset", ",", "val"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], " ", "+", " ", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], " ", "+", " ", "4"}], ")"}]}]]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Denominator", "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}], 
       "]"}], "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The singularities are\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "2"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "3"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "4"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["Z", "4"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39945904253125*^9},
 AspectRatioFixed->False],

Cell["Determine which poles lie in the upper half plane ?", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "3"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "4"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "1"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "2"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "3"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "4"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<,   Is  Im(\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<) > 0 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "1"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<,    Is  Im(\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<) > 0 ?    \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "2"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<, Is  Im(\>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<) > 0 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "3"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<,  Is  Im(\>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<) > 0 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "4"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399459046625*^9, 3.399459051328125*^9}, 
   3.400056413875*^9, {3.400057733265625*^9, 3.400057738796875*^9}, 
   3.400057841453125*^9, {3.400313039546875*^9, 3.40031305315625*^9}}],

Cell[TextData[{
 "\nYou must look carefully at the above list and make the proper choice. \n\
We see that we should compute the residues at  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "2"], "=", "\[ImaginaryI]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], "  ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman"], "  ", 
     SubscriptBox["z", "4"]}], "=", 
    RowBox[{"2", "\[ImaginaryI]"}]}]}]]],
 ", \nand then use the residue calculus to compute the value of the integral.\
\n"
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.40031153525*^9, 3.40031161475*^9}, {3.4003124795625*^9, 
  3.400312490734375*^9}, {3.400313108703125*^9, 3.400313117296875*^9}, {
  3.400313155375*^9, 3.40031316934375*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Res2", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "2"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Res4", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "4"]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{"Res2", " ", "+", " ", "Res4"}], ")"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<] = \>\"", ",", "Res2"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<] = \>\"", ",", "Res4"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "4"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "2"], "]"}], ",", 
            RowBox[{"Im", "[", 
             SubscriptBox["Z", "2"], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.2"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "4"], "]"}], ",", 
            RowBox[{"Im", "[", 
             SubscriptBox["Z", "4"], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.2"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "3", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "\[Pi]"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"segment", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "3"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"3", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", "contour", ",", "segment", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3.1"}], ",", "3.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "3.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<) \[DifferentialD]z = 2\[Pi]\[ImaginaryI]((\>\"", ",", "Res2", " ",
       ",", "\"\<) + (\>\"", ",", " ", "Res4", " ", ",", "\"\<))\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<) \[DifferentialD]z = 2\[Pi]\[ImaginaryI](\>\"", ",", 
      RowBox[{"Res2", " ", "+", " ", "Res4"}], " ", ",", "\"\<) = \>\"", ",", 
      "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The contour is the semicircle \!\(\*SubscriptBox[\(C\), \(R\)]\) \
and interval [-R,R],\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<taken with the positive orientation.\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Let R\[Rule]\[Infinity] to obtain the Cauchy Principal Value of the \
integral.\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x \>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<= 2\[Pi]\[ImaginaryI](\>\"", ",", "Res2", ",", "\"\< + (\>\"", ",", 
      " ", "Res4", ",", "\"\<)) = \>\"", ",", "val"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399459055328125*^9, 3.399459074328125*^9}, {
  3.400056419296875*^9, 3.400056419515625*^9}, {3.400057487484375*^9, 
  3.40005751259375*^9}}],

Cell[TextData[{
 "Or, we can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s integral table and evaluate the integral."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"int", "=", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}], ",", 
       RowBox[{"PrincipalValue", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "int"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399459082515625*^9}],

Cell[TextData[{
 "However, for this simple integral ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s can find the correct answer without resorting to the PrincipalValue \
option."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "x_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[x] = \[Integral]\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",", 
      RowBox[{"g", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[\[Infinity]] = \>\"", ",", 
      RowBox[{"g", "[", "\[Infinity]", "]"}], ",", 
      "\"\<,    g[-\[Infinity]] = \>\"", ",", " ", 
      RowBox[{"g", "[", 
       RowBox[{"-", "\[Infinity]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\< \[DifferentialD]x = g[\[Infinity]]-g[-\[Infinity]] = (\>\"", ",", 
      RowBox[{"g", "[", "\[Infinity]", "]"}], " ", ",", "\"\<) - (\>\"", ",", 
      " ", 
      RowBox[{"g", "[", 
       RowBox[{"-", "\[Infinity]"}], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",", 
      RowBox[{
       RowBox[{"g", "[", "\[Infinity]", "]"}], " ", "-", " ", 
       RowBox[{"g", "[", 
        RowBox[{"-", "\[Infinity]"}], "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39945909690625*^9},
 AspectRatioFixed->True],

Cell["The above answer is correct too.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 8.16.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  ",
 "Evaluate",
 "  ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", 
    RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", "4"}], ")"}], "3"]], 
    RowBox[{"\[DifferentialD]", "x"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{645, 143},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  The integrand  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "+", "4"}], ")"}], "3"]], " ", "=", "  ", 
    FractionBox["1", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", 
         RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], "3"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], "3"]}]]}]}]]],
 "  has a poles of order 3 at the points ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"\[PlusMinus]", "2"}], "\[ImaginaryI]"}]}]]],
 ", and  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"2", "\[ImaginaryI]"}]}]]],
 "  is the only singularity of ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " in the upper half-plane.  Computing the residue at   ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "4"], "=", 
   RowBox[{"2", "\[ImaginaryI]"}]}]]],
 ", we get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", 
      RowBox[{"2", "\[ImaginaryI]"}]}], "]"}], "  ", "=", "  ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "!"}]], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        RowBox[{"2", "\[ImaginaryI]"}]}]], " ", 
      RowBox[{
       FractionBox[
        SuperscriptBox["d", "2"], 
        SuperscriptBox["dz", "2"]], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", 
            RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], "3"], "f", 
         RowBox[{"(", "z", ")"}]}], ")"}]}]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                         ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        RowBox[{"2", "\[ImaginaryI]"}]}]], " ", 
      RowBox[{
       FractionBox[
        SuperscriptBox["d", "2"], 
        SuperscriptBox["dz", "2"]], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", 
            RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], "3"], 
         FractionBox["1", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z", "+", 
              RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], "3"], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z", "-", 
              RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], "3"]}]]}], 
        ")"}]}]}]}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                         ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        RowBox[{"2", "\[ImaginaryI]"}]}]], " ", 
      RowBox[{
       FractionBox[
        SuperscriptBox["d", "2"], 
        SuperscriptBox["dz", "2"]], 
       RowBox[{"(", 
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", 
            RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], "3"]], ")"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                         ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        RowBox[{"2", "\[ImaginaryI]"}]}]], " ", 
      RowBox[{
       FractionBox["d", "dz"], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"-", "3"}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", 
            RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], "4"]], ")"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                         ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        RowBox[{"2", "\[ImaginaryI]"}]}]], " ", 
      RowBox[{"(", 
       FractionBox["12", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", 
           RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], "5"]], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                         ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       FractionBox["12", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "\[ImaginaryI]"}], "+", 
           RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], "5"]], ")"}]}], "  ", "=",
      "  ", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"(", 
        FractionBox["12", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"4", "\[ImaginaryI]"}], ")"}], "5"]], ")"}]}], " ", "=", 
      "  ", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"(", 
        FractionBox["12", 
         RowBox[{"1024", " ", "\[ImaginaryI]"}]], ")"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                         ", 
   RowBox[{"=", "  ", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"3", " ", "\[ImaginaryI]"}], "512"]}]}]}]}]],
 "   "
}], "Text"],

Cell[TextData[{
 "Therefore \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["x", "2"], "+", "4"}], ")"}], "3"]], 
     RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "=", "  ", 
   RowBox[{
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", "  ", 
     RowBox[{"Res", "[", 
      RowBox[{"f", ",", 
       RowBox[{"2", "\[ImaginaryI]"}]}], "]"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], "512"], ")"}]}], "  ", 
     "=", "  ", 
     FractionBox[
      RowBox[{"3", "\[Pi]"}], "256"]}]}]}]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.399453188890625*^9, 3.39945319703125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"8.16", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670560396875*^9, 3.50670560396875*^9}}],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z", "2"], " ", "+", " ", "4"}], ")"}], "3"]]}]],
  AspectRatioFixed->True],
 "  and ",
 "locate the",
 " singularities."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "=", 
      RowBox[{"x", "=", "0"}]}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"x", ",", "z", ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "g", ",", "Res1", ",", "Res2", ",", "Res3", ",", "Res4", ",", 
      "solset", ",", "val"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], " ", "+", " ", "4"}], ")"}], "3"]]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Denominator", "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}], 
       "]"}], "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The singularities are\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "2"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "3"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "4"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["Z", "4"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "5"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(5\)]\) = \>\"", ",", 
      SubscriptBox["Z", "5"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "6"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(6\)]\) = \>\"", ",", 
      SubscriptBox["Z", "6"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39945911628125*^9},
 AspectRatioFixed->False],

Cell["Which poles lie in the upper half plane ?", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "3"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "4"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "5"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "5"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "6"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "6"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "1"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], "+", "0.3"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "3"], "]"}], "+", "0.6"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "4"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(5\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "5"], "]"}], "+", "0.3"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "5"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(6\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "6"], "]"}], "+", "0.6"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "6"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<,  Is  Im(\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<) > 0 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "1"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<,  Is  Im(\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<) > 0 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "2"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<,  Is  Im(\>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<) > 0 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "3"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<,   Is  Im(\>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<) > 0 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "4"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(5\)]\) = \>\"", ",", 
      SubscriptBox["Z", "5"], ",", "\"\<,   Is  Im(\>\"", ",", 
      SubscriptBox["Z", "5"], ",", "\"\<) > 0 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "5"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(6\)]\) = \>\"", ",", 
      SubscriptBox["Z", "6"], ",", "\"\<,   Is  Im(\>\"", ",", 
      SubscriptBox["Z", "6"], ",", "\"\<) > 0 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "6"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39945912203125*^9, 3.39945912821875*^9}, 
   3.400056424609375*^9, {3.40005775490625*^9, 3.400057768765625*^9}}],

Cell[TextData[{
 "\nYou must look carefully at the above list and make the proper choice. \n\
We see that we should compute the residue at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "4"], "=", 
   RowBox[{"2", "\[ImaginaryI]"}]}]]],
 ", \nand then use the residue calculus to compute the value of the integral.\
\n"
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.40031153525*^9, 3.40031161475*^9}, {3.4003124795625*^9, 
  3.400312490734375*^9}, {3.400313108703125*^9, 3.400313117296875*^9}, {
  3.400313155375*^9, 3.40031316934375*^9}, {3.4003132215*^9, 
  3.400313230171875*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Res4", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "4"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", "Res4"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<] = \>\"", ",", "Res4"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Magenta", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            SubscriptBox["Z", "4"], "]"}], ",", 
           RowBox[{"Im", "[", 
            SubscriptBox["Z", "4"], "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\)\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            SubscriptBox["Z", "4"], "]"}], ",", 
           RowBox[{"Im", "[", 
            SubscriptBox["Z", "4"], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.2"}], ",", "0"}], "}"}]}], "]"}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "3", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "\[Pi]"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"segment", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "3"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"3", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", "contour", ",", "segment", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3.1"}], ",", "3.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "3.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<) \[DifferentialD]z = 2\[Pi]\[ImaginaryI](\>\"", ",", "Res4", " ", 
      ",", "\"\<) = \>\"", ",", "val"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The contour is the semicircle \!\(\*SubscriptBox[\(C\), \(R\)]\) \
and interval [-R,R],\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<taken with the positive orientation.\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Let R\[Rule]\[Infinity] to obtain the Cauchy Principal Value of the \
integral.\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\< \[DifferentialD]x = 2\[Pi]\[ImaginaryI](\>\"", ",", "Res4", ",", 
      "\"\<) = \>\"", ",", "val"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399459138890625*^9, 3.3994591520625*^9}, {
  3.400056430046875*^9, 3.40005643025*^9}, {3.400057532703125*^9, 
  3.4000575455*^9}}],

Cell[TextData[{
 "Or, we can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s integral table and evaluate the integral."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"int", "=", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}], ",", 
       RowBox[{"PrincipalValue", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "int"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39945915784375*^9}],

Cell[TextData[{
 "However, for this simple integral ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s can find the correct answer without resorting to the PrincipalValue \
option."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "x_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim1", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"g", "[", "x", "]"}], ",", 
       RowBox[{"x", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim2", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"g", "[", "x", "]"}], ",", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "\[Infinity]"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[x] = \[Integral]\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",", 
      RowBox[{"g", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< g[\[Infinity]] =  \!\(\*UnderscriptBox[\(lim\), \(x \[Rule] \
\[Infinity]\)]\) (\>\"", ",", 
      RowBox[{"g", "[", "x", "]"}], ",", "\"\<) = \>\"", ",", "lim1"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<g[-\[Infinity]] =  \!\(\*UnderscriptBox[\(lim\), \(x \[Rule] \(-\
\[Infinity]\)\)]\) (\>\"", ",", 
      RowBox[{"g", "[", "x", "]"}], ",", "\"\<) = \>\"", ",", "lim2"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\< \[DifferentialD]x = g[\[Infinity]]-g[-\[Infinity]] = (\>\"", ",", 
      "lim1", " ", ",", "\"\<) - (\>\"", ",", " ", "lim2", ",", "\"\<)\>\""}],
      "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",", 
      RowBox[{"lim1", " ", "-", "lim2"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399459161265625*^9},
 AspectRatioFixed->True],

Cell["The above answer is correct too.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{908, 642},
WindowMargins->{{22, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 197, 3, 29, "Text"],
Cell[1748, 51, 3706, 119, 275, "Text"],
Cell[5457, 172, 3694, 113, 234, "Text",
 Evaluatable->False],
Cell[9154, 287, 1420, 26, 152, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[10599, 317, 232, 6, 37, "Subsection"],
Cell[10834, 325, 207, 8, 29, "Text"],
Cell[11044, 335, 8432, 216, 598, "Input"]
}, Closed]],
Cell[19491, 554, 4256, 133, 195, "Text",
 Evaluatable->False],
Cell[23750, 689, 1924, 34, 152, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[25699, 727, 223, 5, 37, "Subsection"],
Cell[25925, 734, 298, 11, 29, "Text"],
Cell[26226, 747, 8290, 223, 579, "Input"]
}, Closed]],
Cell[34531, 973, 1486, 47, 123, "Text"],
Cell[36020, 1022, 326, 11, 32, "Text"],
Cell[36349, 1035, 539, 18, 37, "Text",
 Evaluatable->False],
Cell[36891, 1055, 2091, 37, 163, "Text",
 Evaluatable->False],
Cell[38985, 1094, 2192, 66, 215, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[41202, 1164, 231, 6, 37, "Subsection"],
Cell[41436, 1172, 284, 10, 29, "Text"],
Cell[41723, 1184, 8412, 217, 581, "Input"],
Cell[50138, 1403, 353, 13, 37, "Text"],
Cell[50494, 1418, 2579, 73, 350, "Input"],
Cell[53076, 1493, 114, 2, 29, "Text",
 Evaluatable->False],
Cell[53193, 1497, 3945, 107, 192, "Input"],
Cell[57141, 1606, 254, 8, 29, "Text",
 Evaluatable->False],
Cell[57398, 1616, 5224, 143, 444, "Input"],
Cell[62625, 1761, 190, 7, 29, "Text",
 Evaluatable->False],
Cell[62818, 1770, 741, 20, 107, "Input"],
Cell[63562, 1792, 245, 8, 29, "Text",
 Evaluatable->False],
Cell[63810, 1802, 2714, 71, 326, "Input"],
Cell[66527, 1875, 94, 2, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[66636, 1880, 1033, 38, 52, "Text"],
Cell[67672, 1920, 2882, 104, 145, "Text",
 Evaluatable->False],
Cell[70557, 2026, 9792, 189, 297, "Text"],
Cell[CellGroupData[{
Cell[80374, 2219, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[80518, 2225, 246, 9, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[80779, 2237, 600, 24, 38, "Text",
 Evaluatable->False],
Cell[81382, 2263, 2229, 39, 157, "Text",
 Evaluatable->False],
Cell[83614, 2304, 6616, 208, 423, "Text"],
Cell[90233, 2514, 1672, 47, 215, "Text"],
Cell[CellGroupData[{
Cell[91930, 2565, 230, 6, 37, "Subsection"],
Cell[92163, 2573, 422, 17, 41, "Text"],
Cell[92588, 2592, 3682, 104, 436, "Input"],
Cell[96273, 2698, 114, 2, 29, "Text",
 Evaluatable->False],
Cell[96390, 2702, 6517, 172, 272, "Input"],
Cell[102910, 2876, 801, 22, 101, "Text",
 Evaluatable->False],
Cell[103714, 2900, 7135, 193, 571, "Input"],
Cell[110852, 3095, 190, 7, 29, "Text",
 Evaluatable->False],
Cell[111045, 3104, 742, 20, 107, "Input"],
Cell[111790, 3126, 245, 8, 29, "Text",
 Evaluatable->False],
Cell[112038, 3136, 2713, 71, 326, "Input"],
Cell[114754, 3209, 94, 2, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[114863, 3214, 501, 21, 39, "Text",
 Evaluatable->False],
Cell[115367, 3237, 2221, 39, 157, "Text",
 Evaluatable->False],
Cell[117591, 3278, 5429, 180, 424, "Text"],
Cell[123023, 3460, 940, 30, 80, "Text"],
Cell[CellGroupData[{
Cell[123988, 3494, 230, 6, 37, "Subsection"],
Cell[124221, 3502, 336, 14, 42, "Text"],
Cell[124560, 3518, 4592, 128, 516, "Input"],
Cell[129155, 3648, 104, 2, 29, "Text",
 Evaluatable->False],
Cell[129262, 3652, 8972, 236, 352, "Input"],
Cell[138237, 3890, 621, 15, 101, "Text",
 Evaluatable->False],
Cell[138861, 3907, 5115, 141, 444, "Input"],
Cell[143979, 4050, 190, 7, 29, "Text",
 Evaluatable->False],
Cell[144172, 4059, 741, 20, 107, "Input"],
Cell[144916, 4081, 245, 8, 29, "Text",
 Evaluatable->False],
Cell[145164, 4091, 3247, 87, 406, "Input"],
Cell[148414, 4180, 94, 2, 29, "Text",
 Evaluatable->False]
}, Closed]]
}
]
*)

(* End of internal cache information *)
