(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    408748,      13137]
NotebookOptionsPosition[    398384,      12846]
NotebookOutlinePosition[    399162,      12873]
CellTagsIndexPosition[    399119,      12870]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[{
 StyleBox["9.2  Second Order Homogeneous Difference Equations",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n\n\tBefore proceeding with the ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-transform method, we mention a heuristic method based on \
substitution of a trial solution.  Consider the second order homogeneous ",
  FontFamily->"Times New Roman"],
 "linear constant-coefficient difference equation (HLCCDE) ",
 StyleBox["\n\n",
  FontFamily->"Times New Roman"],
 StyleBox["(9-8)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\t\t\t",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], "  ", "=", "  ", "0"}]]],
 ",  ",
 StyleBox["\n\nwhere ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"a", "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "b"}]]],
 StyleBox[" are constants.  Using the trial solution  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   SuperscriptBox["r", "n"]}]]],
 ",  and direct substitution into ",
 StyleBox["(9-8)",
  FontColor->RGBColor[0, 0, 1]],
 " produces the equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["r", 
     RowBox[{"n", "+", "2"}]], "-", 
    RowBox[{"2", " ", "a", " ", 
     SuperscriptBox["r", 
      RowBox[{"n", "+", "1"}]]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     SuperscriptBox["r", "n"]}]}], " ", "=", " ", "0"}]]],
 ",  and dividing through by ",
 Cell[BoxData[
  SuperscriptBox["r", "n"]]],
 " produces the characteristic polynomial  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["r", "2"], " ", "-", " ", 
   RowBox[{"2", " ", "a", " ", "r"}], " ", "+", " ", "b"}]]],
 "  and characteristic equation \n\n",
 StyleBox["(9-9)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["r", "2"], " ", "-", " ", 
    RowBox[{"2", " ", "a", " ", "r"}], " ", "+", " ", "b"}], "  ", "=", "  ", 
   "0"}]]],
 ". \n\nThere are three types of solutions to ",
 StyleBox["(9-8)",
  FontColor->RGBColor[0, 0, 1]],
 " which are determined by the nature of the roots in ",
 StyleBox["(9-9)",
  FontColor->RGBColor[0, 0, 1]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\t",
 StyleBox["Case (i)",
  FontColor->RGBColor[0, 0, 1]],
 "  If   ",
 Cell[BoxData[
  RowBox[{"b", "<", 
   SuperscriptBox["a", "2"]}]]],
 "  then we have real distinct roots   ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "1"], "=", 
   RowBox[{"a", "-", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", "b"}]]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "2"], "=", 
   RowBox[{"a", "+", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", "b"}]]}]}]]],
 ",  and  \n\n",
 StyleBox["(9-10)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SubsuperscriptBox["r", "1", "n"]}], "  ", "+", "  ", 
    RowBox[{
     SubscriptBox["c", "2"], 
     SubsuperscriptBox["r", "2", "n"]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\t",
 StyleBox["Case (ii)",
  FontColor->RGBColor[0, 0, 1]],
 "  If   ",
 Cell[BoxData[
  RowBox[{"b", "=", 
   SuperscriptBox["a", "2"]}]]],
 "   then we have a double real root   ",
 Cell[BoxData[
  RowBox[{"r", "=", 
   RowBox[{
    SubscriptBox["r", "1"], "=", 
    RowBox[{
     SubscriptBox["r", "2"], "=", "a"}]}]}]]],
 ",  and  \n\n",
 StyleBox["(9-11)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SuperscriptBox["r", "n"]}], "  ", "+", "  ", 
    RowBox[{
     SubscriptBox["c", "2"], "n", " ", 
     SuperscriptBox["r", "n"]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\t",
 StyleBox["Case (iii)",
  FontColor->RGBColor[0, 0, 1]],
 "  If   ",
 Cell[BoxData[
  RowBox[{"b", ">", 
   SuperscriptBox["a", "2"]}]]],
 "   then we have complex roots   ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "1"], "=", 
   RowBox[{"a", "-", 
    RowBox[{"\[ImaginaryI]", 
     SqrtBox[
      RowBox[{"b", "-", 
       SuperscriptBox["a", "2"]}]]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "2"], "=", 
   RowBox[{"a", "+", 
    RowBox[{"\[ImaginaryI]", 
     SqrtBox[
      RowBox[{"b", "-", 
       SuperscriptBox["a", "2"]}]]}]}]}]]],
 ",  and    \n\n",
 StyleBox["(9-12)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["k", "1"], 
     SubsuperscriptBox["r", "1", "n"]}], "  ", "+", "  ", 
    RowBox[{
     SubscriptBox["k", "2"], 
     SubsuperscriptBox["r", "2", "n"]}]}]}]]],
 ".    \n\t\n\tThe solution for case ",
 StyleBox["(iii)",
  FontColor->RGBColor[0, 0, 1]],
 " can also be written as the following linear combination \n\t\n",
 StyleBox["(9-13)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SuperscriptBox["r", "n"], "cos", 
     RowBox[{"(", 
      RowBox[{"\[Phi]", " ", "n"}], ")"}]}], "  ", "+", "  ", 
    RowBox[{
     SubscriptBox["c", "2"], 
     SuperscriptBox["r", "n"], "sin", 
     RowBox[{"(", 
      RowBox[{"\[Phi]", " ", "n"}], ")"}]}]}]}]]],
 ",  \n\t\n\t\t\twhere  ",
 Cell[BoxData[
  RowBox[{"r", "=", 
   SqrtBox["b"]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", "=", 
   RowBox[{"arctan", "[", 
    FractionBox[
     SqrtBox[
      RowBox[{"b", "-", 
       SuperscriptBox["a", "2"]}]], "a"], "]"}]}]]],
 ".  \n\t\n",
 StyleBox["Caution.",
  FontWeight->"Bold",
  FontColor->RGBColor[0.996109, 0.500008, 0.250004]],
 "  Be sure to use the value of arctan that lies in the range  ",
 Cell[BoxData[
  RowBox[{"0", "<", "\[Phi]", "\[LessEqual]", "\[Pi]"}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["Remark About Stability",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tStability depends on the location of the roots of the characteristic \
polynomial.  Without loss if generality, if  ",
 Cell[BoxData[
  RowBox[{"|", 
   SubscriptBox["r", "1"], "|", 
   RowBox[{"\[LessEqual]", 
    RowBox[{"|", 
     SubscriptBox["r", "2"], "|", 
     RowBox[{"<", "1"}]}]}]}]]],
 "  then both roots lie inside the unit circle and the solutions are \
asymptotically stable and tends to zero as  ",
 Cell[BoxData[
  RowBox[{"n", "\[Rule]", "\[Infinity]"}]]],
 ".   If  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "1"], "\[NotEqual]", 
   SubscriptBox["r", "2"]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    SubscriptBox["r", "1"], "|", 
    RowBox[{"\[LessEqual]", 
     RowBox[{"|", 
      SubscriptBox["r", "2"], "|"}]}]}], "=", "1"}]]],
 "  then a root lies on the unit circle and the solutions are stable.  If  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "1"], "=", 
   RowBox[{
    SubscriptBox["r", "2"], "=", 
    RowBox[{"\[PlusMinus]", "1"}]}]}]]],
 "  then there is an unstable solution.  If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"1", "<"}], "|", 
   SubscriptBox["r", "2"], "|"}]]],
 "  then at least one root lies outside the unit circle and there is an \
unstable solution.  "
}], "Text"],

Cell["\<\
\tThe following subroutine uses the characteristic equation to construct \
solutions to a second order homogeneous difference equation.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica Subroutine (",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]],
 StyleBox["Solution of a Difference Equation",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SolveDE", "[", 
    RowBox[{
    "a0_", ",", "b0_", ",", "x0_", ",", "\[Alpha]0_", ",", "\[Beta]0_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", " ", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "=", "a0"}], ";", " ", 
      RowBox[{"b", "=", "b0"}], ";", " ", 
      RowBox[{"\[Alpha]", "=", "\[Alpha]0"}], ";", " ", 
      RowBox[{"\[Beta]", "=", "\[Beta]0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Clear", "[", 
       RowBox[{
       "c", ",", "k", ",", "n", ",", "r", ",", "\[Rho]", ",", "\[Theta]", ",",
         "y"}], "]"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"x", "[", "n_", "]"}], "=", "x0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"HLCCDE", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", 
          RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
         RowBox[{"2", "a", " ", 
          RowBox[{"y", "[", 
           RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
         RowBox[{"b", " ", 
          RowBox[{"y", "[", "n", "]"}]}]}], "\[Equal]", " ", 
        RowBox[{"ZTransform", "[", 
         RowBox[{
          RowBox[{"x", "[", "n", "]"}], ",", "n", ",", "z"}], "]"}]}]}], ";", 
      " ", "\[IndentingNewLine]", 
      RowBox[{"thede", "=", 
       RowBox[{
        RowBox[{"\"\<y[n+2]\>\"", " ", "-", " ", 
         RowBox[{"2", "a", " ", "\"\<y[n+1]\>\""}], " ", "+", " ", 
         RowBox[{"b", " ", "\"\<y[n]\>\""}]}], "\[Equal]", " ", 
        RowBox[{"ZTransform", "[", 
         RowBox[{
          RowBox[{"x", "[", "n", "]"}], ",", "n", ",", "z"}], "]"}]}]}], ";", 
      " ", "\[IndentingNewLine]", 
      RowBox[{"CP", "=", 
       RowBox[{"ReplaceAll", "[", 
        RowBox[{"HLCCDE", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"y", "[", "k_", "]"}], "\[Rule]", 
           SuperscriptBox["r", 
            RowBox[{"k", "-", "n"}]]}], "}"}]}], "]"}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"p", "[", "r_", "]"}], "=", 
       SubscriptBox["CP", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      ";", " ", "\[IndentingNewLine]", 
      RowBox[{"solset", "=", 
       RowBox[{"Solve", "[", 
        RowBox[{"CP", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       SubscriptBox["r", "1"], "=", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";",
       " ", 
      RowBox[{
       SubscriptBox["r", "2"], "=", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"2", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{
      "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
      ";", " ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "HLCCDE", "]"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<\\n\>\"", ",", "\"\<The characteristic polynomial is\>\""}], 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<p[r] = \>\"", ",", 
        RowBox[{"p", "[", "r", "]"}]}], " ", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<\\n\>\"", ",", "\"\<The difference equation has the form\>\""}], 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{
      "Print", "[", "\"\<b y[n] - 2 a y[n+1] + y[n+2] \[Equal] 0\>\"", "]"}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<b = \>\"", ",", "b", ",", "\"\<,  a = \>\"", ",", "a", ",", 
        "\"\<,  \!\(\*SuperscriptBox[\(a\), \(2\)]\) = \>\"", ",", 
        SuperscriptBox["a", "2"]}], "  ", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<For this example we have  \>\"", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"b", "<", 
           SuperscriptBox["a", "2"]}], ",", 
          "\"\<b < \!\(\*SuperscriptBox[\(a\), \(2\)]\)\>\"", ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"b", "\[Equal]", 
             SuperscriptBox["a", "2"]}], ",", 
            "\"\<b = \!\(\*SuperscriptBox[\(a\), \(2\)]\)\>\"", ",", 
            "\"\<b > \!\(\*SuperscriptBox[\(a\), \(2\)]\)\>\""}], "]"}]}], 
         "]"}]}], " ", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<p[r] = \>\"", ",", 
        RowBox[{"Factor", "[", 
         RowBox[{"p", "[", "r", "]"}], "]"}]}], " ", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<The roots are \>\"", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"b", "<", 
           SuperscriptBox["a", "2"]}], ",", "\"\<real and distinct\>\"", ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"b", "\[Equal]", 
             SuperscriptBox["a", "2"]}], ",", "\"\<real and equal\>\"", ",", 
            "\"\<complex\>\""}], "]"}]}], "]"}], ",", "\"\<.\>\""}], " ", 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<\!\(\*SubscriptBox[\(r\), \(1\)]\) = \>\"", ",", 
        SubscriptBox["r", "1"]}], " ", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<\!\(\*SubscriptBox[\(r\), \(2\)]\) = \>\"", ",", 
        SubscriptBox["r", "2"]}], " ", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<\\n\>\"", ",", "\"\<The general solution is\>\""}], "]"}],
       ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["r", "1"], "=!=", 
         SubscriptBox["r", "2"]}], ",", 
        RowBox[{
         RowBox[{"y", "[", "n_", "]"}], "=", 
         RowBox[{
          RowBox[{
           SubscriptBox["c", "1"], 
           SuperscriptBox[
            SubscriptBox["r", "1"], "n"]}], "+", 
          RowBox[{
           SubscriptBox["c", "2"], 
           SuperscriptBox[
            SubscriptBox["r", "2"], "n"]}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["r", "1"], "\[Equal]", 
         SubscriptBox["r", "2"]}], ",", 
        RowBox[{
         RowBox[{"y", "[", "n_", "]"}], "=", 
         RowBox[{
          RowBox[{
           SubscriptBox["c", "1"], 
           SuperscriptBox[
            SubscriptBox["r", "1"], "n"]}], "+", 
          RowBox[{
           SubscriptBox["c", "2"], "n", " ", 
           SuperscriptBox[
            SubscriptBox["r", "2"], "n"]}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<y[n] = \>\"", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"b", "=!=", 
           SuperscriptBox["a", "2"]}], ",", 
          "\"\<\!\(\*SuperscriptBox[SubsuperscriptBox[\(r\), \(1\), \(n\)], \
\(\\\ \)]\)\!\(\*SubscriptBox[\(c\), \(1\)]\) + \
\!\(\*SuperscriptBox[SubsuperscriptBox[\(r\), \(2\), \(n\)], \(\\\ \
\)]\)\!\(\*SubscriptBox[\(c\), \(2\)]\)\>\"", ",", 
          "\"\<\!\(\*SuperscriptBox[SubsuperscriptBox[\(r\), \(1\), \(n\)], \
\(\\\ \)]\)\!\(\*SuperscriptBox[SubscriptBox[\(c\), \(1\)], \(\\\ \)]\) + \
\!\(\*SuperscriptBox[SubsuperscriptBox[\(r\), \(2\), \(n\)], \(\\\ \)]\)n \
\!\(\*SubscriptBox[\(c\), \(2\)]\)\>\""}], "]"}]}], " ", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<y[n] = \>\"", ",", 
        RowBox[{"y", "[", "n", "]"}], ",", "\"\<\\n\>\""}], " ", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"IC", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "0", "]"}], "\[Equal]", " ", "\[Alpha]"}], ",", 
         RowBox[{
          RowBox[{"y", "[", "1", "]"}], "\[Equal]", " ", "\[Beta]"}]}], 
        "}"}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"psol", "=", 
       RowBox[{"Solve", "[", 
        RowBox[{"IC", ",", 
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["c", "1"], ",", 
           SubscriptBox["c", "2"]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"y", "[", "n_", "]"}], "=", 
       RowBox[{"ReplaceAll", "[", 
        RowBox[{
         RowBox[{"y", "[", "n", "]"}], ",", 
         SubscriptBox["psol", 
          RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
        " ", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<Given the initial conditions\>\"", "]"}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<Solve the linear system\>\"", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", " ", "IC", " ", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<Get\>\"", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<\!\(\*SubscriptBox[\(c\), \(1\)]\) = \>\"", ",", " ", 
        SubscriptBox["psol", 
         RowBox[{"\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<\!\(\*SubscriptBox[\(c\), \(2\)]\) = \>\"", ",", 
        SubscriptBox["psol", 
         RowBox[{"\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "2", ",", "2"}], "\[RightDoubleBracket]"}]]}], 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<\\n\>\"", ",", "\"\<The solution with these IC's is\>\""}], "]"}],
       ";", " ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<y[n] = \>\"", ",", 
        RowBox[{"y", "[", "n", "]"}]}], "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<and\>\"", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<y[0] = \>\"", ",", 
        RowBox[{"y", "[", "0", "]"}]}], " ", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "0", "]"}], "===", 
         RowBox[{"Simplify", "[", 
          RowBox[{"y", "[", "0", "]"}], "]"}]}], ",", "\"\<\>\"", ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"\"\<y[0] = \>\"", ",", 
           RowBox[{"Simplify", "[", 
            RowBox[{"y", "[", "0", "]"}], "]"}]}], " ", "]"}], ";"}]}], " ", 
       "]"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<y[1] = \>\"", ",", 
        RowBox[{"y", "[", "1", "]"}]}], " ", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "1", "]"}], "===", 
         RowBox[{"Simplify", "[", 
          RowBox[{"y", "[", "1", "]"}], "]"}]}], ",", "\"\<\>\"", ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"\"\<y[1] = \>\"", ",", 
           RowBox[{"Simplify", "[", 
            RowBox[{"y", "[", "1", "]"}], "]"}]}], " ", "]"}], ";"}]}], " ", 
       "]"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"b", ">", 
         SuperscriptBox["a", "2"]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"\[Rho]", "=", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              SqrtBox[
               RowBox[{"b", "-", 
                SuperscriptBox["a", "2"]}]], ")"}], "2"]}]]}], ";", " ", 
         RowBox[{"\[Phi]", " ", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"a", ">", " ", "0"}], ",", 
            RowBox[{"ArcTan", "[", 
             FractionBox[
              SqrtBox[
               RowBox[{"b", "-", 
                SuperscriptBox["a", "2"]}]], "a"], "]"}], ",", 
            RowBox[{"\[Pi]", "+", 
             RowBox[{"ArcTan", "[", 
              FractionBox[
               SqrtBox[
                RowBox[{"b", "-", 
                 SuperscriptBox["a", "2"]}]], "a"], "]"}]}]}], "]"}]}], ";", 
         " ", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"s", "[", "n_", "]"}], "=", 
          RowBox[{
           RowBox[{
            SubscriptBox["c", "1"], 
            SuperscriptBox["\[Rho]", "n"], "  ", 
            RowBox[{"Cos", "[", 
             RowBox[{"n", " ", "\[Phi]"}], "]"}]}], " ", "+", 
           RowBox[{
            SubscriptBox["c", "2"], " ", 
            SuperscriptBox["\[Rho]", "n"], "  ", 
            RowBox[{"Sin", "[", 
             RowBox[{"n", " ", "\[Phi]"}], "]"}]}]}]}], ";", "  ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\\n\>\"", ",", 
           "\"\<Another form of the complex solution is\>\""}], "]"}], ";", 
         " ", "\[IndentingNewLine]", 
         RowBox[{
         "Print", "[", 
          "\"\<y[n] = \!\(\*SuperscriptBox[\(\[Rho]\), \(n\)]\) Cos[\[Phi] n]\
\!\(\*SubscriptBox[\(c\), \(1\)]\) + \!\(\*SuperscriptBox[\(\[Rho]\), \(\(n\)\
\(\\\ \)\)]\)Sin[\[Phi] n]\!\(\*SubscriptBox[\(c\), \(2\)]\)\>\"", " ", "]"}],
          ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<   \[Rho] = \!\(\*SqrtBox[\(\*SuperscriptBox[\(a\), \(2\)] + \
\*SuperscriptBox[\((\*SqrtBox[\(b - \*SuperscriptBox[\(a\), \(2\)]\)])\), \(2\
\)]\)]\) = \>\"", ",", "\[Rho]"}], "]"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<   \[Phi] = ArcTan[\!\(\*FractionBox[SqrtBox[\(b - \
\*SuperscriptBox[\(a\), \(2\)]\)], \(a\)]\)] = \>\"", ",", "\[Phi]"}], "]"}], 
         ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<y[n] = \>\"", ",", 
           RowBox[{"s", "[", "n", "]"}], ",", "\"\<\\n\>\""}], " ", "]"}], 
         ";", " ", "\[IndentingNewLine]", 
         RowBox[{"IC", "=", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"s", "[", "0", "]"}], "\[Equal]", " ", "\[Alpha]"}], ",", 
            RowBox[{
             RowBox[{"s", "[", "1", "]"}], "\[Equal]", " ", "\[Beta]"}]}], 
           "}"}]}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"psol", "=", 
          RowBox[{"Solve", "[", 
           RowBox[{"IC", ",", 
            RowBox[{"{", 
             RowBox[{
              SubscriptBox["c", "1"], ",", 
              SubscriptBox["c", "2"]}], "}"}]}], "]"}]}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"s", "[", "n_", "]"}], "=", 
          RowBox[{"ReplaceAll", "[", 
           RowBox[{
            RowBox[{"s", "[", "n", "]"}], ",", 
            SubscriptBox["psol", 
             RowBox[{
             "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], " ", 
           "]"}]}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", "\"\<Given the initial conditions\>\"", "]"}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\\n\>\"", ",", "\"\<The solution with these IC's is\>\""}], 
          "]"}], ";", "  ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<y[n] = \>\"", ",", 
           RowBox[{"s", "[", "n", "]"}]}], "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", "\"\<and\>\"", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<y[0] = \>\"", ",", 
           RowBox[{"y", "[", "0", "]"}]}], " ", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "0", "]"}], "===", 
            RowBox[{"Simplify", "[", 
             RowBox[{"y", "[", "0", "]"}], "]"}]}], ",", "\"\<\>\"", ",", 
           RowBox[{
            RowBox[{"Print", "[", 
             RowBox[{"\"\<y[0] = \>\"", ",", 
              RowBox[{"Simplify", "[", 
               RowBox[{"y", "[", "0", "]"}], "]"}]}], " ", "]"}], ";"}]}], 
          " ", "]"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<y[1] = \>\"", ",", 
           RowBox[{"y", "[", "1", "]"}]}], " ", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "1", "]"}], "===", 
            RowBox[{"Simplify", "[", 
             RowBox[{"y", "[", "1", "]"}], "]"}]}], ",", "\"\<\>\"", ",", 
           RowBox[{
            RowBox[{"Print", "[", 
             RowBox[{"\"\<y[1] = \>\"", ",", 
              RowBox[{"Simplify", "[", 
               RowBox[{"y", "[", "1", "]"}], "]"}]}], " ", "]"}], ";"}]}], 
          " ", "]"}], ";"}]}], "  ", "]"}], ";"}]}], " ", "]"}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.40009396715625*^9, 3.400093998984375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztWM1OwkAQXtj2oCdPHgQTjrbAa2g08azXhpjAwWiQRBPUm97Ug/oI+gJ6
U97CF9AXqTszZYF2F/vHVpI2tP0y3+zszO7M0HbfG3SPjr1Br+M1dvreabfX
OWtsn/SFiFcYqzwyxp4bDLAvYHDxxc9/ggtI0uMPuNlg0gFkAWoCqgJqA+KA
XCnbpIEjvCGHCE5HIUNjzJqRjS2HVLfUqnX9hK5C1tI5hlGq2A39BM2YE2hc
n6zkn6sWGevOMTllQSWDM1i1T+lBS4HaEjXlTtfTJdI9GRhLOUnvaOH9IBzk
v4i6gtsazIi8I9EI0Hp4vCORKtosslo4AFfh9CspPeiSMDTwRa9+kJvSYRzv
fNriwvhb6eSFXulGhntuQimWT0UvXJ78kFZFHFWSisOSyP5jNFYqs2f5oPWQ
SqRLVRUmVbJFTYOiJY9hzjSXil2Mv59FZ+My8u+UVYLd0yu9UZkJdteEUiyf
il64SBvCAuAp0nao4Pm8moqIrThlpSzFRDMU1XyGiVzNskZl6yn5f8lny04j
BbTQx5zrFBGUTabkSz5HHiucy/RPmL2GSpgakD22M20z2cONuYYQ+uq1gLaM
G5Tm2bTolCt58/wPlYMvP5mqlL6p1gRby1sp+Z9kxGMjtZtTQ4s0nkn8yd4C
EaxM2cj0xhexxqVHoR1BzVXSRBx8OWeVX/nOKJE=\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Solution", " ", 
   RowBox[{"9.12", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670600125*^9, 3.50670600125*^9}}],

Cell[TextData[{
 "\tThe characteristic equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["r", "2"], "-", 
    RowBox[{"4", " ", "r"}], "+", "3"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "-", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"r", "-", "3"}], ")"}]}], " ", "=", " ", "0"}]}]]],
 "  has roots ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "1"], "=", 
   RowBox[{
    RowBox[{"1", "  ", "and", "  ", 
     SubscriptBox["r", "2"]}], "=", "3"}]}]]],
 "  hence the general solution is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["c", "1"], " ", "+", " ", 
    RowBox[{
     SubscriptBox["c", "2"], 
     SuperscriptBox["3", "n"]}]}]}]]],
 ".   Use the initial conditions and form the linear system  \n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], " ", "+", " ", 
     RowBox[{
      SubscriptBox["c", "2"], "1"}]}], " ", "=", " ", 
    "1"}]}], "\[IndentingNewLine]", "and", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"y", "[", "1", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], " ", "+", " ", 
     RowBox[{
      SubscriptBox["c", "2"], "3"}]}], " ", "=", " ", "5"}]}]}]],
 "  \n\nthen solve for the constants and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["c", "1"], "=", 
    RowBox[{"-", "1"}]}], ",", 
   RowBox[{
    SubscriptBox["c", "2"], "=", "2"}]}]]],
 ".  Hence the solution is \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", "1"}], " ", "+", " ", 
    RowBox[{"2", "*", 
     SuperscriptBox["3", "n"]}]}]}]]],
 "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"9.12", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706003125*^9, 3.506706003125*^9}}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", "0"}]]],
 "  with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["SolveDE"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], "  ", "=", "  ", "0"}]]],
 ".  It will construct the characteristic polynomial and its roots.  The \
format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"SolveDE", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"x", "[", "n", "]"}], ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "3"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"SolveDE", "[", 
    RowBox[{"2", ",", "3", ",", 
     RowBox[{"x", "[", "n", "]"}], ",", "1", ",", "5"}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.399482116890625*^9, 3.40008653475*^9, {3.400347064078125*^9, 
   3.400347075609375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["3", "n"]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "5"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y1", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "500", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "500", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y1", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482118390625*^9, 3.399482169015625*^9}, {
  3.400067155140625*^9, 3.40006715546875*^9}, {3.4000842666875*^9, 
  3.400084330765625*^9}, {3.40008437196875*^9, 3.400084433078125*^9}, {
  3.400093821359375*^9, 3.40009382215625*^9}, {3.400094013828125*^9, 
  3.400094014625*^9}, {3.4000940488125*^9, 3.400094065296875*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztWU1SwjAUDrTdOrp1AR1b8CawUA/RYZyBheIgAnoCda9u4A7qBXShS+/h
Qs9Q+5KSSvPShkJDZygD6Zvvvbyf5HtNgRNv2D0984a9jme3B95Ft9e5tFv9
QQAZFUIqU0LIg01A9gMxHPzg7c9gACS7/AwXC1w6IJkgNUGqgnQIkgGSy7EG
x2zm4pVeKEIl+DgIRt0ScwGbx4iZHuCmLg7X5Xm4CIYFdPgyNNXTSYjbUIwr
8dzIstq4FxkcecAwWQ1hyS88vxhXYlKUfSTVsxH1jjmYo3sMvWX75ofcoPpv
prqByw5EpHqHS18g7cfnO4gnbMdUVwrDavFSXCT8GzO6l7E5NjHB/EjF6Jj7
fJcb0XFXrr/iTp7kRkOezqMOI6Wc0grTqR+xqoJXlTeQySUrZfaEXqxFfdjd
1J94I6giLjEsrzAU0lTDjLOhn3usKafnOZs6RvYzeWcFFxh5lIyEwjdN823X
0zan3DIUySDMjumNJLoKsJkSYSxl+VIRdDa3uECqqa6yRks1dJEYWET9J+NM
oG3LjT5gpDe8lg4jIafVtl0LM3M9n68zVFB2b6kvlH7CqZ3lMVtTC7AGtuZ+
/vtc7tTV11CxXxRyuK3RDcry0LRpypV6Bf4U+1xdU98L/RmVXsin+LQIRtmS
26kf8d0vbMuuLwh+qkbcL7t2Bf0vy8jn/wxgRj8w0u9rNR1GSjmtc2FI5Q9h
Mu8V\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{412, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Solution", " ", 
   RowBox[{"9.13", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670600665625*^9, 3.50670600665625*^9}}],

Cell[TextData[{
 "\tThe characteristic equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["r", "2"], "-", 
    RowBox[{"4", " ", "r"}], "+", "4"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"r", "-", "2"}], ")"}], "2"], " ", "=", " ", "0"}]}]]],
 "  has equal roots ",
 Cell[BoxData[
  RowBox[{"r", "=", 
   RowBox[{
    SubscriptBox["r", "1"], "=", 
    RowBox[{
     SubscriptBox["r", "2"], "=", "2"}]}]}]]],
 "  hence the general solution is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SuperscriptBox["2", "n"]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["c", "2"], 
     SuperscriptBox["2", "n"], "n"}]}]}]]],
 ".  Use the initial conditions and form the linear system  \n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "0", "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["c", "1"], " ", "+", " ", 
      RowBox[{
       SubscriptBox["c", "2"], "0"}]}], "=", "1"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"y", "[", "1", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["c", "1"], "2"}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["c", "2"], "2"}]}], "=", "5"}]}]}]],
 "  \n\nthen solve for the constants and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["c", "1"], "=", "1"}], ",", 
   RowBox[{
    SubscriptBox["c", "2"], "=", 
    FractionBox["3", "2"]}]}]]],
 ".  Hence the solution is \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["2", "n"], "+", 
     RowBox[{
      FractionBox["3", "2"], "n", " ", 
      SuperscriptBox["2", "n"]}]}], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["2", "n"], "+", 
     RowBox[{"3", "n", " ", 
      SuperscriptBox["2", 
       RowBox[{"n", "-", "1"}]]}]}]}]}]]],
 "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"9.13", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706008625*^9, 3.506706008625*^9}}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["SolveDE"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], "  ", "=", "  ", "0"}]]],
 ".  It will construct the characteristic polynomial and its roots.  The \
format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"SolveDE", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"x", "[", "n", "]"}], ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "4"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"SolveDE", "[", 
    RowBox[{"2", ",", "4", ",", 
     RowBox[{"x", "[", "n", "]"}], ",", "1", ",", "5"}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399482179390625*^9, 3.40008654803125*^9, 
  3.40034709821875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      SuperscriptBox["2", "n"], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["2", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "n"}]], " ", "n"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "6"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y1", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "670"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "600", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "670"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "600", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y1", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994821810625*^9, 3.399482199328125*^9}, {
   3.400067161484375*^9, 3.40006716175*^9}, {3.40008446925*^9, 
   3.40008451084375*^9}, 3.400086553828125*^9, {3.4000940910625*^9, 
   3.400094091734375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"5", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztWc1OwkAQXmgbjd5sFzhy0COPoEc5+QymISRwIBIKxrsHTdST+kD6GPoK
vsPa3S27bZmpLf2DWALbLzOzOz/77dDClbucjGfucjpy+8OFO59MR17/8mbh
i4wWIa1XQsh7n3DMfBgMzH+zNz5wSf34RVwMIoNj8sNHszz9Nx8NXpAz3OiL
jxY3Oq3CKFVMRRZmJR36rzZHbY5MAFl/rHMrLmZEv140ozjqBJKFHXuyrDrG
2JoZQ9AZs2C/uHwmHW6ZUCbfCakuY/rKHK9UUYxcJKnjlDf6Rh85QCh70/PY
g49RdWeRWFF9jmYAdNuE9mcVl/kWbb7OvlsAbeqmf6P/33pPYpL3a9wD9GLF
qm+AmGocRThOaHvSf6lNt+l9e6f/5KN4WLvAjT4CQhFyXoVRqpjqLtwu6fXz
Y74H4Aruy3b2rrDe9lhv5ZsGub96R7LZf9mKyx21Yz2OxASqZFTJuhKx8IyO
0tpqZX12jvBAOoDMRu02eNtDp2+YOrCYyngZatBFXSQdvKj9QbYCOIAMCkPv
IqQ92TJhvZdOuWnSlGkiG6rZp7nZUclp5iLUKTk5JGiakEvsB860JYssqT+I
J0RcYDVilW8rfureEusZNIpMYK7uLbFvl4TeUmQTfZZBMBWsj36k6klxzo6y
T/dIgYYKzeXEe3455B6D2WvkAIhyJGYPlGwcKgAUhZOIdIxaBnEuj+wYrx5N
GaZddnDQ1g+A/UMDDu8ptNg1sMQDbn6nzB+r4fau6wUu4K9W0voFyiHDBA==
\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Solution", " ", 
   RowBox[{"9.14", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706011890625*^9, 3.50670601190625*^9}}],

Cell[TextData[{
 "\tThe characteristic equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["r", "2"], "-", 
    RowBox[{"4", " ", "r"}], "+", "5"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "-", "2", "+", "\[ImaginaryI]"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"r", "-", "2", "-", "\[ImaginaryI]"}], ")"}]}], " ", "=", " ", 
    "0"}]}]]],
 "  has complex roots ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "1"], "=", 
   RowBox[{"2", "+", "\[ImaginaryI]"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "2"], "=", 
   RowBox[{"2", "-", "\[ImaginaryI]"}]}]]],
 " hence the general solution is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["c", "2"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"], " "}]}]}]]],
 ".   Use the initial conditions and form the linear system  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], " ", "+", " ", 
     SubscriptBox["c", "2"]}], " ", "=", " ", "1"}]}]]],
 "\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "1", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["c", "1"], 
      RowBox[{"(", 
       RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["c", "2"], 
      RowBox[{"(", 
       RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}]}]}], "  ", "=", " ", 
    "5"}]}]]],
 "  \n\nthen solve for the constants and get ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "1"], "=", 
   FractionBox[
    RowBox[{"1", "-", 
     RowBox[{"3", " ", "\[ImaginaryI]"}]}], "2"]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "2"], "=", 
   FractionBox[
    RowBox[{"1", "+", 
     RowBox[{"3", " ", "\[ImaginaryI]"}]}], "2"]}]]],
 ".  Hence the solution is \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"1", "-", 
       RowBox[{"3", " ", "\[ImaginaryI]"}]}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}], " ", "+", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"1", "+", 
       RowBox[{"3", " ", "\[ImaginaryI]"}]}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]]],
 ". \n\nWe leave it for the reader to verify that this can be written as  \n\n\
\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["5", 
      RowBox[{"n", "/", "2"}]], " ", "cos", 
     RowBox[{"(", 
      RowBox[{"arctan", 
       RowBox[{"(", 
        FractionBox["1", "2"], ")"}], "n"}], ")"}]}], " ", "+", " ", 
    RowBox[{"3", "*", 
     SuperscriptBox["5", 
      RowBox[{"n", "/", "2"}]], " ", "sin", 
     RowBox[{"(", 
      RowBox[{"arctan", 
       RowBox[{"(", 
        FractionBox["1", "2"], ")"}], "n"}], ")"}]}]}]}]]],
 ". "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"9.14", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706014890625*^9, 3.506706014890625*^9}}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"5", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["SolveDE"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], "  ", "=", "  ", "0"}]]],
 ".  It will construct the characteristic polynomial and its roots.  The \
format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"SolveDE", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"x", "[", "n", "]"}], ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "5"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"SolveDE", "[", 
    RowBox[{"2", ",", "5", ",", 
     RowBox[{"x", "[", "n", "]"}], ",", "1", ",", "5"}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994822215*^9, 3.39948222246875*^9}, 
   3.400347107453125*^9}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to compare  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "+", 
       FractionBox[
        RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "-", 
       FractionBox[
        RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["5", 
      RowBox[{"n", "/", "2"}]], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"n", " ", 
       RowBox[{"ArcTan", "[", 
        FractionBox["1", "2"], "]"}]}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["5", 
      RowBox[{"n", "/", "2"}]], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"n", " ", 
       RowBox[{"ArcTan", "[", 
        FractionBox["1", "2"], "]"}]}], "]"}]}]}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "2"], "+", 
         FractionBox[
          RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "2"], "-", 
         FractionBox[
          RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y2", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{
       SuperscriptBox["5", 
        RowBox[{"n", "/", "2"}]], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"n", " ", 
         RowBox[{"ArcTan", "[", 
          FractionBox["1", "2"], "]"}]}], "]"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["5", 
        RowBox[{"n", "/", "2"}]], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"n", " ", 
         RowBox[{"ArcTan", "[", 
          FractionBox["1", "2"], "]"}]}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "10"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y2", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Y2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y2", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y2"}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y1", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g2", ",", "g3"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y2", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y2", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Simplify", "[", 
           RowBox[{"y2", "[", "n", "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482226703125*^9, 3.399482240375*^9}, {
  3.400067167109375*^9, 3.400067167296875*^9}, {3.40008455159375*^9, 
  3.40008465109375*^9}, {3.400094160671875*^9, 3.400094161484375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Higher Order Difference Equations",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n\n\tT",
  FontFamily->"Times New Roman"],
 "he general form of a ",
 Cell[BoxData[
  SuperscriptBox["P", "th"]]],
 " ",
 StyleBox["order linear constant coefficient difference equation",
  FontFamily->"Times New Roman"],
 " (LCCDE), is  ",
 StyleBox["\n\t\n",
  FontFamily->"Times New Roman"],
 StyleBox["(9-14)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\t\t\t",
  FontFamily->"Times New Roman"],
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], "+", 
      RowBox[{
       SubscriptBox["a", "1"], " ", 
       RowBox[{"y", "[", 
        RowBox[{"n", "-", "1"}], "]"}]}], "+", 
      RowBox[{
       SubscriptBox["a", "2"], " ", 
       RowBox[{"y", "[", 
        RowBox[{"n", "-", "2"}], "]"}]}], "+"}], "..."}], "+", 
    RowBox[{
     SubscriptBox["a", 
      RowBox[{"N", "-", "1"}]], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "P", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["a", "P"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "P"}], "]"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"   ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["b", "0"], " ", 
        RowBox[{"x", "[", "n", "]"}]}], "+", 
       RowBox[{
        SubscriptBox["b", "1"], " ", 
        RowBox[{"x", "[", 
         RowBox[{"n", "-", "1"}], "]"}]}], "+", 
       RowBox[{
        SubscriptBox["b", "2"], " ", 
        RowBox[{"x", "[", 
         RowBox[{"n", "-", "2"}], "]"}]}], "+"}], "..."}], "+", 
     RowBox[{
      SubscriptBox["b", 
       RowBox[{"M", "-", "1"}]], " ", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "Q", "+", "1"}], "]"}]}], "+", 
     RowBox[{
      SubscriptBox["b", "Q"], " ", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "Q"}], "]"}]}]}]}]}]}]],
 StyleBox["\n\nwhere ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["a", "p"], "}"}], 
   RowBox[{"p", "=", "1"}], "P"]]],
 StyleBox[" and ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["b", "q"], "}"}], 
   RowBox[{"q", "=", "0"}], "Q"]]],
 StyleBox[". ",
  FontFamily->"Times New Roman"],
 " The sequence ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["x", "n"], "=", 
     RowBox[{"x", "[", "n", "]"}]}], "}"}], 
   RowBox[{"n", "=", "0"}], "\[Infinity]"]]],
 " is given and the sequence ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["x", "n"], "=", 
     RowBox[{"x", "[", "n", "]"}]}], "}"}], 
   RowBox[{"n", "=", "0"}], "\[Infinity]"]]],
 " is output.  The integer  ",
 Cell[BoxData["P"]],
 "  is the order of the difference equation.  ",
 StyleBox["The compact form of writing this difference equation is \n\n",
  FontFamily->"Times New Roman"],
 StyleBox["(9-15)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\t\t\t",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "  ", "+", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"p", "=", "1"}], "P"], 
     RowBox[{
      SubscriptBox["a", "p"], 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "p"}], "]"}]}]}]}], "  ", "=", "  ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"q", "=", "0"}], "Q"], 
    RowBox[{
     SubscriptBox["b", "q"], 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "q"}], "]"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "This formula can be expressed in a recursive form:\n\n",
 StyleBox["(9-16)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", "  ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"q", "=", "0"}], "Q"], 
     RowBox[{
      SubscriptBox["b", "q"], 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "q"}], "]"}]}]}], "  ", "-", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"p", "=", "1"}], "P"], 
     RowBox[{
      SubscriptBox["a", "1"], 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "p"}], "]"}]}]}]}]}]]],
 ".  \n\n\tThis form of the LCCDE explicitly shows that the present output  ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 "  is a function of the past output values  ",
 Cell[BoxData[
  RowBox[{"y", "[", 
   RowBox[{"n", "-", "p"}], "]"}]]],
 ",  for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"p", "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "2", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "P"}]]],
 "; and the present input  ",
 Cell[BoxData[
  RowBox[{"x", "[", "n", "]"}]]],
 ",  and the previous inputs  ",
 Cell[BoxData[
  RowBox[{"x", "[", 
   RowBox[{"n", "-", "q"}], "]"}]]],
 "  for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"q", "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "2", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "Q"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tNow we would like to emphasize the method of",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transforms for solving difference equations.  Applying the linearity and \
time delay shift property of the",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transform to equation ",
 StyleBox["(9-15)",
  FontColor->RGBColor[0, 0, 1]],
 ", we obtain \n\n",
 StyleBox["(9-17)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}]}], "  ", "+", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"p", "=", "1"}], "P"], 
     RowBox[{
      SubscriptBox["a", "p"], "Y", 
      RowBox[{"(", "z", ")"}], 
      SuperscriptBox["z", 
       RowBox[{"-", "p"}]]}]}]}], "  ", "=", "  ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"q", "=", "0"}], "Q"], 
    RowBox[{
     SubscriptBox["b", "q"], "X", 
     RowBox[{"(", "z", ")"}], 
     SuperscriptBox["z", 
      RowBox[{"-", "q"}]]}]}]}]]],
 ". \n\nThis can be rearranged as  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}], 
    RowBox[{"(", 
     RowBox[{"1", " ", "+", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"p", "=", "1"}], "P"], 
       RowBox[{
        SubscriptBox["a", "p"], 
        SuperscriptBox["z", 
         RowBox[{"-", "p"}]]}]}]}], ")"}]}], "  ", "=", "  ", 
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"q", "=", "0"}], "Q"], 
     RowBox[{
      SubscriptBox["b", "q"], 
      SuperscriptBox["z", 
       RowBox[{"-", "q"}]]}]}]}]}]]],
 "  and then solved for the quotient ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}]}], 
    RowBox[{"X", 
     RowBox[{"(", "z", ")"}]}]]}]]],
 ".  The sequence  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", "[", "n", "]"}], "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"H", 
     RowBox[{"(", "z", ")"}]}], "]"}]}]]],
 " can be used to construct a particular solution to ",
 StyleBox["(9-14)",
  FontColor->RGBColor[0, 0, 1]],
 ", i.e.  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[GothicCapitalZ]", 
      RowBox[{"-", "1"}]], "[", 
     RowBox[{"H", 
      RowBox[{"(", "z", ")"}], "X", 
      RowBox[{"(", "z", ")"}]}], "]"}], "=", 
    RowBox[{
     RowBox[{"h", "[", "n", "]"}], "*", 
     RowBox[{"x", "[", "n", "]"}]}]}]}]]],
 ".  This solution can be expressed using the convolution sum, as follows:\n\n\
",
 StyleBox["(9-18)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "0"}], "n"], " ", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"n", "-", "i"}], "]"}], 
     RowBox[{"x", "[", "i", "]"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  This particular solution   ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "p"], "[", "n", "]"}]]],
 " does not involve initial conditions for ",
 StyleBox["(9-14)",
  FontColor->RGBColor[0, 0, 1]],
 ".  We will illustrate how to use convolution at the end of this section.  "
}], "Text"],

Cell[TextData[{
 StyleBox["Difference Equations with Initial Conditions",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tOften times a difference equation involves only one input on the \
right hand side of ",
 StyleBox["(9-14)",
  FontColor->RGBColor[0, 0, 1]],
 " and we write\n\n",
 StyleBox["\t\t\t",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], "+", 
      RowBox[{
       SubscriptBox["a", "1"], " ", 
       RowBox[{"y", "[", 
        RowBox[{"n", "-", "1"}], "]"}]}], "+", 
      RowBox[{
       SubscriptBox["a", "2"], " ", 
       RowBox[{"y", "[", 
        RowBox[{"n", "-", "2"}], "]"}]}], "+"}], "..."}], "+", 
    RowBox[{
     SubscriptBox["a", 
      RowBox[{"N", "-", "1"}]], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "P", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["a", "P"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "P"}], "]"}]}]}], " ", "=", "  ", 
   RowBox[{"x", "[", "n", "]"}]}]]],
 "\n\t\t\nthen we could shift the index and use the form\n\n",
 StyleBox["\t\t\t",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", 
       RowBox[{"n", "+", "P"}], "]"}], "+", 
      RowBox[{
       SubscriptBox["a", "1"], " ", 
       RowBox[{"y", "[", 
        RowBox[{"n", "+", "P", "-", "1"}], "]"}]}], "+", 
      RowBox[{
       SubscriptBox["a", "2"], " ", 
       RowBox[{"y", "[", 
        RowBox[{"n", "+", "P", "-", "2"}], "]"}]}], "+"}], "..."}], "+", 
    RowBox[{
     SubscriptBox["a", 
      RowBox[{"N", "-", "1"}]], " ", 
     RowBox[{"y", "[", 
      RowBox[{"P", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["a", "P"], " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", 
   RowBox[{"x", "[", 
    RowBox[{"n", "+", "P"}], "]"}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "\t",
 StyleBox["Consider the first order linear constant coefficient difference \
equation",
  FontFamily->"Times New Roman"],
 " (LCCDE)  \n\n",
 StyleBox["(9-19)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", 
   RowBox[{"x", "[", 
    RowBox[{"n", "+", "2"}], "]"}]}]]],
 " \n\nwith the initial conditions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "0"], "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     RowBox[{"y", "[", "1", "]"}]}], "=", " ", 
    SubscriptBox["y", "1"]}]}]]],
 "  (and implicitly we have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "0", "]"}], "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "0"], "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     RowBox[{"x", "[", "1", "]"}]}], "=", " ", 
    SubscriptBox["x", "1"]}]}]]],
 "). "
}], "Text"],

Cell[TextData[{
 "\t",
 StyleBox["Step (i)",
  FontColor->RGBColor[0, 0, 1]],
 "  Using the time forward properties  \n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "1"}], "]"}], "]"}], " ", "=", "   ", 
   RowBox[{"z", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Y", 
       RowBox[{"(", "z", ")"}]}], "-", 
      SubscriptBox["y", "0"]}], ")"}]}]}]]],
 ", \n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "]"}], "  ", "=", "  ", 
   RowBox[{
    SuperscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Y", 
       RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
      SubscriptBox["y", "0"], " ", "-", " ", 
      RowBox[{
       SubscriptBox["y", "1"], 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}]}], ")"}]}]}]]],
 ",   \n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    RowBox[{"x", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "]"}], "  ", "=", "  ", 
   RowBox[{
    SuperscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"X", 
       RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
      SubscriptBox["x", "0"], " ", "-", " ", 
      RowBox[{
       SubscriptBox["x", "1"], 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}]}], ")"}]}]}]]],
 " \n\t\tand take the",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transform of each term and get the equation  \n\n",
 StyleBox["(9-20)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
       SubscriptBox["y", "0"], " ", "-", " ", 
       RowBox[{
        SubscriptBox["y", "1"], 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"2", "a", " ", "z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", 
       SubscriptBox["y", "0"]}], ")"}]}], "+", 
    RowBox[{"b", " ", "Y", 
     RowBox[{"(", "z", ")"}]}]}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"X", 
       RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
      SubscriptBox["x", "0"], " ", "-", " ", 
      RowBox[{
       SubscriptBox["x", "1"], 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}]}], ")"}]}]}]]],
 ". \n\t\n\t",
 StyleBox["Step (ii)",
  FontColor->RGBColor[0, 0, 1]],
 "  Solve equation ",
 StyleBox["(9-20)",
  FontColor->RGBColor[0, 0, 1]],
 " for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ". \n\n\t",
 StyleBox["Step (iii)",
  FontColor->RGBColor[0, 0, 1]],
 "  Use partial fractions to expand  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 "  in a sum of terms, and look up the inverse",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transform(s) using Table 1, to get the solution  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}]}], "]"}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "\t",
 StyleBox["Step (iv)",
  FontColor->RGBColor[0, 0, 1]],
 "  Alternate calculation using residues.  Perform steps ",
 StyleBox["(i)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 " listed above.  Then find  ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 "  using residues  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[GothicCapitalZ]", 
      RowBox[{"-", "1"}]], "[", 
     RowBox[{"Y", 
      RowBox[{"(", "z", ")"}]}], "]"}], "  ", "=", "   ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "k"], 
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}], 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       SubscriptBox["z", "i"]}], "]"}]}]}]}]]],
 ".  \n\n\t\twhere  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "k"]}]]],
 "  are the poles of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}], 
    SuperscriptBox["z", 
     RowBox[{"n", "-", "1"}]]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\t",
 StyleBox["Remark",
  FontColor->RGBColor[0, 0, 1]],
 "  The function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}], 
    SuperscriptBox["z", 
     RowBox[{"n", "-", "1"}]]}]}]]],
 "  has real coefficients.  Hence, if , and if ",
 Cell[BoxData[
  SubscriptBox["z", "i"]]],
 " and ",
 Cell[BoxData[
  OverscriptBox[
   SubscriptBox["z", "i"], "_"]]],
 " are poles, then we can use the computational fact: \n\n",
 StyleBox["(9-21)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     OverscriptBox[
      SubscriptBox["z", "i"], "_"]}], "]"}], "  ", "=", "   ", 
   OverscriptBox[
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      SubscriptBox["z", "i"]}], "]"}], "_"]}]]]
}], "Text"],

Cell[TextData[{
 "\tWe now show how to obtain answers to Examples 9.12-9.14 using",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transform methods. "
}], "Text"],

Cell[TextData[{
 "\tThe following subroutine uses",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transforms to construct solutions to a second order homogeneous difference \
equation."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica Subroutines (",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]],
 StyleBox["Solution of a Difference Equation",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Zsolution", "[", 
    RowBox[{
    "a0_", ",", "b0_", ",", "x0_", ",", "\[Alpha]0_", ",", "\[Beta]0_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", " ", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "=", "a0"}], ";", " ", 
      RowBox[{"b", "=", "b0"}], ";", " ", 
      RowBox[{"\[Alpha]", "=", "\[Alpha]0"}], ";", " ", 
      RowBox[{"\[Beta]", "=", "\[Beta]0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Clear", "[", 
       RowBox[{"n", ",", "y", ",", "Y", ",", "z"}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"x", "[", "n_", "]"}], "=", "x0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"LCCDE", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", 
          RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
         RowBox[{"2", "a", " ", 
          RowBox[{"y", "[", 
           RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
         RowBox[{"b", " ", 
          RowBox[{"y", "[", "n", "]"}]}]}], "\[Equal]", " ", 
        RowBox[{"x", "[", 
         RowBox[{"n", "+", "2"}], "]"}]}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"thede", "=", 
       RowBox[{
        RowBox[{"\"\<y[n+2]\>\"", " ", "-", " ", 
         RowBox[{"2", "a", " ", "\"\<y[n+1]\>\""}], " ", "+", " ", 
         RowBox[{"b", " ", "\"\<y[n]\>\""}]}], "\[Equal]", " ", 
        RowBox[{"x", "[", 
         RowBox[{"n", "+", "2"}], "]"}]}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{
      "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
      ";", " ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", " ", "LCCDE", " ", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
      "Print", "[", "\"\<Take the z-transforms of each term\>\"", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"eqn1", " ", "=", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["z", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", 
            SubscriptBox["y", "0"], " ", "-", " ", 
            RowBox[{
             SubscriptBox["y", "1"], 
             SuperscriptBox["z", 
              RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "-", " ", 
         RowBox[{"2", "a", 
          RowBox[{"(", 
           RowBox[{"z", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", 
              SubscriptBox["y", "0"]}], ")"}]}], ")"}]}], "+", 
         RowBox[{"b", 
          RowBox[{"(", 
           RowBox[{"Y", "[", "z", "]"}], ")"}]}]}], "\[Equal]", "  ", 
        RowBox[{"ZTransform", "[", 
         RowBox[{
          RowBox[{"x", "[", 
           RowBox[{"n", "+", "2"}], "]"}], ",", "n", ",", "z"}], "]"}]}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "eqn1", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<Use the initial values\>\"", "]"}], ";", 
      "  ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<y[0] = \!\(\*SubscriptBox[\(y\), \(0\)]\) = \>\"", ",", " ", 
        "\[Alpha]"}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<y[1] = \!\(\*SubscriptBox[\(y\), \(1\)]\) = \>\"", ",", " ", 
        "\[Beta]"}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"eqn2", " ", "=", 
       RowBox[{"ReplaceAll", "[", 
        RowBox[{"eqn1", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SubscriptBox["y", "0"], "\[Rule]", "\[Alpha]"}], ",", 
           RowBox[{
            SubscriptBox["y", "1"], "\[Rule]", "\[Beta]"}]}], "}"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<Substitute them and obtain\>\"", "]"}], ";", 
      "  ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "eqn2", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"solset", "=", 
       RowBox[{"Solve", "[", 
        RowBox[{"eqn2", ",", 
         RowBox[{"Y", "[", "z", "]"}]}], "]"}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Y", "[", "z_", "]"}], "=", 
       RowBox[{"Together", "[", 
        SubscriptBox["solset", 
         RowBox[{"\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], 
        "]"}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{
      "Print", "[", 
       "\"\<Solve this equation for Y[z] = \[GothicCapitalZ][y[n]]\>\"", 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<Y[z] = \>\"", ",", 
        RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"y", "[", "n_", "]"}], "=", 
       RowBox[{"InverseZTransform", "[", 
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], ",", "z", ",", "n"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
      "Print", "[", 
       "\"\<Take the inverse z-transform and get the solution\>\"", "]"}], 
      ";", " ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<y[n] = \!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \
\(-1\)]\)[Y[z]] = \!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)[\>\"",
         ",", 
        RowBox[{"Y", "[", "z", "]"}], ",", "\"\<]\>\""}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<y[n] = \>\"", ",", 
        RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
      "Print", "[", "\"\<It has the desired initial conditions\>\"", "]"}], 
      ";", "  ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<y[0] = \>\"", ",", 
        RowBox[{"y", "[", "0", "]"}]}], " ", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "0", "]"}], "===", 
         RowBox[{"Simplify", "[", 
          RowBox[{"y", "[", "0", "]"}], "]"}]}], ",", "\"\<\>\"", ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"\"\<y[0] = \>\"", ",", 
           RowBox[{"Simplify", "[", 
            RowBox[{"y", "[", "0", "]"}], "]"}]}], " ", "]"}], ";"}]}], " ", 
       "]"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<y[1] = \>\"", ",", 
        RowBox[{"y", "[", "1", "]"}]}], " ", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "1", "]"}], "===", 
         RowBox[{"Simplify", "[", 
          RowBox[{"y", "[", "1", "]"}], "]"}]}], ",", "\"\<\>\"", ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"\"\<y[1] = \>\"", ",", 
           RowBox[{"Simplify", "[", 
            RowBox[{"y", "[", "1", "]"}], "]"}]}], " ", "]"}], ";"}]}], " ", 
       "]"}], ";"}]}], " ", "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.400094287109375*^9, 3.400094312078125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ResidueSolution", "[", 
    RowBox[{"a0_", ",", "b0_", ",", "\[Alpha]0_", ",", "\[Beta]0_"}], "]"}], ":=", 
   RowBox[{"Module", "[", " ", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "=", "a0"}], ";", " ", 
      RowBox[{"b", "=", "b0"}], ";", " ", 
      RowBox[{"\[Alpha]", "=", "\[Alpha]0"}], ";", " ", 
      RowBox[{"\[Beta]", "=", "\[Beta]0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Clear", "[", 
       RowBox[{"n", ",", "y", ",", "Y", ",", "z"}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"HLCCDE", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", 
          RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
         RowBox[{"2", "a", " ", 
          RowBox[{"y", "[", 
           RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
         RowBox[{"b", " ", 
          RowBox[{"y", "[", "n", "]"}]}]}], "\[Equal]", " ", "0"}]}], ";", 
      " ", "\[IndentingNewLine]", 
      RowBox[{"thede", "=", 
       RowBox[{
        RowBox[{"\"\<y[n+2]\>\"", " ", "-", " ", 
         RowBox[{"2", "a", " ", "\"\<y[n+1]\>\""}], " ", "+", " ", 
         RowBox[{"b", " ", "\"\<y[n]\>\""}]}], "\[Equal]", " ", "0"}]}], ";", 
      " ", "\[IndentingNewLine]", 
      RowBox[{
      "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
      ";", " ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", " ", "HLCCDE", " ", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
      "Print", "[", "\"\<Take the z-transforms of each term\>\"", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"eqn1", " ", "=", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["z", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", 
            SubscriptBox["y", "0"], " ", "-", " ", 
            RowBox[{
             SubscriptBox["y", "1"], 
             SuperscriptBox["z", 
              RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "-", " ", 
         RowBox[{"2", "a", 
          RowBox[{"(", 
           RowBox[{"z", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", 
              SubscriptBox["y", "0"]}], ")"}]}], ")"}]}], "+", 
         RowBox[{"b", 
          RowBox[{"(", 
           RowBox[{"Y", "[", "z", "]"}], ")"}]}]}], "\[Equal]", " ", "0"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "eqn1", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<Use the initial values\>\"", "]"}], ";", 
      "  ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<y[0] = \!\(\*SubscriptBox[\(y\), \(0\)]\) = \>\"", ",", " ", 
        "\[Alpha]"}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<y[1] = \!\(\*SubscriptBox[\(y\), \(1\)]\) = \>\"", ",", " ", 
        "\[Beta]"}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<Substitute them and obtain\>\"", "]"}], ";", 
      "  ", "\[IndentingNewLine]", 
      RowBox[{"eqn2", " ", "=", 
       RowBox[{"ReplaceAll", "[", 
        RowBox[{"eqn1", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SubscriptBox["y", "0"], "\[Rule]", "\[Alpha]"}], ",", 
           RowBox[{
            SubscriptBox["y", "1"], "\[Rule]", "\[Beta]"}]}], "}"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "eqn2", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"solset", "=", 
       RowBox[{"Solve", "[", 
        RowBox[{"eqn2", ",", 
         RowBox[{"Y", "[", "z", "]"}]}], "]"}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Y", "[", "z_", "]"}], "=", 
       RowBox[{"Together", "[", 
        SubscriptBox["solset", 
         RowBox[{"\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], 
        "]"}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{
      "Print", "[", 
       "\"\<Solve this equation for Y[z] = \[GothicCapitalZ][y[n]]\>\"", 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<   Y[z] = \>\"", ",", 
        RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"zsolve", "=", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Denominator", "[", 
           RowBox[{"Y", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}],
         "]"}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{
       SubscriptBox["z", "1"], "=", 
       SubscriptBox["zsolve", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{
       SubscriptBox["z", "2"], "=", 
       SubscriptBox["zsolve", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"2", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["z", "1"], "=!=", 
         SubscriptBox["z", "2"]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Print", "[", "\"\<The poles are\>\"", "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"s", "[", "n_", "]"}], "=", 
          RowBox[{
           RowBox[{"Residue", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Y", "[", "z", "]"}], 
              SuperscriptBox[
               RowBox[{"z", " "}], 
               RowBox[{"n", "-", "1"}]]}], ",", 
             RowBox[{"{", 
              RowBox[{"z", ",", 
               SubscriptBox["z", "1"]}], "}"}]}], "]"}], "+", 
           RowBox[{"Residue", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Y", "[", "z", "]"}], 
              SuperscriptBox[
               RowBox[{"z", " "}], 
               RowBox[{"n", "-", "1"}]]}], ",", 
             RowBox[{"{", 
              RowBox[{"z", ",", 
               SubscriptBox["z", "2"]}], "}"}]}], "]"}]}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
           SubscriptBox["z", "1"]}], " ", "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
           SubscriptBox["z", "2"]}], " ", "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", "\"\<The solution is\>\"", "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) =  \
\!\(\*FractionBox[\(1\), \(2\\\ \[Pi]\\\ \[ImaginaryI]\)]\)\>\"", ",", 
           UnderscriptBox["\"\<\[ClockwiseContourIntegral]\>\"", "C"], ",", 
           "\"\<(\>\"", ",", 
           RowBox[{
            RowBox[{"Y", "[", "z", "]"}], " ", 
            SuperscriptBox["z", 
             RowBox[{"n", "-", "1"}]]}], ",", "\"\<) \[DifferentialD]z\>\""}],
           "]"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{
         "Print", "[", 
          "\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) = \
Res[Y[z]z\!\(\*SuperscriptBox[\(\\\ \), \(n - \
1\)]\),\!\(\*SubscriptBox[\(z\), \(1\)]\)] + Res[Y[z]z\!\(\*SuperscriptBox[\(\
\\\ \), \(n - 1\)]\),\!\(\*SubscriptBox[\(z\), \(2\)]\)] \>\"", "]"}], ";", 
         " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) = \
Res[Y[z]z\!\(\*SuperscriptBox[\(\\\ \), \(n - 1\)]\), \>\"", ",", 
           SubscriptBox["z", "1"], ",", 
           "\"\<] + Res[Y[z]z\!\(\*SuperscriptBox[\(\\\ \), \(n - 1\)]\), \
\>\"", ",", 
           SubscriptBox["z", "2"], ",", "\"\<] \>\""}], "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) = Res[\>\"", ",", 
           RowBox[{
            RowBox[{"Y", "[", "z", "]"}], 
            SuperscriptBox["z", 
             RowBox[{"n", "-", "1"}]]}], ",", "\"\<, \>\"", ",", 
           SubscriptBox["z", "1"], ",", "\"\<] + Res[\>\"", ",", 
           RowBox[{
            RowBox[{"Y", "[", "z", "]"}], 
            SuperscriptBox["z", 
             RowBox[{"n", "-", "1"}]]}], ",", "\"\<, \>\"", ",", 
           SubscriptBox["z", "2"], ",", "\"\<]\>\""}], "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) = (\>\"", ",", 
           RowBox[{"Residue", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Y", "[", "z", "]"}], 
              SuperscriptBox[
               RowBox[{"z", " "}], 
               RowBox[{"n", "-", "1"}]]}], ",", 
             RowBox[{"{", 
              RowBox[{"z", ",", 
               SubscriptBox["z", "1"]}], "}"}]}], "]"}], ",", "\"\<) + (\>\"",
            ",", 
           RowBox[{"Residue", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Y", "[", "z", "]"}], 
              SuperscriptBox[
               RowBox[{"z", " "}], 
               RowBox[{"n", "-", "1"}]]}], ",", 
             RowBox[{"{", 
              RowBox[{"z", ",", 
               SubscriptBox["z", "2"]}], "}"}]}], "]"}], ",", "\"\<)\>\""}], 
          " ", "]"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) = \>\"", ",", 
           RowBox[{"s", "[", "n", "]"}]}], " ", "]"}], ";"}]}], "  ", "]"}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["z", "1"], "\[Equal]", 
         SubscriptBox["z", "2"]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Print", "[", "\"\<The pole is\>\"", "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"s", "[", "n_", "]"}], "=", 
          RowBox[{"Residue", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Y", "[", "z", "]"}], 
             SuperscriptBox[
              RowBox[{"z", " "}], 
              RowBox[{"n", "-", "1"}]]}], ",", 
            RowBox[{"{", 
             RowBox[{"z", ",", 
              SubscriptBox["z", "1"]}], "}"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
           SubscriptBox["z", "1"]}], " ", "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) =  \
\!\(\*FractionBox[\(1\), \(2\\\ \[Pi]\\\ \[ImaginaryI]\)]\)\>\"", ",", 
           UnderscriptBox["\"\<\[ClockwiseContourIntegral]\>\"", "C"], ",", 
           "\"\<(\>\"", ",", 
           RowBox[{
            RowBox[{"Y", "[", "z", "]"}], " ", 
            SuperscriptBox["z", 
             RowBox[{"n", "-", "1"}]]}], ",", "\"\<) \[DifferentialD]z\>\""}],
           "]"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{
         "Print", "[", 
          "\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) = \
Res[Y[z]z\!\(\*SuperscriptBox[\(\\\ \), \(n - \
1\)]\),\!\(\*SubscriptBox[\(z\), \(1\)]\)]\>\"", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) = \
Res[Y[z]z\!\(\*SuperscriptBox[\(\\\ \), \(n - 1\)]\), \>\"", ",", 
           SubscriptBox["z", "1"], ",", "\"\<]\>\""}], "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) = Res[\>\"", ",", 
           RowBox[{
            RowBox[{"Y", "[", "z", "]"}], 
            SuperscriptBox["z", 
             RowBox[{"n", "-", "1"}]]}], ",", " ", "\"\<,{z,\>\"", ",", 
           SubscriptBox["z", "1"], ",", "\"\<]\>\""}], "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) = \>\"", ",", 
           RowBox[{"s", "[", "n", "]"}]}], " ", "]"}], ";"}]}], "  ", "]"}], 
      ";"}]}], "\[IndentingNewLine]", " ", "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.400094440484375*^9, 3.400094446859375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.15 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transform methods to solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ".  \n\n",
 StyleBox["9.15 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transform methods to solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", 
   SuperscriptBox["2", 
    RowBox[{"n", "+", "2"}]]}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "3"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztWj9v00AUvyZxZ2Bo0wHISJw/4jMgoCzMSSohFFVIDQiBkgCfACTYETCV
LvABYICBib1s7LDQ78BgfHf2c2K/dzmfz7VDLbX207v7vX/3/thub4/nB/ce
jueT/XFrdzp+fDDZn7VuPpr6rPoGY7VDxtjrFuO055PBxfN/5OWIXzg7B8Yb
fnO4wjanGpzqcKrGqR6n6pxygTcDhAuIHqz2AdEF3o5U9U7cxBoLjJBKYzyh
njWWeKGO2NYr+NY5stVFeD0c3ifhia1N2jVMYZcKgQMRi61OyQAt80ibHcqj
Ldp0TAFmHBH+KH+eaArC7Gsr0kAvrRJY4hDj7mI8/kunVUJkV8Ve1oTldZBW
b8HXLkJFkehA0c2Q1T5CRYUdqLLRS+5LoeESWCU3bcpNE5mUXnAaYvvfMFEX
MD/l9hG/neOGCkwbqG8QjPOS52NcoL5z6kJcYxso7Hiz8K6BBy7iC5beWBlg
qbAdj62LBPAYVHUQQz5IEQ+o9I2JPaZ8jilQiB0ohY2yi9gDez7SIobg3A9k
1QsUUOgohwsHvgJvnxmgX0K4n9LoFxCrI1MRz+HE3ucjQisMahGrjkAdhjVK
GS3gVngmrMYpMRkaQG2aipUjxVle8OS0E4qSg7GGyKqXQb+IxOL8KtrrgfLM
nIKtG9lRg/HEdRvxWT9jbVpXh8RYVX55x6Ts+ofKMyMzdo36aAVMCfwaVpB3
ywD9Rar1Gbs0+rNU4QXvRCYiPgXuMfQtPKWIO5wShRbNFXXn0gpSTAHarony
TrDJUlQccRTmu8iqsr3g+ks3cNVPT9rOWYy5hUl4+v1hoMx/4ykwyJz1DVPV
w8wJ35DFEyZ82Qf5wEbCZwt39RhxVoE59btim3gxb6o7Bj5XM7NMxfAfAXNq
68XOqmI+NOwZ+Fw9GpSpGOwDm5BCVj/xFj1CZGk5UFQaBZby7bIEk2ph4RRV
NyFOuh8qSpr6FfBsAMWwJVuccfcvepoatLiU3xNKMLQztThStYW/EpENkMyn
YgeGpYGsPx+jGOf/kTlSmOlzWzbVdSojqpFYAdcA+Fsmsb96wwD9K1hn7HqJ
0elfBKOoXJUUgV1V5PnO0txmy0nodDBAbD31RA8h9kwX53AiY+6vNuNHnm4O
CeIi2Jp9iP1BLcs0sARxKbMYfWvJGSdAl5VbsApJpJdgY/+xvVhLbOMfQS/G
JQ==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{671, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Solution", " ", "9.15", " ", 
   RowBox[{
    RowBox[{"(", "a", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.5067060210625*^9, 3.5067060210625*^9}}],

Cell[TextData[{
 "Take the z-transforms of each term  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", "1", "-", 
       RowBox[{"5", " ", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"4", 
     RowBox[{"(", 
      RowBox[{"z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Y", 
          RowBox[{"(", "z", ")"}]}], "-", "1"}], ")"}]}], ")"}]}], "+", 
    RowBox[{"3", 
     RowBox[{"(", 
      RowBox[{"Y", 
       RowBox[{"(", "z", ")"}]}], ")"}]}]}], " ", "=", " ", "0"}]]]
}], "Text"],

Cell[TextData[{
 "Solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 " and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z", "2"], "+", "z"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "-", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", "-", "3"}], ")"}]}]]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "Calculate the residues for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], "+", "z"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", "3"}], ")"}]}]], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}]}]}]]],
 "  at the poles \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "1"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", "1"}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "2"], "+", "z"}], 
       RowBox[{"z", "-", "3"}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "*", 
      SuperscriptBox["1", 
       RowBox[{"n", "-", "1"}]]}], " ", "=", " ", 
     RowBox[{"-", "1"}]}]}]}]]],
 "  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "3"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", "3"}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "2"], "+", "z"}], 
       RowBox[{"z", "-", "1"}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"6", "*", 
      SuperscriptBox["3", 
       RowBox[{
        RowBox[{"-", "n"}], "-", "1"}]]}], " ", "=", " ", 
     RowBox[{"2", "*", 
      SuperscriptBox["3", "n"]}]}]}]}]]],
 "  "
}], "Text"],

Cell[TextData[{
 "Thus the solution is  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "1"}], "]"}], "+", 
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["3",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}], "]"}]}]}]]],
 ", \n\t\t\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", " ", "1"}], " ", "+", "  ", 
    RowBox[{"2", "*", 
     SuperscriptBox["3", "n"]}]}]}]]],
 "\n\nwhich agrees with the result of example 1. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Solution", " ", "9.15", " ", 
   RowBox[{
    RowBox[{"(", "b", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670602421875*^9, 3.50670602421875*^9}}],

Cell[TextData[{
 "Take the z-transforms of each term  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", "1", "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"4", 
     RowBox[{"(", 
      RowBox[{"z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Y", 
          RowBox[{"(", "z", ")"}]}], "-", "1"}], ")"}]}], ")"}]}], "+", 
    RowBox[{"3", 
     RowBox[{"(", 
      RowBox[{"Y", 
       RowBox[{"(", "z", ")"}]}], ")"}]}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{"4", " ", "z"}], 
    RowBox[{"z", "-", "2"}]]}]]]
}], "Text"],

Cell[TextData[{
 "Solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 " and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z", "3"], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["z", "2"]}], "+", 
     RowBox[{"6", "z"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "-", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", "-", "2"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", "-", "3"}], ")"}]}]]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "Calculate the residues for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "3"], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["z", "2"]}], "+", 
       RowBox[{"6", "z"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", "2"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", "3"}], ")"}]}]], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}]}]}]]],
 "  at the poles \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "1"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", "1"}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "3"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["z", "2"]}], "+", 
        RowBox[{"6", "z"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "2"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "3"}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"2", "*", 
      SuperscriptBox["1", 
       RowBox[{"n", "-", "1"}]]}], " ", "=", " ", "2"}]}]}]]],
 "  \n\t\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "1"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", "2"}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "3"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["z", "2"]}], "+", 
        RowBox[{"6", "z"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "1"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "3"}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", " ", "8"}], "*", 
      SuperscriptBox["2", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "n"}]]}], "=", " ", 
     RowBox[{"-", 
      SuperscriptBox["2", 
       RowBox[{"n", "+", "2"}]]}]}]}]}]]],
 "  \n\t\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "3"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", "3"}]], " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "3"], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["z", "2"]}], "+", 
       RowBox[{"6", "z"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", "2"}], ")"}]}]]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"9", "*", 
      SuperscriptBox["3", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "n"}]]}], " ", "=", " ", 
     SuperscriptBox["3", 
      RowBox[{"n", "+", "1"}]]}]}]}]]],
 "  "
}], "Text"],

Cell[TextData[{
 "Thus the solution is  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "1"}], "]"}], "+", 
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["2",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}], "]"}], "+", 
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["3",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}], "]"}]}]}]]],
 ", \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{"2", " ", "-", " ", 
    SuperscriptBox["2", 
     RowBox[{"n", "+", "2"}]], " ", "+", " ", 
    SuperscriptBox["3", 
     RowBox[{"n", "+", "1"}]]}]}]]],
 "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", "9.15", " ", 
   RowBox[{
    RowBox[{"(", "a", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706026828125*^9, 3.506706026828125*^9}}],

Cell[TextData[{
 "It is worthwhile to point out how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can do the important step using residues."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"z", "+", 
       SuperscriptBox["z", "2"]}], 
      RowBox[{"3", "-", 
       RowBox[{"4", " ", "z"}], "+", 
       SuperscriptBox["z", "2"]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\) = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", 
      SuperscriptBox[
       RowBox[{"z", " "}], 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),1] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "1"}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),3] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "3"}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<          y[n] = Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - \
1\)]\),1] + Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),3]\>\"", " ", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<          y[n] = \>\"", ",", 
      RowBox[{
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "1"}], "}"}]}], "]"}], "+", 
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "3"}], "}"}]}], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482264125*^9, 3.399482265328125*^9}, {
  3.40006731521875*^9, 3.4000673243125*^9}}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", "0"}]}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["Zsolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", " ", "0"}]}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"Zsolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"x", "[", "n", "]"}], ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "3"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Zsolution", "[", 
     RowBox[{"2", ",", "3", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "1", ",", "5"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<and\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948226853125*^9, 3.399482269625*^9}, 
   3.400347129578125*^9}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["ResidueSolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"ResidueSolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "3"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ResidueSolution", "[", 
     RowBox[{"2", ",", "3", ",", "1", ",", "5"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"s", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399482272296875*^9, 3.400086590359375*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["3", "n"]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "5"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y1", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "500", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "500", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y1", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994822743125*^9, 3.399482289375*^9}, {
   3.400067173375*^9, 3.4000671735625*^9}, {3.400084728875*^9, 
   3.400084761875*^9}, 3.400086595328125*^9, {3.40009423471875*^9, 
   3.400094235125*^9}, 3.40009432753125*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", "9.15", " ", 
   RowBox[{
    RowBox[{"(", "b", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.5067060288125*^9, 3.5067060288125*^9}}],

Cell[TextData[{
 "It is worthwhile to point out how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can do the important step using residues."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"6", " ", "z"}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["z", "2"]}], "+", 
       SuperscriptBox["z", "3"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", "z"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "-", 
         RowBox[{"4", " ", "z"}], "+", 
         SuperscriptBox["z", "2"]}], ")"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\) = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\) = \>\"", ",", 
      FractionBox[
       RowBox[{"Numerator", "[", 
        RowBox[{"Y", "[", "z", "]"}], "]"}], 
       RowBox[{"Factor", "[", 
        RowBox[{"Denominator", "[", 
         RowBox[{"Y", "[", "z", "]"}], "]"}], "]"}]], ",", 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),1] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "1"}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "2"}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),3] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "3"}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<          y[n] = Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - \
1\)]\),1] + Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2] + \
Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),3]\>\"", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<          y[n] = \>\"", ",", 
      RowBox[{
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "1"}], "}"}]}], "]"}], "+", 
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "2"}], "}"}]}], "]"}], "+", 
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "3"}], "}"}]}], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948229753125*^9, 3.3994822989375*^9}, {
  3.400067351140625*^9, 3.400067352359375*^9}}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    SuperscriptBox["2", 
     RowBox[{"n", "+", "2"}]]}]}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "3"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["Zsolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{"x", "[", "n", "]"}]}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"Zsolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"x", "[", "n", "]"}], ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "3"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   SuperscriptBox["2", 
    RowBox[{"n", "+", "2"}]]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     SuperscriptBox["2", 
      RowBox[{"n", "+", "2"}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Zsolution", "[", 
     RowBox[{"2", ",", "3", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "1", ",", "3"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{3.399482301546875*^9, 3.400347144015625*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{"2", "-", 
      SuperscriptBox["2", 
       RowBox[{"2", "+", "n"}]], "+", 
      SuperscriptBox["3", 
       RowBox[{"1", "+", "n"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "5"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y1", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "620"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "600", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "620"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "600", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y1", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948230265625*^9, 3.399482336109375*^9}, {
  3.400067179609375*^9, 3.4000671798125*^9}, {3.40008478603125*^9, 
  3.400084842359375*^9}, {3.4000945154375*^9, 3.4000945158125*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.16 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transform methods to solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ".  \n\n",
 StyleBox["9.16 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transform methods to solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", 
   SuperscriptBox["3", "n"]}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"2", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "3"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztGctuEzHQzSbACXFokdJyiNhNEBc4I1GOcAAuoXCPSqr2gEAl/QvSGzcq
xIUvAPUHypEfAMEXUH7BxK/ZZjPe2I6d3SUrVd7p2PMez9jO08Fof/hqMDrY
HXQeHQ7e7B/svu08fH04QUVrhDQ+EkLedwiD6QSUA538ieETGxg6AOId+7SY
wJhBTQb1GNRg0C0GRQxKANcF3Etr2h7grgvxx/zDMUQqJphlcJyQNKdwSkZm
6U18aYKjh0tToIujN/SOSBAcJjCGOPTM1cEM9yMwtja0ayg3z7OZ3NwLKcYi
jU3TIKsbhtPZoM9h39KxcMu4jqe9k5aADJSGKFNIrGjTCEjxPmrhUDBVU3cR
Y/l4WSyX5Y/K2pIStpRyFNSkoDo9FdQv2Ocq481ZxAB9B5vl7IQmASgG6DOD
rmVViRGlsBw3zS0Md0/I4HopCErCBUuxbDHNqvVsSBLExB+5iqS4sWCG1YQE
EfAzN35dE7aPgdkvZHZkwuIJaPYbmT0CfY71LPh4Z04aY4RHIPurA/UIjP+C
zJ6A5nuuLD6A/4ZBWeS7wYiFNgRGbnAOYEkJ+8plpMEgXtSbALVc2e7wT2t6
noo2xgXNdrwGwhLDLV0+RxVt9Qkk/rg4JeT+UpeUHCWeIcmUn1bmvLFcX4za
3LkV2tlawrbwFcG3/CVXtlt+8i4qg3zuCf7/lRWy2kX+JpJC+cn0jY28zT5w
yPAzlbx0u3hq3jy5f9OscWyeM17pa6OkCegMumkjf6Z4o+3ASnQp+qaR/L6V
cUHcbdUrq9ZxakLPhLJaUPzRcB61rGPqlaJC1OZ2B9pUxVaKYm41zx1sNizM
/CiqbaDzjqJhg9FGJuwasDbLFsvRTa2HrRSrzhm37SPO84Lh8YRbvn5RE64Q
Ie8SEWwFX60vYBswf6SU6meEebqGlOAacGF+iaJ3IDsWvsdWdM+sNGGgDlds
2y7mOfCGg831Ken/vK15apjm/Sv1YrUeCp1FR2Br3bJqwpowNCGvp9H0Vqt8
mfYn3fKmkVavSlfqLbDF5edkxzpe9DnL4TJq+egW7Dj3V3mcbuhVOBeLJrO3
M7N+lDhXTqTreiX+iEVKCe0FFcsxSwH3w7Cw9PW2a06Wr1WQtX8CQNwP\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{671, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Solution", " ", "9.16", " ", 
   RowBox[{
    RowBox[{"(", "a", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706032609375*^9, 3.506706032609375*^9}}],

Cell[TextData[{
 "Take the z-transforms of each term  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", "1", "-", 
       RowBox[{"5", " ", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"4", "z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", "1"}], ")"}]}], "+", 
    RowBox[{"4", "Y", 
     RowBox[{"(", "z", ")"}]}]}], " ", "=", " ", "0"}]]],
 " "
}], "Text"],

Cell[TextData[{
 "Solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 " and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z", "2"], "+", "z"}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "2"}], ")"}], "2"]]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Calculate the residue for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], "+", "z"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "2"}], ")"}], "2"]], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}]}]}]]],
 "  at the pole\n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "2"}], "]"}], " ", "=", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", "\[Rule]", "2"}]], " ", 
    RowBox[{
     FractionBox["\[PartialD]", 
      RowBox[{"\[PartialD]", "z"}]], "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "+", "z"}], ")"}], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], "]"}]}]}]]],
 "  \n\t\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "2"}], "]"}], " ", "=", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", "\[Rule]", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "z"}], "+", "1"}], ")"}], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}], " ", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "-", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "+", 
         SuperscriptBox["z", "2"]}], ")"}], " ", 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "2"}]]}]}], ")"}]}]}]]],
 " \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "2"}], "]"}], " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"5", "*", 
      SuperscriptBox["2", 
       RowBox[{"n", "-", "1"}]]}], "+", 
     RowBox[{"3", "  ", 
      RowBox[{"(", 
       RowBox[{"n", "-", "1"}], ")"}], 
      SuperscriptBox["2", 
       RowBox[{"n", "-", "1"}]]}]}], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["2", "n"], " ", "+", " ", 
     RowBox[{"3", "n", " ", 
      SuperscriptBox["2", 
       RowBox[{"n", "-", "1"}]]}]}]}]}]]],
 " "
}], "Text"],

Cell[TextData[{
 "Thus the solution is  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["2", "n"], " ", "+", " ", 
    RowBox[{"3", "n", " ", 
     SuperscriptBox["2", 
      RowBox[{"n", "-", "1"}]]}]}]}]]],
 "  \n\nwhich agrees with the result of example 2."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Solution", " ", "9.16", " ", 
   RowBox[{
    RowBox[{"(", "b", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706034046875*^9, 3.5067060340625*^9}}],

Cell[TextData[{
 "Take the z-transforms of each term  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", "2", "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"4", 
     RowBox[{"(", 
      RowBox[{"z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Y", 
          RowBox[{"(", "z", ")"}]}], "-", "2"}], ")"}]}], ")"}]}], "+", 
    RowBox[{"4", 
     RowBox[{"(", 
      RowBox[{"Y", 
       RowBox[{"(", "z", ")"}]}], ")"}]}]}], " ", "=", " ", 
   FractionBox["4", 
    RowBox[{"z", "-", "3"}]]}]]]
}], "Text"],

Cell[TextData[{
 "Solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 " and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["z", "3"]}], "-", 
     RowBox[{"11", " ", 
      SuperscriptBox["z", "2"]}], "+", 
     RowBox[{"16", " ", "z"}]}], 
    RowBox[{" ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "2"}], ")"}], "2"], 
      RowBox[{"(", 
       RowBox[{"z", "-", "3"}], ")"}]}]}]]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Calculate the residue for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["z", "3"]}], "-", 
       RowBox[{"11", " ", 
        SuperscriptBox["z", "2"]}], "+", 
       RowBox[{"16", " ", "z"}]}], 
      RowBox[{" ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", "2"}], ")"}], "2"], 
        RowBox[{"(", 
         RowBox[{"z", "-", "3"}], ")"}]}]}]], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}]}]}]]],
 " at the poles \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "2"}], "]"}], " ", "=", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", "\[Rule]", "2"}]], " ", 
    RowBox[{"[", 
     RowBox[{
      FractionBox["\[PartialD]", 
       RowBox[{"\[PartialD]", "z"}]], 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["z", "3"]}], "-", 
          RowBox[{"11", " ", 
           SuperscriptBox["z", "2"]}], "+", 
          RowBox[{"16", " ", "z"}]}], 
         RowBox[{" ", 
          RowBox[{"(", 
           RowBox[{"z", "-", "3"}], ")"}]}]], 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}], ")"}]}], "]"}]}]}]]],
 "  \n\t\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "2"}], "]"}], " ", "=", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", "\[Rule]", "2"}]], " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"2", 
        RowBox[{"(", " ", 
         RowBox[{"n", "+", "1"}], ")"}], " ", 
        SuperscriptBox["z", "3"]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"17", " ", "n"}], "+", "12"}], ")"}], " ", 
        SuperscriptBox["z", "2"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"49", " ", "n"}], "+", "17"}], ")"}], " ", "z"}], "-", 
       RowBox[{"48", " ", "n"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "3"}], ")"}], "2"]], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]], " "}]}]}]]],
 "  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "2"}], "]"}], " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "-", 
       RowBox[{"2", " ", "n"}]}], ")"}], 
     SuperscriptBox["2", 
      RowBox[{"n", "-", "1"}]]}], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["2", "n"], "-", 
     RowBox[{
      SuperscriptBox["2", "n"], " ", "n"}]}]}]}]]],
 " \nand\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "3"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", "3"}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["z", "3"]}], "-", 
        RowBox[{"11", " ", 
         SuperscriptBox["z", "2"]}], "+", 
        RowBox[{"16", " ", "z"}]}], 
       RowBox[{" ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", "2"}], ")"}], "2"]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"3", "*", 
      SuperscriptBox["3", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "n"}]]}], " ", "=", " ", 
     SuperscriptBox["3", "n"]}]}]}]]],
 "  "
}], "Text"],

Cell[TextData[{
 "Thus the solution is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["2", "n"], "-", 
    RowBox[{"n", " ", 
     SuperscriptBox["2", "n"]}], " ", "+", " ", 
    SuperscriptBox["3", "n"]}]}]]]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", "9.16", 
   RowBox[{
    RowBox[{"(", "a", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670603575*^9, 3.50670603575*^9}}],

Cell[TextData[{
 "It is worthwhile to point out how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can do the important step using residues."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"z", "+", 
       SuperscriptBox["z", "2"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "2"}], ")"}], "2"]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\) = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "2"}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<          y[n] = Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - \
1\)]\),2]\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<          y[n] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "2"}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482352359375*^9, 3.399482353671875*^9}, {
  3.4000673620625*^9, 3.40006736240625*^9}}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", "0"}]}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["Zsolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", " ", "0"}]}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"Zsolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"x", "[", "n", "]"}], ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "4"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Zsolution", "[", 
     RowBox[{"2", ",", "4", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "1", ",", "5"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948235584375*^9, 3.399482357140625*^9}, 
   3.400347153203125*^9}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["ResidueSolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"ResidueSolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "4"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ResidueSolution", "[", 
     RowBox[{"2", ",", "4", ",", "1", ",", "5"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"s", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39948235946875*^9, 3.400086618890625*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      SuperscriptBox["2", "n"], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["2", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "n"}]], " ", "n"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "6"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y1", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "670"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "600", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "670"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "600", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y1", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994823614375*^9, 3.3994823789375*^9}, {
  3.400067185765625*^9, 3.40006718596875*^9}, {3.4000848301875*^9, 
  3.400084890515625*^9}, {3.400094549328125*^9, 3.40009455034375*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", "9.16", " ", 
   RowBox[{
    RowBox[{"(", "b", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706038046875*^9, 3.5067060380625*^9}}],

Cell[TextData[{
 "It is worthwhile to point out how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can do the important step using residues."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"16", " ", "z"}], "-", 
       RowBox[{"11", " ", 
        SuperscriptBox["z", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["z", "3"]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", "z"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"4", "-", 
         RowBox[{"4", " ", "z"}], "+", 
         SuperscriptBox["z", "2"]}], ")"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\) = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\) = \>\"", ",", 
      FractionBox[
       RowBox[{"Numerator", "[", 
        RowBox[{"Y", "[", "z", "]"}], "]"}], 
       RowBox[{"Factor", "[", 
        RowBox[{"Denominator", "[", 
         RowBox[{"Y", "[", "z", "]"}], "]"}], "]"}]], ",", 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "2"}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),3] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "3"}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<          y[n] = Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - \
1\)]\),2] + Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),3]\>\"", " ", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<          y[n] = \>\"", ",", 
      RowBox[{
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "2"}], "}"}]}], "]"}], "+", 
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "3"}], "}"}]}], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994823875*^9, 3.399482388390625*^9}, {
  3.400067371046875*^9, 3.400067371515625*^9}}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    SuperscriptBox["3", "n"]}]}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"2", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "3"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["Zsolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{"x", "[", "n", "]"}]}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"Zsolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"x", "[", "n", "]"}], ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "4"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   SuperscriptBox["3", "n"]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     SuperscriptBox["3", "n"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Zsolution", "[", 
     RowBox[{"2", ",", "4", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "2", ",", "3"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39948239084375*^9, 3.400084902421875*^9, 
  3.400347164109375*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      SuperscriptBox["2", "n"], "+", 
      SuperscriptBox["3", "n"], "-", 
      RowBox[{
       SuperscriptBox["2", "n"], " ", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "6"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y1", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "430"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "600", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "430"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "600", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y1", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994823924375*^9, 3.39948240396875*^9}, {
  3.4000671909375*^9, 3.40006719115625*^9}, {3.4000849065625*^9, 
  3.400084945578125*^9}, {3.40009459459375*^9, 3.40009459509375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.17 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transform methods to solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"5", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ".  \n\n",
 StyleBox["9.17 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transform methods to solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"5", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "n"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "0"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztW81u00AQdpNG/AoJNW4bEFJOBYSaXtrwAEBLD4gQHiCEqiKRQKC2AoR4
As4gwQlxgAuIEy8AjwFvAgezO7ZnY3vsXa/X8VaJ1G4ms56Zb2dmd8dr587w
aLT/ZHg03hu2dw6Gz0bjvcP29tMDxqovOE7to+M479oOpz1GBo3H/vzmE284
2yLGW6Drjg/V8/95e9rERb94y1neTf/KcZqmK0THT942OOOGndJ//OGx3l3d
wf/27bDe2xInZ0tvhnidGqdqnFpEqlFIdxe+N6LSHmS3b41ZmuxDdlQhxfuC
Pnqg4ubrBpEA6zOGeSBJknO8WUS3luMOdTjLNoBwiVTLTrpEvO9hKKi8Vchg
avJOpnY/yxn52HLXKSG6G/o3HFXMWE5swkfAuiqxvot5rOOCXKB0nNOL9VeD
6A2m6euJNAUn182lqVDaxSm3gvOhj9RZyTSkdPdoL2xFDSUv6OLILxBaM7aL
VCR9grcpgyFwrqIbzmgYv59mvB7V3ZUB0jGeEoMW2u8SQtII6SARmdZC9VvR
wQMghKZl5THqfq+LUYRFW08vmTreBw09QroVpUD3D4nGy8RoVqLIlPRc4s0p
zg5UJKkWp8DUd06dkGhcI/AIipr11AymeLLVYS06/phvL5ZoWUQDvuok9+Qm
NReU7eCpG6SBig7qJ9vqFli9dOpx9VpTp8ZrmPOVyerXtuiVnrMWzd8mb4ye
FEBb4g3p1O0Da+ZGrWM//wmApbNiLjgXzBSEfQsmk8ETgISBWD+YsuYsxsOV
wgQiUc64ma6VLSKi2NE+mC22RjYLBy41QlXWTG7h6IPqxF5auNaqes9rlur2
+Y5bhmDwLI71PtSQDh4Gst7hMZMuNu5jFOCKBEuajdUuMdXcSqUcdxtc0cWD
N81njVMJyxROksxnsqXHXxVVhBYcFs5PweaCsyAIe1Udp4KBDfglSm/4utl1
8AJXbOeAJ3Ol7lcUuhe0+nUfIKNvAStrbYkqxEd/Od9GoW/uKMivCN61Ynir
KI1EXnS0wa/GeFNEHuN1MLe3c46hhX7QOa1JxQes54TGjoZGS1exETrdRQr6
z0sEH2HGLSElVCwjtYOU7JXdAf84GUSMqw2pJkG5QbT5OhPy9lViQ+FuZlJi
VIJH3fhuaLjaVcSwVMgylR3rRKxS0SjFj7IyIHR/1Z+PrPebdVNotu7EDd0T
q9+ECy+aPcHONkjWRUVM/wtHLX3Vx0X/qO5mf/25xRiyXz+UcWViZMCGRvmH
H87Cf6gLZZQ=\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{671, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Solution", " ", "9.17", " ", 
   RowBox[{
    RowBox[{"(", "a", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670604084375*^9, 3.50670604084375*^9}}],

Cell[TextData[{
 "Take the z-transforms of each term  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", "1", "-", 
       RowBox[{"5", " ", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"4", "z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", "1"}], ")"}]}], "+", 
    RowBox[{"5", "Y", 
     RowBox[{"(", "z", ")"}]}]}], " ", "=", " ", "0"}]]]
}], "Text"],

Cell[TextData[{
 "Solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 " and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["z", "2"], "+", "z"}], 
     RowBox[{
      SuperscriptBox["z", "2"], "-", 
      RowBox[{"4", " ", "z"}], "+", "5"}]], " ", "=", " ", 
    FractionBox[
     RowBox[{
      SuperscriptBox["z", "2"], "+", "z"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}]}]]}]}]]]
}], "Text"],

Cell[TextData[{
 "Calculate the residue for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], "+", "z"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}]}]], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}]}]}]]],
 "  at the poles \n\t\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     RowBox[{"2", "+", "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"2", "+", "\[ImaginaryI]"}]}]], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}], 
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "2"], "+", "z"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", "\[Rule]", 
        RowBox[{"2", "+", "\[ImaginaryI]"}]}]], " ", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["z", "2"], "+", "z"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}]], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"5", "-", 
         RowBox[{"5", " ", "\[ImaginaryI]"}]}], "2"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"n", "-", "1"}]]}], " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", 
          RowBox[{"3", " ", "\[ImaginaryI]"}]}], "2"], ")"}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]}]}]]],
 "  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     RowBox[{"2", "-", "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"2", "-", "\[ImaginaryI]"}]}]], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}], 
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "2"], "+", "z"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", "\[Rule]", 
        RowBox[{"2", "-", "\[ImaginaryI]"}]}]], " ", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["z", "2"], "+", "z"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}]], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"5", "+", 
         RowBox[{"5", " ", "\[ImaginaryI]"}]}], "2"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"n", "-", "1"}]]}], " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "+", 
          RowBox[{"3", " ", "\[ImaginaryI]"}]}], "2"], ")"}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]}]}]]],
 "  \n"
}], "Text"],

Cell[TextData[{
 "Therefore, the solution is  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"2", "+", "\[ImaginaryI]"}]}], "]"}], " ", "+", 
    " \[InvisibleSpace]", 
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"2", "-", "\[ImaginaryI]"}]}], "]"}]}]}]]],
 "\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " \[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"1", "-", 
       RowBox[{"3", " ", "\[ImaginaryI]"}]}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}], " ", "+", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"1", "+", 
       RowBox[{"3", " ", "\[ImaginaryI]"}]}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]]],
 " \n\nwhich agrees with the result of example 3. \n\nRemark.  Observe that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     RowBox[{"2", "-", "\[ImaginaryI]"}]}], "]"}], " ", "=", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      OverscriptBox[
       RowBox[{"2", "+", "\[ImaginaryI]"}], "_"]}], "]"}], " ", "=", " ", 
    OverscriptBox[
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       RowBox[{
        StyleBox["2",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "+", "\[ImaginaryI]"}]}], "]"}], "_"]}]}]]],
 "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Solution", " ", "9.17", " ", 
   RowBox[{
    RowBox[{"(", "b", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706042671875*^9, 3.506706042671875*^9}}],

Cell[TextData[{
 "Take the z-transforms of each term  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], " ", "-", " ", "1", " ", "-", " ", 
       RowBox[{"0", " ", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"4", "z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], " ", "-", " ", "1"}], ")"}]}], "+", 
    RowBox[{"5", "Y", 
     RowBox[{"(", "z", ")"}]}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["z", 
     RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}]], "+", 
    FractionBox["z", 
     RowBox[{"z", "-", "1", "+", "\[ImaginaryI]"}]]}]}]]]
}], "Text"],

Cell[TextData[{
 "Solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 " and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z", "4"], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["z", "3"]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["z", "2"]}], "-", 
     RowBox[{"10", " ", "z"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "-", "1", "+", "\[ImaginaryI]"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}]}]]}]]]
}], "Text"],

Cell[TextData[{
 "Calculate the residues for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "4"], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["z", "3"]}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["z", "2"]}], "-", 
       RowBox[{"10", " ", "z"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "1", "+", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}]}]], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}]}]}]]],
 "  at the poles \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     RowBox[{"1", "+", "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"1", "+", "\[ImaginaryI]"}]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "4"], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["z", "3"]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["z", "2"]}], "-", 
        RowBox[{"10", " ", "z"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "1", "+", "\[ImaginaryI]"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"3", " ", "\[ImaginaryI]"}]}], "5"], ")"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"n", "-", "1"}]]}], " ", "=", " ", 
     RowBox[{
      FractionBox["1", "10"], 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"], " "}]}]}]}]]],
 "\t\t\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     RowBox[{"1", "-", "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"1", "+", "\[ImaginaryI]"}]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "4"], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["z", "3"]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["z", "2"]}], "-", 
        RowBox[{"10", " ", "z"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "1"}], "-", 
         RowBox[{"3", " ", "\[ImaginaryI]"}]}], "5"], ")"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"n", "-", "1"}]]}], " ", "=", " ", 
     RowBox[{
      FractionBox["1", "10"], 
      RowBox[{"(", 
       RowBox[{"2", "-", 
        RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]}]]],
 "\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     RowBox[{"2", "+", "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"2", "+", "\[ImaginaryI]"}]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "4"], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["z", "3"]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["z", "2"]}], "-", 
        RowBox[{"10", " ", "z"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "1", "+", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], ")"}], "  ", 
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{"2", "+", 
         RowBox[{"11", " ", "\[ImaginaryI]"}]}], "10"], ")"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"n", "-", "1"}]]}], " ", "=", 
     RowBox[{
      FractionBox["1", "10"], 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]}]]],
 "\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     RowBox[{"2", "-", "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"2", "-", "\[ImaginaryI]"}]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "4"], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["z", "3"]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["z", "2"]}], "-", 
        RowBox[{"10", " ", "z"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "1", "+", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], ")"}], "  ", 
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{"2", "-", 
         RowBox[{"11", " ", "\[ImaginaryI]"}]}], "10"], ")"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"n", "-", "1"}]]}], " ", "=", " ", 
     RowBox[{
      FractionBox["1", "10"], 
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]}]]]
}], "Text"],

Cell[TextData[{
 "Therefore, the solution is  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"1", "+", "\[ImaginaryI]"}]}], "]"}], "+", "\[InvisibleSpace]", 
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"1", "-", "\[ImaginaryI]"}]}], "]"}], "+", 
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"2", "+", "\[ImaginaryI]"}]}], "]"}], "+", 
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"2", "-", "\[ImaginaryI]"}]}], "]"}]}]}]]],
 "\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "10"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "+", 
         RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"]}], " ", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "-", 
         RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "n"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", "-", 
         RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"]}]}], ")"}]}]}]]],
 " "
}], "Text"],

Cell[TextData[{
 "Remark.  Observe that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     RowBox[{"1", "-", "\[ImaginaryI]"}]}], "]"}], " ", "=", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      OverscriptBox[
       RowBox[{"1", "+", "\[ImaginaryI]"}], "_"]}], "]"}], " ", "=", " ", 
    OverscriptBox[
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       RowBox[{"1", "+", "\[ImaginaryI]"}]}], "]"}], "_"]}]}]]],
 " and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     RowBox[{"2", "-", "\[ImaginaryI]"}]}], "]"}], " ", "=", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      OverscriptBox[
       RowBox[{"2", "+", "\[ImaginaryI]"}], "_"]}], "]"}], " ", "=", " ", 
    OverscriptBox[
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       RowBox[{
        StyleBox["2",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "+", "\[ImaginaryI]"}]}], "]"}], "_"]}]}]]],
 ".\n"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", "9.17", " ", 
   RowBox[{
    RowBox[{"(", "a", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670604384375*^9, 3.50670604384375*^9}}],

Cell[TextData[{
 "It is worthwhile to point out how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can do the important step using residues."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"z", "+", 
       SuperscriptBox["z", "2"]}], 
      RowBox[{"5", "-", 
       RowBox[{"4", " ", "z"}], "+", 
       SuperscriptBox["z", "2"]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\) = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", 
      SuperscriptBox[
       RowBox[{"z", " "}], 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2-\[ImaginaryI]] = \
\>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"2", "-", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2+\[ImaginaryI]] = \
\>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"2", "+", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<          y[n] = Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - \
1\)]\),2-\[ImaginaryI]] + Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2+\
\[ImaginaryI]}]\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<          y[n] = \>\"", ",", 
      RowBox[{
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"2", "-", "\[ImaginaryI]"}]}], "}"}]}], "]"}], "+", 
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"2", "+", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}]}], " ", 
     "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482420078125*^9, 3.399482421234375*^9}, {
  3.400067380015625*^9, 3.40006738034375*^9}}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"5", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", "0"}]}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["Zsolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", " ", "0"}]}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"Zsolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"x", "[", "n", "]"}], ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "5"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Zsolution", "[", 
     RowBox[{"2", ",", "5", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "1", ",", "5"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482423453125*^9, 3.3994824256875*^9}, 
   3.400347173140625*^9}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"5", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["ResidueSolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"ResidueSolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "5"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ResidueSolution", "[", 
     RowBox[{"2", ",", "5", ",", "1", ",", "5"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"s", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482427890625*^9, 3.39948242984375*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to compare  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "+", 
       FractionBox[
        RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "-", 
       FractionBox[
        RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["5", 
      RowBox[{"n", "/", "2"}]], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"n", " ", 
       RowBox[{"ArcTan", "[", 
        FractionBox["1", "2"], "]"}]}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["5", 
      RowBox[{"n", "/", "2"}]], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"n", " ", 
       RowBox[{"ArcTan", "[", 
        FractionBox["1", "2"], "]"}]}], "]"}]}]}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "2"], "+", 
         FractionBox[
          RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "2"], "-", 
         FractionBox[
          RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y2", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{
       SuperscriptBox["5", 
        RowBox[{"n", "/", "2"}]], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"n", " ", 
         RowBox[{"ArcTan", "[", 
          FractionBox["1", "2"], "]"}]}], "]"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["5", 
        RowBox[{"n", "/", "2"}]], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"n", " ", 
         RowBox[{"ArcTan", "[", 
          FractionBox["1", "2"], "]"}]}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "10"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y2", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Y2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y2", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y2"}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y1", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g2", ",", "g3"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y2", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y2", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Simplify", "[", 
           RowBox[{"y2", "[", "n", "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482432796875*^9, 3.399482456484375*^9}, {
  3.4000671961875*^9, 3.400067196390625*^9}, {3.4000849784375*^9, 
  3.400085054734375*^9}, {3.40009463021875*^9, 3.400094630796875*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", "  ", "9.17", " ", 
   RowBox[{
    RowBox[{"(", "b", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706044984375*^9, 3.506706044984375*^9}}],

Cell[TextData[{
 "It is worthwhile to point out how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can do the important step using residues."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "10"}], " ", "z"}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["z", "2"]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["z", "3"]}], "+", 
       SuperscriptBox["z", "4"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", "\[ImaginaryI]"}], ")"}], "+", "z"}], 
        ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ")"}], "+", "z"}], 
        ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"5", "-", 
         RowBox[{"4", " ", "z"}], "+", 
         SuperscriptBox["z", "2"]}], ")"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<            Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<          Y[z]z  = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<          Y[z]z  = \>\"", ",", 
      FractionBox[
       RowBox[{"Numerator", "[", 
        RowBox[{"Y", "[", "z", "]"}], "]"}], 
       RowBox[{"Factor", "[", 
        RowBox[{"Denominator", "[", 
         RowBox[{"Y", "[", "z", "]"}], "]"}], "]"}]], ",", 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),1-\[ImaginaryI]] = \
\>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"1", "-", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),1+\[ImaginaryI]] = \
\>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"1", "+", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2-\[ImaginaryI]] = \
\>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"2", "-", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2+\[ImaginaryI]] = \
\>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"2", "+", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),1-\
\[ImaginaryI]] + Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),1+\
\[ImaginaryI]]+Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2-\
\[ImaginaryI]] + Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2+\
\[ImaginaryI]]\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"1", "-", "\[ImaginaryI]"}]}], "}"}]}], "]"}], "+", 
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"1", "+", "\[ImaginaryI]"}]}], "}"}]}], "]"}], "+", 
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"2", "-", "\[ImaginaryI]"}]}], "}"}]}], "]"}], "+", 
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"2", "+", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}]}], " ", 
     "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482466734375*^9, 3.399482469796875*^9}, {
  3.400067423671875*^9, 3.4000674243125*^9}}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"5", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "n"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "0"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["Zsolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{"x", "[", "n", "]"}]}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"Zsolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"x", "[", "n", "]"}], ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "5"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "n"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "n"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Zsolution", "[", 
     RowBox[{"2", ",", "5", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "1", ",", "0"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39948247375*^9, 3.40008506190625*^9, 3.40034718190625*^9}
  ],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      FractionBox["1", "10"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "-", 
           RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "n"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "+", 
           RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "-", 
           RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "+", 
           RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}], ")"}]}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "9"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y1", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "150"}], ",", "530"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "3"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "100"}], ",", "600", ",", "100"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "150"}], ",", "530"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "3"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "100"}], ",", "600", ",", "100"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y1", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994824754375*^9, 3.399482479546875*^9}, {
  3.4000672020625*^9, 3.400067202578125*^9}, {3.400085064921875*^9, 
  3.400085121328125*^9}, {3.400094663734375*^9, 3.40009466425*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.18.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "3"}], "]"}], "+", 
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "+", 
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "1"}], "]"}], "+", 
    RowBox[{"y", "[", "n", "]"}]}], "=", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "0", "]"}], " ", "=", " ", "2"}], ",", " ", 
   RowBox[{
    RowBox[{"y", "[", "1", "]"}], " ", "=", " ", 
    RowBox[{"-", "2"}]}], ",", " ", 
   RowBox[{
    RowBox[{"and", "  ", 
     RowBox[{"y", "[", "2", "]"}]}], " ", "=", " ", "0"}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztWc1SwjAQDv0ZAWf4p6jjAdCzPy+hJx+iwzgDB0YH0IuPoT5vZZOStGUT
k5LiwXQg2fm+zW52kzZN8xRv5s/LeLOYxePHVfw6X8zW44eX1Rbya4TUPgkh
32MCcrIV0yLZ/pIvKACxL3/QyifMWcL+UEaMX0MVABsgmg0ofejqHSLdK9lG
xkHBbIhgdShDaHiDSLdKts5cbRCzAesPITYcLJXJ8quJap3GkTVb3XDRHHpg
FBuk7Mz5bWY53vGOd7zjHW+LH0JJl8IRSJQccukMJLp29UEKQfI41uVYulLv
Lsp2OOtzey3RIsi1yFkreAi4DdETRTAF7BzBBrTcewGIcJhph/m0pn33EOsd
hT7WQ+y9o23RJ6bfQjAfD78nz3ckG4NQxFptlvMYptdD3O16aJo1U/22tI8m
WR4ZzuDCnTu0kFjsRbxbKhl7A0GV+rJEZe540wgUTwjJnBSqcGFpP8ITouxc
h6trdE+YPi32wjafyhEfUzE/xboz4tiASwGXekos5FInr+fzxGjYU6wtR1mI
6b6xyaVrBLvSxLC2U7l7mnGxSQ65egGbaGLStoS8Q3WZDhrwO2mKYBNNDGt7
AdKJWcxN2dBo6Onaq8Sv/qw6ld2YGnq69mz7VYT412/Qjne84x3veMf/d16c
faXffJIyBydZY9hGtOTpD9v7oWda3uFm32iFfGc4xKjkpMpCcvVPpaiMnIOS
2g9XDLUS\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Solution", " ", 
   RowBox[{"9.18", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706048140625*^9, 3.506706048140625*^9}}],

Cell[TextData[{
 "Take the z-transforms of each term  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", "2", "+", 
       RowBox[{"2", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}], "-", 
       RowBox[{"0", 
        SuperscriptBox["z", 
         RowBox[{"-", "2"}]]}]}], ")"}]}], " ", "+", 
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", "2", "+", 
       RowBox[{"2", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "+", 
    RowBox[{"z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", "2"}], ")"}]}], "+", 
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}]}]}], "=", " ", "0"}]]]
}], "Text"],

Cell[TextData[{
 "Solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 " and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox["z", "3"]}], 
     RowBox[{
      SuperscriptBox["z", "3"], "+", 
      SuperscriptBox["z", "2"], "+", "z", "+", "1"}]], " ", "=", " ", 
    FractionBox[
     RowBox[{"2", 
      SuperscriptBox["z", "3"]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"z", "+", "\[ImaginaryI]"}], ")"}]}]]}]}]]]
}], "Text"],

Cell[TextData[{
 "Calculate the residues for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"2", 
       SuperscriptBox["z", "3"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "+", "\[ImaginaryI]"}], ")"}]}]], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}]}]}]]],
 "  at the poles \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     RowBox[{"-", "1"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"-", "1"}]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{"2", 
        SuperscriptBox["z", "3"]}], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], "+", "1"}], ")"}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"]}]}]]],
 "  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", " ", "\[ImaginaryI]"}], " ", "]"}], " ",
    "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", "\[ImaginaryI]"}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{"2", 
        SuperscriptBox["z", "3"]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"z", "+", "\[ImaginaryI]"}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "+", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
     SuperscriptBox["\[ImaginaryI]", "n"]}]}]}]]],
 "  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     RowBox[{"-", "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"-", "\[ImaginaryI]"}]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{"2", 
        SuperscriptBox["z", "3"]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "-", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]]],
 "  "
}], "Text"],

Cell[TextData[{
 "Thus the solution is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "+", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
     SuperscriptBox["\[ImaginaryI]", "n"]}], " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "-", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]]],
 "  which can be rewritten as \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], "+", " ", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ImaginaryI]", "n"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "\[ImaginaryI]"}], ")"}], "n"]}], ")"}]}], "  ", "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "\[ImaginaryI]"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ImaginaryI]", "n"], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "\[ImaginaryI]"}], ")"}], "n"]}], ")"}]}]}]}]]],
 "\n\t\t\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "n", " ", "\[Pi]"}]], "+", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "n", " ", "\[Pi]"}], "2"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "n", " ", "\[Pi]"}], "2"]]}], 
      ")"}]}], "  ", "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "\[ImaginaryI]"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "n", " ", "\[Pi]"}], "2"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "n", " ", "\[Pi]"}], "2"]]}], 
      ")"}], " "}]}]}]]],
 "\n\t\t\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"\[Pi]", " ", "n"}], ")"}]}], "+", 
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "2"], "n"}], ")"}]}], "-", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "2"], "n"}], ")"}]}]}]}]]],
 "   "
}], "Text"],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  In the next section we will see that \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "4"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "[", "n", "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "3"}], "]"}]}], ")"}]}]}]]],
 "  \n\nis a moving average filter which filters out the signals ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"\[Pi]", " ", "n"}], ")"}]}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", 
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "2"], "n"}], ")"}]}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", 
    RowBox[{"and", "  ", "sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "2"], "n"}], ")"}]}]}]}]]]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"9.18", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706050125*^9, 3.506706050140625*^9}}],

Cell[TextData[{
 "Take the z-transforms of each term and then solve for  ",
 Cell[BoxData[
  RowBox[{"Y", "[", "z", "]"}]]],
 ".  Substitute ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "0"], " ", "=", " ", "2"}], ",", "  ", 
   RowBox[{
    SubscriptBox["y", "1"], " ", "=", " ", 
    RowBox[{"-", "2"}]}], ",", "  ", 
   RowBox[{
    RowBox[{"and", "  ", 
     SubscriptBox["y", "2"]}], " ", "=", " ", "0"}]}]]],
 "  into \n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", 
       SubscriptBox["y", "0"], " ", "-", " ", 
       RowBox[{
        SubscriptBox["y", "1"], 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}], "-", " ", 
       RowBox[{
        SubscriptBox["y", "2"], 
        SuperscriptBox["z", 
         RowBox[{"-", "2"}]]}]}], ")"}]}], " ", "+", 
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", 
       SubscriptBox["y", "0"], " ", "-", " ", 
       RowBox[{
        SubscriptBox["y", "1"], 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "+", 
    RowBox[{"z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", 
       SubscriptBox["y", "0"]}], ")"}]}], "+", 
    RowBox[{"Y", "[", "z", "]"}]}], "=", " ", "0"}]]],
 ",  and get\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", "2", " ", "+", 
       RowBox[{"2", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}], "-", " ", 
       RowBox[{"0", 
        SuperscriptBox["z", 
         RowBox[{"-", "2"}]]}]}], ")"}]}], " ", "+", 
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", "2", " ", "+", 
       RowBox[{"2", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "+", 
    RowBox[{"z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", "2"}], ")"}]}], "+", 
    RowBox[{"Y", "[", "z", "]"}]}], "\[Equal]", " ", "0"}]]]
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqn", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", "2", " ", "+", 
          RowBox[{"2", 
           SuperscriptBox["z", 
            RowBox[{"-", "1"}]]}], "-", " ", 
          RowBox[{"0", 
           SuperscriptBox["z", 
            RowBox[{"-", "2"}]]}]}], ")"}]}], " ", "+", 
       RowBox[{
        SuperscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", "2", " ", "+", 
          RowBox[{"2", 
           SuperscriptBox["z", 
            RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "+", 
       RowBox[{"z", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", "2"}], ")"}]}], "+", 
       RowBox[{"Y", "[", "z", "]"}]}], "\[Equal]", " ", "0"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "eqn", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{"eqn", ",", 
       RowBox[{"Y", "[", "z", "]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], "=", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{"InverseZTransform", "[", 
      RowBox[{
       RowBox[{"Y", "[", "z", "]"}], ",", "z", ",", "n"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve for Y[z] and get\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Take the inverse z-transformation\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<y[n] = \!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)[Y[z]] \
= \!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)[\>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", "\"\<]\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"ComplexExpand", "[", 
        RowBox[{"y", "[", "n", "]"}], "]"}], ",", 
       RowBox[{"n", "\[Element]", "Integers"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948248953125*^9, 3.39948249078125*^9}}],

Cell[TextData[{
 "Compare this solution with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"n", " ", "\[Pi]"}], "]"}], "+", 
    RowBox[{"Cos", "[", 
     FractionBox[
      RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}], "-", 
    RowBox[{"Sin", "[", 
     FractionBox[
      RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}]}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], "+", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}], "-", 
      RowBox[{"Sin", "[", 
       FractionBox[
        RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y2", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"n", " ", "\[Pi]"}], "]"}], "+", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}], "-", 
      RowBox[{"Sin", "[", 
       FractionBox[
        RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "21"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y2", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Y2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y2", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y2"}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g2", ",", "g3"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y2", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482493828125*^9, 3.399482498515625*^9}, {
  3.399482816765625*^9, 3.399482819546875*^9}, {3.400067208796875*^9, 
  3.40006720903125*^9}, {3.400085168859375*^9, 3.400085245578125*^9}, {
  3.40009469390625*^9, 3.4000946944375*^9}, {3.400139562125*^9, 
  3.400139584375*^9}}],

Cell[TextData[{
 "Use the fact that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["z", "3"], "+", 
    SuperscriptBox["z", "2"], "+", "z", "+", "1"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "+", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z", "2"], "+", "1"}], ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "+", "1"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "+", "\[ImaginaryI]"}], ")"}]}]}]}]]],
 " and write  ",
 Cell[BoxData[
  RowBox[{"Y", "[", "z", "]"}]]],
 " in the form"
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["z", "3"]}], 
      RowBox[{"1", "+", "z", "+", 
       SuperscriptBox["z", "2"], "+", 
       SuperscriptBox["z", "3"]}]]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"2", 
       SuperscriptBox["z", "3"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "+", "\[ImaginaryI]"}], ")"}]}]]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"Y", "[", "z", "]"}], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482505390625*^9, 3.39948250646875*^9}, {
  3.400067440703125*^9, 3.40006744134375*^9}}],

Cell[TextData[{
 "The solution y[n]  can be computed using residues\n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Y", "[", "z", "]"}], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{"-", "1"}]}], "}"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Limit", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", 
         SuperscriptBox["z", "3"]}], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "+", "1"}], ")"}]], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}], ",", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"-", "1"}]}]}], "]"}], " ", "=", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"]}]}]]],
 "  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Y", "[", "z", "]"}], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "\[ImaginaryI]"}], "}"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Limit", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", 
         SuperscriptBox["z", "3"]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"z", "+", "\[ImaginaryI]"}], ")"}]}]], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}], ",", 
      RowBox[{"z", "\[Rule]", "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "+", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
     SuperscriptBox["\[ImaginaryI]", "n"]}]}]}]]],
 "  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Y", "[", "z", "]"}], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{"-", "\[ImaginaryI]"}]}], "}"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Limit", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", 
         SuperscriptBox["z", "3"]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}]}]], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}], ",", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"-", "\[ImaginaryI]"}]}]}], "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "-", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]]],
 "  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "y"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}], "+", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "\[ImaginaryI]"}], "}"}]}], "]"}], "+", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"-", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),-1] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),\[ImaginaryI]] = \
\>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "\[ImaginaryI]"}], "}"}]}], "]"}]}], "  ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),-\[ImaginaryI]] = \
\>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"-", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}], "  ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),-1] + \
Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),\[ImaginaryI]] + \
Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),-\[ImaginaryI]]\>\"", " ", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948250984375*^9, 3.39948251171875*^9}, {
  3.400347195375*^9, 3.40034721390625*^9}}],

Cell[TextData[{
 "The solution is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "+", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
     SuperscriptBox["\[ImaginaryI]", "n"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "-", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]]],
 ".  Which can be written as ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"n", " ", "\[Pi]"}], "]"}], "+", 
    RowBox[{"Cos", "[", 
     FractionBox[
      RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}], "-", 
    RowBox[{"Sin", "[", 
     FractionBox[
      RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}]}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "2"], "-", 
         FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "\[ImaginaryI]"}], ")"}], "n"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "2"], "+", 
         FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
       SuperscriptBox["\[ImaginaryI]", "n"]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y2", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"n", " ", "\[Pi]"}], "]"}], "+", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}], "-", 
      RowBox[{"Sin", "[", 
       FractionBox[
        RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "21"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y1", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Y2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y2", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y2"}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g2", ",", "g3"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y2", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482513984375*^9, 3.39948252303125*^9}, {
   3.400067215421875*^9, 3.400067215640625*^9}, {3.400085274546875*^9, 
   3.400085364640625*^9}, {3.40009471009375*^9, 3.40009471053125*^9}, 
   3.400094855140625*^9, {3.4001396036875*^9, 3.400139608703125*^9}}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can show that the two formulas compute the same values."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"FullSimplify", "[", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], " ", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "2"], "+", 
         FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
       SuperscriptBox["\[ImaginaryI]", "n"]}], " ", "+", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "2"], "-", 
         FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "\[ImaginaryI]"}], ")"}], "n"]}]}], ",", " ", 
     RowBox[{"n", "\[Element]", "Integers"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"FullSimplify", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"n", " ", "\[Pi]"}], "]"}], "+", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}], "-", 
      RowBox[{"Sin", "[", 
       FractionBox[
        RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}]}], ",", " ", 
     RowBox[{"n", "\[Element]", "Integers"}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482527796875*^9, 3.399482529171875*^9}, {
  3.40013964321875*^9, 3.400139647671875*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.19.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"y", "[", "n", "]"}]}], "=", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{"2", "  ", "and", "  ", 
     RowBox[{"y", "[", "1", "]"}]}], "=", 
    SqrtBox["2"]}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztWM1Og0AQXlqI0dSjUuiFm17VuwdN9GIfgjSmkGg0FX2R6tH4BvowxudB
hq2zKc4Qlv4sh03a5ct8M8P8MTQdx1lyex9n6SSOrmfxY5JOnqKrh1kh6jtC
OHMhxFskAOcFXBx58clf4QBJe/xSXvpCOs3lF85Rd/kEThDlX7zSFE4PBJ/b
UGoUk+nCWX41foxNPkNU8xzd4OCcIJqbUteM3XSpLW95y7fnD+GEnSCRC2gI
qAcoBFQa+Cgboiwk/FF66h49ZPf4kIZcmKSeuyRjojqgVX1aHLABaKh6y22Q
6rIAFf0dvVL4hIwNw+OCZCqikbrqr7/ZhCmZRkpqmlXEIy5NpcdNy8bSZMrM
zGjVAyWrn6Cmd6oVr6UaamcEBAqJ/lVmr7K1AmRVT11ENZvH9DI+/Qs8Twm0
zxuqX3ZTAg2k4R1czsFswf9HpdfdFnNbWjedv214Gegl4WOVqc2i9WCt0UtN
x02PquUtb3nLd5VXS/QDkfpD45g3VK+Qd0Tq9XrUJcPWOZpujuWb88/Y0B9E
l5LKcEi+EV2sQtXcy3QZhPMLN3jztw==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Solution", " ", 
   RowBox[{"9.19", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706052609375*^9, 3.506706052609375*^9}}],

Cell[TextData[{
 "Take the z-transforms of each term and get\n\n",
 Cell[BoxData[
  RowBox[{"\t\t", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["z", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Y", 
         RowBox[{"(", "z", ")"}]}], "-", " ", "2", " ", "-", " ", 
        RowBox[{
         SqrtBox["2"], 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "-", 
     RowBox[{
      SqrtBox["2"], "z", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Y", 
         RowBox[{"(", "z", ")"}]}], " ", "-", " ", "2"}], ")"}]}], "+", 
     RowBox[{"Y", 
      RowBox[{"(", "z", ")"}]}]}], " ", "=", " ", "0"}]}]]]
}], "Text"],

Cell[TextData[{
 "Solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 "  and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["z", "2"]}], "-", 
      RowBox[{
       SqrtBox["2"], " ", "z"}]}], 
     RowBox[{
      SuperscriptBox["z", "2"], "-", 
      RowBox[{
       SqrtBox["2"], " ", "z"}], "+", "1"}]], " ", "=", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["z", "2"]}], "-", 
      RowBox[{
       SqrtBox["2"], " ", "z"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", 
        FractionBox[
         RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
         SqrtBox["2"]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"z", "-", 
        FractionBox[
         RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
         SqrtBox["2"]]}], ")"}]}]]}]}]]],
 " "
}], "Text"],

Cell[TextData[{
 "Calculate the residues for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}], 
    SuperscriptBox["z", 
     RowBox[{"n", "-", "1"}]]}]}]]],
 "  at the poles  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
   SqrtBox["2"]]]],
 "  and  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"1", " ", "-", "\[ImaginaryI]"}], 
   SqrtBox["2"]]]],
 "\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     FractionBox[
      RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
      SqrtBox["2"]]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", 
       FractionBox[
        RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
        SqrtBox["2"]]}]], 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["z", "2"]}], "-", 
        RowBox[{
         SqrtBox["2"], " ", "z"}]}], 
       RowBox[{" ", 
        RowBox[{"(", 
         RowBox[{"z", "-", 
          FractionBox[
           RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], "=", " ", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"1", "+", "\[ImaginaryI]"}], 
       SqrtBox["2"]], 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "+", "\[ImaginaryI]"}], 
         SqrtBox["2"]], ")"}], 
       RowBox[{"n", "-", "1"}]]}], " ", "=", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{"1", "+", "\[ImaginaryI]"}], 
        SqrtBox["2"]], ")"}], "n"]}]}]}]]],
 " \n\nSimilarly,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     FractionBox[
      RowBox[{"1", " ", "-", "\[ImaginaryI]"}], 
      SqrtBox["2"]]}], "]"}], " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{"1", "-", "\[ImaginaryI]"}], 
      SqrtBox["2"]], ")"}], "n"]}]]],
 ".  Therefore, the solution is \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"1", "+", "\[ImaginaryI]"}], 
       SqrtBox["2"]], ")"}], "n"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"1", "-", "\[ImaginaryI]"}], 
       SqrtBox["2"]], ")"}], "n"]}]}]]],
 ", \nwhich can be written as \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"\[Pi]", "/", "4"}]}]], ")"}], "n"], " ", "+", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"\[Pi]", "/", "4"}]}]], ")"}], "n"]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "n", " ", 
        RowBox[{"\[Pi]", "/", "4"}]}]], " ", "+", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "n", " ", 
        RowBox[{"\[Pi]", "/", "4"}]}]]}], " ", "=", 
     RowBox[{"2", "cos", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]}]}]]],
 "  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{"2", "cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Remark.  The solution can also be obtained by applying the z-transform \
identity with ",
 Cell[BoxData[
  RowBox[{"a", "=", 
   FractionBox["\[Pi]", "4"]}]]],
 "that was proven in example 5 of the first section of this chapter to get  \n\
\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}], "]"}], "=", " ", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z", "2"], "-", 
     RowBox[{"cos", 
      RowBox[{"(", 
       FractionBox["\[Pi]", "4"], ")"}], "z"}]}], 
    RowBox[{
     SuperscriptBox["z", "2"], "-", 
     RowBox[{"2", "cos", 
      RowBox[{"(", 
       FractionBox["\[Pi]", "4"], ")"}], " ", "z"}], " ", "+", "1"}]]}]]],
 ",  \nthen we have\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[GothicCapitalZ]", 
      RowBox[{"-", "1"}]], "[", 
     FractionBox[
      RowBox[{
       RowBox[{"2", 
        SuperscriptBox["z", "2"]}], "-", 
       RowBox[{
        SqrtBox["2"], "z"}]}], 
      RowBox[{
       SuperscriptBox["z", "2"], "-", 
       RowBox[{
        SqrtBox["2"], " ", "z"}], " ", "+", "1"}]], "]"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[GothicCapitalZ]", 
       RowBox[{"-", "1"}]], "[", 
      FractionBox[
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["z", "2"]}], "-", 
        RowBox[{"2", "cos", 
         RowBox[{"(", 
          FractionBox["\[Pi]", "4"], ")"}], "z"}]}], 
       RowBox[{
        SuperscriptBox["z", "2"], "-", 
        RowBox[{"2", "cos", 
         RowBox[{"(", 
          FractionBox["\[Pi]", "4"], ")"}], " ", "z"}], " ", "+", "1"}]], 
      "]"}], "=", 
     RowBox[{"2", "cos", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}]}]}]}]]],
 ". "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"9.19", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706054265625*^9, 3.506706054265625*^9}}],

Cell[TextData[{
 "It is worthwhile to point out how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can do the important step using residues."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{
        SqrtBox["2"], " ", "z"}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["z", "2"]}]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SqrtBox["2"], " ", "z"}], "-", 
       SuperscriptBox["z", "2"]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<            Y[z]z  = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),\!\(\*FractionBox[\
\(1 - \[ImaginaryI]\), SqrtBox[\(2\)]]\)] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          FractionBox[
           RowBox[{"1", "-", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),\!\(\*FractionBox[\
\(1 + \[ImaginaryI]\), SqrtBox[\(2\)]]\)] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          FractionBox[
           RowBox[{"1", "+", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<              y[n] = Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\
\),\!\(\*FractionBox[\(1 - \[ImaginaryI]\), SqrtBox[\(2\)]]\)] + Res[Y[z]\!\(\
\*SuperscriptBox[\(z\), \(n - 1\)]\),\!\(\*FractionBox[\(1 + \[ImaginaryI]\), \
SqrtBox[\(2\)]]\)}]\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              y[n] = \>\"", ",", 
      RowBox[{
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           FractionBox[
            RowBox[{"1", "-", "\[ImaginaryI]"}], 
            SqrtBox["2"]]}], "}"}]}], "]"}], "+", 
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           FractionBox[
            RowBox[{"1", "+", "\[ImaginaryI]"}], 
            SqrtBox["2"]]}], "}"}]}], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482548828125*^9, 3.399482550203125*^9}, {
  3.40006745040625*^9, 3.400067450734375*^9}}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"y", "[", "n", "]"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], " ", "=", " ", "0"}]}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "0"], "=", 
   RowBox[{
    RowBox[{"y", "[", "0", "]"}], "=", 
    RowBox[{
     RowBox[{"2", "  ", "and", "  ", 
      SubscriptBox["y", "1"]}], "=", 
     RowBox[{
      RowBox[{"y", "[", "1", "]"}], "=", 
      SqrtBox["2"]}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["Zsolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", " ", "0"}]}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"Zsolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"x", "[", "n", "]"}], ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", 
    FractionBox[
     SqrtBox["2"], "2"]}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "1"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Zsolution", "[", 
     RowBox[{
      FractionBox[
       SqrtBox["2"], "2"], ",", "1", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "2", ",", 
      SqrtBox["2"]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which agrees with\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y2", "[", "n_", "]"}], "=", 
     RowBox[{"2", 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y2", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39948255265625*^9, 3.400085393484375*^9, 
  3.400347269515625*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      SuperscriptBox["2", 
       RowBox[{
        RowBox[{"-", "n"}], "/", "2"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "n"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"]}], ")"}]}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y2", "[", "n_", "]"}], "=", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"n", " ", "\[Pi]"}], "4"], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "10"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y1", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Y2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y2", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y2"}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y1", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g2", ",", "g3"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y2", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y2", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482555328125*^9, 3.3994825640625*^9}, {
   3.400067220640625*^9, 3.400067220859375*^9}, {3.400085396765625*^9, 
   3.400085504859375*^9}, {3.400094732796875*^9, 3.400094753453125*^9}, {
   3.4000947979375*^9, 3.400094803125*^9}, 3.40009483640625*^9}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"y", "[", "n", "]"}]}], " ", "=", " ", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "0"], "=", 
   RowBox[{
    RowBox[{"y", "[", "0", "]"}], "=", 
    RowBox[{
     RowBox[{"2", "  ", "and", "  ", 
      SubscriptBox["y", "1"]}], "=", 
     RowBox[{
      RowBox[{"y", "[", "1", "]"}], "=", 
      SqrtBox["2"]}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["ResidueSolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"ResidueSolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", 
    FractionBox[
     SqrtBox["2"], "2"]}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "1"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ResidueSolution", "[", 
     RowBox[{
      FractionBox[
       SqrtBox["2"], "2"], ",", "1", ",", "2", ",", 
      SqrtBox["2"]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"s", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which agrees with\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{"2", 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948257325*^9, 3.399482574578125*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Convolution for Solving a Non-homogeneous Equation",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n",
 StyleBox["(i)",
  FontColor->RGBColor[0, 0, 1]],
 "\tSolve the homogeneous equation   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["y", "h"], "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{
      SubscriptBox["y", "h"], "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{
      SubscriptBox["y", "h"], "[", "n", "]"}]}]}], "  ", "=", "  ", "0"}]]],
 "   and get  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "h"], "[", "n", "]"}]]],
 ".  \n\n",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 "\tUse the transfer function   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", " ", 
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", 
     RowBox[{"2", "a", " ", 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], " ", "+", " ", 
     RowBox[{"b", " ", 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}]}]]}]]],
 ".    \n\n",
 StyleBox["(iii)",
  FontColor->RGBColor[0, 0, 1]],
 "\tConstruct the particular solution using convolution  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], "  ", "=", "   ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"H", 
     RowBox[{"(", "z", ")"}], "X", 
     RowBox[{"(", "z", ")"}]}], "]"}]}]]],
 ",   or\n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], "  ", "=", "   ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "0"}], "n"], " ", 
    RowBox[{
     RowBox[{"h", "[", "i", "]"}], 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "i"}], "]"}]}]}]}]]],
 ".  \n\n",
 StyleBox["(iv)",
  FontColor->RGBColor[0, 0, 1]],
 "\tThe total solution to the nonhomogeneous difference equation is  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "h"], "[", "n", "]"}], "  ", "+", "  ", 
    RowBox[{
     SubscriptBox["y", "p"], "[", "n", "]"}]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 9.20 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the general solution to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 ". \n\n",
 StyleBox["9.20 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the general solution to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]]],
 ".   "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztWd0uA0EU3na30V1caolGmuCeKyparkiUuBV3jUj0oirdViSeQnDtNXgB
XoMH4BVqfrZn7O6Z2Wm7+kOFneOcb85+c+abMR1HlebFea3SrJ5V8vuNytVF
9czN79UbxGUmDCNxbxjGY96gdpuY3qNNvtsP9EE98dst2pj8fcTKce81a5ib
WeyHPhd53KVNikZNf/8Mj9doY1FvkjksXybyZcle4CVoBuI6fdhQkjrI2zGM
r/BCk+iXHLTM54VEPwcB0uIUZ2Fc0FXUFLtIPNWl6LhyO/peh8F+BEWOkTER
3xoU9f0nS63VEerbBLlj4wrBsdKGhjQMYZdgHEXOubNrMF8B8W1B4U3wOfIX
FPEilzxN+Lh6W00SSbPZJX5DKooQFVtOfhfxbffEHNG1Bk6yfysYi/nciYGn
mPVuRz0VQRH1xUA24CvgBeyxrsxVhJpY/jUhfCbii1onUQs1wxOT6ClYT3L4
HH2yHegELAc63ul0PAS4DT5hlSB6rJOsDFYaSWZDMgexpmVEpDgsyyyneUOb
HCXJvKtgrVDLy93xOeBLKy07FlygeAo1FqEO4qSQRaqUVlYdi+riZnTIiRPK
AoLTfb2tHFgMNIXQ1erLKqMKzSk2FBKdB+tFDher+LlPUNnPMwp+gGwfCp4C
/tonSPB8k4OG/blgVI7HP5EtBImdh8OMevugKD0Fj9LkTOL9xcVNRZSUsNsL
7GgWkp/iRqMfeU7uMf5p3AUpRW1OPcpL1Y31EicXFnR0eImzC/vdxpXMX9xV
b1M2JLwPVl18PMOe5/8e1/8j/Fs6HyibyZnjr8TZFW7gdtETVWeLyXJknTX6
10NiN8uMTwIrGAuV4dJfpiSsvSUeZ7b3ryUj8Q39yHNG\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\t\tFigure 9.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  A typical solution to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztWc1u00AQdupEkBQOiDb8SgS1lGuRQNCKUOAAEgi4UuASVU2bSmlRnLb8
XOAB4AI3JLgi8QA8AkeQ4Ai8AC+ABJLx7joz/pldjx0nrVCq1Lud+WZ2fr2b
7a1Gd3W53ei2lhq1653Gw9XWklO7ttHxSHbBsgqvLMv6WLPE3PWm/sP1Pu5r
8RCU4c03xWArO7zZcUXdkoMky5n8Fc9jiu+IoSS4dli+qvhtMRQFdUwSiiFN
3k9Rt4CvoBvhc2SkK2Mc5NMRf+j8m71CcT/pQTd6deV2AX6HA4eCdG/nBkeL
x2HW5AjeBdAiCFai/jjQIlS1ogqc3Q8IRuCldCqi3eXKFvUNtC6BqYdhthhV
0TaabxO0OpHbB0GXWC8J1PI14IvseioIMTiVL3T4W/b6/gJKrupBn8GcK8MA
NcGmFY51y6DzQ0KwZLxPAfxgb6Ze95I7R9DmoWhsoFX0S9XpspiGdSf94g/l
SYH8jSes8EJK/HltaceMKuvduEzQpiAf1Uw+EL3LwGk2Y4PtZ8DOCmRsIQeL
sSYuptS2R2/sLBRGWVe4KRY6EUkRFcowbY4Ob/qoRxyRzDpErAizk4CbCHOl
xDwhYeg2XLQDsxanMhwO/D3A1/SgPM8gj8QgA31APMb1UgsEjepZLs6wVL8O
/oAontODvkM+zvYJcmC5JgeOddPk2Inwt32C0M532WP7BpRs60HTRNWjs/v1
glNEd+F+u2+gglQaDYLo40+OZ2lq2nzojSEZp9xfYOJpJWg+2z4nQjGjBDcJ
Qeoc+4xIw0zQaNY51qDFfKJFQdgb3HvRIFB5QNfLROke1Qu+IEw9khv8JZER
A/w3x+I895ERvz8+XjBRzRREUpdO1DEr9powXESl6MgqVNZfBePeQU1C3f4J
uKy9iIrBqQiyQDGLdzrXI/5g+bCRkztDxrrnitG9xbJGuycnydgco3c6KyN+
ej6eXeTfhq+le8WzBEjDt+ZBIGk7zSe0YffhwK3hL5BUCk/C4TykqI/D6aim
p9J6d2Ph/0/8di8Xgeu8pArZkAP/Fi7pAJhJX6yFdoVVBn3rEF+8ykuKtJwn
/PfXKvwDEMZ+NQ==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 183},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\t\tFigure 9.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  A typical solution to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Solution", " ", "9.20", " ", 
   RowBox[{
    RowBox[{"(", "a", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670605915625*^9, 3.506706059171875*^9}}],

Cell[TextData[{
 "\tThe homogeneous difference equation has the form  ",
 StyleBox["(9-8)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" with ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"a", "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      SqrtBox["2"], "3"], "  ", "and", "  ", "b"}], "=", 
    FractionBox["4", "9"]}]}]]],
 " and  ",
 Cell[BoxData[
  RowBox[{"b", ">", 
   SuperscriptBox["a", "2"]}]]],
 " so that the solution are complex and have the form  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "h"], "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SuperscriptBox["r", "n"], "cos", 
     RowBox[{"(", 
      RowBox[{"\[Phi]", " ", "n"}], " ", ")"}]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["c", "2"], 
     SuperscriptBox["r", "n"], "sin", 
     RowBox[{"(", 
      RowBox[{"\[Phi]", " ", "n"}], ")"}]}]}]}]]],
 ",  \n\nwhere  ",
 Cell[BoxData[
  RowBox[{"r", "=", 
   RowBox[{
    SqrtBox["b"], "=", 
    RowBox[{
     SqrtBox[
      FractionBox["4", "9"]], "=", 
     FractionBox["2", "3"]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", "=", 
   RowBox[{
    RowBox[{"arctan", 
     RowBox[{"(", 
      FractionBox[
       SqrtBox[
        RowBox[{"b", "-", 
         SuperscriptBox["a", "2"]}]], "a"], ")"}]}], "=", 
    RowBox[{
     RowBox[{"arctan", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox["4", "9"], "-", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox[
              SqrtBox["2"], "3"], ")"}], "2"]}], ")"}]], "/", 
        RowBox[{"(", 
         FractionBox[
          SqrtBox["2"], "3"], ")"}]}], ")"}]}], " ", "=", 
     RowBox[{
      RowBox[{"arctan", 
       RowBox[{"(", "1", ")"}]}], "=", 
      FractionBox["\[Pi]", "4"]}]}]}]}]]],
 ".  Hence, the general homogeneous solution is  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "h"], "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", "3"], ")"}], "n"], "Cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "n"}], " ", ")"}]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["c", "2"], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", "3"], ")"}], "n"], "sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}]}]}]]],
 ". \n\n",
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The homogeneous solution is transient and and will decay to ",
 Cell[BoxData["0"]],
 " as ",
 Cell[BoxData[
  RowBox[{"n", "\[Rule]", "\[Infinity]"}]]],
 ", i.e.  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    RowBox[{
     SubscriptBox["y", "h"], "[", "n", "]"}]}], "=", "0"}]]],
 ".  An illustration using ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "1"], "=", 
   RowBox[{
    RowBox[{"10", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     SubscriptBox["c", "2"]}], "=", "5"}]}]]],
 " is shown in figure 2 below. \n\n",
 StyleBox["Typo.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Please note that there is a typo in the book which mistakenly stated that \
the homogeneous solution involves ",
 Cell[BoxData[
  RowBox[{
   FractionBox["\[Pi]", "3"], " ", "n"}]]],
 ".  We apologize for this inconvenience. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Solution", " ", "9.20", " ", 
   RowBox[{
    RowBox[{"(", "b", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706061171875*^9, 3.506706061171875*^9}}],

Cell[TextData[{
 "\tThe transfer function is seen to be  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      SuperscriptBox["z", "2"], "-", 
      RowBox[{
       FractionBox["2", "3"], 
       SqrtBox["2"], "z"}], "+", 
      FractionBox["4", "9"]}]], " ", "=", " ", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          FractionBox[
           RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          FractionBox[
           RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}]}], ")"}]}], ")"}]}]}]}]]],
 " .  Using the z-transform ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}], "]"}], "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["z", "2"], "-", 
      RowBox[{"cos", 
       RowBox[{"(", 
        FractionBox["\[Pi]", "4"], ")"}], "z"}]}], 
     RowBox[{
      SuperscriptBox["z", "2"], "-", 
      RowBox[{"2", "cos", 
       RowBox[{"(", 
        FractionBox["\[Pi]", "4"], ")"}], " ", "z"}], " ", "+", "1"}]], " ", 
    "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], "-", 
       RowBox[{"z", "/", 
        SqrtBox["2"]}]}], 
      RowBox[{
       SuperscriptBox["z", "2"], "-", 
       RowBox[{
        SqrtBox["2"], " ", "z"}], "+", "1"}]], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "-", 
        RowBox[{
         FractionBox["1", 
          SqrtBox["2"]], "z"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", 
          FractionBox[
           RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"z", "-", 
          FractionBox[
           RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}], ")"}]}], ")"}]}]}]}]}]]],
 " in example 8 and the fact that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}]}], 
    RowBox[{"X", 
     RowBox[{"(", "z", ")"}]}]]}]]],
 " we can write the z-transform ",
 Cell[BoxData[
  RowBox[{"Y", "[", "z", "]"}]]],
 "using convolution   \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"H", 
     RowBox[{"(", "z", ")"}], "X", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    FractionBox[
     RowBox[{
      SuperscriptBox["z", "2"], "-", 
      RowBox[{"z", "/", 
       SqrtBox["2"]}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{
         FractionBox["2", "3"], 
         FractionBox[
          RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
          SqrtBox["2"]]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{
         FractionBox["2", "3"], 
         FractionBox[
          RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
          SqrtBox["2"]]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", "-", 
        FractionBox[
         RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
         SqrtBox["2"]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"z", "-", 
        FractionBox[
         RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
         SqrtBox["2"]]}], ")"}]}]]}]}]]],
 "  "
}], "Text"],

Cell[TextData[{
 "Residue calculus can again be used to find the solution, but the details \
are tedious.  Let us announce that the following computations hold true  \n\n\
\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"Residue", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], ",", 
      RowBox[{
       FractionBox["2", "3"], 
       FractionBox[
        RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
        SqrtBox["2"]]}]}], "]"}], "+", 
    RowBox[{"Residue", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], ",", 
      RowBox[{
       FractionBox["2", "3"], 
       FractionBox[
        RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
        SqrtBox["2"]]}]}], "]"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     FractionBox["18", "13"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", "3"], ")"}], "n"], " ", "cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "4"], "n"}], ")"}]}], " ", "-", " ", 
    RowBox[{
     FractionBox["63", "26"], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", "3"], ")"}], "n"], " ", "sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "4"], "n"}], ")"}]}]}]}]]],
 " \n\nwhich is part of the homogeneous solution.  And the steady state or \
particular part of the solution is  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}], ",", 
       FractionBox[
        RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
        SqrtBox["2"]]}], "]"}], "+", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}], ",", 
       FractionBox[
        RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
        SqrtBox["2"]]}], "]"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["18", "13"]}], " ", "cos", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], ")"}]}], " ", "+", " ", 
     RowBox[{
      FractionBox["27", "13"], " ", "sin", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]}]}]]],
 " \n\nTherefore, the general solution to part (b) is \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["y", "h"], "[", "n", "]"}], "+", 
     RowBox[{
      SubscriptBox["y", "p"], "[", "n", "]"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["c", "1"], 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["2", "3"], ")"}], "n"], "cos", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "4"], " ", "n"}], " ", ")"}]}], "+", 
     RowBox[{
      SubscriptBox["c", "2"], 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["2", "3"], ")"}], "n"], "sin", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}], " ", "-", " ", 
     RowBox[{
      FractionBox["18", "13"], " ", "cos", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], ")"}]}], "+", 
     RowBox[{
      FractionBox["27", "13"], " ", "sin", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "\tFor applications, it is useful to determine the limiting amplitude of  ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 ".  We need to simplify ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "p"], "[", "n", "]"}]]],
 " in a form that displays it's amplitude and to do this we apply to the \
trigonometric identity (also known as the ",
 ButtonBox["harmonic addition theorem",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/HarmonicAdditionTheorem.html"], None}],
 ")  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"a", "  ", "cos", 
     RowBox[{"(", "\[Theta]", ")"}]}], " ", "+", " ", 
    RowBox[{"b", " ", "sin", 
     RowBox[{"(", "\[Theta]", ")"}]}]}], " ", "=", " ", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}]], "cos", 
    RowBox[{"(", 
     RowBox[{"\[Theta]", "+", 
      RowBox[{"arctan", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"-", "b"}], "a"], ")"}]}]}], ")"}]}]}]]],
 ".  \n\nTherefore, the steady state solution is \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], " ", "=", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", " ", 
          FractionBox["18", "13"]}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["27", "13"], ")"}], "2"]}]], "Cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], "+", 
       RowBox[{"arctan", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{"-", 
           FractionBox["27", "13"]}], 
          RowBox[{"-", " ", 
           FractionBox["18", "13"]}]], ")"}]}]}], ")"}]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"9", " "}], 
      SqrtBox["13"]], " ", "cos", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], "+", 
       RowBox[{"arctan", 
        RowBox[{"(", 
         FractionBox["3", "2"], ")"}]}]}], ")"}]}]}]}]]],
 "\n\t\t\nand the output signal ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 " tends to this limit as ",
 Cell[BoxData[
  RowBox[{"n", "\[Rule]", "\[Infinity]"}]]],
 ",  i.e.  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    RowBox[{"y", "[", "n", "]"}]}], "=", 
   RowBox[{
    SubscriptBox["y", "h"], "[", "n", "]"}]}]]],
 ".  Loosely speaking, for large values of  ",
 Cell[BoxData["n"]],
 "  the values of the input signal  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{" ", "\[Pi]"}], "4"], "n"}], ")"}]}]}]]],
 "  are amplified by the factor  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"9", " "}], 
    SqrtBox["13"]], " ", "=", " ", "2.49615"}]]],
 " to produce the values of the output signal  ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 ".    An illustration using ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "1"], "=", 
   RowBox[{
    RowBox[{"10", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     SubscriptBox["c", "2"]}], "=", "5"}]}]]],
 " is shown in figure 3 below. "
}], "Text"],

Cell[TextData[{
 StyleBox["Typo.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Please note that there is a typo in the book which mistakenly stated that \
the homogeneous solution involves ",
 Cell[BoxData[
  RowBox[{
   FractionBox["\[Pi]", "3"], " ", "n"}]]],
 ".  We apologize for this inconvenience. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", "9.20", " ", 
   RowBox[{
    RowBox[{"(", "a", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.5067060631875*^9, 3.5067060631875*^9}}],

Cell[TextData[{
 "Use the initial conditions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{"1", "  ", "and", "  ", 
     RowBox[{"y", "[", "1", "]"}]}], "=", 
    FractionBox[
     SqrtBox["2"], "3"]}]}]]],
 "  and get the solution  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["2", "3"], ")"}], "n"], "Cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], " ", "n"}], " ", ")"}]}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SolveDE", "[", 
     RowBox[{
      FractionBox[
       SqrtBox["2"], "3"], ",", 
      FractionBox["4", "9"], ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "1", ",", 
      FractionBox[
       SqrtBox["2"], "3"]}], "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482584421875*^9, 3.399482585453125*^9}, 
   3.400347294203125*^9}],

Cell[TextData[{
 "Use the initial conditions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{"0", "  ", "and", "  ", 
     RowBox[{"y", "[", "1", "]"}]}], "=", 
    FractionBox[
     SqrtBox["2"], "3"]}]}]]],
 "  and get the solution  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["2", "3"], ")"}], "n"], "Sin", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], " ", "n"}], " ", ")"}]}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SolveDE", "[", 
     RowBox[{
      FractionBox[
       SqrtBox["2"], "3"], ",", 
      FractionBox["4", "9"], ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "0", ",", 
      FractionBox[
       SqrtBox["2"], "3"]}], "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482588546875*^9, 3.3994825899375*^9}, 
   3.40034730184375*^9}],

Cell["\<\
The above derivation can also be accomplished using z-transforms.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Zsolution", "[", 
     RowBox[{
      FractionBox[
       SqrtBox["2"], "3"], ",", 
      FractionBox["4", "9"], ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "1", ",", 
      FractionBox[
       SqrtBox["2"], "3"]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which agrees with\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["2", "3"], ")"}], "n"], 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482593046875*^9, 3.399482598125*^9}, 
   3.400347306125*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Zsolution", "[", 
     RowBox[{
      FractionBox[
       SqrtBox["2"], "3"], ",", 
      FractionBox["4", "9"], ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "0", ",", 
      FractionBox[
       SqrtBox["2"], "3"]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which agrees with\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["2", "3"], ")"}], "n"], 
      RowBox[{"Sin", "[", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482595296875*^9, 3.399482599359375*^9}, 
   3.40034730996875*^9}],

Cell[TextData[{
 "Form the linear combination  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "h"], "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", "3"], ")"}], "n"], "Cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "n"}], " ", ")"}]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["c", "2"], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", "3"], ")"}], "n"], "sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}]}]}]]],
 "  and substitute it into the difference equation\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["y", "h"], "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{
      SubscriptBox["y", "h"], "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{
      SubscriptBox["y", "h"], "[", "n", "]"}]}]}], "  ", "=", "  ", "0"}]]]
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["y", "h"], "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{
       SubscriptBox["c", "1"], 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["2", "3"], ")"}], "n"], 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox["\[Pi]", "4"], " ", "n"}], " ", "]"}]}], " ", "+", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["2", "3"], ")"}], "n"], 
       RowBox[{"Sin", "[", 
        RowBox[{
         FractionBox["\[Pi]", "4"], " ", "n"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \!\(\*SubscriptBox[\(y\), \(h\)]\)[n] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "h"], "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(y\), \(h\)]\)[n+1] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "h"], "[", 
       RowBox[{"n", "+", "1"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(y\), \(h\)]\)[n+1] = \>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{
        SubscriptBox["y", "h"], "[", 
        RowBox[{"n", "+", "1"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(y\), \(h\)]\)[n+2] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "h"], "[", 
       RowBox[{"n", "+", "2"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(y\), \(h\)]\)[n+2] = \>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{
        SubscriptBox["y", "h"], "[", 
        RowBox[{"n", "+", "2"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<         \!\(\*SubscriptBox[\(y\), \(h\)]\)[n] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "h"], "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<-\!\(\*FractionBox[\(2\), \
\(3\)]\)\!\(\*SqrtBox[\(2\)]\)\!\(\*SubscriptBox[\(y\), \(h\)]\)[n+1] = \>\"",
       ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["2", "3"]}], 
       SqrtBox["2"], 
       RowBox[{"TrigExpand", "[", 
        RowBox[{
         SubscriptBox["y", "h"], "[", 
         RowBox[{"n", "+", "1"}], "]"}], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     \!\(\*FractionBox[\(4\), \(9\)]\)\!\(\*SubscriptBox[\(y\), \(h\
\)]\)[n+2] = \>\"", ",", 
      RowBox[{
       FractionBox["4", "9"], 
       RowBox[{"TrigExpand", "[", 
        RowBox[{
         SubscriptBox["y", "h"], "[", 
         RowBox[{"n", "+", "2"}], "]"}], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Now add up the three terms\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubscriptBox[\(y\), \(h\)]\)[n+2]-\!\(\*FractionBox[\(2\), \
\(3\)]\) \!\(\*SqrtBox[\(2\)]\) \!\(\*SubscriptBox[\(y\), \
\(h\)]\)[n+1]+\!\(\*FractionBox[\(4\), \(9\)]\) \!\(\*SubscriptBox[\(y\), \(h\
\)]\)[n]\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    =    \>\"", ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["y", "h"], "[", 
        RowBox[{"n", "+", "2"}], "]"}], "-", 
       RowBox[{
        FractionBox["2", "3"], " ", 
        SqrtBox["2"], " ", 
        RowBox[{
         SubscriptBox["y", "h"], "[", 
         RowBox[{"n", "+", "1"}], "]"}]}], "+", 
       RowBox[{
        FractionBox["4", "9"], " ", 
        RowBox[{
         SubscriptBox["y", "h"], "[", "n", "]"}]}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(y\), \(h\)]\)[n+2]-\!\(\*FractionBox[\(2\), \
\(3\)]\) \!\(\*SqrtBox[\(2\)]\) \!\(\*SubscriptBox[\(y\), \
\(h\)]\)[n+1]+\!\(\*FractionBox[\(4\), \(9\)]\) \!\(\*SubscriptBox[\(y\), \(h\
\)]\)[n] = \>\"", ",", 
      RowBox[{"MapAll", "[", 
       RowBox[{"Expand", ",", 
        RowBox[{
         RowBox[{
          SubscriptBox["y", "h"], "[", 
          RowBox[{"n", "+", "2"}], "]"}], "-", 
         RowBox[{
          FractionBox["2", "3"], " ", 
          SqrtBox["2"], " ", 
          RowBox[{
           SubscriptBox["y", "h"], "[", 
           RowBox[{"n", "+", "1"}], "]"}]}], "+", 
         RowBox[{
          FractionBox["4", "9"], " ", 
          RowBox[{
           SubscriptBox["y", "h"], "[", "n", "]"}]}]}]}], "]"}]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(y\), \(h\)]\)[n+2]-\!\(\*FractionBox[\(2\), \
\(3\)]\) \!\(\*SqrtBox[\(2\)]\) \!\(\*SubscriptBox[\(y\), \
\(h\)]\)[n+1]+\!\(\*FractionBox[\(4\), \(9\)]\) \!\(\*SubscriptBox[\(y\), \(h\
\)]\)[n] = \>\"", ",", 
      RowBox[{"MapAll", "[", 
       RowBox[{"TrigExpand", ",", 
        RowBox[{
         RowBox[{
          SubscriptBox["y", "h"], "[", 
          RowBox[{"n", "+", "2"}], "]"}], "-", 
         RowBox[{
          FractionBox["2", "3"], " ", 
          SqrtBox["2"], " ", 
          RowBox[{
           SubscriptBox["y", "h"], "[", 
           RowBox[{"n", "+", "1"}], "]"}]}], "+", 
         RowBox[{
          FractionBox["4", "9"], " ", 
          RowBox[{
           SubscriptBox["y", "h"], "[", "n", "]"}]}]}]}], "]"}]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948260775*^9, 3.399482610359375*^9}, {
  3.400139903203125*^9, 3.400139917578125*^9}}],

Cell[TextData[{
 "The following graph is shows the solution for the choice of constants ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "1"], "=", 
   RowBox[{
    RowBox[{"10", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     SubscriptBox["c", "2"]}], "=", "5"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "y"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"10", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["2", "3"], ")"}], "n"], 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox["\[Pi]", "3"], " ", "n"}], " ", "]"}]}], " ", "+", 
      RowBox[{"5", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["2", "3"], ")"}], "n"], 
       RowBox[{"Sin", "[", 
        RowBox[{
         FractionBox["\[Pi]", "3"], " ", "n"}], "]"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "20"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "10.25"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "10.25"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", 
      RowBox[{"y", "[", "0", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", 
      RowBox[{"y", "[", "1", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948261396875*^9, 3.39948261996875*^9}, {
  3.400067226234375*^9, 3.400067226453125*^9}, {3.400085580328125*^9, 
  3.400085641171875*^9}, {3.40009493278125*^9, 3.400094933359375*^9}, {
  3.40009501021875*^9, 3.400095010484375*^9}, {3.40009506365625*^9, 
  3.4000951411875*^9}, {3.40034732053125*^9, 3.400347323734375*^9}}],

Cell[TextData[{
 StyleBox["Figure 9.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  A typical solution to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", "9.20", " ", 
   RowBox[{
    RowBox[{"(", "b", ")"}], "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706065984375*^9, 3.506706065984375*^9}}],

Cell["\<\
The important step in the solution is the computation of a particular \
solution residues. \
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], "-", 
       RowBox[{"z", "/", 
        SqrtBox["2"]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          FractionBox[
           RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          FractionBox[
           RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         FractionBox[
          RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
          SqrtBox["2"]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         FractionBox[
          RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
          SqrtBox["2"]]}], ")"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{
           FractionBox["2", "3"], 
           FractionBox[
            RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
            SqrtBox["2"]]}]}], "}"}]}], "]"}], "+", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{
           FractionBox["2", "3"], 
           FractionBox[
            RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
            SqrtBox["2"]]}]}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482628390625*^9, 3.399482629546875*^9}, {
  3.400067479484375*^9, 3.400067479984375*^9}}],

Cell[TextData[{
 "To show that this is equivalent to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{
     FractionBox["18", "13"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", "3"], ")"}], "n"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "4"], "n"}], "]"}]}], " ", "-", " ", 
    RowBox[{
     FractionBox["63", "26"], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", "3"], ")"}], "n"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "4"], "n"}], "]"}]}]}]}]]],
 ",  we shall resort to comparing their graphs.  Also note that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will expand the fractions in the printout, i.e.  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["18", "13"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["2", "3"], ")"}], "n"]}], "  ", "=", " ", 
   RowBox[{
    FractionBox["1", "13"], " ", 
    SuperscriptBox["2", 
     RowBox[{"1", "+", "n"}]], " ", 
    SuperscriptBox["3", 
     RowBox[{"2", "-", "n"}]]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", " ", 
     FractionBox["63", "26"]}], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["2", "3"], ")"}], "n"]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["7", "13"]}], " ", 
    SuperscriptBox["2", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "n"}]], " ", 
    SuperscriptBox["3", 
     RowBox[{"2", "-", "n"}]]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], "-", 
       RowBox[{"z", "/", 
        SqrtBox["2"]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          FractionBox[
           RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          FractionBox[
           RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         FractionBox[
          RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
          SqrtBox["2"]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         FractionBox[
          RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
          SqrtBox["2"]]}], ")"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox[
          RowBox[{"z", " "}], 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{
           FractionBox["2", "3"], 
           FractionBox[
            RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
            SqrtBox["2"]]}]}], "}"}]}], "]"}], "+", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox[
          RowBox[{"z", " "}], 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{
           FractionBox["2", "3"], 
           FractionBox[
            RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
            SqrtBox["2"]]}]}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y2", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{
       FractionBox["18", "13"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["2", "3"], ")"}], "n"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox[
          RowBox[{" ", "\[Pi]"}], "4"], "n"}], "]"}]}], " ", "-", " ", 
      RowBox[{
       FractionBox["63", "26"], 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["2", "3"], ")"}], "n"], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         FractionBox[
          RowBox[{" ", "\[Pi]"}], "4"], "n"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "21"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y2", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Y2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y2", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y2"}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.13"}], ",", "1.45"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.13"}], ",", "1.45"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.13"}], ",", "1.45"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.13"}], ",", "1.45"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g2", ",", "g3"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y2", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482632234375*^9, 3.39948264109375*^9}, {
  3.400067231859375*^9, 3.4000672320625*^9}, {3.400085657546875*^9, 
  3.40008572396875*^9}, {3.400095225296875*^9, 3.400095268921875*^9}}],

Cell[TextData[{
 "The following graph is the solution to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]]],
 "  for the choice of constants ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "1"], "=", 
   RowBox[{
    RowBox[{"10", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     SubscriptBox["c", "2"]}], "=", "5"}]}]]],
 "."
}], "Text",
 CellChangeTimes->{{3.400095367265625*^9, 3.400095368359375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "y"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"10", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["2", "3"], ")"}], "n"], 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox["\[Pi]", "4"], " ", "n"}], " ", "]"}]}], " ", "+", 
      RowBox[{"5", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["2", "3"], ")"}], "n"], 
       RowBox[{"Sin", "[", 
        RowBox[{
         FractionBox["\[Pi]", "4"], " ", "n"}], "]"}]}], "+", 
      RowBox[{
       FractionBox[
        RowBox[{"9", " "}], 
        SqrtBox["13"]], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{
          FractionBox["\[Pi]", "4"], "n"}], "+", 
         RowBox[{"ArcTan", "[", 
          RowBox[{
           RowBox[{"-", "2"}], ",", 
           RowBox[{"-", "3"}]}], "]"}]}], "]"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "20"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "10.25"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "10.25"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", 
      RowBox[{"y", "[", "0", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", 
      RowBox[{"y", "[", "1", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948264678125*^9, 3.399482651265625*^9}, {
  3.40006723728125*^9, 3.4000672375*^9}, {3.400085739578125*^9, 
  3.400085764328125*^9}, {3.40009537696875*^9, 3.400095397140625*^9}, {
  3.40034733396875*^9, 3.400347337140625*^9}}],

Cell[TextData[{
 StyleBox["Figure 9.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  A typical solution to ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]]],
 ".  "
}], "Text"]
}, Closed]]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{902, 630},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageHeaderLines->{Inherited, False},
PrintingOptions->{"FirstPageFooter"->False,
"FirstPageHeader"->False,
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->False,
"PrintingMargins"->{{54, 54}, {36, 54}}},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 2703, 87, 245, "Text"],
Cell[4254, 135, 911, 39, 73, "Text"],
Cell[5168, 176, 718, 30, 65, "Text"],
Cell[5889, 208, 2133, 81, 233, "Text"],
Cell[8025, 291, 1363, 44, 119, "Text"],
Cell[9391, 337, 159, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[9575, 344, 367, 11, 29, "Text"],
Cell[9945, 357, 17709, 427, 1509, "Input",
 InitializationCell->True]
}, Closed]],
Cell[27669, 787, 937, 35, 26, "Text"],
Cell[28609, 824, 879, 17, 163, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[29513, 845, 208, 6, 37, "Subsection"],
Cell[29724, 853, 1790, 63, 194, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[31551, 921, 226, 6, 29, "Subsection"],
Cell[31780, 929, 2037, 72, 65, "Text"],
Cell[33820, 1003, 547, 15, 112, "Input"],
Cell[34370, 1020, 4684, 132, 415, "Input"]
}, Closed]],
Cell[39069, 1155, 937, 35, 26, "Text"],
Cell[40009, 1192, 904, 18, 163, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[40938, 1214, 214, 6, 37, "Subsection"],
Cell[41155, 1222, 2010, 72, 206, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43202, 1299, 226, 6, 37, "Subsection"],
Cell[43431, 1307, 2038, 72, 65, "Text"],
Cell[45472, 1381, 521, 14, 112, "Input"],
Cell[45996, 1397, 4629, 134, 415, "Input"]
}, Closed]],
Cell[50640, 1534, 937, 35, 26, "Text"],
Cell[51580, 1571, 961, 19, 163, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[52566, 1594, 215, 6, 37, "Subsection"],
Cell[52784, 1602, 3317, 116, 289, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[56138, 1723, 232, 6, 29, "Subsection"],
Cell[56373, 1731, 2038, 72, 65, "Text"],
Cell[58414, 1805, 520, 14, 112, "Input"],
Cell[58937, 1821, 1262, 47, 37, "Text"],
Cell[60202, 1870, 9527, 276, 693, "Input"]
}, Closed]],
Cell[69744, 2149, 3692, 129, 233, "Text"],
Cell[73439, 2280, 2596, 94, 122, "Text"],
Cell[76038, 2376, 3308, 121, 206, "Text"],
Cell[79349, 2499, 386, 12, 31, "Text"],
Cell[79738, 2513, 1953, 65, 173, "Text"],
Cell[81694, 2580, 1594, 56, 101, "Text"],
Cell[83291, 2638, 3522, 128, 254, "Text"],
Cell[86816, 2768, 2213, 81, 104, "Text"],
Cell[89032, 2851, 1433, 54, 65, "Text"],
Cell[90468, 2907, 261, 9, 29, "Text"],
Cell[90732, 2918, 296, 10, 29, "Text"],
Cell[CellGroupData[{
Cell[91053, 2932, 368, 11, 29, "Text"],
Cell[91424, 2945, 7350, 182, 682, "Input",
 InitializationCell->True],
Cell[98777, 3129, 12518, 298, 1014, "Input",
 InitializationCell->True]
}, Closed]],
Cell[111310, 3430, 2246, 85, 62, "Text"],
Cell[113559, 3517, 1392, 26, 163, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[114976, 3547, 247, 7, 37, "Subsection"],
Cell[115226, 3556, 705, 25, 68, "Text"],
Cell[115934, 3583, 425, 19, 43, "Text"],
Cell[116362, 3604, 2367, 88, 139, "Text"],
Cell[118732, 3694, 1367, 47, 137, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[120136, 3746, 249, 7, 29, "Subsection"],
Cell[120388, 3755, 777, 28, 71, "Text"],
Cell[121168, 3785, 568, 24, 43, "Text"],
Cell[121739, 3811, 3967, 144, 193, "Text"],
Cell[125709, 3957, 1959, 68, 101, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[127705, 4030, 267, 7, 29, "Subsection"],
Cell[127975, 4039, 161, 5, 29, "Text"],
Cell[128139, 4046, 2814, 82, 246, "Input"],
Cell[130956, 4130, 2473, 88, 65, "Text"],
Cell[133432, 4220, 1137, 32, 155, "Input"],
Cell[134572, 4254, 2332, 83, 65, "Text"],
Cell[136907, 4339, 863, 24, 115, "Input"],
Cell[137773, 4365, 4569, 131, 415, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[142379, 4501, 263, 7, 29, "Subsection"],
Cell[142645, 4510, 161, 5, 29, "Text"],
Cell[142809, 4517, 4242, 123, 309, "Input"],
Cell[147054, 4642, 2629, 95, 65, "Text"],
Cell[149686, 4739, 1137, 32, 134, "Input"],
Cell[150826, 4773, 4577, 131, 415, "Input"]
}, Closed]],
Cell[155418, 4907, 2221, 84, 62, "Text"],
Cell[157642, 4993, 1322, 24, 163, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[158989, 5021, 251, 7, 37, "Subsection"],
Cell[159243, 5030, 615, 22, 68, "Text"],
Cell[159861, 5054, 379, 17, 44, "Text"],
Cell[160243, 5073, 3042, 112, 161, "Text"],
Cell[163288, 5187, 339, 11, 101, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[163664, 5203, 249, 7, 29, "Subsection"],
Cell[163916, 5212, 752, 27, 71, "Text"],
Cell[164671, 5241, 600, 25, 44, "Text"],
Cell[165274, 5268, 4727, 170, 230, "Text"],
Cell[170004, 5440, 284, 10, 29, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[170325, 5455, 254, 7, 29, "Subsection"],
Cell[170582, 5464, 161, 5, 29, "Text"],
Cell[170746, 5471, 2007, 58, 225, "Input"],
Cell[172756, 5531, 2473, 88, 65, "Text"],
Cell[175232, 5621, 1137, 32, 155, "Input"],
Cell[176372, 5655, 2327, 83, 65, "Text"],
Cell[178702, 5740, 862, 24, 115, "Input"],
Cell[179567, 5766, 4606, 133, 415, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[184210, 5904, 265, 7, 29, "Subsection"],
Cell[184478, 5913, 161, 5, 29, "Text"],
Cell[184642, 5920, 3524, 102, 287, "Input"],
Cell[188169, 6024, 2578, 93, 65, "Text"],
Cell[190750, 6119, 1161, 33, 155, "Input"],
Cell[191914, 6154, 4575, 131, 415, "Input"]
}, Closed]],
Cell[196504, 6288, 2402, 90, 62, "Text"],
Cell[198909, 6380, 1461, 27, 163, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[200395, 6411, 249, 7, 37, "Subsection"],
Cell[200647, 6420, 609, 21, 68, "Text"],
Cell[201259, 6443, 672, 25, 44, "Text"],
Cell[201934, 6470, 4587, 151, 164, "Text"],
Cell[206524, 6623, 2948, 98, 185, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[209509, 6726, 251, 7, 29, "Subsection"],
Cell[209763, 6735, 805, 26, 72, "Text"],
Cell[210571, 6763, 783, 27, 44, "Text"],
Cell[211357, 6792, 7152, 229, 248, "Text"],
Cell[218512, 7023, 2889, 95, 107, "Text"],
Cell[221404, 7120, 2916, 100, 71, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[224357, 7225, 265, 7, 29, "Subsection"],
Cell[224625, 7234, 161, 5, 29, "Text"],
Cell[224789, 7241, 3054, 88, 246, "Input"],
Cell[227846, 7331, 2473, 88, 65, "Text"],
Cell[230322, 7421, 1136, 32, 155, "Input"],
Cell[231461, 7455, 2327, 83, 65, "Text"],
Cell[233791, 7540, 864, 24, 115, "Input"],
Cell[234658, 7566, 1262, 47, 37, "Text"],
Cell[235923, 7615, 9527, 276, 693, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[245487, 7896, 268, 7, 29, "Subsection"],
Cell[245758, 7905, 161, 5, 29, "Text"],
Cell[245922, 7912, 5715, 167, 353, "Input"],
Cell[251640, 8081, 2946, 105, 83, "Text"],
Cell[254589, 8188, 1358, 40, 155, "Input"],
Cell[255950, 8230, 5592, 161, 431, "Input"]
}, Closed]],
Cell[261557, 8394, 735, 27, 26, "Text"],
Cell[262295, 8423, 908, 18, 163, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[263228, 8445, 216, 6, 37, "Subsection"],
Cell[263447, 8453, 930, 33, 68, "Text"],
Cell[264380, 8488, 718, 27, 44, "Text"],
Cell[265101, 8517, 3058, 111, 200, "Text"],
Cell[268162, 8630, 2885, 97, 183, "Text"],
Cell[271050, 8729, 1475, 51, 115, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[272562, 8785, 229, 6, 29, "Subsection"],
Cell[272794, 8793, 2318, 77, 71, "Text"],
Cell[275115, 8872, 3290, 95, 318, "Input"],
Cell[278408, 8969, 408, 15, 37, "Text"],
Cell[278819, 8986, 7488, 218, 599, "Input"],
Cell[286310, 9206, 689, 25, 32, "Text"],
Cell[287002, 9233, 1899, 57, 260, "Input"],
Cell[288904, 9292, 2842, 99, 185, "Text"],
Cell[291749, 9393, 3208, 95, 224, "Input"],
Cell[294960, 9490, 1022, 37, 37, "Text"],
Cell[295985, 9529, 7723, 225, 603, "Input"],
Cell[303711, 9756, 136, 4, 29, "Text"],
Cell[303850, 9762, 1337, 38, 123, "Input"]
}, Closed]],
Cell[305202, 9803, 587, 24, 29, "Text"],
Cell[305792, 9829, 749, 15, 163, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[306566, 9848, 216, 6, 37, "Subsection"],
Cell[306785, 9856, 695, 24, 69, "Text"],
Cell[307483, 9882, 997, 39, 69, "Text"],
Cell[308483, 9923, 3816, 137, 343, "Text"],
Cell[312302, 10062, 1924, 66, 153, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[314263, 10133, 232, 6, 29, "Subsection"],
Cell[314498, 10141, 161, 5, 29, "Text"],
Cell[314662, 10148, 3497, 100, 341, "Input"],
Cell[318162, 10250, 2287, 83, 83, "Text"],
Cell[320452, 10335, 2262, 66, 294, "Input"],
Cell[322717, 10403, 8485, 245, 654, "Input"],
Cell[331205, 10650, 2136, 78, 83, "Text"],
Cell[333344, 10730, 1987, 58, 255, "Input"]
}, Closed]],
Cell[335346, 10791, 2275, 80, 292, "Text"],
Cell[337624, 10873, 1092, 41, 82, "Text"],
Cell[338719, 10916, 1066, 20, 163, "Text",
 Evaluatable->False],
Cell[339788, 10938, 506, 19, 38, "Text"],
Cell[340297, 10959, 1282, 24, 197, "Text",
 Evaluatable->False],
Cell[341582, 10985, 602, 23, 37, "Text"],
Cell[CellGroupData[{
Cell[342209, 11012, 250, 7, 37, "Subsection"],
Cell[342462, 11021, 3749, 135, 311, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[346248, 11161, 251, 7, 29, "Subsection"],
Cell[346502, 11170, 3782, 134, 197, "Text"],
Cell[350287, 11306, 3480, 116, 247, "Text"],
Cell[353770, 11424, 3517, 121, 285, "Text"],
Cell[357290, 11547, 332, 10, 35, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[357659, 11562, 263, 7, 29, "Subsection"],
Cell[357925, 11571, 570, 22, 44, "Text"],
Cell[358498, 11595, 653, 19, 135, "Input"],
Cell[359154, 11616, 570, 22, 44, "Text"],
Cell[359727, 11640, 650, 19, 135, "Input"],
Cell[360380, 11661, 89, 2, 29, "Text"],
Cell[360472, 11665, 2392, 71, 299, "Input"],
Cell[362867, 11738, 2397, 71, 299, "Input"],
Cell[365267, 11811, 1142, 40, 82, "Text"],
Cell[366412, 11853, 6403, 181, 546, "Input"],
Cell[372818, 12036, 494, 17, 29, "Text"],
Cell[373315, 12055, 4822, 137, 430, "Input"],
Cell[378140, 12194, 500, 19, 38, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[378677, 12218, 267, 7, 29, "Subsection"],
Cell[378947, 12227, 115, 3, 29, "Text"],
Cell[379065, 12232, 2598, 81, 221, "Input"],
Cell[381666, 12315, 1611, 59, 63, "Text"],
Cell[383280, 12376, 8826, 265, 599, "Input"],
Cell[392109, 12643, 1017, 36, 37, "Text"],
Cell[393129, 12681, 4641, 137, 357, "Input"],
Cell[397773, 12820, 595, 23, 37, "Text"]
}, Closed]]
}
]
*)

(* End of internal cache information *)
