(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    511958,      15620]
NotebookOptionsPosition[    501053,      15331]
NotebookOutlinePosition[    501832,      15358]
CellTagsIndexPosition[    501789,      15355]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[{
 StyleBox["9.3.1  Introduction to Filtering",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tIn the field of signal processing the design of digital signal \
filters involves the process of suppressing certain frequencies and boosting \
others.  A simplified filter model is\n\n",
 StyleBox["(9-22)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "+", 
    RowBox[{
     SubscriptBox["a", "1"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["a", "2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["b", "0"], " ", 
     RowBox[{"x", "[", "n", "]"}]}], "+", 
    RowBox[{
     SubscriptBox["b", "1"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["b", "2"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["b", "3"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "3"}], "]"}]}]}]}]]],
 ", \n\nwhere the input signal is ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], "=", 
   RowBox[{"x", "[", "n", "]"}]}]]],
 " is modified to obtain the output signal ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "n"], "=", 
   RowBox[{"y", "[", "n", "]"}]}]]],
 " using the recursion formula    \n\n",
 StyleBox["(9-23)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["b", "0"], " ", 
     RowBox[{"x", "[", "n", "]"}]}], "+", 
    RowBox[{
     SubscriptBox["b", "1"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["b", "2"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["b", "3"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "3"}], "]"}]}], "-", 
    RowBox[{
     SubscriptBox["a", "1"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "-", 
    RowBox[{
     SubscriptBox["a", "2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}]}]]],
 ".  \n\nThe implementation of ",
 StyleBox["(9-23)",
  FontColor->RGBColor[0, 0, 1]],
 " is straightforward and only requires starting values, then ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "n"], "=", 
   RowBox[{"y", "[", "n", "]"}]}]]],
 " is obtained by simple iteration.  Since the signals must have a starting \
point, it is common to require that  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], "=", "0"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "n"], "=", "0"}]]],
 "  for  ",
 Cell[BoxData[
  RowBox[{"n", "<", "0"}]]],
 ".  We emphasize this concept by making the following definition.  "
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 9.3 (Causal Sequence)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Given the the input ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["x", "n"], "}"}], 
   RowBox[{"n", "=", 
    RowBox[{"-", "\[Infinity]"}]}], "\[Infinity]"]]],
 " and output ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["y", "n"], "}"}], 
   RowBox[{"n", "=", 
    RowBox[{"-", "\[Infinity]"}]}], "\[Infinity]"]]],
 " sequences.  If  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], "=", "0"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "n"], "=", "0"}]]],
 "  for  ",
 Cell[BoxData[
  RowBox[{"n", "<", "0"}]]],
 ", the sequence is said to be causal.  "
}], "Text"],

Cell[TextData[{
 "\tGiven the causal sequence ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["x", "n"], "=", 
     RowBox[{"x", "[", "n", "]"}]}], "}"}], 
   RowBox[{"n", "=", "0"}], "\[Infinity]"]]],
 ", it is easy to calculate the solution ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["y", "n"], "=", 
     RowBox[{"y", "[", "n", "]"}]}], "}"}], 
   RowBox[{"n", "=", "0"}], "\[Infinity]"]]],
 " to ",
 StyleBox["(9-23)",
  FontColor->RGBColor[0, 0, 1]],
 ".  Use the fact that these sequences are causal: \n\n",
 StyleBox["(9-24)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", 
     RowBox[{"-", "3"}]], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   RowBox[{
    SubscriptBox["x", 
     RowBox[{"-", "2"}]], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   RowBox[{
    SubscriptBox["x", 
     RowBox[{"-", "1"}]], "=", 
    RowBox[{
     RowBox[{"0", "    ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "    ", 
      SubscriptBox["y", 
       RowBox[{"-", "2"}]]}], "=", "0"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   RowBox[{
    SubscriptBox["y", 
     RowBox[{"-", "1"}]], "=", "0"}]}]]],
 ". \n\nThen compute  \n\n",
 StyleBox["(9-25)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "0"], "   ", "=", "   ", 
    RowBox[{
     SubscriptBox["b", "0"], 
     SubscriptBox["x", "0"]}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["y", "1"], "   ", "=", "   ", 
    RowBox[{
     RowBox[{
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["x", "1"]}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["b", "1"], " ", 
      SubscriptBox["x", "0"]}], " ", "-", " ", 
     RowBox[{
      SubscriptBox["a", "1"], " ", 
      SubscriptBox["y", "0"]}]}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["y", "2"], "   ", "=", "   ", 
    RowBox[{
     RowBox[{
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["x", "2"]}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["b", "1"], " ", 
      SubscriptBox["x", "1"]}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["b", "2"], " ", 
      SubscriptBox["x", "0"]}], " ", "-", " ", 
     RowBox[{
      SubscriptBox["a", "1"], " ", 
      SubscriptBox["y", "1"]}], " ", "-", " ", 
     RowBox[{
      SubscriptBox["a", "2"], " ", 
      SubscriptBox["y", "0"]}]}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["y", "3"], "   ", "=", "   ", 
    RowBox[{
     RowBox[{
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["x", "3"]}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["b", "1"], " ", 
      SubscriptBox["x", "2"]}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["b", "2"], " ", 
      SubscriptBox["x", "1"]}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["b", "3"], " ", 
      SubscriptBox["x", "0"]}], " ", "-", " ", 
     RowBox[{
      SubscriptBox["a", "1"], " ", 
      SubscriptBox["y", "2"]}], " ", "-", " ", 
     RowBox[{
      SubscriptBox["a", "2"], " ", 
      RowBox[{
       SubscriptBox["y", "1"], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[".",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]}]}]}]}]]],
 "  \n\t \nThe general iterative step is   \n\n",
 StyleBox["(9-26)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "n"], "   ", "=", "   ", 
   RowBox[{
    RowBox[{
     SubscriptBox["b", "0"], " ", 
     SubscriptBox["x", "n"]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["b", "1"], " ", 
     SubscriptBox["x", 
      RowBox[{"n", "-", "1"}]]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["b", "2"], " ", 
     SubscriptBox["x", 
      RowBox[{"n", "-", "2"}]]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["b", "3"], " ", 
     SubscriptBox["x", 
      RowBox[{"n", "-", "3"}]]}], " ", "-", " ", 
    RowBox[{
     SubscriptBox["a", "1"], " ", 
     SubscriptBox["y", 
      RowBox[{"n", "-", "1"}]]}], " ", "-", " ", 
    RowBox[{
     SubscriptBox["a", "2"], " ", 
     SubscriptBox["y", 
      RowBox[{"n", "-", "2"}]]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["9.3.2  The Basic Filters",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tThe following three simplified basic filters serve as illustrations.  \
\n\t\n",
 StyleBox["(i) Zeroing Out Filter",
  FontColor->RGBColor[0, 0, 1]],
 "  \t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["b", "0"], " ", 
     RowBox[{"x", "[", "n", "]"}]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["b", "1"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["b", "2"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["b", "3"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "3"}], "]"}]}]}]}]]],
 ",     (note that  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "1"], "=", 
   RowBox[{
    RowBox[{"0", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     SubscriptBox["a", "2"]}], "=", "0"}]}]]],
 ").  \n\n",
 StyleBox["(ii) Boosting Up Filter",
  FontColor->RGBColor[0, 0, 1]],
 "  \t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["b", "0"], " ", 
     RowBox[{"x", "[", "n", "]"}]}], " ", "-", " ", 
    RowBox[{
     SubscriptBox["a", "1"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], " ", "-", " ", 
    RowBox[{
     SubscriptBox["a", "2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}]}]]],
 ",     (note that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["b", "1"], "=", "0"}], "  ", ",", 
   RowBox[{
    SubscriptBox["b", "2"], "=", 
    RowBox[{
     RowBox[{"0", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      SubscriptBox["b", "3"]}], "=", "0"}]}]}]]],
 ").  \n\n",
 StyleBox["(iii) Combination Filter",
  FontColor->RGBColor[0, 0, 1]],
 " \t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["b", "0"], " ", 
     RowBox[{"x", "[", "n", "]"}]}], "+", 
    RowBox[{
     SubscriptBox["b", "1"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["b", "2"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["b", "3"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "3"}], "]"}]}], "-", 
    RowBox[{
     SubscriptBox["a", "1"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "-", 
    RowBox[{
     SubscriptBox["a", "2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["\tThe transfer function  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"H", 
   RowBox[{"(", "z", ")"}]}]]],
 " ",
 StyleBox["for these model filters has the following general form \n",
  FontFamily->"Times New Roman"],
 "\n",
 StyleBox["(9-27)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox[
     RowBox[{"Y", 
      RowBox[{"(", "z", ")"}]}], 
     RowBox[{"X", 
      RowBox[{"(", "z", ")"}]}]], "  ", "=", "  ", 
    FractionBox[
     RowBox[{
      SubscriptBox["b", "0"], "+", 
      RowBox[{
       SubscriptBox["b", "1"], 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["b", "2"], 
       SuperscriptBox["z", 
        RowBox[{"-", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["b", "3"], 
       SuperscriptBox["z", 
        RowBox[{"-", "3"}]]}]}], 
     RowBox[{"1", "+", 
      RowBox[{
       SubscriptBox["a", "1"], 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["a", "2"], 
       SuperscriptBox["z", 
        RowBox[{"-", "2"}]]}]}]]}]}]]],
 ", \n\nwhere the z-transforms of the input and output sequences are ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"\[GothicCapitalZ]", "[", 
    SubscriptBox["x", "n"], "]"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"\[GothicCapitalZ]", "[", 
    SubscriptBox["y", "n"], "]"}]}]]],
 ", respectively.   In the previous section we mentioned that the general \
solution to a homogeneous difference equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "+", 
    RowBox[{
     SubscriptBox["a", "1"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["a", "2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}], "=", "0"}]]],
 "  is stable only if the zeros of the characteristic equation lie inside the \
unit circle.  Similarly, if a filter is stable then the poles of the transfer \
function  ",
 Cell[BoxData[
  RowBox[{"H", 
   RowBox[{"(", "z", ")"}]}]]],
 "  must all lie inside the unit circle. "
}], "Text"],

Cell[TextData[{
 "\tBefore developing the general theory, we would like to investigate the \
amplitude response  ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 " when the input signal is a linear combination of  ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{"\[Theta]", " ", "n"}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"sin", 
   RowBox[{"(", 
    RowBox[{"\[Theta]", " ", "n"}], ")"}]}]]],
 ".   The amplitude response for the frequency ",
 Cell[BoxData["\[Theta]"]],
 " uses the complex unit signal ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"]}]]],
 ", and is defined to be \n\n",
 StyleBox["(9-28)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", "\[Theta]", ")"}]}], " ", "=", " ", 
   RowBox[{"|", 
    RowBox[{"H", 
     RowBox[{"(", 
      SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"], ")"}]}], 
    "|"}]}]]],
 ". \n\nThe formula for ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}], " "}]]],
 " will be rigorously explained after a few introductory examples.  "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 9.21.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Given the filter  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "2"}], "]"}]}]}]]],
 ".\n\n",
 StyleBox["9.21 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that it is a zeroing out filter for the signals ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "4"], "n"}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"sin", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "4"], "n"}], ")"}]}]]],
 " and calculate the amplitude response  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", 
     FractionBox["\[Pi]", "4"], ")"}]}], "=", 
   RowBox[{"A", 
    RowBox[{"(", "0.7853981633974483`", ")"}]}]}]]],
 ".\n\n",
 StyleBox["9.21 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Calculate the amplitude responses ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "0.10", ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "A", 
   RowBox[{"(", "0.77", ")"}]}]]],
 " and investigate the the filtered signal for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", " ", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"0.10", " ", "n"}], ")"}]}], "+", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{"0.77", " ", "n"}], ")"}]}]}]}]]],
 ".  \n\n",
 StyleBox["9.21 (c).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Calculate the amplitude responses ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "0.10", ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "A", 
   RowBox[{"(", 
    FractionBox[
     RowBox[{"2", "\[Pi]"}], "3"], ")"}]}]]],
 " and investigate the the filtered signal for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", " ", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"0.10", " ", "n"}], ")"}]}], "+", 
    RowBox[{"0.20", "sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"2", "\[Pi]"}], "3"], " ", "n"}], ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJy12GlPE0EcBvCFFohGCTEEPKJAkUMxhpgYQgLIIfet3ChSzpabUu4bBUQD
IlFjTHxlYrw+hR9LX+DObJku7fMsrWIj6zD7e/47Ozts2611el39o06vu9eZ
XO5xTrjcvVPJZeMevcsWoWkRpZqmbSdron2oN32bQ/3fYZnYiJ7/1I4UG5s4
XpGp1ybbslu2xE+hsf+7CqSLll20MkQrylTkB8ingb5MubUf69NfxUbjqyqb
QbP+vsBgcNkbrEqkKfsNlM3A9UZNMyJL+IuliNY5GbCpMuIl9+YFX4zPajJR
wCG6osHeYVOlm+D0IkFfvCmThc8s0Wj8VucTFWLtFDB7vmK/8KGicPd1XuhL
iGNJ/csxi5/A8xWvVLUcEyyXGVktaP3bwWEK+DpES95hMa1ysPnh1UtV17wi
8K8wXbVGghfwmrEENbFi9V/XReuiaVfAmctaNiHRsg0cGOtL4AdIO7qOpj75
o//+nseO1p05ZgN9b3kJhzGD+t4Y1bLgKaD6GdB3wEskqeOcB8HXPHgN8FjQ
t89LXAU8DvS94iWuqOHHg+AeD15SwUQQ3OXBRBW8rFoWPF4tVjRhL3jwgqru
AMEdHoxTwTQQfM6DsSqYCYLbPHhWbO1CZ4HgFg/Ke1i00NkguGkKxog9OQA9
49XzAH/KeT7gG5wXAL7O+T3A1zgvBHyV8yLAVzgvBnyZ8xLAlzi/D/gi56WA
Lxh8Tvwn3zXQp8oyEJw3gguAoxLloMTcCSXkG1wlCM6Gd+yKfy+BRjFjlJhX
Q0Wfv6pAcJpfomrAvZzXAD7FeS3gHs7rAJ/kvB7wiVPjDYCPc94I+BjnDwAf
5fwh4COcNwE+zHkz4EOctwDuPjXeCriL8zbABzlvB3yA8w7A+znvBLyP80eA
93L+GPAezrsAd3L+BPBuzrsBN0oYt1n53SPwm4x/CMeDXaZgAEf3uB5Qwpgc
37sE+Cwib5h9IGhchJBvzKhEp3n4QV+60CT0gyodpjOgt3eLILpKA4C3cz4I
eBvnLsBbOXcD3sL5EODNnA8D3sT5iDHN+l4LNAZqNnI+DngD5xOA13M+CXgd
5x7AazmfAryGcy/g1ZxPA17F+QzglZzPAl7B+Rzg5ZzPA17G+YJaWBZoCdQs
4XwZ8GLOVwAv4nxVjdiHrG9B66C67/FUGHfADXVQX9b6U/mm4r7HpIuAo+d4
W2C0uWGPdlsdPjeUKdpRPIdP+0uF7nK0C4Z/h/M9VdMC7SuUzdGBQrc5eqPQ
LY7eia3d//ABog9ia/M/2oDoo9jKhwpJHH0SW/lQweJB488Td2kRfwCcn/Pv
\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{325, 135},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["Figure 9.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "The amplitude response ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", "\[Theta]", ")"}]}], "=", 
   RowBox[{"|", 
    RowBox[{"1", "-", " ", 
     RowBox[{
      SqrtBox["2"], 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], "+", 
     SuperscriptBox["z", 
      RowBox[{"-", "2"}]]}], "|"}]}]]],
 " for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "2"}], "]"}]}]}]]],
 ". "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{612, 140},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["Figure 9.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The input  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"0.10", "n"}], ")"}]}], "+", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{"0.77", "n"}], ")"}]}]}]}]]],
 "  and output  ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 "."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{612, 140},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["Figure 9.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The input ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"0.10", "n"}], ")"}]}], "+", 
    RowBox[{"0.20", "sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"2", "\[Pi]"}], "3"], " ", "n"}], ")"}]}]}]}]]],
 " and output  ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Solution", " ", 
   RowBox[{"9.21", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706101*^9, 3.506706101*^9}}],

Cell[TextData[{
 StyleBox["9.21 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  In Section 9.2, Example 9.19, we established that the difference equation \
 ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"x", "[", "n", "]"}]}], "=", "0"}]]],
 "  with initial conditions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{"2", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     RowBox[{"x", "[", "1", "]"}]}], "=", 
    SqrtBox["2"]}]}]]],
 "  has the solution  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   RowBox[{"2", "cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]]],
 ".  Thus ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "4"], 
     RowBox[{"(", 
      RowBox[{"n", "+", "2"}], ")"}]}], ")"}]}]]],
 " is a solution to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "2"}], "]"}]}], "=", "0"}]]],
 " and so are the signals ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "4"], "n"}], ")"}], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "sin", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "4"], "n"}], ")"}]}]]],
 ".  This can also be proven by direct substitution of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]]],
 ", and using the trigonometric identities  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", 
    RowBox[{"n", "-", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], "-", 
       FractionBox["\[Pi]", "4"]}], ")"}]}], "=", 
    RowBox[{
     FractionBox["1", 
      SqrtBox["2"]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["\[Pi]", "4"], "n"}], ")"}]}], "+", 
       RowBox[{"sin", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}], ")"}]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", 
    RowBox[{"n", "-", "2"}], "]"}], "=", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], "-", 
       FractionBox["\[Pi]", "2"]}], ")"}]}], "=", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]}]]],
 ".  An easy calculation shows that  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"x", "[", "n", "]"}], "-", 
     RowBox[{
      SqrtBox["2"], " ", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}], "+", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}], " "}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"cos", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], ")"}]}], "-", 
     RowBox[{
      SqrtBox["2"], 
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", 
         SqrtBox["2"]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"cos", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["\[Pi]", "4"], "n"}], ")"}]}], "+", 
          RowBox[{"sin", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}], ")"}]}], ")"}]}], 
     "+", " ", 
     RowBox[{"sin", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]}], 
   " "}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", "  ", "0"}]}]}]],
 "  \n\t\nTesting  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   RowBox[{"sin", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]]],
 "  is similar. "
}], "Text"],

Cell[TextData[{
 "\tFor this filter, the amplitude response is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", "\[Theta]", ")"}]}], "=", 
   RowBox[{"|", 
    RowBox[{"H", 
     RowBox[{"(", 
      SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"], ")"}]}], 
    "|"}]}]]],
 "  where  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], "=", " ", 
   RowBox[{"1", "-", 
    RowBox[{
     SqrtBox["2"], 
     SuperscriptBox["z", 
      RowBox[{"-", "1"}]]}], "+", 
    SuperscriptBox["z", 
     RowBox[{"-", "2"}]]}]}]]],
 "  is the transfer function.  Calculation reveals that \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", 
     FractionBox["\[Pi]", "4"], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"|", 
     RowBox[{"H", 
      RowBox[{"(", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"\[Pi]", "/", "4"}]}]], ")"}]}], "|"}], " ", "=", " ", 
    RowBox[{"|", 
     RowBox[{"1", "-", " ", 
      RowBox[{
       SqrtBox["2"], 
       SuperscriptBox[
        RowBox[{"(", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"\[Pi]", "/", "4"}]}]], ")"}], 
        RowBox[{"-", "1"}]]}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "4"}]}]], ")"}], 
       RowBox[{"-", "2"}]]}], "|"}]}]}]]],
 "\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", 
     FractionBox["\[Pi]", "4"], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"1", "-", " ", 
     RowBox[{
      SqrtBox["2"], 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "+", "\[ImaginaryI]"}], 
         SqrtBox["2"]], ")"}], 
       RowBox[{"-", "1"}]]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{"1", "+", "\[ImaginaryI]"}], 
        SqrtBox["2"]], ")"}], 
      RowBox[{"-", "2"}]]}], "  ", "=", "  ", 
    RowBox[{"1", "-", " ", 
     RowBox[{
      SqrtBox["2"], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"1", "-", "\[ImaginaryI]"}], 
        SqrtBox["2"]], ")"}]}], "-", "\[ImaginaryI]"}]}]}]]],
 " \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", 
     FractionBox["\[Pi]", "4"], ")"}]}], "  ", "=", "  ", "0"}]]],
 " \n\nThe graph of   ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 "  is given in Figure 9.4. "
}], "Text"],

Cell[TextData[{
 StyleBox["Figure 9.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "The amplitude response ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", "\[Theta]", ")"}]}], "=", 
   RowBox[{"|", 
    RowBox[{"1", "-", " ", 
     RowBox[{
      SqrtBox["2"], 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], "+", 
     SuperscriptBox["z", 
      RowBox[{"-", "2"}]]}], "|"}]}]]],
 " for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "2"}], "]"}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "Notice that there is a zero amplitude response at   ",
 Cell[BoxData[
  RowBox[{"\[Theta]", " ", "=", 
   FractionBox["\[Pi]", "4"]}]]],
 "  and that the amplitude response increases for values of  ",
 Cell[BoxData[
  RowBox[{"\[Theta]", " "}]]],
 " in the interval ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{
    FractionBox["\[Pi]", "4"], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "\[Pi]"}], "]"}]]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["9.21 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Calculate the amplitude responses ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "0.10", ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "A", 
   RowBox[{"(", "0.77", ")"}]}]]],
 " and investigate the the filtered signal for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", " ", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"0.10", " ", "n"}], ")"}]}], "+", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{"0.77", " ", "n"}], ")"}]}]}]}]]],
 ".  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", "0.10", ")"}]}], "  ", "=", "  ", 
   RowBox[{"|", 
    RowBox[{"1", "-", " ", 
     RowBox[{
      SqrtBox["2"], 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"0.10", "\[ImaginaryI]"}]], ")"}], 
       RowBox[{"-", "1"}]]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"0.10", "\[ImaginaryI]"}]], ")"}], 
      RowBox[{"-", "2"}]]}], "|"}]}]]],
 "  \t\n\t\t\t\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"A", 
     RowBox[{"(", "0.10", ")"}]}], "  ", "=", "  ", 
    RowBox[{"|", 
     RowBox[{"0.5729182", "\[InvisibleSpace]", "-", 
      RowBox[{"0.0574835589950729`", " ", "\[ImaginaryI]"}]}], "|"}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "   ", "0.5757948"}]}]}]],
 "  \n\t\t\n\t\t\tand\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", "0.77", ")"}]}], "  ", "=", "  ", 
   RowBox[{"|", 
    RowBox[{"1", "-", " ", 
     RowBox[{
      SqrtBox["2"], 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"0.77", "\[ImaginaryI]"}]], ")"}], 
       RowBox[{"-", "1"}]]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"0.77", "\[ImaginaryI]"}]], ")"}], 
      RowBox[{"-", "2"}]]}], "|"}]}]]],
 "  \t\t\n\t\t\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"A", 
     RowBox[{"(", "0.77", ")"}]}], "  ", "=", "  ", 
    RowBox[{"|", 
     RowBox[{"0.015512453546319582`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.015041934892840225`", " ", "\[ImaginaryI]"}]}], "|"}]}], " ",
    "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", "0.02160777684879144`"}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "From the above calculations we expect that components ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{"0.10", " ", "n"}], ")"}], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "cos", 
   RowBox[{"(", 
    RowBox[{"0.77", " ", "n"}], ")"}]}]]],
 "  of the signal are attenuated by the factors  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", "0.10", ")"}]}], "=", "0.5757948"}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", "0.77", ")"}]}], "=", "0.0216078"}]]],
 ",  respectively.  Hence the filter almost eliminates the signal component ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{"0.77", " ", "n"}], ")"}]}]]],
 " which is close to the \"zero-out\" frequency  ",
 Cell[BoxData[
  RowBox[{"0.7853981633974483`", "=", 
   FractionBox["\[Pi]", "4"]}]]],
 ".  The Figure 9.5 illustrates the situation. "
}], "Text"],

Cell[TextData[{
 StyleBox["Figure 9.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The input  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"0.10", "n"}], ")"}]}], "+", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{"0.77", "n"}], ")"}]}]}]}]]],
 "  and output  ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["9.21 (c).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Calculate the amplitude responses ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "0.10", ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "A", 
   RowBox[{"(", 
    FractionBox[
     RowBox[{"2", "\[Pi]"}], "3"], ")"}]}]]],
 " and investigate the the filtered signal for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", " ", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"0.10", " ", "n"}], ")"}]}], "+", 
    RowBox[{"0.20", "sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"2", "\[Pi]"}], "3"], " ", "n"}], ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "In part (b) we found ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", "0.10", ")"}]}], "=", "0.5757948"}]]],
 " and now we make the calculation \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", 
     FractionBox[
      RowBox[{"2", "\[Pi]"}], "3"], ")"}]}], "  ", "=", "  ", 
   RowBox[{"|", 
    RowBox[{"1", "-", " ", 
     RowBox[{
      SqrtBox["2"], 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "2", 
          RowBox[{"\[Pi]", "/", "3"}]}]], ")"}], 
       RowBox[{"-", "1"}]]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "2", 
         RowBox[{"\[Pi]", "/", "3"}]}]], ")"}], 
      RowBox[{"-", "2"}]]}], "|"}]}]]],
 "  \t\n\t\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", 
     FractionBox[
      RowBox[{"2", "\[Pi]"}], "3"], ")"}]}], "  ", "=", "  ", 
   RowBox[{"|", 
    RowBox[{"1", "-", 
     RowBox[{
      SqrtBox["2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], "-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["3"]}], "2"]}], ")"}]}], "-", 
     FractionBox["1", "2"], "+", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox["3"]}], "2"]}], "|"}]}]]],
 "  \t\n\t\t\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"A", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"2", "\[Pi]"}], "3"], ")"}]}], "  ", "=", "  ", 
    RowBox[{"|", 
     FractionBox[
      RowBox[{"1", "+", 
       SqrtBox["2"], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          SqrtBox["3"], "+", 
          SqrtBox["6"]}], ")"}]}]}], "2"], "|"}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", "2.24650723546738`"}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "We expect that components ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{"0.10", " ", "n"}], ")"}], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "0.20", "sin", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"2", "\[Pi]"}], "3"], " ", "n"}], ")"}]}]]],
 "  of the input signal are attenuated by ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", "0.10", ")"}]}], "=", "0.5757948"}]]],
 ", and amplified by  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", 
     FractionBox[
      RowBox[{"2", "\[Pi]"}], "3"], ")"}]}], "=", "2.24650723546738`"}]]],
 ", respectively.  The Figure 9.6 illustrates the situation. "
}], "Text"],

Cell[TextData[{
 StyleBox["Figure 9.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The input ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"0.10", "n"}], ")"}]}], "+", 
    RowBox[{"0.20", "sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"2", "\[Pi]"}], "3"], " ", "n"}], ")"}]}]}]}]]],
 " and output  ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 "."
}], "Text"],

Cell["\<\
Background for the z-transform and its application for solving difference \
equations can be found in the book.\
\>", "Text",
 CellChangeTimes->{{3.506762898125*^9, 3.5067628988125*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"9.21", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706103484375*^9, 3.5067061035*^9}}],

Cell[TextData[{
 StyleBox["9.21.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Given the recursion formula  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "2"}], "]"}]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["9.21 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   ",
 "Show that it is a zeroing out filter for the signals ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "4"], "n"}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"sin", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "4"], "n"}], ")"}]}]]],
 " and calculate the amplitude response  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", 
     FractionBox["\[Pi]", "4"], ")"}]}], "=", 
   RowBox[{"A", 
    RowBox[{"(", "0.7853981633974483`", ")"}]}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"filter", " ", "=", " ", 
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], " ", "\[Equal]", " ", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], "-", 
       RowBox[{
        SqrtBox["2"], " ", 
        RowBox[{"x", "[", 
         RowBox[{"n", "-", "1"}], "]"}]}], "+", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}]}]}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The FIR filter is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \>\"", ",", " ", "filter"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{"n", " ", "\[Pi]"}], "4"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Use the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-1] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "1"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-2] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Substitute into the filter and get\>\"", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  \>\"", ",", 
      "\"\<y[n] == x[n] - \!\(\*SqrtBox[\(2\)]\)x[n-1] + x[n-2]\>\""}], "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \>\"", ",", " ", "filter"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  y[n] == \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "\"\< - \!\(\*SqrtBox[\(2\)]\)(\>\"",
       ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "1"}], "]"}], "]"}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}], "]"}], ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  y[n] == \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "\"\< - (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{
        SqrtBox["2"], 
        RowBox[{"x", "[", 
         RowBox[{"n", "-", "1"}], "]"}]}], "]"}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}], "]"}], ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \>\"", ",", " ", 
      RowBox[{"Simplify", "[", "filter", "]"}]}], " ", "]"}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{3.3994829073125*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"filter", " ", "=", " ", 
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], " ", "\[Equal]", " ", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], "-", 
       RowBox[{
        SqrtBox["2"], " ", 
        RowBox[{"x", "[", 
         RowBox[{"n", "-", "1"}], "]"}]}], "+", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}]}]}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The FIR filter is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \>\"", ",", " ", "filter"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Sin", "[", 
      FractionBox[
       RowBox[{"n", " ", "\[Pi]"}], "4"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Use the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-1] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "1"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-2] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Substitute into the filter and get\>\"", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  \>\"", ",", 
      "\"\<y[n] == x[n] - \!\(\*SqrtBox[\(2\)]\)x[n-1] + x[n-2]\>\""}], "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \>\"", ",", " ", "filter"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  y[n] == \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "\"\< - \!\(\*SqrtBox[\(2\)]\)(\>\"",
       ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "1"}], "]"}], "]"}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}], "]"}], ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  y[n] == \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "\"\< - (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{
        SqrtBox["2"], 
        RowBox[{"x", "[", 
         RowBox[{"n", "-", "1"}], "]"}]}], "]"}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}], "]"}], ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \>\"", ",", " ", 
      RowBox[{"Simplify", "[", "filter", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399482910140625*^9, 3.39949220546875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     RowBox[{"1", "-", " ", 
      RowBox[{
       SqrtBox["2"], 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}], "+", 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}]}], ";"}], " ", "\n", 
   RowBox[{"graph1", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Theta]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "\[Pi]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "3.5"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "\[Pi]", ",", 
           FractionBox["\[Pi]", "4"]}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "3.5", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< A[\[Theta]] =  |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Theta]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], ",", 
      "\"\<|\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(\[Pi]\), \(4\)]\)] = |H[\!\(\*SuperscriptBox[\
\(\[ExponentialE]\), \(\[ImaginaryI] \*FractionBox[\(\[Pi]\), \(4\)]\)]\)]| = \
\>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          FractionBox["\[Pi]", "4"]}]], "]"}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The amplitude response for the filter\>\"", "]"}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n+2] = x[n] - \!\(\*SqrtBox[\(2\)]\)x[n-1] + x[n-2]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Where the transfer function is\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< H[z] = \>\"", ",", 
      RowBox[{"H", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\[Theta]\
\)]\)] = \>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}]}], " ", "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482916140625*^9, 3.39948292475*^9}, {
  3.40014018384375*^9, 3.40014018403125*^9}}],

Cell[TextData[{
 StyleBox["Figure 9.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "The amplitude response ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", "\[Theta]", ")"}]}], "=", 
   RowBox[{"|", 
    RowBox[{"1", "-", " ", 
     RowBox[{
      SqrtBox["2"], 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], "+", 
     SuperscriptBox["z", 
      RowBox[{"-", "2"}]]}], "|"}]}]]],
 " for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "2"}], "]"}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["9.21 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   Calculate the amplitude responses ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "0.10", ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "A", 
   RowBox[{"(", "0.77", ")"}]}]]],
 " and investigate the the filtered signal for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", " ", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"0.10", " ", "n"}], ")"}]}], "+", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{"0.77", " ", "n"}], ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.77", ",", 
          FractionBox["\[Pi]", "2"], ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "3.5", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   A[\[Theta]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Theta]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], ",", 
      "\"\<|\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[0.10] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(0.10  \
\[ImaginaryI]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         FractionBox["10", "100"], "\[ImaginaryI]"}]], "]"}], ",", 
      "\"\<|\>\""}], " ", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[0.10] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(0.10  \
\[ImaginaryI]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"0.10", "\[ImaginaryI]"}]], "]"}], ",", "\"\<|\>\""}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[0.10] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(0.10  \
\[ImaginaryI]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"0.10", "\[ImaginaryI]"}]], "]"}], "]"}]}], " ", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<And\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[0.77] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(0.77  \
\[ImaginaryI]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         FractionBox["77", "100"], "\[ImaginaryI]"}]], "]"}], ",", 
      "\"\<|\>\""}], " ", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[0.77] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(0.77  \
\[ImaginaryI]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"0.77", "\[ImaginaryI]"}]], "]"}], ",", "\"\<|\>\""}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[0.77] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(0.77  \
\[ImaginaryI]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"0.77", "\[ImaginaryI]"}]], "]"}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994829343125*^9, 3.399482936078125*^9}, 3.39949222*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"0.10", " ", "n"}], "]"}], "+", 
      RowBox[{"Sin", "[", 
       RowBox[{"0.77", " ", "n"}], "]"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "65"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"0.10", " ", "i"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"X2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"0.10", " ", "i"}], "]"}], "+", 
         RowBox[{"Sin", "[", 
          RowBox[{"0.77", " ", "i"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X1", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", "X1"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X2", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", "X2"}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y2", "=", 
     RowBox[{"Y1", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", 
          RowBox[{"m0", "+", "9"}]}], "}"}]}], "]"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "10"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"m0", "+", "10"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        SubscriptBox["Y1", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Chop", "[", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["X1", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           " ", "-", 
           RowBox[{
            SqrtBox["2"], 
            SubscriptBox["X1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], " ", "+", 
           SubscriptBox["X1", 
            RowBox[{"\[LeftDoubleBracket]", 
             RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}], " ", 
          ")"}], " ", "]"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{
        SubscriptBox["Y2", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Chop", "[", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["X2", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           " ", "-", 
           RowBox[{
            SqrtBox["2"], 
            SubscriptBox["X2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], " ", "+", 
           SubscriptBox["X2", 
            RowBox[{"\[LeftDoubleBracket]", 
             RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}], " ", 
          ")"}], " ", "]"}]}], ";"}]}], "  ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"X1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"X1", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"X2", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"Y1", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"Y2", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X1pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X2pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g22", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", "g22", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "m0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<n\>\"", ",", "\"\<x[n]\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Input signal x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Take", "[", 
        RowBox[{"Y1pts", ",", 
         RowBox[{"-", "64"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "m0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr4", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Take", "[", 
        RowBox[{"Y2pts", ",", 
         RowBox[{"-", "66"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "m0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g44", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Take", "[", 
        RowBox[{"Y2pts", ",", 
         RowBox[{"-", "66"}]}], "]"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr3", ",", "gr4", ",", "g44", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "m0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.6"}], ",", "1.0"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "0.6"}], ",", "1.2", ",", "0.3"}], "]"}]}], "}"}]}], 
     ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<n\>\"", ",", "\"\<y[n]\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Output signal y[n] = x[n] - \!\(\*SqrtBox[\(2\)]\)x[n-1] + x[n-2]\>\
\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The  amplitude  responses\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Low  frequency:  A[0.10] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(0.10  \[ImaginaryI]\)]\)]| =  \
\>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"0.10", "\[ImaginaryI]"}]], "]"}], "]"}]}], " ", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<High frequency:  A[0.77] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(0.77  \[ImaginaryI]\)]\)]| =  \
\>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"0.77", "\[ImaginaryI]"}]], "]"}], "]"}]}], " ", "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948293990625*^9, 3.39948296271875*^9}, {
   3.3994837654375*^9, 3.39948377696875*^9}, 3.40014018996875*^9, {
   3.40014074596875*^9, 3.400140800125*^9}, {3.400140911015625*^9, 
   3.40014091803125*^9}, {3.400140960828125*^9, 3.400141125125*^9}, {
   3.4003475298125*^9, 3.40034754925*^9}}],

Cell[TextData[{
 StyleBox["Figure 9.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "The amplitude response ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", "\[Theta]", ")"}]}], "=", 
   RowBox[{"|", 
    RowBox[{"1", "-", " ", 
     RowBox[{
      SqrtBox["2"], 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], "+", 
     SuperscriptBox["z", 
      RowBox[{"-", "2"}]]}], "|"}]}]]],
 " for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "2"}], "]"}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["9.21 (c).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   ",
 "Calculate the amplitude responses ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "0.10", ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "A", 
   RowBox[{"(", 
    FractionBox[
     RowBox[{"2", "\[Pi]"}], "3"], ")"}]}]]],
 " and investigate the the filtered signal for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", " ", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"0.10", " ", "n"}], ")"}]}], "+", 
    RowBox[{"0.20", "sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"2", "\[Pi]"}], "3"], " ", "n"}], ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0.1", ",", 
          FractionBox[
           RowBox[{"2", "\[Pi]"}], "3"], ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "3.5", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   A[\[Theta]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Theta]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], ",", 
      "\"\<|\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[0.10] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(0.10  \
\[ImaginaryI]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         FractionBox["10", "100"], "\[ImaginaryI]"}]], "]"}], ",", 
      "\"\<|\>\""}], " ", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[0.10] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(0.10  \
\[ImaginaryI]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"0.10", "\[ImaginaryI]"}]], "]"}], ",", "\"\<|\>\""}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[0.10] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(0.10  \
\[ImaginaryI]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"0.10", "\[ImaginaryI]"}]], "]"}], "]"}]}], " ", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<And\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(2  \[Pi]\), \(3\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]2\[Pi]/3\)]\)]| = \
|\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "2", 
         RowBox[{"\[Pi]", "/", "3"}]}]], "]"}], ",", "\"\<| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "2", 
          RowBox[{"\[Pi]", "/", "3"}]}]], "]"}], "]"}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(2  \[Pi]\), \(3\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]2\[Pi]/3\)]\)]| = \
|\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "2.", 
         RowBox[{"\[Pi]", "/", "3"}]}]], "]"}], ",", "\"\<| \>\""}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(2  \[Pi]\), \(3\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]2\[Pi]/3\)]\)]| = \
 \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "2.", 
          RowBox[{"\[Pi]", "/", "3"}]}]], "]"}], "]"}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482969546875*^9, 3.39948297675*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"0.10", "n"}], "]"}], "+", 
      RowBox[{"0.20", 
       RowBox[{"Sin", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"2", "\[Pi]"}], "3"], " ", "n"}], "]"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "65"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"0.10", " ", "i"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"X2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"0.10", " ", "i"}], "]"}], "+", 
         RowBox[{"0.20", 
          RowBox[{"Sin", "[", 
           RowBox[{
            FractionBox[
             RowBox[{"2", "\[Pi]"}], "3"], " ", "i"}], "]"}]}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X1", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", "X1"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X2", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", "X2"}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y2", "=", 
     RowBox[{"Y1", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", 
          RowBox[{"m0", "+", "9"}]}], "}"}]}], "]"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "10"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"m0", "+", "10"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        SubscriptBox["Y1", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Chop", "[", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["X1", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           " ", "-", 
           RowBox[{
            SqrtBox["2"], 
            SubscriptBox["X1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], " ", "+", 
           SubscriptBox["X1", 
            RowBox[{"\[LeftDoubleBracket]", 
             RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}], " ", 
          ")"}], " ", "]"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{
        SubscriptBox["Y2", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Chop", "[", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["X2", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           " ", "-", 
           RowBox[{
            SqrtBox["2"], 
            SubscriptBox["X2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], " ", "+", 
           SubscriptBox["X2", 
            RowBox[{"\[LeftDoubleBracket]", 
             RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}], " ", 
          ")"}], " ", "]"}]}], ";"}]}], "  ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"X1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"X1", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"X2", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"Y1", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"Y2", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X1pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X2pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g22", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", "g22", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "m0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "0.5"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<n\>\"", ",", "\"\<x[n]\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Input signal x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Take", "[", 
        RowBox[{"Y1pts", ",", 
         RowBox[{"-", "64"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "m0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr4", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "m0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g44", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr3", ",", "gr4", ",", "g44", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "m0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "0.5"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<n\>\"", ",", "\"\<y[n]\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Output signal y[n] = x[n] - \!\(\*SqrtBox[\(2\)]\)x[n-1] + x[n-2]\>\
\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The  amplitude  responses\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Low  frequency:  A[0.10] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]0  .10\)]\)]| =  \
\>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"0.10", "\[ImaginaryI]"}]], "]"}], "]"}]}], " ", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<High frequency:  A[\!\(\*FractionBox[\(2  \[Pi]\), \(3\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]2\[Pi]/3\)]\)]| = \
 \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "2.", 
          RowBox[{"\[Pi]", "/", "3"}]}]], "]"}], "]"}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       0.20\[Cross]A[\!\(\*FractionBox[\(2  \[Pi]\), \(3\)]\)] = \
0.20\[Cross]|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \
\(\[ImaginaryI]2\[Pi]/3\)]\)]| =  \>\"", ",", 
      RowBox[{"0.20", 
       RowBox[{"Abs", "[", 
        RowBox[{"H", "[", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "2.", 
           RowBox[{"\[Pi]", "/", "3"}]}]], "]"}], "]"}]}]}], " ", "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482980984375*^9, 3.399482998875*^9}, {
   3.399483801453125*^9, 3.3994838070625*^9}, 3.400140200984375*^9, {
   3.4001411696875*^9, 3.400141203078125*^9}, {3.400347554484375*^9, 
   3.4003475824375*^9}}],

Cell[TextData[{
 StyleBox["Figure 9.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The input ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"0.10", "n"}], ")"}]}], "+", 
    RowBox[{"0.20", "sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"2", "\[Pi]"}], "3"], " ", "n"}], ")"}]}]}]}]]],
 " and output  ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 "."
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.22.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Given the filter  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "-", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}]}]]],
 ".\n\n",
 StyleBox["9.22 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that it is a boosting up filter for the signals ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "4"], "n"}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"sin", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "4"], "n"}], ")"}]}]]],
 " and calculate the amplitude response  ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", 
    FractionBox["\[Pi]", "4"], ")"}]}]]],
 ".\n\n",
 StyleBox["9.22 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Calculate the amplitude responses ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", 
    FractionBox["\[Pi]", "8"], ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "A", 
   RowBox[{"(", "2.60", ")"}]}]]],
 " and investigate the the filtered signal for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", " ", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "8"], " ", "n"}], ")"}]}], "+", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}], "+", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{"2.60", " ", "n"}], ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztmWlPE0EYx5d2KaWgeKMtR4smvBDvW7wQC/HAEDVGozFW0ACKIOCBghcg
RfBISPRDaPHiq+krTd2Z2U7H7f+Z7pJ9aQOzwzO/5z/PzDyzs106UiM9N/tT
I71dqXj7UGqwp7drON42MGSZgiWGUZI0DGM6brB61qraRdb6ybaxgln8r/9m
lyDryjb84Rdu4TX2mxRN3yUbZzWT1RKsVqr4/wD+9cDWwEvzH5v1aReVr1I2
QfrmbU7HQtmNlEpA8f0GZBNY744yI1wiLxZjtUruEJQy7MNbWwqXYIFdwqyx
Vtb6FKwOxB4AtrjiU6+bBuOXDLbUpXYUTI0t9hN3VYrNtbTQF5exOCUoLgZs
zvGyT43MtQZtDhGpgJLbBN200kmG8rlGM6082OPe9Grlmnc4t1hc1jrkDo8p
ydRoT50aSk5WJIbxll3mvWRUteLoaHKz5Skb8uXbMMQsG+hOP2gGqXH7KGcs
SkOL/5uUpjQrw+x82ySgMZmaJlVzSIyysopJNAmJJ3i3hLE5CCQHWBlhks1a
yQpgzoXaJxLN4pJajXLt4LrFdrTI08VVUKo7bCmRopZPp3O+IzJ7keM16Xie
Xs0rErpIQ5ckdJmGLrDSZNBVGjonYrdar9NQp4Ru0NBZCXXT0BkJ3aKhUxLq
oaGTufVRbBq8XWrepqE2oKnBkwC3H2SmRc4ZBrxXnwCO/cJxBuBIohVI3C0i
wVMUOQ5467sFSAx6kzgGJO4JibQMFW3mo8BxiF6iIwAfpvHDAB/xDT8E8Ps0
3gzwBzR+EOAPafwAwB/5hu8H+CiN7wP44yXh/N6e33guzr69QEycEMY4wMt4
6eoI3AOUx2jlCFDOBY6C1EiFtSPeDcTGi4i5OBd3AdmnQtbtCamRQHmwE+DP
fMN3APy5b/h2gL/wDd8G8Je+4VsBPuEbvgXgkwLnx6pJZU8xRweOtkYTkJgS
EmlqG/BHrM20o9szkes0Ap1X6hhc3XlMscvkVwKopz9oy0RrNv/GSJWYppev
HOB13iQiAK8BtjQtUQHwmDeJSjkDUeA4QzsuB3i1N4kqgK8Ftte0xAqAr/Em
sRLgq4BtlpZAOIpsjpZYDXA0PxoJNO5lwPaGlkCzj5JM+IoniPydysVzyDqZ
bsVk4YZzdV9YD5TLgO2dEBkjNxZ+SonKIYSA6Hsh6v15he9b/hpgXp2FJX+B
X1RG5+KhxMb5Hz78h2AOdBECtozAZ6npctg+C3xCDspwvi0v9AnIcaO3jJ8U
ReJFXkDThqYSBWF3M+lYAyxqatoyipDSR16yIGlDVJx2TFNkQumGXJCXC0pg
fGlCOJwgtU4ZfUYZJX8BC61hkA==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{325, 135},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["Figure 9.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "The amplitude response ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", "\[Theta]", ")"}]}], "=", 
   RowBox[{"|", 
    FractionBox["1", 
     RowBox[{"1", "-", 
      RowBox[{
       FractionBox["2", "3"], " ", 
       SqrtBox["2"], 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}], "+", 
      RowBox[{
       FractionBox["4", "9"], 
       SuperscriptBox["z", 
        RowBox[{"-", "2"}]]}]}]], "|"}]}]]],
 " for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", 
    RowBox[{
     FractionBox["2", "3"], 
     SqrtBox["2"], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "-", 
    RowBox[{
     FractionBox["4", "9"], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}]}]]],
 ". "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{650, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["Figure 9.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The input  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "8"], " ", "n"}], ")"}]}], "+", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}], "+", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{"2.60", " ", "n"}], ")"}]}]}]}]]],
 "  and output  ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Solution", " ", 
   RowBox[{"9.22", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706107046875*^9, 3.506706107046875*^9}}],

Cell[TextData[{
 StyleBox["9.22 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  \tIn Section 9.2, in Example 9.20 (b), we found that the difference \
equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], "=", 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]]],
 "  has the general solution  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", "3"], ")"}], "n"], "cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "n"}], " ", ")"}]}], "+", 
    RowBox[{
     SubscriptBox["c", "2"], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", "3"], ")"}], "n"], "sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}], "+", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"9", " "}], 
      SqrtBox["13"]], " ", "cos", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], "+", 
       RowBox[{"arctan", 
        RowBox[{"(", 
         FractionBox["3", "2"], ")"}]}]}], ")"}]}]}]}]]],
 ".\n\nSince  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["c", "1"], 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["2", "3"], ")"}], "n"], "cos", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["\[Pi]", "4"], " ", "n"}], " ", ")"}]}], "+", 
      RowBox[{
       SubscriptBox["c", "2"], 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["2", "3"], ")"}], "n"], "sin", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}]}], ")"}]}], " ", "=", 
   " ", "0"}]]],
 ",  the output signal ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 " tends to the steady state signal  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"9", " "}], 
    SqrtBox["13"]], " ", "cos", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox["\[Pi]", "4"], "n"}], "+", 
     RowBox[{"arctan", 
      RowBox[{"(", 
       FractionBox["3", "2"], ")"}]}]}], ")"}]}]]],
 "  as  ",
 Cell[BoxData[
  RowBox[{"n", "\[Rule]", "\[Infinity]"}]]],
 ".   Hence the signal  ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "4"], "n"}], ")"}]}]]],
 "  is boosted up by an amplification factor of  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"9", " "}], 
    SqrtBox["13"]], " ", "=", " ", "2.49615"}]]],
 ".  A similar boost will be observed for the signal    ",
 Cell[BoxData[
  RowBox[{"sin", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "4"], "n"}], ")"}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tFor this filter, the amplitude response is ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", "\[Theta]", ")"}]}], "=", 
   RowBox[{"|", 
    RowBox[{"H", 
     RowBox[{"(", 
      SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"], ")"}]}], 
    "|"}]}]]],
 "  where  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"H", 
     RowBox[{"(", "z", ")"}]}], "=", " ", 
    FractionBox["1", 
     RowBox[{"1", "-", 
      RowBox[{
       FractionBox["2", "3"], " ", 
       SqrtBox["2"], 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}], "+", 
      RowBox[{
       FractionBox["4", "9"], 
       SuperscriptBox["z", 
        RowBox[{"-", "2"}]]}]}]]}]}]]],
 ".  We compute the boost for  ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "4"], "n"}], ")"}]}]]],
 " by evaluating  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", 
     FractionBox["\[Pi]", "4"], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"1", "/"}], "|", 
    RowBox[{"1", "-", 
     RowBox[{
      FractionBox["2", "3"], " ", 
      SqrtBox["2"], 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          FractionBox["\[Pi]", "4"]}]], ")"}], 
       RowBox[{"-", "1"}]]}], "+", 
     RowBox[{
      FractionBox["4", "9"], 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          FractionBox["\[Pi]", "4"]}]], ")"}], 
       RowBox[{"-", "2"}]]}]}], "|"}]}]]],
 "   \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"A", 
     RowBox[{"(", 
      FractionBox["\[Pi]", "4"], ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"1", "/"}], "|", 
     RowBox[{"1", "-", 
      RowBox[{
       FractionBox["2", "3"], " ", 
       SqrtBox["2"], 
       RowBox[{"(", " ", 
        FractionBox[
         RowBox[{"1", "-", "\[ImaginaryI]"}], 
         SqrtBox["2"]], ")"}]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]"}], "9"]}], " ", "|"}]}], 
   "  "}], "\[IndentingNewLine]", 
  RowBox[{"          ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"|", 
      RowBox[{"9", 
       FractionBox[
        RowBox[{"3", "-", 
         RowBox[{"2", " ", "\[ImaginaryI]"}]}], "13"]}], "|"}], "  ", "=", 
     "  ", 
     FractionBox[
      RowBox[{"9", " ", 
       SqrtBox["13"]}], "13"]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "   ", "2.496150883013531`"}]}]}]],
 ", \n\nwhich is the same value that was obtained in Example 9.20 (b) in \
Section 9.2.  The amplitude response ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 " for an arbitrary frequency  ",
 Cell[BoxData["\[Theta]"]],
 "  for is given in the Figure 9.7 below.  Observe that a maximum occurs near \
 ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "=", 
   FractionBox["\[Pi]", "4"]}]]],
 "and there is amplification for signals with  ",
 Cell[BoxData[
  RowBox[{"0", "<", "\[Theta]", "<", "1.4944"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Figure 9.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "The amplitude response ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", "\[Theta]", ")"}]}], "=", 
   RowBox[{"|", 
    FractionBox["1", 
     RowBox[{"1", "-", 
      RowBox[{
       FractionBox["2", "3"], " ", 
       SqrtBox["2"], 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}], "+", 
      RowBox[{
       FractionBox["4", "9"], 
       SuperscriptBox["z", 
        RowBox[{"-", "2"}]]}]}]], "|"}]}]]],
 " for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", 
    RowBox[{
     FractionBox["2", "3"], 
     SqrtBox["2"], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "-", 
    RowBox[{
     FractionBox["4", "9"], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["9.22 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Calculate the amplitude responses ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", 
    FractionBox["\[Pi]", "8"], ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "A", 
   RowBox[{"(", "2.60", ")"}]}]]],
 " and investigate the filtered signal for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", " ", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "8"], " ", "n"}], ")"}]}], "+", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}], "+", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{"2.60", " ", "n"}], ")"}]}]}]}]]],
 ".  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", 
     FractionBox["\[Pi]", "8"], ")"}]}], "  ", "=", "   ", 
   RowBox[{
    RowBox[{"1", "/"}], "|", 
    RowBox[{"1", "-", 
     RowBox[{
      FractionBox["2", "3"], 
      SqrtBox["2"], 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "8"}]}]], ")"}], 
       RowBox[{"-", "1"}]]}], "+", 
     RowBox[{
      FractionBox["4", "9"], 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "8"}]}]], ")"}], 
       RowBox[{"-", "2"}]]}]}], "|"}]}]]],
 "  \n\t\t\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"A", 
     RowBox[{"(", 
      FractionBox["\[Pi]", "8"], ")"}]}], "  ", "=", "  ", 
    RowBox[{"|", 
     RowBox[{"2.2315852602022903`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.23426011564658894`", " ", "\[ImaginaryI]"}]}], "|"}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"          ", 
   RowBox[{"=", "   ", "2.243847270946682`"}]}]}]],
 "  \n\t\t\n\t\t\tand\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", "2.60", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"1", "/"}], "|", 
    RowBox[{"1", "-", 
     RowBox[{
      FractionBox["2", "3"], 
      SqrtBox["2"], 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2.60", "\[ImaginaryI]"}]], ")"}], 
       RowBox[{"-", "1"}]]}], "+", 
     RowBox[{
      FractionBox["4", "9"], 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2.60", "\[ImaginaryI]"}]], ")"}], 
       RowBox[{"-", "2"}]]}]}], "|"}]}]]],
 "  \n\t\t\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"A", 
     RowBox[{"(", "2.60", ")"}]}], "  ", "=", "  ", 
    RowBox[{"|", 
     RowBox[{"0.4168309759180071`", "\[InvisibleSpace]", "-", 
      RowBox[{"0.18166408106617016`", " ", "\[ImaginaryI]"}]}], "|"}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "   ", "0.45469759272990906`"}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "Using the above calculations we conclude that the components  ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "8"], " ", "n"}], ")"}], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "sin", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}]]],
 "  will be boosted up by the factors ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", 
     FractionBox["\[Pi]", "8"], ")"}]}], "=", 
   RowBox[{
    RowBox[{"2.243847270946683`", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "A", 
     RowBox[{"(", 
      FractionBox["\[Pi]", "4"], ")"}]}], "=", "2.4961508830135313`"}]}]]],
 ", respectively; and the component ",
 Cell[BoxData[
  RowBox[{"sin", 
   RowBox[{"(", 
    RowBox[{"2.60", " ", "n"}], ")"}]}]]],
 "  will be attenuated by the factor ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", "2.60", ")"}]}], "=", "0.45469759272990906`"}]]],
 ".  The situation is shown in Figure 9.8. "
}], "Text"],

Cell[TextData[{
 StyleBox["Figure 9.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The input  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "8"], " ", "n"}], ")"}]}], "+", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}], "+", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{"2.60", " ", "n"}], ")"}]}]}]}]]],
 "  and output  ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 "."
}], "Text"],

Cell["\<\
Background for the z-transform and its application for solving difference \
equations can be found in the book.\
\>", "Text",
 CellChangeTimes->{{3.506762912984375*^9, 3.506762913953125*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"9.22", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.5067061084375*^9, 3.5067061084375*^9}}],

Cell[TextData[{
 StyleBox["9.22.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Given the recursion formula  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "-", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["9.22 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that it is a boosting up filter for the signals ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "4"], "n"}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"sin", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "4"], "n"}], ")"}]}]]],
 " and calculate the amplitude response  ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", 
    FractionBox["\[Pi]", "4"], ")"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     FractionBox["1", 
      RowBox[{"1", "-", 
       RowBox[{
        FractionBox["2", "3"], " ", 
        SqrtBox["2"], 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}], "+", 
       RowBox[{
        FractionBox["4", "9"], 
        SuperscriptBox["z", 
         RowBox[{"-", "2"}]]}]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "\[Theta]_", "]"}], "=", 
     RowBox[{"Abs", "[", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"graph2", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"A", "[", "\[Theta]", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Theta]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "\[Pi]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "2.6"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "\[Pi]", ",", 
           FractionBox["\[Pi]", "4"]}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "2.5", ",", "0.5"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<\[Theta]\>\"", ",", "\"\<A(\[Theta])\>\""}], "}"}]}], 
      ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< A[\[Theta]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Theta]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], ",", 
      "\"\<|\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(\[Pi]\), \(4\)]\)] = |H[\!\(\*SuperscriptBox[\
\(\[ExponentialE]\), \(\[ImaginaryI] \*FractionBox[\(\[Pi]\), \(4\)]\)]\)]| = \
\>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          FractionBox["\[Pi]", "4"]}]], "]"}], "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"Abs", "[", 
        RowBox[{"H", "[", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           FractionBox["\[Pi]", "4"]}]], "]"}], "]"}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The amplitude response for the filter\>\"", "]"}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n+2] = x[n] + \!\(\*FractionBox[\(2\), \(3\)]\) \!\(\*SqrtBox[\(2\
\)]\) y[n+1] - \!\(\*FractionBox[\(4\), \(9\)]\) y[n]\>\"", "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Where the transfer function is\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< H[z] = \>\"", ",", 
      RowBox[{"H", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\[Theta]\
\)]\)] = \>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}]}], " ", "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399483032515625*^9, 3.399483036984375*^9}, 
   3.400140207*^9}],

Cell[TextData[{
 StyleBox["Figure 9.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "The amplitude response ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", "\[Theta]", ")"}]}], "=", 
   RowBox[{"|", 
    FractionBox["1", 
     RowBox[{"1", "-", 
      RowBox[{
       FractionBox["2", "3"], " ", 
       SqrtBox["2"], 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}], "+", 
      RowBox[{
       FractionBox["4", "9"], 
       SuperscriptBox["z", 
        RowBox[{"-", "2"}]]}]}]], "|"}]}]]],
 " for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", 
    RowBox[{
     FractionBox["2", "3"], 
     SqrtBox["2"], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "-", 
    RowBox[{
     FractionBox["4", "9"], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["9.22 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Calculate the amplitude responses ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", 
    FractionBox["\[Pi]", "8"], ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "A", 
   RowBox[{"(", "2.60", ")"}]}]]],
 " and investigate the the filtered signal for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", " ", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "8"], " ", "n"}], ")"}]}], "+", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}], "+", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{"2.60", " ", "n"}], ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"graph2", ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          FractionBox["\[Pi]", "8"], ",", 
          FractionBox["\[Pi]", "4"], ",", "2.60", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "3.5", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     A[\[Theta]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Theta]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], ",", 
      "\"\<|\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  A[\!\(\*FractionBox[\(\[Pi]\), \(8\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\[Pi]/8\)]\)]| = \
|\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"\[Pi]", "/", "8"}]}]], "]"}], ",", "\"\<|\>\""}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  A[\!\(\*FractionBox[\(\[Pi]\), \(8\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\[Pi]/8\)]\)]| = \
|\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"\[Pi]", "/", "8."}]}]], "]"}], ",", "\"\<|\>\""}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  A[\!\(\*FractionBox[\(\[Pi]\), \(8\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\[Pi]/8\)]\)]| =  \
\>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "8."}]}]], "]"}], "]"}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<And\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  A[\!\(\*FractionBox[\(\[Pi]\), \(4\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\[Pi]/4\)]\)]| = \
|\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"\[Pi]", "/", "4"}]}]], "]"}], ",", "\"\<|\>\""}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  A[\!\(\*FractionBox[\(\[Pi]\), \(4\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\[Pi]/4\)]\)]| = \
|\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"\[Pi]", "/", "4."}]}]], "]"}], ",", "\"\<|\>\""}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  A[\!\(\*FractionBox[\(\[Pi]\), \(4\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\[Pi]/4\)]\)]| =  \
\>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "4."}]}]], "]"}], "]"}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<And\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[2.60] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]2  .60\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         FractionBox["260", "100"], "\[ImaginaryI]"}]], "]"}], ",", 
      "\"\<|\>\""}], " ", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[2.60] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]2  .60\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2.60", "\[ImaginaryI]"}]], "]"}], ",", "\"\<|\>\""}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[2.60] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]2  .60\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2.60", "\[ImaginaryI]"}]], "]"}], "]"}]}], " ", "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399483042421875*^9, 3.3994830449375*^9}, 
   3.399492263625*^9}],

Cell[BoxData[
 RowBox[{" ", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox["\[Pi]", "8"], " ", "n"}], "]"}], "+", 
      RowBox[{"Sin", "[", 
       RowBox[{
        FractionBox["\[Pi]", "4"], " ", "n"}], "]"}], "+", 
      RowBox[{"Sin", "[", 
       RowBox[{"2.60", " ", "n"}], "]"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "32"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox["\[Pi]", "8"], " ", "i"}], "]"}], "+", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox["\[Pi]", "4"], " ", "i"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"X2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox["\[Pi]", "8"], " ", "i"}], "]"}], "+", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox["\[Pi]", "4"], " ", "i"}], "]"}], "+", 
         RowBox[{"Sin", "[", 
          RowBox[{"2.60", " ", "i"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X1", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", "X1"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X2", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", "X2"}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y2", "=", 
     RowBox[{"Y1", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", 
          RowBox[{"m0", "+", "9"}]}], "}"}]}], "]"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "10"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"m0", "+", "10"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        SubscriptBox["Y1", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Chop", "[", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["X1", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           " ", "+", 
           RowBox[{
            FractionBox["2", "3"], 
            SqrtBox["2"], " ", 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], "-", 
           RowBox[{
            FractionBox["4", "9"], 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}]}], " ", 
          ")"}], " ", "]"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{
        SubscriptBox["Y2", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Chop", "[", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["X2", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           " ", "+", 
           RowBox[{
            FractionBox["2", "3"], 
            SqrtBox["2"], 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], " ", "-", 
           RowBox[{
            FractionBox["4", "9"], 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}]}], " ", 
          ")"}], " ", "]"}]}], ";"}]}], "  ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"X1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"X1", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"X2", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"Y1", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"Y2", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X1pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X2pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g22", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", "g22", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "m0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.4"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<n\>\"", ",", "\"\<x[n]\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Input signal x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr4", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g44", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr3", ",", "gr4", ",", "g44", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "m0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4.8"}], ",", "4.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "2"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<n\>\"", ",", "\"\<y[n]\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Output signal y[n] = x[n] - \!\(\*SqrtBox[\(2\)]\)x[n-1] + x[n-2]\>\
\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  A[\!\(\*FractionBox[\(\[Pi]\), \(8\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\[Pi]/8\)]\)]| =  \
\>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "8."}]}]], "]"}], "]"}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  A[\!\(\*FractionBox[\(\[Pi]\), \(4\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\[Pi]/4\)]\)]| =  \
\>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "4."}]}]], "]"}], "]"}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[2.60] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]2  .60\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2.60", "\[ImaginaryI]"}]], "]"}], "]"}]}], " ", "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399483047921875*^9, 3.39948308171875*^9}, {
   3.399483338171875*^9, 3.399483389015625*^9}, {3.399483440109375*^9, 
   3.399483445203125*^9}, {3.399483486234375*^9, 3.399483488015625*^9}, {
   3.399483729484375*^9, 3.399483734734375*^9}, 3.399492272359375*^9, 
   3.400140215015625*^9, {3.400141219625*^9, 3.400141247328125*^9}, {
   3.400347595671875*^9, 3.40034761975*^9}}],

Cell[TextData[{
 StyleBox["Figure 9.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The input  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "8"], " ", "n"}], ")"}]}], "+", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}], "+", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{"2.60", " ", "n"}], ")"}]}]}]}]]],
 "  and output  ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 "."
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["9.3.3  The General Filter Equation",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n\n\tT",
  FontFamily->"Times New Roman"],
 "he general form of a ",
 Cell[BoxData[
  SuperscriptBox["P", "th"]]],
 " ",
 StyleBox["order filter difference equation",
  FontFamily->"Times New Roman"],
 " is  ",
 StyleBox["\n\t\n",
  FontFamily->"Times New Roman"],
 StyleBox["(9-29)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\t\t\t",
  FontFamily->"Times New Roman"],
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], "+", 
      RowBox[{
       SubscriptBox["a", "1"], " ", 
       RowBox[{"y", "[", 
        RowBox[{"n", "-", "1"}], "]"}]}], "+", 
      RowBox[{
       SubscriptBox["a", "2"], " ", 
       RowBox[{"y", "[", 
        RowBox[{"n", "-", "2"}], "]"}]}], "+"}], "..."}], "+", 
    RowBox[{
     SubscriptBox["a", 
      RowBox[{"P", "-", "1"}]], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "P", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["a", "P"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "P"}], "]"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"=", "   ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["b", "0"], " ", 
        RowBox[{"x", "[", "n", "]"}]}], "+", 
       RowBox[{
        SubscriptBox["b", "1"], " ", 
        RowBox[{"x", "[", 
         RowBox[{"n", "-", "1"}], "]"}]}], "+", 
       RowBox[{
        SubscriptBox["b", "2"], " ", 
        RowBox[{"x", "[", 
         RowBox[{"n", "-", "2"}], "]"}]}], "+"}], "..."}], "+", 
     RowBox[{
      SubscriptBox["b", 
       RowBox[{"Q", "-", "1"}]], " ", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "Q", "+", "1"}], "]"}]}], "+", 
     RowBox[{
      SubscriptBox["b", "Q"], " ", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "Q"}], "]"}]}]}]}]}]}]],
 " ",
 StyleBox["\n\nwhere ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["a", "p"], "}"}], 
   RowBox[{"p", "=", "1"}], "P"]]],
 StyleBox[" and ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["b", "q"], "}"}], 
   RowBox[{"q", "=", "0"}], "Q"]]],
 StyleBox[" are constants. ",
  FontFamily->"Times New Roman"],
 " Note carefully that the terms involved are of the form ",
 Cell[BoxData[
  RowBox[{"y", "[", 
   RowBox[{"n", "-", "p"}], "]"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"y", "[", 
   RowBox[{"n", "-", "q"}], "]"}]]],
 " where ",
 Cell[BoxData[
  RowBox[{"p", "\[GreaterEqual]", "0"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"q", "\[GreaterEqual]", "0"}]]],
 ", which makes these terms time delayed. ",
 StyleBox["The compact form of writing the difference equation is \n\n",
  FontFamily->"Times New Roman"],
 StyleBox["(9-30)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\t\t\t",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], " ", "+", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"p", "=", "0"}], "P"], 
     RowBox[{
      SubscriptBox["a", "p"], 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "p"}], "]"}]}]}]}], "  ", "=", "  ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"q", "=", "0"}], "Q"], 
    RowBox[{
     SubscriptBox["b", "q"], 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "q"}], "]"}]}]}]}]]],
 ",  \n\t\t\nwhere the input signal ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], "=", 
   RowBox[{"x", "[", "n", "]"}]}]]],
 " is modified to obtain the output signal ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "n"], "=", 
   RowBox[{"y", "[", "n", "]"}]}]]],
 " using the recursion formula    \n\t\t\n",
 StyleBox["(9-31)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", "  ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"q", "=", "0"}], "Q"], 
     RowBox[{
      SubscriptBox["b", "q"], 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "q"}], "]"}]}]}], " ", "-", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"p", "=", "1"}], "P"], 
     RowBox[{
      SubscriptBox["a", "p"], 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "p"}], "]"}]}]}]}]}]]],
 ".  \n\nThe portion  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"q", "=", "0"}], "Q"], 
   RowBox[{
    SubscriptBox["b", "q"], 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "q"}], "]"}]}]}]]],
 " will \"zero out\" signals and  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"p", "=", "1"}], "P"], 
   RowBox[{
    SubscriptBox["a", "p"], 
    RowBox[{"y", "[", 
     RowBox[{"n", "-", "p"}], "]"}]}]}]]],
 " will \"boost up\" signals. "
}], "Text"],

Cell[TextData[{
 StyleBox["Remark 9.14.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Formula ",
 StyleBox["(9-31)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" is called the recursion equation and the recursion coefficients \
are ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["a", "p"], "}"}], 
   RowBox[{"p", "=", "1"}], "P"]],
  FontFamily->"Times New Roman"],
 StyleBox[" and ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["b", "q"], "}"}], 
   RowBox[{"q", "=", "0"}], "Q"]],
  FontFamily->"Times New Roman"],
 StyleBox[".  It ",
  FontFamily->"Times New Roman"],
 "explicitly shows that the present output  ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 "  is a function of the past values  ",
 Cell[BoxData[
  RowBox[{"y", "[", 
   RowBox[{"n", "-", "p"}], "]"}]]],
 ",  for ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"p", "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "2", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "P"}]]],
 ", the present input  ",
 Cell[BoxData[
  RowBox[{"x", "[", "n", "]"}]]],
 ",  and the previous inputs  ",
 Cell[BoxData[
  RowBox[{"x", "[", 
   RowBox[{"n", "-", "q"}], "]"}]]],
 "  for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"q", "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "2", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "Q"}]]],
 ".  The sequences can be regarded as signals and they are zero for negative \
indices.  With this information we can now define the general formula for the \
transfer function  ",
 Cell[BoxData[
  RowBox[{"H", 
   RowBox[{"(", "z", ")"}]}]]],
 ".  Using the time delayed-shift property for causal sequences and taking \
the z-transform of each term in ",
 StyleBox["(9-31)",
  FontColor->RGBColor[0, 0, 1]],
 ", we obtain  \n\n",
 StyleBox["(9-32)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", "[", "z", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"-", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"p", "=", "1"}], "P"], 
      RowBox[{
       SubscriptBox["a", "p"], 
       RowBox[{"Y", "[", "z", "]"}], 
       SuperscriptBox["z", 
        RowBox[{"-", "p"}]]}]}]}], "  ", "+", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"q", "=", "0"}], "Q"], 
     RowBox[{
      SubscriptBox["b", "q"], 
      RowBox[{"X", "[", "z", "]"}], 
      SuperscriptBox["z", 
       RowBox[{"-", "q"}]]}]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "We can factor   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", "[", "z", "]"}], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   RowBox[{"Y", "[", "z", "]"}]}]]],
 "  out of the summations and write this in an equivalent form \n\n",
 StyleBox["(9-33)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"Y", "[", "z", "]"}], 
    RowBox[{"(", 
     RowBox[{"1", " ", "+", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"p", "=", "1"}], "P"], " ", 
       RowBox[{
        SubscriptBox["a", "p"], 
        SuperscriptBox["z", 
         RowBox[{"-", "p"}]]}]}]}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"X", "[", "z", "]"}], " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"q", "=", "0"}], "Q"], " ", 
     RowBox[{
      SubscriptBox["b", "q"], 
      SuperscriptBox["z", 
       RowBox[{"-", "q"}]]}]}]}]}]]],
 ". \n\nFrom equation ",
 StyleBox["(9-33)",
  FontColor->RGBColor[0, 0, 1]],
 " we obtain \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox[
     RowBox[{"Y", "[", "z", "]"}], 
     RowBox[{"X", "[", "z", "]"}]], "  ", "=", "  ", 
    FractionBox[
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"q", "=", "0"}], "Q"], " ", 
      RowBox[{
       SubscriptBox["b", "q"], 
       SuperscriptBox["z", 
        RowBox[{"-", "q"}]]}]}], 
     RowBox[{"1", " ", "+", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"p", "=", "1"}], "P"], " ", 
       RowBox[{
        SubscriptBox["a", "p"], 
        SuperscriptBox["z", 
         RowBox[{"-", "p"}]]}]}]}]]}]}]]],
 "  \n\t\t\nwhich leads to the following important definition."
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 9.4 (Transfer Function)",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["  The transfer function corresponding to the ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  SuperscriptBox["P", "th"]]],
 StyleBox[" order difference equation (8) is given by  \n",
  FontFamily->"Times New Roman"],
 "\n",
 StyleBox["(9-34)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox[
     RowBox[{"Y", "[", "z", "]"}], 
     RowBox[{"X", "[", "z", "]"}]], "  ", "=", "  ", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["b", "0"], "+", 
        RowBox[{
         SubscriptBox["b", "1"], 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}], "+", 
        RowBox[{
         SubscriptBox["b", "2"], 
         SuperscriptBox["z", 
          RowBox[{"-", "2"}]]}], "+"}], "..."}], "+", 
      RowBox[{
       SubscriptBox["b", 
        RowBox[{"Q", "-", "1"}]], 
       SuperscriptBox["z", 
        RowBox[{
         RowBox[{"-", "Q"}], "+", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["b", "Q"], 
       SuperscriptBox["z", 
        RowBox[{"-", "Q"}]]}]}], 
     RowBox[{
      RowBox[{
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["a", "1"], 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}], "+", 
        RowBox[{
         SubscriptBox["a", "2"], 
         SuperscriptBox["z", 
          RowBox[{"-", "2"}]]}], "+"}], "..."}], "+", 
      RowBox[{
       SubscriptBox["a", 
        RowBox[{"P", "-", "1"}]], 
       SuperscriptBox["z", 
        RowBox[{
         RowBox[{"-", "P"}], "+", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["a", "P"], 
       SuperscriptBox["z", 
        RowBox[{"-", "P"}]]}]}]]}]}]]],
 ". \n\nFormula ",
 StyleBox["(9-34)",
  FontColor->RGBColor[0, 0, 1]],
 " is the transfer function for an infinite impulse response filter (IIR \
filter).   In the special case when the denominator is unity it becomes the \
transfer function for a finite impulse response filter (FIR filter)."
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 9.5 (Unit-Sample Response)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The sequence  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"H", 
     RowBox[{"(", "z", ")"}]}], "]"}]}]]],
 " corresponding to the transfer function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}]}], 
    RowBox[{"X", 
     RowBox[{"(", "z", ")"}]}]]}]]],
 " is called the unit-sample response.  "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 9.6 (Output Response)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The output response  ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 "  of a the filter (10) given an input signal  ",
 Cell[BoxData[
  RowBox[{"x", "[", "n", "]"}]]],
 "  is given by the inverse z-transformation \n\n",
 StyleBox["(9-35)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[GothicCapitalZ]", 
      RowBox[{"-", "1"}]], "[", 
     RowBox[{"Y", 
      RowBox[{"(", "z", ")"}]}], "]"}], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["\[GothicCapitalZ]", 
      RowBox[{"-", "1"}]], "[", 
     RowBox[{"H", 
      RowBox[{"(", "z", ")"}], "X", 
      RowBox[{"(", "z", ")"}]}], "]"}]}]}]]],
 ",   \n\t\t\nand in convolution form it is given by  \n\n",
 StyleBox["(9-36)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "0"}], "n"], " ", 
    RowBox[{
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "i"}], "]"}], 
     RowBox[{"h", "[", "i", "]"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tAnother important use of the transfer function is to study how a filter \
affects various frequencies.  In practice, a continuous time signal is \
sampled at a frequency  ",
 Cell[BoxData[
  SubscriptBox["f", "S"]]],
 "  that is at least twice the highest input signal frequency to avoid \
frequency fold-over, or aliasing. That is because the Fourier transform of a \
sampled signal is periodic with period  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Omega]", "S"], " ", "=", " ", 
   FractionBox[
    RowBox[{"2", "\[Pi]"}], 
    SubscriptBox["f", "S"]]}]]],
 ",  though we will not prove this here.  Aliasing prevents accurate recovery \
of the original signal from its samples. \n\n\tNow it can be shown that the \
argument of the Fourier transform maps onto the z-plane unit circle via the \
formula\n\n",
 StyleBox["(9-37)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t ",
 Cell[BoxData[
  RowBox[{"\[Theta]", " ", "=", " ", 
   RowBox[{"2", "\[Pi]", " ", 
    FractionBox["f", 
     SubscriptBox["f", "S"]]}]}]]],
 ",    where  ",
 Cell[BoxData["\[Theta]"]],
 "  is called the normalized frequency.  \n\nTherefore the z-transform \
evaluated on the unit circle is also periodic, except with period ",
 Cell[BoxData[
  RowBox[{"2", "\[Pi]"}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 9.6 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Amplitude Response",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[")",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  \tThe amplitude response ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}], " "}]]],
 " is defined to be the magnitude of the transfer function evaluated at the \
complex unit signal ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"]}]]],
 ".  The formula is   \n\n",
 StyleBox["(9-38)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", "\[Theta]", ")"}]}], "  ", "=", "  ", 
   RowBox[{"|", 
    RowBox[{"H", 
     RowBox[{"(", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], ")"}]}], "|"}]}]]],
 " over the interval ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"0", ",", "\[Pi]"}], "]"}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "\tSinusoidal signals are linear combinations of  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Theta]"}]]}]]],
 ".  To determine the amplitude response we input  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], " ", "=", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "n", " ", "\[Theta]"}]]}]]],
 "  which has z-transform   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"\[GothicCapitalZ]", "[", 
     RowBox[{"x", "[", "n", "]"}], "]"}], " ", "=", " ", 
    FractionBox["z", 
     RowBox[{"z", " ", "-", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]]}]}]]],
 "  \nThe z-transform of the output is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"X", 
     RowBox[{"(", "z", ")"}], "H", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     FractionBox["z", 
      RowBox[{"z", " ", "-", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]], "H", 
     RowBox[{"(", "z", ")"}]}]}]}]]],
 "  which can be written as \n\n",
 StyleBox["(9-39)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"X", 
     RowBox[{"(", "z", ")"}], "H", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"z", 
     FractionBox["1", 
      RowBox[{"z", " ", "-", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]], 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["b", "0"], "+", 
         RowBox[{
          SubscriptBox["b", "1"], 
          SuperscriptBox["z", 
           RowBox[{"-", "1"}]]}], "+", 
         RowBox[{
          SubscriptBox["b", "2"], 
          SuperscriptBox["z", 
           RowBox[{"-", "2"}]]}], "+"}], "..."}], "+", 
       RowBox[{
        SubscriptBox["b", 
         RowBox[{"Q", "-", "1"}]], 
        SuperscriptBox["z", 
         RowBox[{
          RowBox[{"-", "Q"}], "+", "1"}]]}], "+", 
       RowBox[{
        SubscriptBox["b", "Q"], 
        SuperscriptBox["z", 
         RowBox[{"-", "Q"}]]}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["a", "1"], 
          SuperscriptBox["z", 
           RowBox[{"-", "1"}]]}], "+", 
         RowBox[{
          SubscriptBox["a", "2"], 
          SuperscriptBox["z", 
           RowBox[{"-", "2"}]]}], "+"}], "..."}], "+", 
       RowBox[{
        SubscriptBox["a", 
         RowBox[{"P", "-", "1"}]], 
        SuperscriptBox["z", 
         RowBox[{
          RowBox[{"-", "P"}], "+", "1"}]]}], "+", 
       RowBox[{
        SubscriptBox["a", "P"], 
        SuperscriptBox["z", 
         RowBox[{"-", "P"}]]}]}]]}]}]}]]],
 "\n\nIt is possible to use a technique like partial fraction expansions to \
write ",
 StyleBox["(9-39)",
  FontColor->RGBColor[0, 0, 1]],
 " in the form \n\n",
 StyleBox["(9-40)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"z", " ", 
      FractionBox[
       SubscriptBox["F", "0"], 
       RowBox[{"z", " ", "-", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]]}], " ", "+", " ", 
     RowBox[{"Q", 
      RowBox[{"(", "z", ")"}]}]}], " ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["F", "0"], " ", 
      FractionBox["z", 
       RowBox[{"z", " ", "-", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]]}], " ", "+", " ", 
     RowBox[{"Q", 
      RowBox[{"(", "z", ")"}]}]}]}]}]]],
 ", \n\nwhere  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["F", "0"], " ", "=", " ", 
   RowBox[{"H", 
    RowBox[{"(", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tFor stable solutions we have already mentioned (see Section 9.2.1) that \
the poles of the transfer function must all lie inside the unit circle.  \
Hence the terms in the solution  ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 "  corresponding to the poles of  ",
 Cell[BoxData[
  RowBox[{"Q", 
   RowBox[{"(", "z", ")"}]}]]],
 "  are all transient and decay to zero as ",
 Cell[BoxData[
  RowBox[{"n", "\[Rule]", "\[Infinity]"}]]],
 ".  The steady state portion of the solution   ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 "  is the inverse of the term ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["F", "0"], 
   RowBox[{"\[GothicCapitalZ]", "[", 
    FractionBox["z", 
     RowBox[{"z", " ", "-", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]], "]"}]}]]],
 " and its magnitude is \n\n",
 StyleBox["(9-41)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", "\[Theta]", ")"}]}], "  ", "=", "  ", 
   RowBox[{"|", 
    RowBox[{"H", 
     RowBox[{"(", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], ")"}]}], "|"}]}]]],
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]n", " ", "\[Theta]"}]], "|"}], "  ", "=", "  ", 
   RowBox[{"|", 
    RowBox[{"H", 
     RowBox[{"(", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], ")"}]}], "|"}]}]]],
 ". "
}], "Text"],

Cell["This proof is in the book.", "Text"]
}, Open  ]],

Cell[TextData[{
 StyleBox["\tT",
  FontFamily->"Times New Roman"],
 "he fundamental theorem of algebra implies that the numerator has ",
 Cell[BoxData["Q"]],
 " roots (called zeros) and the denominator has ",
 Cell[BoxData["P"]],
 " roots (called poles).  The zeros ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["z", "q"], "}"}], 
   RowBox[{"q", "=", "1"}], "Q"]]],
 " may be chosen in conjugate pairs on the unit circle and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    SubscriptBox["z", "q"], "|"}], "=", "1"}]]],
 " for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"q", "=", "1"}], ",", "2", ",", "...", ",", "Q"}]]],
 ".   For stability, all the poles ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["w", "p"], "}"}], 
   RowBox[{"p", "=", "1"}], "P"]]],
 " must inside the unit circle and  ",
 Cell[BoxData[
  RowBox[{"|", 
   SubscriptBox["w", "p"], "|", 
   RowBox[{"<", "1"}]}]]],
 " for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"p", "=", "1"}], ",", "2", ",", "...", ",", "P"}]]],
 ".   Furthermore, the poles are chosen to be real numbers and/or in \
conjugate pairs.  This will guarantee that the ",
 StyleBox["recursion coefficients",
  FontFamily->"Times New Roman"],
 " are all real numbers.  IIR filters may be all pole or zero-pole and \
stability is a concern; FIR filters and all zero-filters are always stable. "
}], "Text"],

Cell[TextData[{
 StyleBox["9.3.4  Design of Filters",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n\n\tIn practice recursion formula (10) is used to calculate the \
output signal.  However, digital filter design is based on the above theory.  \
One starts by selecting the location of zeros and poles corresponding to \
filter design requirements and constructing the transfer function  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}]}], 
    RowBox[{"X", 
     RowBox[{"(", "z", ")"}]}]]}]]],
 ".  Since t",
 StyleBox["he coefficients in ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"H", 
   RowBox[{"(", "z", ")"}]}]]],
 StyleBox[" are real, all zeros and poles having an imaginary component must \
occur in conjugate pairs.  ",
  FontFamily->"Times New Roman"],
 "Then the ",
 StyleBox["recursion coefficients",
  FontFamily->"Times New Roman"],
 " are identified in (13) and used in (10) to write the recursive filter.  \
Both the numerator and denominator of   ",
 Cell[BoxData[
  RowBox[{"H", 
   RowBox[{"(", "z", ")"}]}]]],
 " can be factored into quadratic factors with real coefficients and possibly \
one or two linear factors with real coefficients.  The following principles \
are used to construct  ",
 Cell[BoxData[
  RowBox[{"H", 
   RowBox[{"(", "z", ")"}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["(i) Zeroing Out Factors",
  FontColor->RGBColor[0, 0, 1]],
 "  \n\n\tTo filter out the signals ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{"\[Theta]", " ", "n"}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"sin", 
   RowBox[{"(", 
    RowBox[{"\[Theta]", " ", "n"}], ")"}]}]]],
 ", use factors of the form \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"(", " ", 
     FractionBox[
      RowBox[{"z", "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "z"], ")"}], 
    RowBox[{"(", " ", 
     FractionBox[
      RowBox[{"z", "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Theta]"}]]}], "z"], ")"}]}], 
   "  ", "=", "  ", 
   RowBox[{"1", " ", "-", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Theta]"}]]}], ")"}], 
     SuperscriptBox["z", 
      RowBox[{"-", "1"}]]}], " ", "+", " ", 
    SuperscriptBox["z", 
     RowBox[{"-", "2"}]]}]}]]],
 "   if   ",
 Cell[BoxData[
  RowBox[{"0", "<", "\[Theta]", "<", "\[Pi]"}]]],
 ",    and  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", " ", 
    FractionBox[
     RowBox[{"z", "-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]]}], "z"], ")"}], "  ", "=", 
   "  ", 
   RowBox[{"1", "+", 
    SuperscriptBox["z", 
     RowBox[{"-", "1"}]]}]}]]],
 "   if   ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "=", "\[Pi]"}]]],
 ",  \n\nin the numerator of  ",
 Cell[BoxData[
  RowBox[{"H", 
   RowBox[{"(", "z", ")"}]}]]],
 ".  They will contribute to the term \n\n",
 StyleBox["(9-42)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["b", "0"], "+", 
      RowBox[{
       SubscriptBox["b", "1"], 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["b", "2"], 
       SuperscriptBox["z", 
        RowBox[{"-", "2"}]]}], "+"}], "..."}], "+", 
    RowBox[{
     SubscriptBox["b", 
      RowBox[{"Q", "-", "1"}]], 
     SuperscriptBox["z", 
      RowBox[{
       RowBox[{"-", "Q"}], "+", "1"}]]}], "+", 
    RowBox[{
     SubscriptBox["b", "Q"], 
     SuperscriptBox["z", 
      RowBox[{"-", "Q"}]]}]}], "  ", "=", "  ", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["z", "Q"], 
        SubscriptBox["b", "0"]}], "+", 
       RowBox[{
        SubscriptBox["b", "1"], 
        SuperscriptBox["z", 
         RowBox[{"Q", "-", "1"}]]}], "+", 
       RowBox[{
        SubscriptBox["b", "2"], 
        SuperscriptBox["z", 
         RowBox[{"Q", "-", "2"}]]}], "+"}], "..."}], "+", 
     RowBox[{
      SubscriptBox["b", 
       RowBox[{"Q", "-", "1"}]], "z"}], "+", 
     SubscriptBox["b", "Q"]}], 
    SuperscriptBox["z", "Q"]]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["(ii) Boosting Up Factors",
  FontColor->RGBColor[0, 0, 1]],
 "  \n\n\tTo amplify the signals ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{"\[Theta]", " ", "n"}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"sin", 
   RowBox[{"(", 
    RowBox[{"\[Theta]", " ", "n"}], ")"}]}]]],
 ", use factors of the form \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"(", " ", 
     FractionBox[
      RowBox[{"z", "-", 
       RowBox[{"\[Rho]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]]}]}], "z"], ")"}], 
    RowBox[{"(", " ", 
     FractionBox[
      RowBox[{"z", "-", 
       RowBox[{"\[Rho]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]]}]}], "z"], ")"}]}],
    "  ", "=", "  ", 
   RowBox[{"1", " ", "-", " ", 
    RowBox[{"\[Rho]", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]]}], ")"}], 
     SuperscriptBox["z", 
      RowBox[{"-", "1"}]]}], " ", "+", " ", 
    RowBox[{
     SuperscriptBox["\[Rho]", "2"], " ", 
     SuperscriptBox["z", 
      RowBox[{"-", "2"}]]}]}]}]]],
 "     if  ",
 Cell[BoxData[
  RowBox[{"0", "<", "\[Rho]", "<", "1"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"0", "<", "\[Phi]", "<", "\[Pi]"}]]],
 ",    and\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", " ", 
    FractionBox[
     RowBox[{"z", "-", 
      RowBox[{"\[Rho]", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]]}]}], "z"], ")"}], "  ", "=", 
   "  ", 
   RowBox[{"1", " ", "+", " ", 
    RowBox[{"\[Rho]", " ", 
     SuperscriptBox["z", 
      RowBox[{"-", "1"}]]}]}]}]]],
 "     if  ",
 Cell[BoxData[
  RowBox[{"0", "<", "\[Rho]", "<", "1"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", "=", "\[Pi]"}]]],
 ",    and  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", " ", 
    FractionBox[
     RowBox[{"z", "-", "\[Rho]"}], "z"], ")"}], "  ", "=", "  ", 
   RowBox[{"1", " ", "-", " ", 
    RowBox[{"\[Rho]", " ", 
     SuperscriptBox["z", 
      RowBox[{"-", "1"}]]}]}]}]]],
 "     if  ",
 Cell[BoxData[
  RowBox[{"0", "<", "\[Rho]", "<", "1"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", "=", "0"}]]],
 ",  \n\nin the denominator of  ",
 Cell[BoxData[
  RowBox[{"H", 
   RowBox[{"(", "z", ")"}]}]]],
 ".  They will contribute to the term \n\n",
 StyleBox["(9-43)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"1", "+", 
      RowBox[{
       SubscriptBox["a", "1"], 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["a", "2"], 
       SuperscriptBox["z", 
        RowBox[{"-", "2"}]]}], "+"}], "..."}], "+", 
    RowBox[{
     SubscriptBox["a", 
      RowBox[{"P", "-", "1"}]], 
     SuperscriptBox["z", 
      RowBox[{
       RowBox[{"-", "P"}], "+", "1"}]]}], "+", 
    RowBox[{
     SubscriptBox["a", "P"], 
     SuperscriptBox["z", 
      RowBox[{"-", "P"}]]}]}], "  ", "=", "  ", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["z", "P"], "+", 
       RowBox[{
        SubscriptBox["a", "1"], 
        SuperscriptBox["z", 
         RowBox[{"P", "-", "1"}]]}], "+", 
       RowBox[{
        SubscriptBox["a", "2"], 
        SuperscriptBox["z", 
         RowBox[{"P", "-", "2"}]]}], "+"}], "..."}], "+", 
     RowBox[{
      SubscriptBox["a", 
       RowBox[{"P", "-", "1"}]], "z"}], "+", 
     SubscriptBox["a", "P"]}], 
    SuperscriptBox["z", "P"]]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["(iii) Attenuating Factors",
  FontColor->RGBColor[0, 0, 1]],
 "  \n\n\tTo attenuate the signals ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{"\[Theta]", " ", "n"}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"sin", 
   RowBox[{"(", 
    RowBox[{"\[Theta]", " ", "n"}], ")"}]}]]],
 ",  use factors of the form \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"(", " ", 
     FractionBox[
      RowBox[{"z", "-", 
       RowBox[{"\[Rho]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]}], "z"], ")"}], 
    RowBox[{"(", " ", 
     FractionBox[
      RowBox[{"z", "-", 
       RowBox[{"\[Rho]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Theta]"}]]}]}], "z"], 
     ")"}]}], "  ", "=", "  ", 
   RowBox[{"1", " ", "-", " ", 
    RowBox[{"\[Rho]", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Theta]"}]]}], ")"}], 
     SuperscriptBox["z", 
      RowBox[{"-", "1"}]]}], " ", "+", " ", 
    RowBox[{
     SuperscriptBox["\[Rho]", "2"], " ", 
     SuperscriptBox["z", 
      RowBox[{"-", "2"}]]}]}]}]]],
 "     if  ",
 Cell[BoxData[
  RowBox[{"0", "<", "\[Rho]", "<", "1"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"0", "<", "\[Theta]", "<", "\[Pi]"}]]],
 ",    and  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", " ", 
    FractionBox[
     RowBox[{"z", "-", 
      RowBox[{"\[Rho]", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]]}]}], "z"], ")"}], "  ", "=", 
   "  ", 
   RowBox[{"1", " ", "+", " ", 
    RowBox[{"\[Rho]", " ", 
     SuperscriptBox["z", 
      RowBox[{"-", "1"}]]}]}]}]]],
 "     if  ",
 Cell[BoxData[
  RowBox[{"0", "<", "\[Rho]", "<", "1"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "=", "\[Pi]"}]]],
 ".  \n\t\t\n\tThe factor\t\n\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", " ", 
    FractionBox[
     RowBox[{"z", "-", "\[Rho]"}], "z"], ")"}], "  ", "=", "  ", 
   RowBox[{"1", " ", "-", " ", 
    RowBox[{"\[Rho]", " ", 
     SuperscriptBox["z", 
      RowBox[{"-", "1"}]]}]}]}]]],
 "     if  ",
 Cell[BoxData[
  RowBox[{"0", "<", "\[Rho]", "<", "1"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", "=", "0"}]]],
 ",  \n\t\t\nis a special case that attenuates low frequency signals.  These \
factors will contribute to the term ",
 StyleBox["(9-42)",
  FontColor->RGBColor[0, 0, 1]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["(iv) Combination of Factors",
  FontColor->RGBColor[0, 0, 1]],
 "  \n\n\tThe transfer function ",
 Cell[BoxData[
  RowBox[{"H", 
   RowBox[{"(", "z", ")"}]}]]],
 " could have a zero or pole at the origin, but this has no net effect on the \
output signal.  The other zeros and poles determine the nature of the filter. \
 A conjugate pair of zeros ",
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}], " ", "\[Theta]"}]]]],
 " of  ",
 Cell[BoxData[
  RowBox[{"H", 
   RowBox[{"(", "z", ")"}]}]]],
 " on the unit circle will \"zero-out\" the signals ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{"\[Theta]", " ", "n"}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"sin", 
   RowBox[{"(", 
    RowBox[{"\[Theta]", " ", "n"}], ")"}]}]]],
 ".  If ",
 Cell[BoxData[
  RowBox[{"0", "<", "\[Rho]", "\[TildeTilde]", "1"}]]],
 " the conjugate pair of zeros ",
 Cell[BoxData[
  RowBox[{"\[Rho]", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}], " ", "\[Theta]"}]]}]]],
 " of  ",
 Cell[BoxData[
  RowBox[{"H", 
   RowBox[{"(", "z", ")"}]}]]],
 " will attenuate the signals ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{"\[Theta]", " ", "n"}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"sin", 
   RowBox[{"(", 
    RowBox[{"\[Theta]", " ", "n"}], ")"}]}]]],
 ", and the conjugate pair of poles ",
 Cell[BoxData[
  RowBox[{"\[Rho]", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}], " ", "\[Phi]"}]]}]]],
 " of  ",
 Cell[BoxData[
  RowBox[{"H", 
   RowBox[{"(", "z", ")"}]}]]],
 " will amplify the signals  ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{"\[Theta]", " ", "n"}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"sin", 
   RowBox[{"(", 
    RowBox[{"\[Theta]", " ", "n"}], ")"}]}]]],
 ".  It is useful to plot the location of the zeros and poles and notice \
their magnitude and argument.  As a general rule, zeros are used to attenuate \
signals and poles are used to amplify signals.  The primary goal of filter \
design is to construct  ",
 Cell[BoxData[
  RowBox[{"H", 
   RowBox[{"(", "z", ")"}]}]]],
 " so that the amplitude response ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}], " "}]]],
 " has a desired shape.  The following examples have been chosen to \
illustrate these concepts.  Books on digital signal filter design will \
explain the process in detail. "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 9.23 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The filter  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", " ", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "2"}], "]"}]}]}]]],
 "  is designed to zero out  ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "2"], "n"}], ")"}], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "sin", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "2"], "n"}], ")"}]}]]],
 ".  \n\n",
 StyleBox["9.23 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The moving average filter   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "4"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "[", "n", "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "3"}], "]"}]}], ")"}]}]}]]],
 "   is designed to zero out  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{"n", " ", "\[Pi]"}], ")"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "2"], "n"}], ")"}], " ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", "sin", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "2"], "n"}], ")"}]}]}]]],
 ". "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{597, 183},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["Figure 9.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "Amplitude response ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 ", and zero-pole plot for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    FractionBox["1", "4"], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], "3"], 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "k"}], "]"}]}]}]}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Solution", " ", 
   RowBox[{"9.23", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670611525*^9, 3.506706115265625*^9}}],

Cell[TextData[{
 StyleBox["9.23 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  For part (a) use the conjugate pair of zeros  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[Pi]", "/", "2"}]}]], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", 
     RowBox[{"\[Pi]", "/", "2"}]}]]}]]],
 "  and calculate \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", " ", 
      FractionBox[
       RowBox[{"z", "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "2"}]}]]}], "z"], ")"}], 
     RowBox[{"(", " ", 
      FractionBox[
       RowBox[{"z", "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{"\[Pi]", "/", "2"}]}]]}], "z"], ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["z", "2"]], 
      RowBox[{"(", 
       RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"z", "+", "\[ImaginaryI]"}], ")"}]}], " ", "=", "  ", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["z", "2"]], 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["z", "2"]}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                               ", 
   RowBox[{"=", "  ", 
    RowBox[{"1", "  ", "+", "  ", 
     RowBox[{"0", 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], "  ", "+", "  ", 
     SuperscriptBox["z", 
      RowBox[{"-", "2"}]]}]}]}]}]],
 "  \n\nThe transfer function has the form  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SubscriptBox["b", "0"], "+", 
     RowBox[{
      SubscriptBox["b", "1"], 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], "+", 
     RowBox[{
      SubscriptBox["b", "2"], 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}]}], "1"]}]]],
 " and we see that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["b", "0"], "=", "1"}], ",", 
   RowBox[{
    SubscriptBox["b", "1"], "=", 
    RowBox[{
     RowBox[{"0", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      SubscriptBox["b", "2"]}], "=", "1"}]}]}]]],
 ".  The desired filter for (a) is \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["b", "0"], " ", 
      RowBox[{"x", "[", "n", "]"}]}], "+", 
     RowBox[{
      SubscriptBox["b", "1"], " ", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}], "+", 
     RowBox[{
      SubscriptBox["b", "2"], " ", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", " ", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "2"}], "]"}]}]}]}]],
 " "
}], "Text"],

Cell[TextData[{
 StyleBox["9.23 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  For part (b) we introduce the additional zero  ",
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]]]],
 "  and calculate \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", " ", 
      FractionBox[
       RowBox[{"z", "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "2"}]}]]}], "z"], ")"}], 
     RowBox[{"(", " ", 
      FractionBox[
       RowBox[{"z", "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{"\[Pi]", "/", "2"}]}]]}], "z"], ")"}], 
     RowBox[{"(", " ", 
      FractionBox[
       RowBox[{"z", "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Pi]"}]]}], "z"], ")"}]}], 
    "  ", "=", "  ", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["z", "3"]], 
     RowBox[{"(", 
      RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "+", "\[ImaginaryI]"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", "+", "1"}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   "                                                                   ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["z", "3"]], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z", "2"], "+", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", "+", "1"}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   "                                                                   ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["z", "3"]], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z", "3"], "+", 
       SuperscriptBox["z", "2"], "+", "z", "+", "1"}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   "                                                                   ", 
   RowBox[{"=", "  ", 
    RowBox[{"1", " ", "+", " ", 
     SuperscriptBox["z", 
      RowBox[{"-", "1"}]], " ", "+", " ", 
     SuperscriptBox["z", 
      RowBox[{"-", "2"}]], " ", "+", " ", 
     SuperscriptBox["z", 
      RowBox[{"-", "3"}]]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "The transfer function has the form  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SubscriptBox["b", "0"], "+", 
     RowBox[{
      SubscriptBox["b", "1"], 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], "+", 
     RowBox[{
      SubscriptBox["b", "2"], 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["b", "3"], 
      SuperscriptBox["z", 
       RowBox[{"-", "3"}]]}]}], "1"]}]]],
 " and we see that  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["b", "0"], "=", 
   RowBox[{
    SubscriptBox["b", "1"], "=", 
    RowBox[{
     SubscriptBox["b", "2"], "=", 
     RowBox[{
      SubscriptBox["b", "3"], "=", "1"}]}]}]}]]],
 ".  Hence, a filter for zeroing out ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{"n", " ", "\[Pi]"}], ")"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "2"], "n"}], ")"}], " ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", "sin", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "2"], "n"}], ")"}]}]}]]],
 " is \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["b", "0"], " ", 
     RowBox[{"x", "[", "n", "]"}]}], "+", 
    RowBox[{
     SubscriptBox["b", "1"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["b", "2"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["b", "3"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "3"}], "]"}]}]}]}], "\[IndentingNewLine]", 
  StyleBox["or",
   FontFamily->"Times New Roman"], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", " ", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "1"}], "]"}], "+", " ", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "2"}], "]"}], "+", " ", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "3"}], "]"}]}]}]}]],
 " "
}], "Text"],

Cell[TextData[{
 "If we multiply terms on the right hand side by ",
 Cell[BoxData[
  FractionBox["1", "4"]]],
 ", then we get the moving average filter  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    FractionBox["1", "4"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "[", "n", "]"}], "+", " ", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}], "+", " ", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}], "+", " ", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "3"}], "]"}]}], ")"}]}]}]]],
 " \n\nand this filter will still zero out the same frequencies.  "
}], "Text"],

Cell[TextData[{
 StyleBox["Figure 9.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "Amplitude response ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 ", and zero-pole plot for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    FractionBox["1", "4"], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], "3"], 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "k"}], "]"}]}]}]}]]],
 ". "
}], "Text"],

Cell["\<\
Background for the z-transform and its application for solving difference \
equations can be found in the book.\
\>", "Text",
 CellChangeTimes->{{3.506762939890625*^9, 3.506762940546875*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"9.23", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706116828125*^9, 3.506706116828125*^9}}],

Cell[TextData[{
 StyleBox["9.23 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The filter  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", " ", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "2"}], "]"}]}]}]]],
 "  is designed to zero out  ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "2"], "n"}], ")"}], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "sin", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "2"], "n"}], ")"}]}]]],
 ".  Use the conjugate pair of zeros  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[Pi]", "/", "2"}]}]], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", 
     RowBox[{"\[Pi]", "/", "2"}]}]]}]]],
 "  and calculate "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"\[Pi]", "/", "2"}]}]]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"\[Pi]", "/", "2"}]}]]}], "z"], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<H[z] = \>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Pi]/2\)]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*SuperscriptBox[\(\[ExponentialE]\), \
\(\(-\[ImaginaryI]\[Pi]\)/2\)]\), \(z\)]\))\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"H", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"H", "[", "z", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"H", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948384453125*^9, 3.399483845453125*^9}, {
  3.40035806784375*^9, 3.40035807021875*^9}}],

Cell[TextData[{
 "There are no poles, so the transfer function has the form  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SubscriptBox["b", "0"], "+", 
     RowBox[{
      SubscriptBox["b", "1"], 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], "+", 
     RowBox[{
      SubscriptBox["b", "2"], 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}]}], "1"]}]]],
 " and we see that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["b", "0"], "=", "1"}], ",", 
   RowBox[{
    SubscriptBox["b", "1"], "=", 
    RowBox[{
     RowBox[{"0", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      SubscriptBox["b", "2"]}], "=", "1"}]}]}]]],
 ".  The desired filter is  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"k", ",", "n", ",", "x", ",", "y"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"filter", "=", 
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], "\[Equal]", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{
        RowBox[{"H", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "\[Rule]", 
           RowBox[{"x", "[", "n", "]"}]}], ",", 
          RowBox[{
           RowBox[{"Power", "[", 
            RowBox[{"z", ",", "k_"}], "]"}], "\[Rule]", 
           RowBox[{"x", "[", 
            RowBox[{"n", "+", "k"}], "]"}]}]}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<For the transfer function\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"H", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The filter is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "filter", " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948384703125*^9, 3.39948384859375*^9}}],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     RowBox[{"1", "+", 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "\[Theta]_", "]"}], "=", 
     RowBox[{"Abs", "[", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"A", "[", "\[Theta]", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "2.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "\[Pi]", ",", 
          FractionBox["\[Pi]", "4"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\[Theta]\>\"", ",", "\"\<A(\[Theta])\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< A[\[Theta]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Theta]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], ",", 
      "\"\<|\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(\[Pi]\), \(2\)]\)] = |H[\!\(\*SuperscriptBox[\
\(\[ExponentialE]\), \(\[ImaginaryI] \*FractionBox[\(\[Pi]\), \(2\)]\)]\)]| = \
\>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          FractionBox["\[Pi]", "2"]}]], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The amplitude response for the filter\>\"", "]"}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<y[n] = x[n] + x[n-2]\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Where the transfer function is\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"H", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\[Theta]\
\)]\)] = \>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}]}], " ", "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399483849546875*^9, 3.399483851609375*^9}, 
   3.399483982453125*^9, 3.4001402215625*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ZeroPolePlot1", ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399483855171875*^9, 3.3994838558125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"filter", " ", "=", " ", 
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], " ", "\[Equal]", " ", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], "+", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}]}]}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The FIR filter is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "filter", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Use the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-1] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "1"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-2] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Substitute into the filter and get\>\"", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \>\"", ",", "\"\<y[n] \[Equal] x[n] + x[n-2]\>\""}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \>\"", ",", " ", "filter"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  y[n] == \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "\"\< + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}], "]"}], ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \>\"", ",", " ", 
      RowBox[{"Simplify", "[", "filter", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399483860234375*^9, 3.3994838654375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"filter", " ", "=", " ", 
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], " ", "\[Equal]", " ", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], "+", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}]}]}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The FIR filter is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "filter", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Sin", "[", 
      FractionBox[
       RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Use the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-1] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "1"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-2] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Substitute into the filter and get\>\"", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \>\"", ",", "\"\<y[n] \[Equal] x[n] + x[n-2]\>\""}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \>\"", ",", " ", "filter"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  y[n] == \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "\"\< + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}], "]"}], ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \>\"", ",", " ", 
      RowBox[{"Simplify", "[", "filter", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399483866875*^9, 3.399483870109375*^9}}],

Cell[TextData[{
 StyleBox["9.23 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The moving average filter  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "4"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "[", "n", "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "3"}], "]"}]}], ")"}]}]}]]],
 "  is designed to zero out ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{"n", " ", "\[Pi]"}], ")"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "2"], "n"}], ")"}], " ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", "sin", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "2"], "n"}], ")"}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "Use the conjugate pair of zeros  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[Pi]", "/", "2"}]}]], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", 
     RowBox[{"\[Pi]", "/", "2"}]}]]}]]],
 "  and the additional zero  ",
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]]]],
 "  and calculate "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"\[Pi]", "/", "2"}]}]]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"\[Pi]", "/", "2"}]}]]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Pi]"}]]}], "z"], ")"}]}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<H[z] = \>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Pi]/2\)]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*SuperscriptBox[\(\[ExponentialE]\), \
\(\(-\[ImaginaryI]\[Pi]\)/2\)]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*SuperscriptBox[\(\[ExponentialE]\), \(-\
\[ImaginaryI]\[Pi]\)]\), \(z\)]\))\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"H", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"H", "[", "z", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"H", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399483871765625*^9, 3.399483872921875*^9}, {
  3.40035688634375*^9, 3.40035690103125*^9}}],

Cell[TextData[{
 "The transfer function has the form  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SubscriptBox["b", "0"], "+", 
     RowBox[{
      SubscriptBox["b", "1"], 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], "+", 
     RowBox[{
      SubscriptBox["b", "2"], 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["b", "3"], 
      SuperscriptBox["z", 
       RowBox[{"-", "3"}]]}]}], "1"]}]]],
 " and we see that  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["b", "0"], "=", 
   RowBox[{
    SubscriptBox["b", "1"], "=", 
    RowBox[{
     SubscriptBox["b", "2"], "=", 
     RowBox[{
      SubscriptBox["b", "3"], "=", "1"}]}]}]}]]],
 ".    The desired filter is  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"k", ",", "n", ",", "x", ",", "y"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"filter", "=", 
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], "\[Equal]", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{
        RowBox[{"H", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "\[Rule]", 
           RowBox[{"x", "[", "n", "]"}]}], ",", 
          RowBox[{
           RowBox[{"Power", "[", 
            RowBox[{"z", ",", "k_"}], "]"}], "\[Rule]", 
           RowBox[{"x", "[", 
            RowBox[{"n", "+", "k"}], "]"}]}]}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<For the transfer function\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"H", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The filter is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "filter", " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399483874546875*^9, 3.399483875453125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"filter", " ", "=", " ", 
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], " ", "\[Equal]", 
      RowBox[{
       FractionBox["1", "4"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", "[", "n", "]"}], "+", 
         RowBox[{"x", "[", 
          RowBox[{"n", "-", "1"}], "]"}], "+", 
         RowBox[{"x", "[", 
          RowBox[{"n", "-", "2"}], "]"}], "+", 
         RowBox[{"x", "[", 
          RowBox[{"n", "-", "3"}], "]"}]}], ")"}]}]}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The FIR filter is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "filter", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Cos", "[", 
      RowBox[{"n", " ", "\[Pi]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Use the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-1] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "1"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-2] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-3] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "3"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "3"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Substitute into the filter and get\>\"", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] \[Equal] \!\(\*FractionBox[\(1\), \(4\)]\)(x[n] + x[n-1] + \
x[n-2] + x[n-3])\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "filter", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] \[Equal] \!\(\*FractionBox[\(1\), \(4\)]\)(\>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "\"\< + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "1"}], "]"}], "]"}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}], "]"}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "3"}], "]"}], "]"}], ",", "\"\<))\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{"Simplify", "[", "filter", "]"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948387784375*^9, 3.399483880890625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"filter", " ", "=", " ", 
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], " ", "\[Equal]", 
      RowBox[{
       FractionBox["1", "4"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", "[", "n", "]"}], "+", 
         RowBox[{"x", "[", 
          RowBox[{"n", "-", "1"}], "]"}], "+", 
         RowBox[{"x", "[", 
          RowBox[{"n", "-", "2"}], "]"}], "+", 
         RowBox[{"x", "[", 
          RowBox[{"n", "-", "3"}], "]"}]}], ")"}]}]}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The FIR filter is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "filter", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Use the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-1] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "1"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-2] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-3] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "3"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "3"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Substitute into the filter and get\>\"", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] \[Equal] \!\(\*FractionBox[\(1\), \(4\)]\)(x[n] + x[n-1] + \
x[n-2] + x[n-3])\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "filter", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] \[Equal] \!\(\*FractionBox[\(1\), \(4\)]\)(\>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "\"\< + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "1"}], "]"}], "]"}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}], "]"}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "3"}], "]"}], "]"}], ",", "\"\<))\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{"Simplify", "[", "filter", "]"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994838826875*^9, 3.3994838849375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"filter", " ", "=", " ", 
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], " ", "\[Equal]", " ", 
      RowBox[{
       FractionBox["1", "4"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", "[", "n", "]"}], "+", 
         RowBox[{"x", "[", 
          RowBox[{"n", "-", "1"}], "]"}], "+", 
         RowBox[{"x", "[", 
          RowBox[{"n", "-", "2"}], "]"}], "+", 
         RowBox[{"x", "[", 
          RowBox[{"n", "-", "3"}], "]"}]}], ")"}]}]}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The FIR filter is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "filter", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Sin", "[", 
      FractionBox[
       RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Use the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-1] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "1"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-2] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-3] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "3"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "3"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Substitute into the filter and get\>\"", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] \[Equal] \!\(\*FractionBox[\(1\), \(4\)]\)(x[n] + x[n-1] + \
x[n-2] + x[n-3])\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "filter", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] \[Equal] \!\(\*FractionBox[\(1\), \(4\)]\)(\>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "\"\< + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "1"}], "]"}], "]"}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}], "]"}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "3"}], "]"}], "]"}], ",", "\"\<))\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{"Simplify", "[", "filter", "]"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399483886171875*^9, 3.399483890578125*^9}, {
  3.39948413834375*^9, 3.399484138609375*^9}}],

Cell[TextData[{
 StyleBox["Remark 9.15.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The function ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 " can be proven to be even, i.e.  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", 
    RowBox[{"(", 
     RowBox[{"-", "\[Theta]"}], ")"}]}], "=", 
   RowBox[{"A", 
    RowBox[{"(", "\[Theta]", ")"}]}]}]]],
 " which reinforces the fact that the zeros come in conjugate pairs.  Also, \
when expanded over a common denominator, the transfer function ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"1", "+", "z", "+", 
     SuperscriptBox["z", "2"], "+", 
     SuperscriptBox["z", "3"]}], 
    RowBox[{"4", " ", 
     SuperscriptBox["z", "3"]}]]}]]],
 " actually has a triple pole at the origin.  Finally it can be shown that \
the zeros are all equally spaced on the unit circle and that the arguments of \
the zeros correspond to frequencies that are zeroed out by the filter. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     RowBox[{
      FractionBox["1", "4"], 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]], "+", 
        SuperscriptBox["z", 
         RowBox[{"-", "2"}]], "+", 
        SuperscriptBox["z", 
         RowBox[{"-", "3"}]]}], ")"}]}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "\[Theta]_", "]"}], "=", 
     RowBox[{"Abs", "[", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"A", "[", "\[Theta]", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "\[Pi]", ",", 
          FractionBox["\[Pi]", "4"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "0.25"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\[Theta]\>\"", ",", "\"\<A(\[Theta])\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< A[\[Theta]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Theta]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], ",", 
      "\"\<|\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(\[Pi]\), \(2\)]\)] = |H[\!\(\*SuperscriptBox[\
\(\[ExponentialE]\), \(\[ImaginaryI] \*FractionBox[\(\[Pi]\), \(2\)]\)]\)]| = \
\>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          FractionBox["\[Pi]", "2"]}]], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< A[\[Pi]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Pi]\)]\)]| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]], "]"}], "]"}]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The amplitude response for the filter\>\"", "]"}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = \!\(\*FractionBox[\(1\), \(4\)]\)(x[n]+x[n-1]+x[n-2]+x[n-3])\
\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Where the transfer function is\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"H", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\[Theta]\
\)]\)] = \>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}]}], " ", "]"}], 
    ";"}], " "}]}]], "Input",
 CellChangeTimes->{3.39948414903125*^9, 3.399492330171875*^9, 
  3.400140227796875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ZeroPolePlot1", ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399484155515625*^9, 3.39948415628125*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.24.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The moving average filter   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    FractionBox["1", "8"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "[", "n", "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}], "+", " ", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "3"}], "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "4"}], "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "5"}], "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "6"}], "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "7"}], "]"}]}], ")"}]}]}]]],
 "  \nis designed to zero out  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{"n", " ", "\[Pi]"}], ")"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "4"], "n"}], ")"}]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"sin", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "4"], "n"}], ")"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "2"], "n"}], ")"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"sin", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "2"], "n"}], ")"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], "n"}], ")"}], " ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", "sin", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]]],
 ". "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{597, 183},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["Figure 9.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "Amplitude response ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 ", and zero-pole plot for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    FractionBox["1", "8"], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], "7"], 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "k"}], "]"}]}]}]}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Solution", " ", 
   RowBox[{"9.24", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670612015625*^9, 3.50670612015625*^9}}],

Cell[TextData[{
 "\tWe use the property (i) zeroing out filter. Recall that the solutions to  \
",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "8"], "=", "1"}]]],
 " are the eighth roots of unity  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "k", " ", 
     RowBox[{"\[Pi]", "/", "4"}]}]]}]]],
 " for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"k", "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "1", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "2", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "3", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "4", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "5", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "6", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "7"}]]],
 " and lie on the unit circle.  Hence the roots of \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["1", "8"], 
    FractionBox[
     RowBox[{
      SuperscriptBox["z", "8"], "-", "1"}], 
     RowBox[{"z", "-", "1"}]]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox["1", "8"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z", "7"], "+", 
       SuperscriptBox["z", "6"], "+", 
       SuperscriptBox["z", "5"], "+", 
       SuperscriptBox["z", "4"], "+", 
       SuperscriptBox["z", "3"], "+", 
       SuperscriptBox["z", "2"], "+", "z", "+", "1"}], ")"}]}], "  ", "=", 
    "  ", "0"}]}]]],
 "\n\nare ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "=", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]]}], ",", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "3", 
     RowBox[{"\[Pi]", "/", "4"}]}]], ",", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "3", 
     RowBox[{"\[Pi]", "/", "4"}]}]], ",", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[Pi]", "/", "2"}]}]], ",", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], "  ", 
     RowBox[{"\[Pi]", "/", "2"}]}]], ",", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[Pi]", "/", "4"}]}]], ",", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], "  ", 
     RowBox[{"\[Pi]", "/", "4"}]}]]}]]],
 ".  There are no poles, so the transfer function has the form \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "8"], 
    RowBox[{"(", 
     FractionBox[
      RowBox[{"z", "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]]}], "z"], ")"}], 
    RowBox[{"(", 
     FractionBox[
      RowBox[{"z", "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "3", 
         RowBox[{"\[Pi]", "/", "4"}]}]]}], "z"], ")"}], 
    RowBox[{"(", 
     FractionBox[
      RowBox[{"z", "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "3", 
         RowBox[{"\[Pi]", "/", "4"}]}]]}], "z"], ")"}], 
    RowBox[{"(", 
     FractionBox[
      RowBox[{"z", "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"\[Pi]", "/", "2"}]}]]}], "z"], ")"}], 
    RowBox[{"(", 
     FractionBox[
      RowBox[{"z", "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], "  ", 
         RowBox[{"\[Pi]", "/", "2"}]}]]}], "z"], ")"}], 
    RowBox[{"(", 
     FractionBox[
      RowBox[{"z", "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"\[Pi]", "/", "4"}]}]]}], "z"], ")"}], 
    RowBox[{"(", 
     FractionBox[
      RowBox[{"z", "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], "  ", 
         RowBox[{"\[Pi]", "/", "4"}]}]]}], "z"], ")"}]}]}]]],
 " \n\t\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "8"], 
    FractionBox["1", 
     SuperscriptBox["z", "7"]], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z", "7"], "+", 
      SuperscriptBox["z", "6"], "+", 
      SuperscriptBox["z", "5"], "+", 
      SuperscriptBox["z", "4"], "+", 
      SuperscriptBox["z", "3"], "+", 
      SuperscriptBox["z", "2"], "+", "z", "+", "1"}], ")"}]}]}]]],
 "\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "8"], 
    RowBox[{"(", " ", 
     RowBox[{"1", "+", 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]], "+", 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]], "+", 
      SuperscriptBox["z", 
       RowBox[{"-", "3"}]], "+", 
      SuperscriptBox["z", 
       RowBox[{"-", "4"}]], "+", 
      SuperscriptBox["z", 
       RowBox[{"-", "5"}]], "+", 
      SuperscriptBox["z", 
       RowBox[{"-", "6"}]], "+", 
      SuperscriptBox["z", 
       RowBox[{"-", "7"}]]}], ")"}]}]}]]],
 "\n\t\t\nUse  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["b", "i"], "=", 
   FractionBox["1", "8"]}]]],
 " for ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"i", "=", "0"}], ",", "...", ",", "7"}]]],
 " to get the desired recursive formula  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "8"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "[", "n", "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}], "+", " ", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "3"}], "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "4"}], "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "5"}], "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "6"}], "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "7"}], "]"}]}], ")"}], " "}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Remark 9.16.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  This is an extension of the filter in Example 9.23, and zeros out twice \
as many frequencies.  The function ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 " has additional zeros located at  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], "  ", 
     RowBox[{"\[Pi]", "/", "4"}]}]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], "  ", 
     RowBox[{"\[Pi]", "/", "2"}]}]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   RowBox[{
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "3", 
      RowBox[{"\[Pi]", "/", "4"}]}]]}]}]]],
 ".  The transfer function can be written  \n\n",
 "\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   FractionBox[
    RowBox[{"1", "+", "z", "+", 
     SuperscriptBox["z", "2"], "+", 
     SuperscriptBox["z", "3"], "+", 
     SuperscriptBox["z", "4"], "+", 
     SuperscriptBox["z", "5"], "+", 
     SuperscriptBox["z", "6"], "+", 
     SuperscriptBox["z", "7"]}], 
    RowBox[{"8", 
     SuperscriptBox["z", "7"]}]]}]]],
 ".  ",
 "\n\t\t\t\n\tThe representation has a pole of order seven at the origin.  \
Also, as in the previous example the zeros are equally spaced points on the \
unit circle, and their arguments correspond to the frequencies that are \
zeroed out  by the filter.  The situation is illustrated in Figure 9.10."
}], "Text"],

Cell[TextData[{
 StyleBox["Figure 9.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "Amplitude response ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 ", and zero-pole plot for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    FractionBox["1", "8"], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], "7"], 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "k"}], "]"}]}]}]}]]],
 ". "
}], "Text"],

Cell["\<\
Background for the z-transform and its application for solving difference \
equations can be found in the book.\
\>", "Text",
 CellChangeTimes->{{3.50676295328125*^9, 3.50676295390625*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"9.24", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670612128125*^9, 3.50670612128125*^9}}],

Cell[TextData[{
 "Use the conjugate pairs of zeros  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[Pi]", "/", "4"}]}]], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", 
     RowBox[{"\[Pi]", "/", "4"}]}]]}]]],
 ";  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[Pi]", "/", "2"}]}]], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", 
     RowBox[{"\[Pi]", "/", "2"}]}]]}]]],
 ";   ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "3", 
     RowBox[{"\[Pi]", "/", "4"}]}]], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "3", 
     RowBox[{"\[Pi]", "/", "4"}]}]]}]]],
 "  and the additional zero  ",
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]]]],
 "  and calculate "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"\[Pi]", "/", "4"}]}]]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"\[Pi]", "/", "4"}]}]]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"\[Pi]", "/", "2"}]}]]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"\[Pi]", "/", "2"}]}]]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "3", 
           RowBox[{"\[Pi]", "/", "4"}]}]]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "3", 
           RowBox[{"\[Pi]", "/", "4"}]}]]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Pi]"}]]}], "z"], ")"}]}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<H[z] = \>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Pi]/2\)]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*SuperscriptBox[\(\[ExponentialE]\), \
\(\(-\[ImaginaryI]\[Pi]\)/2\)]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*SuperscriptBox[\(\[ExponentialE]\), \(-\
\[ImaginaryI]\[Pi]\)]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*SuperscriptBox[\(\[ExponentialE]\), \
\(\(-\[ImaginaryI]\[Pi]\)/4\)]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Pi]/4\)]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*SuperscriptBox[\(\[ExponentialE]\), \
\(\(-\[ImaginaryI]3\[Pi]\)/4\)]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]3\[Pi]/4\)]\), \(z\)]\))\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"H", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"H", "[", "z", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"H", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948417615625*^9, 3.399484177328125*^9}, {
  3.40035693425*^9, 3.400356951328125*^9}, {3.4003584318125*^9, 
  3.400358516375*^9}}],

Cell[TextData[{
 "The transfer function has the form  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SubscriptBox["b", "0"], "+", 
     RowBox[{
      SubscriptBox["b", "1"], 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], "+", 
     RowBox[{
      SubscriptBox["b", "2"], 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["b", "3"], 
      SuperscriptBox["z", 
       RowBox[{"-", "3"}]]}], "+", 
     RowBox[{
      SubscriptBox["b", "4"], 
      SuperscriptBox["z", 
       RowBox[{"-", "4"}]]}], "+", 
     RowBox[{
      SubscriptBox["b", "5"], 
      SuperscriptBox["z", 
       RowBox[{"-", "5"}]]}], "+", 
     RowBox[{
      SubscriptBox["b", "6"], 
      SuperscriptBox["z", 
       RowBox[{"-", "6"}]]}], "+", 
     RowBox[{
      SubscriptBox["b", "7"], 
      SuperscriptBox["z", 
       RowBox[{"-", "7"}]]}]}], "1"]}]]],
 " and we see that  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["b", "0"], "=", 
   RowBox[{
    SubscriptBox["b", "1"], "=", 
    RowBox[{
     SubscriptBox["b", "2"], "=", 
     RowBox[{
      SubscriptBox["b", "3"], "=", 
      RowBox[{
       SubscriptBox["b", "4"], "=", 
       RowBox[{
        SubscriptBox["b", "5"], "=", 
        RowBox[{
         SubscriptBox["b", "6"], "=", 
         RowBox[{
          SubscriptBox["b", "7"], "=", "1"}]}]}]}]}]}]}]}]]],
 ".    The desired filter is  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"k", ",", "n", ",", "x", ",", "y"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"filter", "=", 
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], "\[Equal]", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{
        RowBox[{"H", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "\[Rule]", 
           RowBox[{"x", "[", "n", "]"}]}], ",", 
          RowBox[{
           RowBox[{"Power", "[", 
            RowBox[{"z", ",", "k_"}], "]"}], "\[Rule]", 
           RowBox[{"x", "[", 
            RowBox[{"n", "+", "k"}], "]"}]}]}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<For the transfer function\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"H", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The filter is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "filter", " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399484180171875*^9, 3.3994841811875*^9}}],

Cell[TextData[{
 "To obtain the moving average filter use  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["b", "i"], "=", 
   FractionBox["1", "8"]}]]],
 " for ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"i", "=", "0"}], ",", "...", ",", "7"}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"k", ",", "n", ",", "x", ",", "y"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"filter", "=", 
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], "\[Equal]", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{
        RowBox[{"H", "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "\[Rule]", 
           RowBox[{"x", "[", "n", "]"}]}], ",", 
          RowBox[{
           RowBox[{"Power", "[", 
            RowBox[{"z", ",", "k_"}], "]"}], "\[Rule]", 
           RowBox[{"x", "[", 
            RowBox[{"n", "+", "k"}], "]"}]}]}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<For the transfer function\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{
       FractionBox["1", "8"], 
       RowBox[{"H", "[", "z", "]"}]}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"filter", " ", "=", " ", 
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], " ", "\[Equal]", 
      RowBox[{
       FractionBox["1", "8"], 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "0"}], "7"], 
        RowBox[{"x", "[", 
         RowBox[{"n", "-", "k"}], "]"}]}]}]}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The filter is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "filter", " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399484184546875*^9, 3.399484186765625*^9}}],

Cell[TextData[{
 "As a typical example, we substitute  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   RowBox[{"Cos", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"3", "\[Pi]"}], "4"], "n"}], "]"}]}]]],
 " into the filter."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"filter", " ", "=", " ", 
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], " ", "\[Equal]", 
      RowBox[{
       FractionBox["1", "8"], 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "0"}], "7"], 
        RowBox[{"x", "[", 
         RowBox[{"n", "-", "k"}], "]"}]}]}]}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The FIR filter is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "filter", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Cos", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "4"], "n"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Use the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-1] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "1"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-2] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-3] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "3"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "3"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-4] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "4"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "4"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-5] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "5"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "5"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-6] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "6"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "6"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-7] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "7"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "7"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Substitute into the filter and get\>\"", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] \[Equal] \!\(\*FractionBox[\(1\), \
\(8\)]\)\!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \(7\)]\)x[n-k]\>\"", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "filter", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] \[Equal] \!\(\*FractionBox[\(1\), \(8\)]\)(\>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "\"\< + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "1"}], "]"}], "]"}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}], "]"}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "3"}], "]"}], "]"}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "4"}], "]"}], "]"}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "5"}], "]"}], "]"}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "6"}], "]"}], "]"}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "7"}], "]"}], "]"}], ",", "\"\<))\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{"Simplify", "[", "filter", "]"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399484189359375*^9, 3.399484191984375*^9}}],

Cell[TextData[{
 StyleBox["Remark 9.16.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " This is an extension of the filter in Example 9.23 (b), and zeros out \
twice as many frequencies.  The function ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 " has additional zeros located at  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", 
    FractionBox["\[Pi]", "4"]}], ",", 
   RowBox[{"-", 
    FractionBox["\[Pi]", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"3", "\[Pi]"}], "4"]}]}]]],
 ".  The transfer function can be written  \n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{"1", "+", "z", "+", 
     SuperscriptBox["z", "2"], "+", 
     SuperscriptBox["z", "3"], "+", 
     SuperscriptBox["z", "4"], "+", 
     SuperscriptBox["z", "5"], "+", 
     SuperscriptBox["z", "6"], "+", 
     SuperscriptBox["z", "7"]}], 
    RowBox[{"8", " ", 
     SuperscriptBox["z", "7"]}]]}]]],
 ".  \nThe representation and has a pole of order seven at the origin.  Also, \
as in the previous example the zeros are equally spaced points on the unit \
circle, and their arguments correspond to frequencies that are zeroed out by \
the filter. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     RowBox[{
      FractionBox["1", "8"], 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]], "+", 
        SuperscriptBox["z", 
         RowBox[{"-", "2"}]], "+", 
        SuperscriptBox["z", 
         RowBox[{"-", "3"}]], "+", 
        SuperscriptBox["z", 
         RowBox[{"-", "4"}]], "+", 
        SuperscriptBox["z", 
         RowBox[{"-", "5"}]], "+", 
        SuperscriptBox["z", 
         RowBox[{"-", "6"}]], "+", 
        SuperscriptBox["z", 
         RowBox[{"-", "7"}]]}], ")"}]}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "\[Theta]_", "]"}], "=", 
     RowBox[{"Abs", "[", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"A", "[", "\[Theta]", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "\[Pi]", ",", 
          FractionBox["\[Pi]", "4"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "0.25"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\[Theta]\>\"", ",", "\"\<A(\[Theta])\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   A[\[Theta]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Theta]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], ",", 
      "\"\<|\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  A[\!\(\*FractionBox[\(\[Pi]\), \(4\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI] \*FractionBox[\(\
\[Pi]\), \(4\)]\)]\)]| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          FractionBox["\[Pi]", "4"]}]], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  A[\!\(\*FractionBox[\(\[Pi]\), \(2\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI] \*FractionBox[\(\
\[Pi]\), \(2\)]\)]\)]| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          FractionBox["\[Pi]", "2"]}]], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(3  \[Pi]\), \(4\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI] \
\*FractionBox[\(3  \[Pi]\), \(4\)]\)]\)]| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          FractionBox[
           RowBox[{"3", "\[Pi]"}], "4"]}]], "]"}], "]"}]}], " ", "]"}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  A[\[Pi]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Pi]\)]\)]| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]], "]"}], "]"}]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The amplitude response for the filter\>\"", "]"}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = \!\(\*FractionBox[\(1\), \(8\)]\)\!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(k = 0\), \(7\)]\)x[n-k]\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Where the transfer function is\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  H[z] = \>\"", ",", 
      RowBox[{"H", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\[Theta]\
\)]\)] = \>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}]}], " ", "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948421903125*^9, 3.399484227*^9}, 3.40014023496875*^9}
  ],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ZeroPolePlot1", ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399484223640625*^9, 3.399484224546875*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.25 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   Design a filter with poles  ",
 Cell[BoxData[
  FractionBox["2", "3"]]],
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[Pi]", "/", "4"}]}]], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   FractionBox["2", "3"], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", 
     RowBox[{"\[Pi]", "/", "4"}]}]]}]]],
 "  for boosting up signals near ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "4"], "n"}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"sin", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "4"], "n"}], ")"}]}]]],
 ".\n\n",
 StyleBox["9.25 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   Include the additional pole at  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "0"}]]}], "=", 
   FractionBox["1", "2"]}]]],
 " to the filter design in (a) so that it also boosts up low frequency \
signals."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{597, 183},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["Figure 9.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "Amplitude response ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 ", and zero-pole plot for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", 
    RowBox[{
     FractionBox["2", "3"], 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "-", 
    RowBox[{
     FractionBox["4", "9"], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}]}]]],
 ". "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{597, 183},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["Figure 9.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "Amplitude response ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 ", and zero-pole plot for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", 
    RowBox[{
     FractionBox["1", "6"], 
     RowBox[{"(", 
      RowBox[{"3", "+", " ", 
       RowBox[{"4", 
        SqrtBox["2"]}]}], ")"}], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "-", 
    RowBox[{
     FractionBox["1", "9"], 
     RowBox[{"(", 
      RowBox[{"4", "+", 
       RowBox[{"3", 
        SqrtBox["2"]}]}], ")"}], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["2", "9"], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "3"}], "]"}]}]}]}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Solution", " ", 
   RowBox[{"9.25", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706125*^9, 3.506706125*^9}}],

Cell[TextData[{
 StyleBox["9.25 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  We use the property ",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 " boosting up filter.  The conjugate pair of poles  ",
 Cell[BoxData[
  FractionBox["2", "3"]]],
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[Pi]", "/", "4"}]}]], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   FractionBox["2", "3"], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", 
     RowBox[{"\[Pi]", "/", "4"}]}]]}]]],
 "  lie on the circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "=", 
   FractionBox["2", "3"]}]]],
 ".  We then calculate \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", " ", 
      FractionBox[
       RowBox[{"z", "-", 
        RowBox[{
         FractionBox["2", "3"], 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"\[Pi]", "/", "4"}]}]]}]}], "z"], ")"}], 
     RowBox[{"(", " ", 
      FractionBox[
       RowBox[{"z", "-", 
        RowBox[{
         FractionBox["2", "3"], 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"\[Pi]", "/", "4"}]}]]}]}], "z"], ")"}]}], "   ", "=", 
    "  ", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["z", "2"]], 
     RowBox[{"(", 
      RowBox[{"z", "-", 
       RowBox[{
        FractionBox[
         SqrtBox["2"], "3"], 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", 
       RowBox[{
        FractionBox[
         SqrtBox["2"], "3"], 
        RowBox[{"(", 
         RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}]}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                                        ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["z", "2"]], 
     RowBox[{"(", " ", 
      RowBox[{
       SuperscriptBox["z", "2"], "-", 
       RowBox[{
        FractionBox["2", "3"], 
        SqrtBox["2"], "z"}], "+", 
       FractionBox["4", "9"]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                                        ", 
   RowBox[{"=", "  ", 
    RowBox[{"1", "  ", "-", "  ", 
     RowBox[{
      FractionBox["2", "3"], 
      SqrtBox["2"], 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], "  ", "+", "  ", 
     RowBox[{
      FractionBox["4", "9"], 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}]}]}]}]}]]
}], "Text"],

Cell[TextData[{
 "There are no zeros, so the transfer function is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    SubscriptBox["b", "0"], 
    RowBox[{"1", "+", 
     RowBox[{
      SubscriptBox["a", "1"], 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], "+", 
     RowBox[{
      SubscriptBox["a", "2"], 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}]}]]}]]],
 " and we see that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["b", "0"], "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["a", "1"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], 
      SqrtBox["2"], "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      SubscriptBox["a", "2"]}], "=", 
     FractionBox["4", "9"]}]}]}]]],
 ".  The desired filter for (a) is \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["b", "0"], " ", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "-", " ", 
     RowBox[{
      SubscriptBox["a", "1"], " ", 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}], " ", "-", " ", 
     RowBox[{
      SubscriptBox["a", "2"], " ", 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "2"}], "]"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], " ", "+", " ", 
    RowBox[{
     FractionBox["2", "3"], 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], " ", "-", " ", 
    RowBox[{
     FractionBox["4", "9"], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}]}]}]],
 " \n\nObserve that this is the same filter that was investigated in Example \
9.22. "
}], "Text"],

Cell[TextData[{
 StyleBox["Remark 9.17.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The transfer function can be written  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", "[", "z", "]"}], "=", 
   FractionBox[
    SuperscriptBox["z", "2"], 
    RowBox[{
     SuperscriptBox["z", "2"], "-", 
     RowBox[{
      FractionBox["2", "3"], 
      SqrtBox["2"], "z"}], "+", 
     FractionBox["4", "9"]}]]}]]],
 " and has a zero of order two at the origin, and two poles inside the unit \
circle.  The arguments of the poles  ",
 Cell[BoxData[
  RowBox[{
   FractionBox["2", "3"], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}], " ", 
     RowBox[{"\[Pi]", "/", "4"}]}]]}]]],
 " correspond to frequencies that are boosted up by the filter. The situation \
is illustrated in Figure 9.11."
}], "Text"],

Cell[TextData[{
 StyleBox["Figure 9.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "Amplitude response ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 ", and zero-pole plot for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", 
    RowBox[{
     FractionBox["2", "3"], 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "-", 
    RowBox[{
     FractionBox["4", "9"], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["9.25 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  For part (b) use the additional pole at  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "0"}]]}], "=", 
   FractionBox["1", "2"]}]]],
 "  and calculate \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"(", " ", 
     FractionBox[
      RowBox[{"z", "-", 
       RowBox[{
        FractionBox["2", "3"], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "4"}]}]]}]}], "z"], ")"}], 
    RowBox[{"(", " ", 
     FractionBox[
      RowBox[{"z", "-", 
       RowBox[{
        FractionBox["2", "3"], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{"\[Pi]", "/", "4"}]}]]}]}], "z"], ")"}], 
    RowBox[{"(", " ", 
     FractionBox[
      RowBox[{"z", "-", 
       FractionBox["1", "2"]}], "z"], ")"}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{"1", "-", 
       RowBox[{
        FractionBox["2", "3"], 
        SqrtBox["2"], 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}], "+", 
       RowBox[{
        FractionBox["4", "9"], 
        SuperscriptBox["z", 
         RowBox[{"-", "2"}]]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        FractionBox["1", "2"], 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", "  ", 
    RowBox[{"1", " ", "-", " ", 
     RowBox[{
      FractionBox["1", "6"], 
      RowBox[{"(", 
       RowBox[{"3", "+", " ", 
        RowBox[{"4", 
         SqrtBox["2"]}]}], ")"}], 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], " ", "+", " ", 
     RowBox[{
      FractionBox["1", "9"], 
      RowBox[{"(", 
       RowBox[{"4", "+", 
        RowBox[{"3", 
         SqrtBox["2"]}]}], ")"}], 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}], " ", "-", " ", 
     RowBox[{
      FractionBox["2", "9"], 
      SuperscriptBox["z", 
       RowBox[{"-", "3"}]]}]}]}]}]}]],
 "  \n\nThe transfer function is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    SubscriptBox["b", "0"], 
    RowBox[{"1", "+", 
     RowBox[{
      SubscriptBox["a", "1"], 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], "+", 
     RowBox[{
      SubscriptBox["a", "2"], 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["a", "3"], 
      SuperscriptBox["z", 
       RowBox[{"-", "3"}]]}]}]], " "}]]],
 " where  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["b", "0"], "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["a", "1"], "=", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "6"]}], 
     RowBox[{"(", 
      RowBox[{"3", "+", " ", 
       RowBox[{"4", 
        SqrtBox["2"]}]}], ")"}]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["a", "2"], "=", 
    RowBox[{
     RowBox[{
      FractionBox["1", "9"], 
      RowBox[{"(", 
       RowBox[{"4", "+", 
        RowBox[{"3", 
         SqrtBox["2"]}]}], ")"}], "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      SubscriptBox["a", "3"]}], "=", 
     RowBox[{"-", 
      FractionBox["2", "9"]}]}]}]}]]],
 ".  The desired filter for (b) is \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["b", "0"], " ", 
      RowBox[{"x", "[", "n", "]"}]}], "-", 
     RowBox[{
      SubscriptBox["a", "1"], " ", 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}], "-", 
     RowBox[{
      SubscriptBox["a", "2"], " ", 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "2"}], "]"}]}], "-", 
     RowBox[{
      SubscriptBox["a", "3"], " ", 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "2"}], "]"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", 
    RowBox[{
     FractionBox["1", "6"], 
     RowBox[{"(", 
      RowBox[{"3", "+", " ", 
       RowBox[{"4", 
        SqrtBox["2"]}]}], ")"}], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "-", 
    RowBox[{
     FractionBox["1", "9"], 
     RowBox[{"(", 
      RowBox[{"4", "+", 
       RowBox[{"3", 
        SqrtBox["2"]}]}], ")"}], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["2", "9"], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "3"}], "]"}]}]}]}]}]],
 " "
}], "Text"],

Cell[TextData[{
 StyleBox["Remark 9.18.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The transfer function can be written  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", "[", "z", "]"}], "=", 
   FractionBox[
    SuperscriptBox["z", "3"], 
    RowBox[{" ", 
     RowBox[{
      SuperscriptBox["z", "3"], "-", 
      RowBox[{
       FractionBox["1", "6"], 
       RowBox[{"(", 
        RowBox[{"3", "+", " ", 
         RowBox[{"4", 
          SqrtBox["2"]}]}], ")"}], 
       SuperscriptBox["z", "2"]}], "+", 
      RowBox[{
       FractionBox["1", "9"], 
       RowBox[{"(", 
        RowBox[{"4", "+", 
         RowBox[{"3", 
          SqrtBox["2"]}]}], ")"}], "z"}], "-", 
      FractionBox["2", "9"]}]}]]}]]],
 " and has a zero of order three at the origin, and three poles inside the \
unit circle.  The arguments of the poles  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["2", "3"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", "*", "0"}]]}], ",", 
   RowBox[{
    FractionBox["2", "3"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}], " ", 
      RowBox[{"\[Pi]", "/", "4"}]}]]}]}]]],
 " correspond to frequencies that are boosted up by the filter. The situation \
is illustrated in Figure 9.12. "
}], "Text"],

Cell[TextData[{
 StyleBox["Figure 9.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "Amplitude response ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 ", and zero-pole plot for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", 
    RowBox[{
     FractionBox["1", "6"], 
     RowBox[{"(", 
      RowBox[{"3", "+", " ", 
       RowBox[{"4", 
        SqrtBox["2"]}]}], ")"}], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "-", 
    RowBox[{
     FractionBox["1", "9"], 
     RowBox[{"(", 
      RowBox[{"4", "+", 
       RowBox[{"3", 
        SqrtBox["2"]}]}], ")"}], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["2", "9"], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "3"}], "]"}]}]}]}]]],
 ". "
}], "Text"],

Cell["\<\
Background for the z-transform and its application for solving difference \
equations can be found in the book.\
\>", "Text",
 CellChangeTimes->{{3.506762966125*^9, 3.50676296675*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"9.25", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670612628125*^9, 3.50670612628125*^9}}],

Cell[TextData[{
 StyleBox["9.25 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   Design a filter with poles  ",
 Cell[BoxData[
  FractionBox["2", "3"]]],
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[Pi]", "/", "4"}]}]], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   FractionBox["2", "3"], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", 
     RowBox[{"\[Pi]", "/", "4"}]}]]}]]],
 "  for boosting up signals near ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "4"], "n"}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"sin", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "4"], "n"}], ")"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"\[Pi]", "/", "4"}]}]]}]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            RowBox[{"\[Pi]", "/", "4"}]}]]}]}], "z"], ")"}]}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<H[z] = 1/[\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*FractionBox[\(2\), \(3\)]\\\ \
\*SuperscriptBox[\(\[ExponentialE]\), FractionBox[\(\[ImaginaryI]\\\ \[Pi]\), \
\(4\)]]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*FractionBox[\(2\), \(3\)]\\\ \
\*SuperscriptBox[\(\[ExponentialE]\), \(-\*FractionBox[\(\[ImaginaryI]\\\ \
\[Pi]\), \(4\)]\)]\), \(z\)]\))]\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"1", "/", 
       RowBox[{"G", "[", "z", "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "z_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"G", "[", "z", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"1", "/", 
       RowBox[{"G", "[", "z", "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399484249703125*^9, 3.399484251765625*^9}, {
  3.40035698184375*^9, 3.400357007375*^9}, {3.40035706425*^9, 
  3.400357111015625*^9}, {3.400357985828125*^9, 3.40035798803125*^9}}],

Cell[TextData[{
 "There are no zeros, so the transfer function is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    SubscriptBox["b", "0"], 
    RowBox[{"1", "+", 
     RowBox[{
      SubscriptBox["a", "1"], 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], "+", 
     RowBox[{
      SubscriptBox["a", "2"], 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}]}]]}]]],
 " and we see that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["b", "0"], "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["a", "1"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], 
      SqrtBox["2"], "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      SubscriptBox["a", "2"]}], "=", 
     FractionBox["4", "9"]}]}]}]]],
 ".  \nThe desired filter is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], " ", "+", " ", 
    RowBox[{
     FractionBox["2", "3"], 
     SqrtBox["2"], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], " ", "-", 
    RowBox[{
     FractionBox["4", 
      RowBox[{" ", "9"}]], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["Remark 9.17.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The transfer function can be written  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", "[", "z", "]"}], "=", 
   FractionBox[
    SuperscriptBox["z", "2"], 
    RowBox[{
     SuperscriptBox["z", "2"], "-", 
     RowBox[{
      FractionBox["2", "3"], 
      SqrtBox["2"], "z"}], "+", 
     FractionBox["4", "9"]}]]}]]],
 " and has a zero of order two at the origin, and two poles inside the unit \
circle.  The arguments of the poles  ",
 Cell[BoxData[
  RowBox[{
   FractionBox["2", "3"], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}], " ", 
     RowBox[{"\[Pi]", "/", "4"}]}]]}]]],
 " correspond to frequencies that are boosted up by the filter. The situation \
is illustrated in Figure 9.11."
}], "Text"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     FractionBox["1", 
      RowBox[{"1", "-", 
       RowBox[{
        FractionBox["2", "3"], 
        SqrtBox["2"], 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}], "+", 
       RowBox[{
        FractionBox["4", "9"], 
        SuperscriptBox["z", 
         RowBox[{"-", "2"}]]}]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "\[Theta]_", "]"}], "=", 
     RowBox[{"Abs", "[", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"gr1", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"A", "[", "\[Theta]", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Theta]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "\[Pi]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "2.6"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "\[Pi]", ",", 
           FractionBox["\[Pi]", "4"]}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "2.5", ",", "0.5"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<\[Theta]\>\"", ",", "\"\<A(\[Theta])\>\""}], "}"}]}], 
      ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The amplitude response\>\"", "]"}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\[Theta]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Theta]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], ",", 
      "\"\<|\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<For the filter\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = y[n] = x[n] + \!\(\*FractionBox[\(2\), \
\(3\)]\)\!\(\*SqrtBox[\(2\)]\)y[n-1] -\!\(\*FractionBox[\(4\), \(9\)]\)y[n-2]\
\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994842561875*^9, 3.399484261234375*^9}, 
   3.400140240734375*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ZeroPolePlot1", ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399484265015625*^9, 3.3994842659375*^9}}],

Cell[TextData[{
 StyleBox["Figure 9.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "Amplitude response ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 ", and zero-pole plot for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", 
    RowBox[{
     FractionBox["2", "3"], 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "-", 
    RowBox[{
     FractionBox["4", "9"], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "We are done with part (a).\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can investigate how this filter work."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          FractionBox["\[Pi]", "16"], ",", 
          FractionBox["\[Pi]", "2"], ",", 
          FractionBox[
           RowBox[{"3", " ", "\[Pi]"}], "4"], ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2.5", ",", "0.5"}], "]"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The amplitude response\>\"", "]"}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\[Theta]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Theta]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], ",", 
      "\"\<|\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(\[Pi]\), \(16\)]\)]  = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI] \*FractionBox[\(\
\[Pi]\), \(16\)]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["\[Pi]", "16."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(3  \[Pi]\), \(4\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI] \
\*FractionBox[\(3  \[Pi]\), \(4\)]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox[
           RowBox[{"3", "\[Pi]"}], "4."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<For the filter\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = y[n] = x[n] + \!\(\*FractionBox[\(2\), \
\(3\)]\)\!\(\*SqrtBox[\(2\)]\)y[n-1] -\!\(\*FractionBox[\(4\), \(9\)]\)y[n-2]\
\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399484268828125*^9, 3.399484278359375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox["\[Pi]", "16"], " ", "n"}], "]"}], "+", 
      RowBox[{"Sin", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"3", "\[Pi]"}], "4"], " ", "n"}], "]"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "65"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{
          FractionBox["\[Pi]", "16"], " ", "i"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"X2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox["\[Pi]", "16"], " ", "i"}], "]"}], "+", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"3", "\[Pi]"}], "4"], " ", "i"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X1", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", "X1"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X2", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", "X2"}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y2", "=", 
     RowBox[{"Y1", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", 
          RowBox[{"m0", "+", "9"}]}], "}"}]}], "]"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "10"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"m0", "+", "10"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        SubscriptBox["Y1", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Chop", "[", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["X1", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           " ", "+", " ", 
           RowBox[{
            FractionBox["2", "3"], 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], " ", "-", 
           RowBox[{
            FractionBox["4", 
             RowBox[{" ", "9"}]], 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}]}], " ", 
          ")"}], " ", "]"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{
        SubscriptBox["Y2", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Chop", "[", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["X2", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           " ", "+", " ", 
           RowBox[{
            FractionBox["2", "3"], 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], " ", "-", 
           RowBox[{
            FractionBox["4", 
             RowBox[{" ", "9"}]], 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}]}], " ", 
          ")"}], " ", "]"}]}], ";"}]}], "  ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"X1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"X1", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"X2", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"Y1", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"Y2", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X1pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X2pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g22", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", "g22", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "m0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<n\>\"", ",", "\"\<x[n]\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Input signal x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Take", "[", 
        RowBox[{"Y1pts", ",", 
         RowBox[{"-", "65"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr4", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Take", "[", 
        RowBox[{"Y2pts", ",", 
         RowBox[{"-", "66"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g44", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr3", ",", "gr4", ",", "g44", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "m0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.7"}], ",", "2.4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<n\>\"", ",", "\"\<y[n]\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Output signal\>\"", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = y[n] = x[n] + \!\(\*FractionBox[\(2\), \
\(3\)]\)\!\(\*SqrtBox[\(2\)]\)y[n-1] -\!\(\*FractionBox[\(4\), \(9\)]\)y[n-2]\
\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The  amplitude  responses\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Low  frequency:   A[\!\(\*FractionBox[\(\[Pi]\), \(16\)]\)] = |H[\!\
\(\*SuperscriptBox[\(\[ExponentialE]\), \(FractionBox[\[Pi], 16] \
\[ImaginaryI]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["\[Pi]", "16."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<High frequency:  A[\!\(\*FractionBox[\(3  \[Pi]\), \(4\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(FractionBox[3  \[Pi], 4] \
\[ImaginaryI]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox[
           RowBox[{"3", "\[Pi]"}], "4."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948428171875*^9, 3.399484319171875*^9}, 
   3.400140247609375*^9, {3.40014129878125*^9, 3.40014133103125*^9}, {
   3.40034762834375*^9, 3.40034765090625*^9}}],

Cell[TextData[{
 StyleBox["9.25 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   Include the additional pole at  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "0"}]]}], "=", 
   FractionBox["1", "2"]}]]],
 " to the filter design in (a) so that it also boosts up low frequency \
signals."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"(", " ", 
       FractionBox[
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"\[Pi]", "/", "4"}]}]]}]}], "z"], ")"}], 
      RowBox[{"(", " ", 
       FractionBox[
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            RowBox[{"\[Pi]", "/", "4"}]}]]}]}], "z"], ")"}], 
      RowBox[{"(", " ", 
       FractionBox[
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["1", "2"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"0", " ", "\[ImaginaryI]"}]]}]}], "z"], ")"}]}]}], " ", 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<H[z] = \>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*FractionBox[\(1\), \(2\)]\\\ \
\*SuperscriptBox[\(\[ExponentialE]\), \(0  \[ImaginaryI]\)]\), \(z\)]\))\>\"",
       ",", "\"\<(\!\(\*FractionBox[\(z - \*FractionBox[\(2\), \(3\)]\\\ \
\*SuperscriptBox[\(\[ExponentialE]\), FractionBox[\(\(-\[ImaginaryI]\)\\\ \
\[Pi]\), \(4\)]]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*FractionBox[\(2\), \(3\)]\\\ \
\*SuperscriptBox[\(\[ExponentialE]\), FractionBox[\(\[ImaginaryI]\\\ \[Pi]\), \
\(4\)]]\), \(z\)]\))\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"1", "/", 
       RowBox[{"G", "[", "z", "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "z_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"G", "[", "z", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"1", "/", 
       RowBox[{"G", "[", "z", "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "z_", "]"}], "=", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"G", "[", "z", "]"}], ",", "z"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"1", "/", 
       RowBox[{"G", "[", "z", "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399484326140625*^9, 3.39948432703125*^9}, {
  3.40035714971875*^9, 3.40035732459375*^9}, {3.40035865365625*^9, 
  3.400358691703125*^9}}],

Cell[TextData[{
 "There are no zeros, so the transfer function is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    SubscriptBox["b", "0"], 
    RowBox[{"1", "+", 
     RowBox[{
      SubscriptBox["a", "1"], 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], "+", 
     RowBox[{
      SubscriptBox["a", "2"], 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}], "+", 
     RowBox[{
      SubscriptBox["a", "3"], 
      SuperscriptBox["z", 
       RowBox[{"-", "3"}]]}]}]], " "}]]],
 " where  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["b", "0"], "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["a", "1"], "=", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "6"]}], 
     RowBox[{"(", 
      RowBox[{"3", "+", " ", 
       RowBox[{"4", 
        SqrtBox["2"]}]}], ")"}]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["a", "2"], "=", 
    RowBox[{
     RowBox[{
      FractionBox["1", "9"], 
      RowBox[{"(", 
       RowBox[{"4", "+", 
        RowBox[{"3", 
         SqrtBox["2"]}]}], ")"}], "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      SubscriptBox["a", "3"]}], "=", 
     RowBox[{"-", 
      FractionBox["2", "9"]}]}]}]}]]],
 ".  \nThe desired filter is ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", 
    RowBox[{
     FractionBox["1", "6"], 
     RowBox[{"(", 
      RowBox[{"3", "+", " ", 
       RowBox[{"4", 
        SqrtBox["2"]}]}], ")"}], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "-", 
    RowBox[{
     FractionBox["1", "9"], 
     RowBox[{"(", 
      RowBox[{"4", "+", 
       RowBox[{"3", 
        SqrtBox["2"]}]}], ")"}], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["2", "9"], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "3"}], "]"}]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["Remark 9.18.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The transfer function can be written  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", "[", "z", "]"}], "=", 
   FractionBox[
    SuperscriptBox["z", "3"], 
    RowBox[{" ", 
     RowBox[{
      SuperscriptBox["z", "3"], "-", 
      RowBox[{
       FractionBox["1", "6"], 
       RowBox[{"(", 
        RowBox[{"3", "+", " ", 
         RowBox[{"4", 
          SqrtBox["2"]}]}], ")"}], 
       SuperscriptBox["z", "2"]}], "+", 
      RowBox[{
       FractionBox["1", "9"], 
       RowBox[{"(", 
        RowBox[{"4", "+", 
         RowBox[{"3", 
          SqrtBox["2"]}]}], ")"}], "z"}], "-", 
      FractionBox["2", "9"]}]}]]}]]],
 " and has a zero of order three at the origin, and three poles inside the \
unit circle.  The arguments of the poles  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["2", "3"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", "*", "0"}]]}], ",", 
   RowBox[{
    FractionBox["2", "3"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}], " ", 
      RowBox[{"\[Pi]", "/", "4"}]}]]}]}]]],
 " correspond to frequencies that are boosted up by the filter. The situation \
is illustrated in Figure 9.12. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     FractionBox["1", 
      RowBox[{" ", 
       RowBox[{"1", "-", 
        RowBox[{
         FractionBox["1", "6"], 
         RowBox[{"(", 
          RowBox[{"3", "+", " ", 
           RowBox[{"4", 
            SqrtBox["2"]}]}], ")"}], 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}], "+", 
        RowBox[{
         FractionBox["1", "9"], 
         RowBox[{"(", 
          RowBox[{"4", "+", 
           RowBox[{"3", 
            SqrtBox["2"]}]}], ")"}], 
         SuperscriptBox["z", 
          RowBox[{"-", "2"}]]}], "-", 
        RowBox[{
         FractionBox["2", "9"], 
         SuperscriptBox["z", 
          RowBox[{"-", "3"}]]}]}]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "\[Theta]_", "]"}], "=", 
     RowBox[{"Abs", "[", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"gr2", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"A", "[", "\[Theta]", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Theta]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "\[Pi]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "4"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "\[Pi]", ",", 
           FractionBox["\[Pi]", "4"]}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<\[Theta]\>\"", ",", "\"\<A(\[Theta])\>\""}], "}"}]}], 
      ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The amplitude response\>\"", "]"}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\[Theta]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Theta]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], ",", 
      "\"\<|\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<For the filter\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = x[n] + \!\(\*FractionBox[\(1\), \(6\)]\)(3+ \
4\!\(\*SqrtBox[\(2\)]\))y[n-1] - \!\(\*FractionBox[\(1\), \
\(9\)]\)(4+3\!\(\*SqrtBox[\(2\)]\))y[n-2] + \!\(\*FractionBox[\(2\), \
\(9\)]\)y[n-3]\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399484330125*^9, 3.399484334390625*^9}, 
   3.400140254234375*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ZeroPolePlot1", ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399484337171875*^9, 3.399484338109375*^9}}],

Cell[TextData[{
 StyleBox["Figure 9.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "Amplitude response ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 ", and zero-pole plot for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", 
    RowBox[{
     FractionBox["1", "6"], 
     RowBox[{"(", 
      RowBox[{"3", "+", " ", 
       RowBox[{"4", 
        SqrtBox["2"]}]}], ")"}], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "-", 
    RowBox[{
     FractionBox["1", "9"], 
     RowBox[{"(", 
      RowBox[{"4", "+", 
       RowBox[{"3", 
        SqrtBox["2"]}]}], ")"}], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["2", "9"], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "3"}], "]"}]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "We are done with part (b).\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can investigate how this filter work."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"gr2", ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          FractionBox["\[Pi]", "16"], ",", 
          FractionBox["\[Pi]", "2"], ",", 
          FractionBox[
           RowBox[{"3", " ", "\[Pi]"}], "4"], ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "4", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The amplitude response\>\"", "]"}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\[Theta]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Theta]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], ",", 
      "\"\<|\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(\[Pi]\), \(16\)]\)]  = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI] \*FractionBox[\(\
\[Pi]\), \(16\)]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["\[Pi]", "16."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(3  \[Pi]\), \(4\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI] \
\*FractionBox[\(3  \[Pi]\), \(4\)]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox[
           RowBox[{"3", "\[Pi]"}], "4."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<For the filter\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = x[n] + \!\(\*FractionBox[\(1\), \(6\)]\)(3+ \
4\!\(\*SqrtBox[\(2\)]\))y[n-1] - \!\(\*FractionBox[\(1\), \
\(9\)]\)(4+3\!\(\*SqrtBox[\(2\)]\))y[n-2] + \!\(\*FractionBox[\(2\), \
\(9\)]\)y[n-3]\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399484341578125*^9, 3.399484342921875*^9}, 
   3.399492395328125*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox["\[Pi]", "16"], " ", "n"}], "]"}], "+", 
      RowBox[{"Sin", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"3", "\[Pi]"}], "4"], " ", "n"}], "]"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "65"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{
          FractionBox["\[Pi]", "16"], " ", "i"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"X2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox["\[Pi]", "16"], " ", "i"}], "]"}], "+", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"3", "\[Pi]"}], "4"], " ", "i"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X1", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", "X1"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X2", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", "X2"}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y2", "=", 
     RowBox[{"Y1", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", 
          RowBox[{"m0", "+", "9"}]}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "10"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"m0", "+", "10"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        SubscriptBox["Y1", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Chop", "[", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["X1", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           " ", "+", " ", 
           RowBox[{
            FractionBox["1", "6"], 
            RowBox[{"(", 
             RowBox[{"3", "+", " ", 
              RowBox[{"4", 
               SqrtBox["2"]}]}], ")"}], 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], " ", "-",
            " ", 
           RowBox[{
            FractionBox["1", "9"], 
            RowBox[{"(", 
             RowBox[{"4", "+", 
              RowBox[{"3", 
               SqrtBox["2"]}]}], ")"}], 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}], " ", "+",
            " ", 
           RowBox[{
            FractionBox["2", "9"], 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "3"}], "\[RightDoubleBracket]"}]]}]}], ")"}], 
         " ", "]"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{
        SubscriptBox["Y2", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Chop", "[", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["X2", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           " ", "+", " ", 
           RowBox[{
            FractionBox["1", "6"], 
            RowBox[{"(", 
             RowBox[{"3", "+", " ", 
              RowBox[{"4", 
               SqrtBox["2"]}]}], ")"}], 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], " ", "-",
            " ", 
           RowBox[{
            FractionBox["1", "9"], 
            RowBox[{"(", 
             RowBox[{"4", "+", 
              RowBox[{"3", 
               SqrtBox["2"]}]}], ")"}], 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}], " ", "+",
            " ", 
           RowBox[{
            FractionBox["2", "9"], 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "3"}], "\[RightDoubleBracket]"}]]}]}], ")"}], 
         " ", "]"}]}], ";"}]}], "  ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"X1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"X1", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"X2", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"Y1", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"Y2", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X1pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X2pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g22", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", "g22", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "m0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<n\>\"", ",", "\"\<x[n]\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Input signal x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Take", "[", 
        RowBox[{"Y1pts", ",", 
         RowBox[{"-", "65"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr4", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Take", "[", 
        RowBox[{"Y2pts", ",", 
         RowBox[{"-", "66"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g44", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr3", ",", "gr4", ",", "g44", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "m0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4.2"}], ",", "4.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<n\>\"", ",", "\"\<y[n]\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Output signal\>\"", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = x[n] + \!\(\*FractionBox[\(1\), \(6\)]\)(3+ \
4\!\(\*SqrtBox[\(2\)]\))y[n-1] - \!\(\*FractionBox[\(1\), \
\(9\)]\)(4+3\!\(\*SqrtBox[\(2\)]\))y[n-2] + \!\(\*FractionBox[\(2\), \
\(9\)]\)y[n-3]\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The  amplitude  responses\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Low  frequency:   A[\!\(\*FractionBox[\(\[Pi]\), \(16\)]\)] = |H[\!\
\(\*SuperscriptBox[\(\[ExponentialE]\), \(FractionBox[\[Pi], 16] \
\[ImaginaryI]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["\[Pi]", "16."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<High frequency:  A[\!\(\*FractionBox[\(3  \[Pi]\), \(4\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(FractionBox[3  \[Pi], 4] \
\[ImaginaryI]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox[
           RowBox[{"3", "\[Pi]"}], "4."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399484345484375*^9, 3.399484369734375*^9}, 
   3.400140260140625*^9, {3.4001413464375*^9, 3.40014138384375*^9}, {
   3.40034765884375*^9, 3.40034768271875*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.26.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Design a combination filter using the zeros ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}], " ", 
     RowBox[{"\[Pi]", "/", "2"}]}]], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]]}]]],
 " for zeroing out ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{"\[Pi]", " ", "n"}], ")"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "2"], "n"}], ")"}], " ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", "sin", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "2"], "n"}], ")"}]}]}]]],
 " and poles ",
 Cell[BoxData[
  RowBox[{
   FractionBox["2", "3"], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}], " ", 
     RowBox[{"\[Pi]", "/", "4"}]}]]}]]],
 " boosting up some of the low frequencies."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{597, 183},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["Figure 9.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "Amplitude response ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 ", and zero-pole plot for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "1"}], "]"}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "2"}], "]"}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "3"}], "]"}], "+", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], " ", "-", " ", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}]}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Solution", " ", 
   RowBox[{"9.26", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706129*^9, 3.506706129*^9}}],

Cell[TextData[{
 "The zeroing out portion of this filter design is similar to the filter in \
Example 9.23 (b) where we showed that \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"(", " ", 
     FractionBox[
      RowBox[{"z", "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"\[Pi]", "/", "2"}]}]]}], "z"], ")"}], 
    RowBox[{"(", " ", 
     FractionBox[
      RowBox[{"z", "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"\[Pi]", "/", "2"}]}]]}], "z"], ")"}], 
    RowBox[{"(", " ", 
     FractionBox[
      RowBox[{"z", "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]]}], "z"], ")"}]}], "  ", "=", 
   "  ", 
   RowBox[{"1", "+", 
    SuperscriptBox["z", 
     RowBox[{"-", "1"}]], "+", 
    SuperscriptBox["z", 
     RowBox[{"-", "2"}]], "+", 
    SuperscriptBox["z", 
     RowBox[{"-", "3"}]]}]}]]],
 ".  \n\nOf course, we could multiply by the constant ",
 Cell[BoxData[
  FractionBox["1", "4"]]],
 " to give this filter a moving average effect on the input signal ",
 Cell[BoxData[
  RowBox[{"x", "[", "n", "]"}]]],
 ".  However for simplicity, we use  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["b", "0"], "=", 
   RowBox[{
    SubscriptBox["b", "1"], "=", 
    RowBox[{
     SubscriptBox["b", "2"], "=", 
     RowBox[{
      SubscriptBox["b", "3"], "=", "1"}]}]}]}]]],
 ". in the numerator of the transfer function. "
}], "Text"],

Cell[TextData[{
 "For the boosting out portion of this filter design we choose the one \
developed in Example 9.22 (a):  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"(", " ", 
     FractionBox[
      RowBox[{"z", "-", 
       RowBox[{
        FractionBox["2", "3"], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "4"}]}]]}]}], "z"], ")"}], 
    RowBox[{"(", " ", 
     FractionBox[
      RowBox[{"z", "-", 
       RowBox[{
        FractionBox["2", "3"], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{"\[Pi]", "/", "4"}]}]]}]}], "z"], ")"}]}], "   ", "=", "  ", 
   RowBox[{"1", " ", "-", " ", 
    RowBox[{
     FractionBox["2", "3"], 
     SqrtBox["2"], 
     SuperscriptBox["z", 
      RowBox[{"-", "1"}]]}], " ", "+", " ", 
    RowBox[{
     FractionBox["4", "9"], 
     SuperscriptBox["z", 
      RowBox[{"-", "2"}]]}]}]}]]],
 " \n\nand we will use  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "1"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["2", "3"]}], 
     SqrtBox["2"], "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     SubscriptBox["a", "2"]}], "=", 
    FractionBox["4", "9"]}]}]]],
 "  in the denominator of the transfer function.  Putting the two parts \
together we obtain\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox[
     RowBox[{
      SubscriptBox["b", "0"], "+", 
      RowBox[{
       SubscriptBox["b", "1"], 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["b", "2"], 
       SuperscriptBox["z", 
        RowBox[{"-", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["b", "3"], 
       SuperscriptBox["z", 
        RowBox[{"-", "3"}]]}]}], 
     RowBox[{"1", "+", 
      RowBox[{
       SubscriptBox["a", "1"], 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["a", "2"], 
       SuperscriptBox["z", 
        RowBox[{"-", "2"}]]}]}]], "  ", "=", "  ", 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"1", "+", 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]], "+", 
       SuperscriptBox["z", 
        RowBox[{"-", "2"}]], "+", 
       SuperscriptBox["z", 
        RowBox[{"-", "3"}]]}]}], 
     RowBox[{"1", "-", 
      RowBox[{
       FractionBox["2", "3"], " ", 
       SqrtBox["2"], 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}], "+", 
      RowBox[{
       FractionBox["4", "9"], 
       SuperscriptBox["z", 
        RowBox[{"-", "2"}]]}]}]]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "The corresponding filter for this transfer function is \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["b", "0"], " ", 
      RowBox[{"x", "[", "n", "]"}]}], "+", 
     RowBox[{
      SubscriptBox["b", "1"], " ", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}], "+", 
     RowBox[{
      SubscriptBox["b", "2"], " ", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}]}], "+", 
     RowBox[{
      SubscriptBox["b", "3"], " ", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "3"}], "]"}]}], "-", 
     RowBox[{
      SubscriptBox["a", "1"], " ", 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}], "-", 
     RowBox[{
      SubscriptBox["a", "2"], " ", 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "2"}], "]"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "1"}], "]"}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "2"}], "]"}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "3"}], "]"}], "+", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], " ", "-", " ", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox["Remark 9.19.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The zeros  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}], " ", 
     RowBox[{"\[Pi]", "/", "2"}]}]], "  ", "and", "  ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]]}]]],
 "  of  ",
 Cell[BoxData[
  RowBox[{"H", 
   RowBox[{"(", "z", ")"}]}]]],
 " determine which signals are zeroed out and the arguments of the poles ",
 Cell[BoxData[
  RowBox[{
   FractionBox["2", "3"], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}], " ", 
     RowBox[{"\[Pi]", "/", "4"}]}]]}]]],
 " of  ",
 Cell[BoxData[
  RowBox[{"H", 
   RowBox[{"(", "z", ")"}]}]]],
 "point to frequencies that are boosted up by the filter. "
}], "Text"],

Cell[TextData[{
 StyleBox["Remark 9.20.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The flat portion of the graph in the interval ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"0", ",", 
    FractionBox["\[Pi]", "4"]}], "]"}]]],
 "  makes this filter more practical for boosting low frequencies than the \
filter in Example 9.22 (a).  "
}], "Text"],

Cell[TextData[{
 StyleBox["Remark 9.21.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The higher frequencies in the interval ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{
    FractionBox["\[Pi]", "2"], ",", "\[Pi]"}], "]"}]]],
 " are attenuated more than they are in Example 9.23 (b).  The situation is \
illustrated in Figure 9.13."
}], "Text"],

Cell[TextData[{
 StyleBox["Figure 9.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "Amplitude response ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 ", and zero-pole plot for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "1"}], "]"}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "2"}], "]"}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "3"}], "]"}], "+", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], " ", "-", " ", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}]}]]],
 ". "
}], "Text"],

Cell["\<\
Background for the z-transform and its application for solving difference \
equations can be found in the book.\
\>", "Text",
 CellChangeTimes->{{3.5067629805625*^9, 3.50676298121875*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"9.26", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706130578125*^9, 3.506706130578125*^9}}],

Cell[TextData[{
 StyleBox["Remark 9.19.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The zeros  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}], " ", 
     RowBox[{"\[Pi]", "/", "2"}]}]], "  ", "and", "  ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]]}]]],
 "  of  ",
 Cell[BoxData[
  RowBox[{"H", 
   RowBox[{"(", "z", ")"}]}]]],
 " determine which signals are zeroed out and the arguments of the poles ",
 Cell[BoxData[
  RowBox[{
   FractionBox["2", "3"], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}], " ", 
     RowBox[{"\[Pi]", "/", "4"}]}]]}]]],
 " of  ",
 Cell[BoxData[
  RowBox[{"H", 
   RowBox[{"(", "z", ")"}]}]]],
 "point to frequencies that are boosted up by the filter. "
}], "Text"],

Cell[TextData[{
 StyleBox["Remark 9.20.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The flat portion of the graph in the interval ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"0", ",", 
    FractionBox["\[Pi]", "4"]}], "]"}]]],
 "  makes this filter more practical for boosting low frequencies than the \
filter in Example 9.22 (a).  "
}], "Text"],

Cell[TextData[{
 StyleBox["Remark 9.21.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The higher frequencies in the interval ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{
    FractionBox["\[Pi]", "2"], ",", "\[Pi]"}], "]"}]]],
 " are attenuated more than they are in Example 9.23 (b).  The situation is \
illustrated in Figure 9.13."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"\[Pi]", "/", "2"}]}]]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"\[Pi]", "/", "2"}]}]]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Pi]"}]]}], "z"], ")"}]}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"\[Pi]", "/", "4"}]}]]}]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            RowBox[{"\[Pi]", "/", "4"}]}]]}]}], "z"], ")"}]}]}], " ", ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<H[z] = \>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Pi]/2\)]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*SuperscriptBox[\(\[ExponentialE]\), \
\(\(-\[ImaginaryI]\[Pi]\)/2\)]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*SuperscriptBox[\(\[ExponentialE]\), \(-\
\[ImaginaryI]\[Pi]\)]\), \(z\)]\))/[\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*FractionBox[\(2\), \(3\)]\\\ \
\*SuperscriptBox[\(\[ExponentialE]\), \(-\*FractionBox[\(\[ImaginaryI]\\\ \
\[Pi]\), \(4\)]\)]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*FractionBox[\(2\), \(3\)]\\\ \
\*SuperscriptBox[\(\[ExponentialE]\), FractionBox[\(\[ImaginaryI]\\\ \[Pi]\), \
\(4\)]]\), \(z\)]\))]\>\""}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"H", "[", "z", "]"}], "/", 
       RowBox[{"G", "[", "z", "]"}]}]}], " ", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"H", "[", "z", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "z_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"G", "[", "z", "]"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"H", "[", "z", "]"}], "/", 
       RowBox[{"G", "[", "z", "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399484385640625*^9, 3.399484387046875*^9}, {
  3.400357866109375*^9, 3.400357952703125*^9}, {3.400358734625*^9, 
  3.40035874578125*^9}}],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     FractionBox[
      RowBox[{"1", "+", 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]], "+", 
       SuperscriptBox["z", 
        RowBox[{"-", "2"}]], "+", 
       SuperscriptBox["z", 
        RowBox[{"-", "3"}]]}], 
      RowBox[{"1", "-", 
       RowBox[{
        FractionBox["2", "3"], " ", 
        SqrtBox["2"], 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}], "+", 
       RowBox[{
        FractionBox["4", "9"], 
        SuperscriptBox["z", 
         RowBox[{"-", "2"}]]}]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "\[Theta]_", "]"}], "=", 
     RowBox[{"Abs", "[", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"gr3", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"A", "[", "\[Theta]", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Theta]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "\[Pi]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "8.3"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "\[Pi]", ",", 
           FractionBox["\[Pi]", "4"]}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "8", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<\[Theta]\>\"", ",", "\"\<A(\[Theta])\>\""}], "}"}]}], 
      ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The amplitude response\>\"", "]"}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\[Theta]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Theta]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], ",", 
      "\"\<|\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<For the filter\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = x[n]+x[n-1]+x[n-2]+x[n-3] + \!\(\*FractionBox[\(2\), \
\(3\)]\)\!\(\*SqrtBox[\(2\)]\)y[n-1] - \!\(\*FractionBox[\(4\), \
\(9\)]\)y[n-2]\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948438971875*^9, 3.3994843938125*^9}, 
   3.400140265828125*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ZeroPolePlot1", ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994843986875*^9, 3.3994843995625*^9}}],

Cell[TextData[{
 StyleBox["Figure 9.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 "Amplitude response ",
 Cell[BoxData[
  RowBox[{"A", 
   RowBox[{"(", "\[Theta]", ")"}]}]]],
 ", and zero-pole plot for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "1"}], "]"}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "2"}], "]"}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "3"}], "]"}], "+", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], " ", "-", " ", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can investigate how this filter work."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"gr3", ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          FractionBox["\[Pi]", "16"], ",", 
          FractionBox["\[Pi]", "2"], ",", 
          FractionBox[
           RowBox[{"3", " ", "\[Pi]"}], "4"], ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "8", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The amplitude response\>\"", "]"}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\[Theta]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Theta]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], ",", 
      "\"\<|\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(\[Pi]\), \(16\)]\)]  = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI] \*FractionBox[\(\
\[Pi]\), \(16\)]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["\[Pi]", "16."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(3  \[Pi]\), \(4\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI] \
\*FractionBox[\(3  \[Pi]\), \(4\)]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox[
           RowBox[{"3", "\[Pi]"}], "4."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<For the filter\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = x[n]+x[n-1]+x[n-2]+x[n-3] + \!\(\*FractionBox[\(2\), \
\(3\)]\)\!\(\*SqrtBox[\(2\)]\) y[n-1] - \!\(\*FractionBox[\(4\), \
\(9\)]\)y[n-2]\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994844029375*^9, 3.399484408296875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox["\[Pi]", "16"], " ", "n"}], "]"}], "+", 
      RowBox[{"Sin", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"3", "\[Pi]"}], "4"], " ", "n"}], "]"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "65"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{
          FractionBox["\[Pi]", "16"], " ", "i"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"X2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox["\[Pi]", "16"], " ", "i"}], "]"}], "+", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"3", "\[Pi]"}], "4"], " ", "i"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X1", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", "X1"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X2", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", "X2"}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y2", "=", 
     RowBox[{"Y1", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", 
          RowBox[{"m0", "+", "9"}]}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "10"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"m0", "+", "10"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        SubscriptBox["Y1", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Chop", "[", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["X1", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           " ", "+", 
           SubscriptBox["X1", 
            RowBox[{"\[LeftDoubleBracket]", 
             RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]], " ", "+", 
           SubscriptBox["X1", 
            RowBox[{"\[LeftDoubleBracket]", 
             RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]], " ", "+", 
           SubscriptBox["X1", 
            RowBox[{"\[LeftDoubleBracket]", 
             RowBox[{"i", "-", "3"}], "\[RightDoubleBracket]"}]], " ", "+", 
           " ", 
           RowBox[{
            FractionBox["2", "3"], 
            SqrtBox["2"], 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], " ", "-",
            " ", 
           RowBox[{
            FractionBox["4", "9"], 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}]}], " ", 
          ")"}], " ", "]"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{
        SubscriptBox["Y2", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Chop", "[", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["X2", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           " ", "+", 
           SubscriptBox["X2", 
            RowBox[{"\[LeftDoubleBracket]", 
             RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]], " ", "+", 
           SubscriptBox["X2", 
            RowBox[{"\[LeftDoubleBracket]", 
             RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]], " ", "+", 
           SubscriptBox["X2", 
            RowBox[{"\[LeftDoubleBracket]", 
             RowBox[{"i", "-", "3"}], "\[RightDoubleBracket]"}]], " ", "+", 
           " ", 
           RowBox[{
            FractionBox["2", "3"], 
            SqrtBox["2"], 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], " ", "-",
            " ", 
           RowBox[{
            FractionBox["4", "9"], 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}]}], ")"}], 
         " ", "]"}]}], ";"}]}], "  ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"X1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"X1", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"X2", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"Y1", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"Y2", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X1pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X2pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g22", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", "g22", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "m0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<n\>\"", ",", "\"\<x[n]\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Input signal x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Take", "[", 
        RowBox[{"Y1pts", ",", 
         RowBox[{"-", "65"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr4", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Take", "[", 
        RowBox[{"Y2pts", ",", 
         RowBox[{"-", "66"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g44", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr3", ",", "gr4", ",", "g44", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "m0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "8.2"}], ",", "8.8"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "8"}], ",", "8", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<n\>\"", ",", "\"\<y[n]\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Output signal\>\"", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = x[n]+x[n-1]+x[n-2]+x[n-3] + \!\(\*FractionBox[\(2\), \
\(3\)]\)\!\(\*SqrtBox[\(2\)]\) y[n-1] - \!\(\*FractionBox[\(4\), \
\(9\)]\)y[n-2]\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The  amplitude  responses\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Low  frequency:   A[\!\(\*FractionBox[\(\[Pi]\), \(16\)]\)] = |H[\!\
\(\*SuperscriptBox[\(\[ExponentialE]\), \(FractionBox[\[Pi], 16] \
\[ImaginaryI]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["\[Pi]", "16."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<High frequency:  A[\!\(\*FractionBox[\(3  \[Pi]\), \(4\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(FractionBox[3  \[Pi], 4] \
\[ImaginaryI]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox[
           RowBox[{"3", "\[Pi]"}], "4."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948441090625*^9, 3.3994844356875*^9}, 
   3.400140272734375*^9, {3.400141396265625*^9, 3.4001414213125*^9}, {
   3.400347691171875*^9, 3.40034771125*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Low Frequency Filter",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tThe previous examples emphasize high frequency filters.  To boost up \
high frequencies place the poles near the higher frequencies. The following \
example is similar to Example 9.25.  The poles have been changed from  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["2", "3"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"\[Pi]", "/", "4"}]}]]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    FractionBox["2", "3"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      RowBox[{"\[Pi]", "/", "4"}]}]], "  ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", 
    FractionBox["1", "2"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "0"}]]}]}]]],
 "  to ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["2", "3"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "3", 
      RowBox[{"\[Pi]", "/", "4"}]}]]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    FractionBox["2", "3"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "3", 
      RowBox[{"\[Pi]", "/", "4"}]}]], "  ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", 
    FractionBox["1", "2"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Extra Example 1 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   Design a filter with poles  ",
 Cell[BoxData[
  RowBox[{
   FractionBox["2", "3"], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "3", 
     RowBox[{"\[Pi]", "/", "4"}]}]], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   FractionBox["2", "3"], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "3", 
     RowBox[{"\[Pi]", "/", "4"}]}]]}]]],
 "  for boosting up signals near ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"3", "\[Pi]"}], "4"], "n"}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"sin", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"3", "\[Pi]"}], "4"], "n"}], ")"}]}]]],
 ".\n\n",
 StyleBox["1 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   Include the additional pole at  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]]}], "=", 
   RowBox[{"-", 
    FractionBox["1", "2"]}]}]]],
 " to the filter design in (a) so that it also boosts up high frequency \
signals."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "1."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706134140625*^9, 3.506706134140625*^9}}],

Cell[TextData[{
 StyleBox["1 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   Design a filter with poles  ",
 Cell[BoxData[
  RowBox[{
   FractionBox["2", "3"], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "3", 
     RowBox[{"\[Pi]", "/", "4"}]}]], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   FractionBox["2", "3"], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]3"}], " ", 
     RowBox[{"\[Pi]", "/", "4"}]}]]}]]],
 "  for boosting up signals near ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"3", "\[Pi]"}], "4"], "n"}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"sin", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"3", "\[Pi]"}], "4"], "n"}], ")"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "3", " ", 
            RowBox[{"\[Pi]", "/", "4"}]}]]}]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "3", 
            RowBox[{"\[Pi]", "/", "4"}]}]]}]}], "z"], ")"}]}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<H[z] = 1/[\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*FractionBox[\(2\), \(3\)]\\\ \
\*SuperscriptBox[\(\[ExponentialE]\), \(-\*FractionBox[\(3\\\ \[ImaginaryI]\\\
\ \[Pi]\), \(4\)]\)]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*FractionBox[\(2\), \(3\)]\\\ \
\*SuperscriptBox[\(\[ExponentialE]\), FractionBox[\(3\\\ \[ImaginaryI]\\\ \
\[Pi]\), \(4\)]]\), \(z\)]\))]\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"1", "/", 
       RowBox[{"G", "[", "z", "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "z_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"G", "[", "z", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"1", "/", 
       RowBox[{"G", "[", "z", "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399484444109375*^9, 3.399484446578125*^9}, {
  3.40035774853125*^9, 3.40035781065625*^9}, {3.4003587699375*^9, 
  3.40035877603125*^9}}],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     FractionBox["1", 
      RowBox[{"1", "+", 
       RowBox[{
        FractionBox["2", "3"], 
        SqrtBox["2"], 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}], "+", 
       RowBox[{
        FractionBox["4", "9"], 
        SuperscriptBox["z", 
         RowBox[{"-", "2"}]]}]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "\[Theta]_", "]"}], "=", 
     RowBox[{"Abs", "[", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"gr1", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"A", "[", "\[Theta]", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Theta]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "\[Pi]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "2.6"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "\[Pi]", ",", 
           FractionBox["\[Pi]", "4"]}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "2.5", ",", "0.5"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<\[Theta]\>\"", ",", "\"\<A(\[Theta])\>\""}], "}"}]}], 
      ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The amplitude response\>\"", "]"}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\[Theta]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Theta]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], ",", 
      "\"\<|\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<For the filter\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = y[n] = x[n] - \!\(\*FractionBox[\(2\), \
\(3\)]\)\!\(\*SqrtBox[\(2\)]\)y[n-1] -\!\(\*FractionBox[\(4\), \(\(\\\ \
\)\(9\)\)]\)y[n-2]\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994844490625*^9, 3.3994844528125*^9}, 
   3.4001402779375*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ZeroPolePlot1", ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948445609375*^9, 3.399484457*^9}}],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can investigate how this filter work."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          FractionBox["\[Pi]", "16"], ",", 
          FractionBox["\[Pi]", "2"], ",", 
          FractionBox[
           RowBox[{"3", " ", "\[Pi]"}], "4"], ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2.5", ",", "0.5"}], "]"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The amplitude response\>\"", "]"}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\[Theta]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\\\ \[Theta]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], ",", 
      "\"\<|\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(\[Pi]\), \(16\)]\)]  = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI] \*FractionBox[\(\
\[Pi]\), \(16\)]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["\[Pi]", "16."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(3  \[Pi]\), \(4\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI] \
\*FractionBox[\(3  \[Pi]\), \(4\)]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox[
           RowBox[{"3", "\[Pi]"}], "4."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<For the filter\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = y[n] = x[n] + \!\(\*FractionBox[\(2\), \
\(3\)]\)\!\(\*SqrtBox[\(2\)]\)y[n-1] -\!\(\*FractionBox[\(4\), \(\(\\\ \
\)\(9\)\)]\)y[n-2]\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399484460015625*^9, 3.399484463640625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox["\[Pi]", "16"], " ", "n"}], "]"}], "+", 
      RowBox[{"Sin", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"3", "\[Pi]"}], "4"], " ", "n"}], "]"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "65"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{
          FractionBox["\[Pi]", "16"], " ", "i"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"X2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox["\[Pi]", "16"], " ", "i"}], "]"}], "+", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"3", "\[Pi]"}], "4"], " ", "i"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X1", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", "X1"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X2", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", "X2"}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y2", "=", 
     RowBox[{"Y1", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", 
          RowBox[{"m0", "+", "9"}]}], "}"}]}], "]"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "10"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"m0", "+", "10"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        SubscriptBox["Y1", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Chop", "[", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["X1", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           " ", "-", " ", 
           RowBox[{
            FractionBox["2", "3"], 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], " ", "-", 
           RowBox[{
            FractionBox["4", 
             RowBox[{" ", "9"}]], 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}]}], " ", 
          ")"}], " ", "]"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{
        SubscriptBox["Y2", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Chop", "[", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["X2", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           " ", "-", " ", 
           RowBox[{
            FractionBox["2", "3"], 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], " ", "-", 
           RowBox[{
            FractionBox["4", 
             RowBox[{" ", "9"}]], 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}]}], " ", 
          ")"}], " ", "]"}]}], ";"}]}], "  ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"X1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"X1", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"X2", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"Y1", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"Y2", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X1pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X2pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g22", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", "g22", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "m0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<n\>\"", ",", "\"\<x[n]\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Input signal x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Take", "[", 
        RowBox[{"Y1pts", ",", 
         RowBox[{"-", "65"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr4", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Take", "[", 
        RowBox[{"Y2pts", ",", 
         RowBox[{"-", "66"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g44", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr3", ",", "gr4", ",", "g44", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "m0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<n\>\"", ",", "\"\<y[n]\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Output signal\>\"", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = y[n] = x[n] + \!\(\*FractionBox[\(2\), \
\(3\)]\)\!\(\*SqrtBox[\(2\)]\)y[n-1] -\!\(\*FractionBox[\(4\), \(\(\\\ \
\)\(9\)\)]\)y[n-2]\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The  amplitude  responses\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Low  frequency:   A[\!\(\*FractionBox[\(\[Pi]\), \(16\)]\)] = |H[\!\
\(\*SuperscriptBox[\(\[ExponentialE]\), \(FractionBox[\[Pi], 16] \
\[ImaginaryI]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["\[Pi]", "16."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<High frequency:  A[\!\(\*FractionBox[\(3  \[Pi]\), \(4\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(FractionBox[3  \[Pi], 4] \
\[ImaginaryI]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox[
           RowBox[{"3", "\[Pi]"}], "4."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399484466375*^9, 3.3994844901875*^9}, 
   3.40014028346875*^9, {3.400141431921875*^9, 3.4001414544375*^9}, {
   3.40034771821875*^9, 3.400347739*^9}}],

Cell[TextData[{
 StyleBox["1 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   Include the additional pole at  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]]}], "=", 
   RowBox[{"-", 
    FractionBox["1", "2"]}]}]]],
 " to the filter design in (a) so that it also boosts up high frequency \
signals."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"(", " ", 
       FractionBox[
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "3", 
            RowBox[{"\[Pi]", "/", "4"}]}]]}]}], "z"], ")"}], 
      RowBox[{"(", " ", 
       FractionBox[
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "3", 
            RowBox[{"\[Pi]", "/", "4"}]}]]}]}], "z"], ")"}], 
      RowBox[{"(", " ", 
       FractionBox[
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["1", "2"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]]}]}], "z"], ")"}]}]}], " ",
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = 1/[\>\"", ",", 
      RowBox[{"\"\<(\>\"", " ", 
       FractionBox[
        "\"\<z-\!\(\*FractionBox[\(2\), \(3\)]\)\!\(\*SuperscriptBox[\(\
\[ExponentialE]\), \(\[ImaginaryI]\\\ 3  \[Pi]/4\)]\)\>\"", "z"]}], ",", 
      "\"\<)(\>\"", " ", ",", 
      FractionBox[
       "\"\<z-\!\(\*FractionBox[\(2\), \(3\)]\)\!\(\*SuperscriptBox[\(\
\[ExponentialE]\), \(\(-\[ImaginaryI]\)\\\ 3  \[Pi]/4\)]\)\>\"", "z"], ",", 
      "\"\<)(\>\"", ",", " ", 
      FractionBox[
       "\"\<z-\!\(\*FractionBox[\(1\), \(2\)]\)\!\(\*SuperscriptBox[\(\
\[ExponentialE]\), \(\[ImaginaryI]\\\ \[Pi]\)]\)\>\"", "z"], ",", 
      "\"\<)]\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"1", "/", 
       RowBox[{"G", "[", "z", "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "z_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"G", "[", "z", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"1", "/", 
       RowBox[{"G", "[", "z", "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "z_", "]"}], "=", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"G", "[", "z", "]"}], ",", "z"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"1", "/", 
       RowBox[{"G", "[", "z", "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948449465625*^9, 3.399484496125*^9}, {
  3.40034802028125*^9, 3.40034805925*^9}, {3.400348092328125*^9, 
  3.400348264546875*^9}, {3.4003576859375*^9, 3.40035770296875*^9}}],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     FractionBox["1", 
      RowBox[{" ", 
       RowBox[{"1", "+", 
        RowBox[{
         FractionBox["1", "6"], 
         RowBox[{"(", 
          RowBox[{"3", "+", " ", 
           RowBox[{"4", 
            SqrtBox["2"]}]}], ")"}], 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}], "+", 
        RowBox[{
         FractionBox["1", "9"], 
         RowBox[{"(", 
          RowBox[{"4", "+", 
           RowBox[{"3", 
            SqrtBox["2"]}]}], ")"}], 
         SuperscriptBox["z", 
          RowBox[{"-", "2"}]]}], "+", 
        RowBox[{
         FractionBox["2", "9"], 
         SuperscriptBox["z", 
          RowBox[{"-", "3"}]]}]}]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "\[Theta]_", "]"}], "=", 
     RowBox[{"Abs", "[", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"gr2", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"A", "[", "\[Theta]", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Theta]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "\[Pi]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "4"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "\[Pi]", ",", 
           FractionBox["\[Pi]", "4"]}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<\[Theta]\>\"", ",", "\"\<A(\[Theta])\>\""}], "}"}]}], 
      ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The amplitude response\>\"", "]"}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\[Theta]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Theta]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], ",", 
      "\"\<|\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<For the filter\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = x[n] - \!\(\*FractionBox[\(1\), \(6\)]\)(3+ \
4\!\(\*SqrtBox[\(2\)]\))y[n-1] - \!\(\*FractionBox[\(1\), \
\(9\)]\)(4+3\!\(\*SqrtBox[\(2\)]\))y[n-2] - \!\(\*FractionBox[\(2\), \
\(9\)]\)y[n-3]\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994844991875*^9, 3.399484503015625*^9}, 
   3.40014028878125*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ZeroPolePlot1", ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948450565625*^9, 3.39948450628125*^9}}],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can investigate how this filter work."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"gr2", ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          FractionBox["\[Pi]", "16"], ",", 
          FractionBox["\[Pi]", "2"], ",", 
          FractionBox[
           RowBox[{"3", " ", "\[Pi]"}], "4"], ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "4", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The amplitude response\>\"", "]"}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\[Theta]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Theta]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], ",", 
      "\"\<|\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(\[Pi]\), \(16\)]\)]  = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI] \*FractionBox[\(\
\[Pi]\), \(16\)]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["\[Pi]", "16."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(3  \[Pi]\), \(4\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI] \
\*FractionBox[\(3  \[Pi]\), \(4\)]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox[
           RowBox[{"3", "\[Pi]"}], "4."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<For the filter\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = x[n] - \!\(\*FractionBox[\(1\), \(6\)]\)(3+ \
4\!\(\*SqrtBox[\(2\)]\))y[n-1] - \!\(\*FractionBox[\(1\), \
\(9\)]\)(4+3\!\(\*SqrtBox[\(2\)]\))y[n-2] - \!\(\*FractionBox[\(2\), \
\(9\)]\)y[n-3]\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948450953125*^9, 3.39948451371875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox["\[Pi]", "16"], " ", "n"}], "]"}], "+", 
      RowBox[{"Sin", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"3", "\[Pi]"}], "4"], " ", "n"}], "]"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "65"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{
          FractionBox["\[Pi]", "16"], " ", "i"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"X2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox["\[Pi]", "16"], " ", "i"}], "]"}], "+", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"3", "\[Pi]"}], "4"], " ", "i"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X1", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", "X1"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X2", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", "X2"}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y2", "=", 
     RowBox[{"Y1", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", 
          RowBox[{"m0", "+", "9"}]}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "10"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"m0", "+", "10"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        SubscriptBox["Y1", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Chop", "[", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["X1", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           " ", "-", " ", 
           RowBox[{
            FractionBox["1", "6"], 
            RowBox[{"(", 
             RowBox[{"3", "+", " ", 
              RowBox[{"4", 
               SqrtBox["2"]}]}], ")"}], 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], " ", "-",
            " ", 
           RowBox[{
            FractionBox["1", "9"], 
            RowBox[{"(", 
             RowBox[{"4", "+", 
              RowBox[{"3", 
               SqrtBox["2"]}]}], ")"}], 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}], " ", "-",
            " ", 
           RowBox[{
            FractionBox["2", "9"], 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "3"}], "\[RightDoubleBracket]"}]]}]}], ")"}], 
         " ", "]"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{
        SubscriptBox["Y2", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Chop", "[", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["X2", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           " ", "-", " ", 
           RowBox[{
            FractionBox["1", "6"], 
            RowBox[{"(", 
             RowBox[{"3", "+", " ", 
              RowBox[{"4", 
               SqrtBox["2"]}]}], ")"}], 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], " ", "-",
            " ", 
           RowBox[{
            FractionBox["1", "9"], 
            RowBox[{"(", 
             RowBox[{"4", "+", 
              RowBox[{"3", 
               SqrtBox["2"]}]}], ")"}], 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}], " ", "-",
            " ", 
           RowBox[{
            FractionBox["2", "9"], 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "3"}], "\[RightDoubleBracket]"}]]}]}], ")"}], 
         " ", "]"}]}], ";"}]}], "  ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"X1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"X1", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"X2", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"Y1", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"Y2", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X1pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X2pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g22", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", "g22", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "m0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<n\>\"", ",", "\"\<x[n]\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Input signal x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Take", "[", 
        RowBox[{"Y1pts", ",", 
         RowBox[{"-", "65"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr4", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Take", "[", 
        RowBox[{"Y2pts", ",", 
         RowBox[{"-", "66"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g44", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr3", ",", "gr4", ",", "g44", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "m0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3.2"}], ",", "3.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<n\>\"", ",", "\"\<y[n]\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Output signal\>\"", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = x[n] - \!\(\*FractionBox[\(1\), \(6\)]\)(3+ \
4\!\(\*SqrtBox[\(2\)]\))y[n-1] - \!\(\*FractionBox[\(1\), \
\(9\)]\)(4+3\!\(\*SqrtBox[\(2\)]\))y[n-2] - \!\(\*FractionBox[\(2\), \
\(9\)]\)y[n-3]\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The  amplitude  responses\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Low  frequency:   A[\!\(\*FractionBox[\(\[Pi]\), \(16\)]\)] = |H[\!\
\(\*SuperscriptBox[\(\[ExponentialE]\), \(FractionBox[\[Pi], 16] \
\[ImaginaryI]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["\[Pi]", "16."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<High frequency:  A[\!\(\*FractionBox[\(3  \[Pi]\), \(4\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(FractionBox[3  \[Pi], 4] \
\[ImaginaryI]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox[
           RowBox[{"3", "\[Pi]"}], "4."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948451628125*^9, 3.39948453840625*^9}, 
   3.400140294609375*^9, {3.400141479484375*^9, 3.400141505890625*^9}, {
   3.400347748140625*^9, 3.400347772734375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Band Pass Filter",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tPoles can be placed near frequencies to boost them up and zeros for \
attenuating the other frequencies."
}], "Text"],

Cell[TextData[{
 StyleBox["Extra Example 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Design a combination filter boosting up some of the low frequencies where \
",
 Cell[BoxData[
  RowBox[{
   FractionBox["\[Pi]", "3"], "<", "\[Theta]", "<", 
   FractionBox["\[Pi]", "2"]}]]],
 " and attenuating frequencies ",
 Cell[BoxData[
  RowBox[{"\[Theta]", "<", 
   RowBox[{
    FractionBox["22", "100"], "\[Pi]"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["63", "100"], "\[Pi]"}], "<", "\[Theta]"}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "2."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706137359375*^9, 3.506706137375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"\[Pi]", "/", "6"}]}]]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"\[Pi]", "/", "6"}]}]]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "2", 
           RowBox[{"\[Pi]", "/", "3"}]}]]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "2", 
           RowBox[{"\[Pi]", "/", "3"}]}]]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "0"}]]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Pi]"}]]}], "z"], ")"}]}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["5", "6"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"\[Pi]", "/", "3"}]}]]}]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["5", "6"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            RowBox[{"\[Pi]", "/", "3"}]}]]}]}], "z"], ")"}], " ", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["5", "6"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"\[Pi]", "/", "2"}]}]]}]}], "z"], ")"}], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["5", "6"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            RowBox[{"\[Pi]", "/", "2"}]}]]}]}], "z"], ")"}]}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<H[z] = \>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*SuperscriptBox[\(\[ExponentialE]\), \
\(\(-\[ImaginaryI]\)\\\ 0\)]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*SuperscriptBox[\(\[ExponentialE]\), \
\(\(-\[ImaginaryI]\)\\\ \[Pi]\)]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*SuperscriptBox[\(\[ExponentialE]\), \
FractionBox[\(\(-\[ImaginaryI]\)\\\ \[Pi]\), \(6\)]]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*SuperscriptBox[\(\[ExponentialE]\), \
FractionBox[\(\[ImaginaryI]\\\ \[Pi]\), \(6\)]]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*SuperscriptBox[\(\[ExponentialE]\), \
FractionBox[\(\(-\[ImaginaryI]\)\\\ 2  \[Pi]\), \(3\)]]\), \(z\)]\))\>\"", 
      ",", "\"\<(\!\(\*FractionBox[\(z - \
\*SuperscriptBox[\(\[ExponentialE]\), FractionBox[\(\[ImaginaryI]\\\ 2  \[Pi]\
\), \(3\)]]\), \(z\)]\))\>\"", ",", "\"\</[\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*FractionBox[\(5\), \(6\)]\\\ \
\*SuperscriptBox[\(\[ExponentialE]\), FractionBox[\(\[ImaginaryI]\\\ \[Pi]\), \
\(2\)]]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*FractionBox[\(5\), \(6\)]\\\ \
\*SuperscriptBox[\(\[ExponentialE]\), \(-\*FractionBox[\(\[ImaginaryI]\\\ \
\[Pi]\), \(2\)]\)]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*FractionBox[\(5\), \(6\)]\\\ \
\*SuperscriptBox[\(\[ExponentialE]\), \(-\*FractionBox[\(\[ImaginaryI]\\\ \
\[Pi]\), \(3\)]\)]\), \(z\)]\))\>\"", ",", 
      "\"\<(\!\(\*FractionBox[\(z - \*FractionBox[\(5\), \(6\)]\\\ \
\*SuperscriptBox[\(\[ExponentialE]\), FractionBox[\(\[ImaginaryI]\\\ \[Pi]\), \
\(3\)]]\), \(z\)]\))]\>\""}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"F", "[", "z", "]"}], "/", 
      RowBox[{"G", "[", "z", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"H", "[", "z", "]"}]}], " ", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], "=", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"ComplexExpand", "[", 
        RowBox[{"F", "[", "z", "]"}], "]"}], ",", "z"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "z_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"G", "[", "z", "]"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"F", "[", "z", "]"}], "/", 
      RowBox[{"G", "[", "z", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"H", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994845464375*^9, 3.399484548171875*^9}, {
  3.40035736521875*^9, 3.400357376078125*^9}, {3.400357418578125*^9, 
  3.400357483921875*^9}, {3.400357533796875*^9, 3.40035757709375*^9}, {
  3.400358831484375*^9, 3.40035883703125*^9}, {3.40035886909375*^9, 
  3.40035890084375*^9}, {3.400358941515625*^9, 3.40035900309375*^9}, {
  3.400359074203125*^9, 3.400359123171875*^9}, {3.400359176015625*^9, 
  3.40035917721875*^9}, {3.400359216625*^9, 3.400359218265625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"k", ",", "n", ",", "x", ",", "y"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"filter", "=", 
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], "\[Equal]", 
      RowBox[{
       RowBox[{"ReplaceAll", "[", 
        RowBox[{
         RowBox[{"Expand", "[", 
          RowBox[{"F", "[", "z", "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"1", "\[Rule]", 
            RowBox[{"x", "[", "n", "]"}]}], ",", 
           RowBox[{
            RowBox[{"Power", "[", 
             RowBox[{"z", ",", "k_"}], "]"}], "\[Rule]", 
            RowBox[{"x", "[", 
             RowBox[{"n", "+", "k"}], "]"}]}]}], "}"}]}], "]"}], "-", 
       RowBox[{"ReplaceAll", "[", 
        RowBox[{
         RowBox[{"G", "[", "z", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"1", "\[Rule]", "0"}], ",", 
           RowBox[{
            RowBox[{"Power", "[", 
             RowBox[{"z", ",", "k_"}], "]"}], "\[Rule]", 
            RowBox[{"y", "[", 
             RowBox[{"n", "+", "k"}], "]"}]}]}], "}"}]}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<For the transfer function\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<H[z] = \>\"", ",", 
      RowBox[{"H", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The filter is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "filter", " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948455059375*^9, 3.39948455225*^9}}],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", "\[Theta]_", "]"}], "=", 
     RowBox[{"Abs", "[", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"gr3", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"A", "[", "\[Theta]", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Theta]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "\[Pi]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "15"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", 
           FractionBox["\[Pi]", "6"], ",", 
           FractionBox["\[Pi]", "3"], ",", 
           FractionBox["\[Pi]", "2"], ",", 
           FractionBox[
            RowBox[{"2", "\[Pi]"}], "3"], ",", "\[Pi]"}], "}"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "16", ",", "2"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<\[Theta]\>\"", ",", "\"\<A(\[Theta])\>\""}], "}"}]}], 
      ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The amplitude response\>\"", "]"}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\[Theta]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Theta]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], ",", 
      "\"\<|\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(22\), \(100\)]\)\[Pi]] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]  FractionBox[22, \
100] \[Pi]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{" ", 
          RowBox[{"\[ImaginaryI]", 
           FractionBox["22.", "100"], "\[Pi]"}]}]], "]"}], "]"}]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(63\), \(100\)]\)\[Pi]] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]  FractionBox[63, \
100] \[Pi]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{" ", 
          RowBox[{"\[ImaginaryI]", 
           FractionBox["63.", "100"], "\[Pi]"}]}]], "]"}], "]"}]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<For the filter\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "filter", " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399484558609375*^9, 3.399484562421875*^9}, 
   3.40014030275*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ZeroPolePlot1", ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948456540625*^9, 3.39948456615625*^9}}],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can investigate how this filter work."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"gr3", ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          FractionBox["13", "25"], ",", 
          FractionBox["\[Pi]", "3"], ",", 
          FractionBox["\[Pi]", "2"], ",", 
          FractionBox["21", "10"], ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "15", ",", "2"}], "]"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The amplitude response\>\"", "]"}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\[Theta]] = |H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\[Theta]\)]\)]| = |\>\"", ",", 
      RowBox[{"H", "[", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], ",", 
      "\"\<|\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(13\), \(25\)]\)] = |H[\!\(\*SuperscriptBox[\(\
\[ExponentialE]\), \(\[ImaginaryI] \*FractionBox[\(13\), \(25\)]\)]\)]| =  \>\
\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["13", "25."], "\[ImaginaryI]"}]], "]"}], "]"}]}], " ", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< A[\!\(\*FractionBox[\(\[Pi]\), \(2\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI] \*FractionBox[\(\
\[Pi]\), \(2\)]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["\[Pi]", "2."], "\[ImaginaryI]"}]], "]"}], "]"}]}], " ",
      "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A[\!\(\*FractionBox[\(21\), \(10\)]\)] = |H[\!\(\*SuperscriptBox[\(\
\[ExponentialE]\), \(\[ImaginaryI] \*FractionBox[\(21\), \(10\)]\)]\)]| =  \>\
\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["21", "10."], "\[ImaginaryI]"}]], "]"}], "]"}]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<For the filter\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = x[n]+x[n-1]+x[n-2]+x[n-3] + \!\(\*FractionBox[\(2\), \
\(3\)]\)\!\(\*SqrtBox[\(2\)]\) y[n-1] - \!\(\*FractionBox[\(4\), \
\(9\)]\)y[n-2]\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399484569078125*^9, 3.39948457225*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox["13", "25"], " ", "n"}], "]"}], "+", 
      RowBox[{"Sin", "[", 
       RowBox[{
        FractionBox["21", "10"], " ", "n"}], "]"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "65"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{
          FractionBox["13", "25"], " ", "i"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"X2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox["13", "25"], " ", "i"}], "]"}], "+", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox["21", "10"], " ", "i"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X1", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", "X1"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X2", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", "X2"}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y2", "=", 
     RowBox[{"Y1", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", 
          RowBox[{"m0", "+", "9"}]}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "10"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"m0", "+", "10"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        SubscriptBox["Y1", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Chop", "[", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["X1", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              SqrtBox["3"]}], ")"}], 
            SubscriptBox["X1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              SqrtBox["3"]}], ")"}], " ", 
            SubscriptBox["X1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SqrtBox["3"], "-", "1"}], ")"}], " ", 
            SubscriptBox["X1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "4"}], "\[RightDoubleBracket]"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SqrtBox["3"], "-", "1"}], ")"}], " ", 
            SubscriptBox["X1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "5"}], "\[RightDoubleBracket]"}]]}], "-", 
           SubscriptBox["X1", 
            RowBox[{"\[LeftDoubleBracket]", 
             RowBox[{"i", "-", "6"}], "\[RightDoubleBracket]"}]], "+", 
           RowBox[{
            FractionBox["5", "6"], " ", 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], "-", 
           RowBox[{
            FractionBox["25", "18"], " ", 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}], "+", 
           RowBox[{
            FractionBox["125", "216"], " ", 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "3"}], "\[RightDoubleBracket]"}]]}], "-", 
           RowBox[{
            FractionBox[
             RowBox[{"625", " "}], "1296"], 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "4"}], "\[RightDoubleBracket]"}]]}]}], " ", 
          ")"}], " ", "]"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{
        SubscriptBox["Y2", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Chop", "[", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["X2", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              SqrtBox["3"]}], ")"}], 
            SubscriptBox["X2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              SqrtBox["3"]}], ")"}], " ", 
            SubscriptBox["X2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SqrtBox["3"], "-", "1"}], ")"}], " ", 
            SubscriptBox["X2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "4"}], "\[RightDoubleBracket]"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SqrtBox["3"], "-", "1"}], ")"}], " ", 
            SubscriptBox["X2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "5"}], "\[RightDoubleBracket]"}]]}], "-", 
           SubscriptBox["X2", 
            RowBox[{"\[LeftDoubleBracket]", 
             RowBox[{"i", "-", "6"}], "\[RightDoubleBracket]"}]], "+", 
           RowBox[{
            FractionBox["5", "6"], " ", 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], "-", 
           RowBox[{
            FractionBox["25", "18"], " ", 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}], "+", 
           RowBox[{
            FractionBox["125", "216"], " ", 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "3"}], "\[RightDoubleBracket]"}]]}], "-", 
           RowBox[{
            FractionBox[
             RowBox[{"625", " "}], "1296"], 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "4"}], "\[RightDoubleBracket]"}]]}]}], ")"}], 
         " ", "]"}]}], ";"}]}], "  ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"X1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"X1", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"X2", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"Y1", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"Y2", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X1pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X2pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g22", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr2", ",", "gr1", ",", "g22", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"10", ",", "m0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.75"}], ",", "1.75"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "0.5"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<n\>\"", ",", "\"\<x[n]\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Input signal x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Take", "[", 
        RowBox[{"Y1pts", ",", 
         RowBox[{"-", "65"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr4", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Take", "[", 
        RowBox[{"Y2pts", ",", 
         RowBox[{"-", "66"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g44", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr4", ",", "gr3", ",", "g44", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"10", ",", "m0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.35"}], ",", "0.35"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
        RowBox[{"Chop", "[", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "0.6"}], ",", "0.6", ",", "0.1"}], "]"}], "]"}]}], 
       "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<n\>\"", ",", "\"\<y[n]\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Output signal\>\"", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = x[n]+(1-\!\(\*SqrtBox[\(3\)]\)) \
x[n-1]+(1-\!\(\*SqrtBox[\(3\)]\)) x[n-2]+(\!\(\*SqrtBox[\(3\)]\)-1) \
x[n-4]+(\!\(\*SqrtBox[\(3\)]\)-1) x[n-5]-x[n-6]+\!\(\*FractionBox[\(5\), \
\(6\)]\) y[n-1]-\!\(\*FractionBox[\(25\), \(18\)]\) y[n-2]+\!\(\*FractionBox[\
\(125\), \(216\)]\) y[n-3]-\!\(\*FractionBox[\(\(625\)\(\\\ \)\), \
\(1296\)]\)y[n-4]\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The  amplitude  responses\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Low  frequency:  A[\!\(\*FractionBox[\(13\), \(25\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(FractionBox[13, 25] \
\[ImaginaryI]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["13", "25."], "\[ImaginaryI]"}]], "]"}], "]"}]}], " ", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<High frequency:  A[\!\(\*FractionBox[\(21\), \(10\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(FractionBox[21, 10] \
\[ImaginaryI]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["21", "10."], "\[ImaginaryI]"}]], "]"}], "]"}]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994845755*^9, 3.39948459225*^9}, {3.399493135171875*^9,
    3.399493138609375*^9}, 3.400140309171875*^9, {3.400141520546875*^9, 
   3.400141550484375*^9}, {3.400347781234375*^9, 3.4003478040625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox["\[Pi]", "12"], " ", "n"}], "]"}], "+", 
      RowBox[{"Sin", "[", 
       RowBox[{
        FractionBox["\[Pi]", "2"], " ", "n"}], "]"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "65"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{
          FractionBox["\[Pi]", "12"], " ", "i"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"X2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{
           FractionBox["\[Pi]", "12"], " ", "i"}], "]"}], "+", 
         RowBox[{"Sin", "[", 
          RowBox[{
           FractionBox["\[Pi]", "2"], " ", "i"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X1", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", "X1"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X2", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", "X2"}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y2", "=", 
     RowBox[{"Y1", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", 
          RowBox[{"m0", "+", "9"}]}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "10"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"m0", "+", "10"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        SubscriptBox["Y1", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Chop", "[", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["X1", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              SqrtBox["3"]}], ")"}], 
            SubscriptBox["X1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              SqrtBox["3"]}], ")"}], " ", 
            SubscriptBox["X1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SqrtBox["3"], "-", "1"}], ")"}], " ", 
            SubscriptBox["X1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "4"}], "\[RightDoubleBracket]"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SqrtBox["3"], "-", "1"}], ")"}], " ", 
            SubscriptBox["X1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "5"}], "\[RightDoubleBracket]"}]]}], "-", 
           SubscriptBox["X1", 
            RowBox[{"\[LeftDoubleBracket]", 
             RowBox[{"i", "-", "6"}], "\[RightDoubleBracket]"}]], "+", 
           RowBox[{
            FractionBox["5", "6"], " ", 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], "-", 
           RowBox[{
            FractionBox["25", "18"], " ", 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}], "+", 
           RowBox[{
            FractionBox["125", "216"], " ", 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "3"}], "\[RightDoubleBracket]"}]]}], "-", 
           RowBox[{
            FractionBox[
             RowBox[{"625", " "}], "1296"], 
            SubscriptBox["Y1", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "4"}], "\[RightDoubleBracket]"}]]}]}], " ", 
          ")"}], " ", "]"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{
        SubscriptBox["Y2", 
         RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ",
         "=", " ", 
        RowBox[{"Chop", "[", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["X2", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              SqrtBox["3"]}], ")"}], 
            SubscriptBox["X2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              SqrtBox["3"]}], ")"}], " ", 
            SubscriptBox["X2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SqrtBox["3"], "-", "1"}], ")"}], " ", 
            SubscriptBox["X2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "4"}], "\[RightDoubleBracket]"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SqrtBox["3"], "-", "1"}], ")"}], " ", 
            SubscriptBox["X2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "5"}], "\[RightDoubleBracket]"}]]}], "-", 
           SubscriptBox["X2", 
            RowBox[{"\[LeftDoubleBracket]", 
             RowBox[{"i", "-", "6"}], "\[RightDoubleBracket]"}]], "+", 
           RowBox[{
            FractionBox["5", "6"], " ", 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]]}], "-", 
           RowBox[{
            FractionBox["25", "18"], " ", 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "2"}], "\[RightDoubleBracket]"}]]}], "+", 
           RowBox[{
            FractionBox["125", "216"], " ", 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "3"}], "\[RightDoubleBracket]"}]]}], "-", 
           RowBox[{
            FractionBox[
             RowBox[{"625", " "}], "1296"], 
            SubscriptBox["Y2", 
             RowBox[{"\[LeftDoubleBracket]", 
              RowBox[{"i", "-", "4"}], "\[RightDoubleBracket]"}]]}]}], ")"}], 
         " ", "]"}]}], ";"}]}], "  ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"X1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"X1", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"X2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"X2", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"Y1", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", 
        RowBox[{"Take", "[", 
         RowBox[{"Y2", ",", 
          RowBox[{
           RowBox[{"-", "m0"}], "-", "1"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X1pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X2pts", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g22", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"X2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr2", ",", "gr1", ",", "g22", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "m0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.6"}], ",", "1.6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<n\>\"", ",", "\"\<x[n]\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Input signal x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Take", "[", 
        RowBox[{"Y1pts", ",", 
         RowBox[{"-", "65"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", "Blue", "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr4", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Take", "[", 
        RowBox[{"Y2pts", ",", 
         RowBox[{"-", "66"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g44", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.015", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr4", ",", "gr3", ",", "g44", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "m0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "13"}], ",", "13"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "m0", ",", "10"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "14"}], ",", "14", ",", "2"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<n\>\"", ",", "\"\<y[n]\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Output signal\>\"", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = x[n]+(1-\!\(\*SqrtBox[\(3\)]\)) \
x[n-1]+(1-\!\(\*SqrtBox[\(3\)]\)) x[n-2]+(\!\(\*SqrtBox[\(3\)]\)-1) \
x[n-4]+(\!\(\*SqrtBox[\(3\)]\)-1) x[n-5]-x[n-6]+\!\(\*FractionBox[\(5\), \
\(6\)]\) y[n-1]-\!\(\*FractionBox[\(25\), \(18\)]\) y[n-2]+\!\(\*FractionBox[\
\(125\), \(216\)]\) y[n-3]-\!\(\*FractionBox[\(\(625\)\(\\\ \)\), \
\(1296\)]\)y[n-4]\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The  amplitude  responses\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Low  frequency:  A[\!\(\*FractionBox[\(\[Pi]\), \(12\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(FractionBox[\[Pi], 12] \
\[ImaginaryI]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["\[Pi]", "12."], "\[ImaginaryI]"}]], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<High frequency:   A[\!\(\*FractionBox[\(\[Pi]\), \(2\)]\)] = \
|H[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(FractionBox[\[Pi], 2] \
\[ImaginaryI]\)]\)]| =  \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"H", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["\[Pi]", "2."], "\[ImaginaryI]"}]], "]"}], "]"}]}], " ",
      "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399484599890625*^9, 3.39948462603125*^9}, 
   3.399493261265625*^9, 3.40014031478125*^9, {3.400141682375*^9, 
   3.400141704984375*^9}, {3.40034781228125*^9, 3.4003478353125*^9}}]
}, Closed]],

Cell["\<\
\tA signal processing engineer uses complex analysis to construct filters \
with the desired amplitude and phase response characteristics.  Finite \
impulse response (FIR) filters have only zeros, whereas infinite impulse \
response (IIR) filters have poles and may have zeros as well.  The area of \
filter design involves many types, such as: low pass, high pass, all pass, \
band pass and band stop. Special forms of such filters include, but are not \
limited to Bessel, Butterworth, Chebyshev, Gaussian, moving average, single \
pole, Remez, etc.  More information about filter design can be found in books \
on digital signal processing.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Algorithm (Analysis of Filters)",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]],
 "  The following subroutine will analyze the transfer function for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"p", "=", "0"}], "P"], 
    RowBox[{
     SubscriptBox["a", "p"], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "p"}], "]"}]}]}], "  ", "=", "  ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"q", "=", "0"}], "Q"], 
    RowBox[{
     SubscriptBox["b", "q"], 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "q"}], "]"}]}]}]}]]],
 ".  The z-transform is\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"Y", "[", "z", "]"}], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"p", "=", "0"}], "P"], 
     RowBox[{
      SubscriptBox["a", "p"], 
      SuperscriptBox["z", 
       RowBox[{"-", "p"}]]}]}]}], "   ", "=", "   ", 
   RowBox[{
    RowBox[{"X", "[", "z", "]"}], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"q", "=", "0"}], "Q"], 
     RowBox[{
      SubscriptBox["b", "q"], 
      SuperscriptBox["z", 
       RowBox[{"-", "q"}]]}]}]}]}]]],
 " \n\nThe functions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", "[", "z", "]"}], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"p", "=", "0"}], "P"], 
    RowBox[{
     SubscriptBox["a", "p"], 
     SuperscriptBox["z", 
      RowBox[{"-", "p"}]]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"B", "[", "z", "]"}], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"q", "=", "0"}], "Q"], 
    RowBox[{
     SubscriptBox["b", "q"], 
     SuperscriptBox["z", 
      RowBox[{"-", "q"}]]}]}]}]]],
 "  must be defined. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica Subroutine (Analysis of Filters)",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]],
 "  "
}], "Text"],

Cell[BoxData[
 RowBox[{"ZeroPolePlot1", " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Clear", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"H", "[", "z_", "]"}], "=", 
      RowBox[{"Together", "[", 
       RowBox[{"H", "[", "z", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"a", "=", 
      RowBox[{"CoefficientList", "[", 
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{"Numerator", "[", 
          RowBox[{"H", "[", "z", "]"}], "]"}], "]"}], ",", "z"}], "]"}]}], 
     ";", " ", "\[IndentingNewLine]", 
     RowBox[{"b", "=", 
      RowBox[{"CoefficientList", "[", 
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{"Denominator", "[", 
          RowBox[{"H", "[", "z", "]"}], "]"}], "]"}], ",", "z"}], "]"}]}], 
     ";", " ", "\[IndentingNewLine]", 
     RowBox[{"Zeros", " ", "=", " ", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Numerator", "[", 
          RowBox[{"Together", "[", 
           RowBox[{"H", "[", "z", "]"}], "]"}], "]"}], "\[Equal]", "0"}], ",",
         "z"}], "]"}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{"Poles", " ", "=", " ", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"Together", "[", 
           RowBox[{"H", "[", "p", "]"}], "]"}], "]"}], "\[Equal]", "0"}], ",",
         "p"}], "]"}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{"Zeros", " ", "=", " ", 
      RowBox[{"MapAll", "[", 
       RowBox[{"ComplexExpand", ",", "Zeros"}], "]"}]}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"Z", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        SubscriptBox["Zeros", 
         RowBox[{"\[LeftDoubleBracket]", 
          RowBox[{"i", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", "Zeros", "]"}]}], "}"}]}], "]"}]}], ";", " ",
      "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"arg", "[", "z_", "]"}], "=", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"0", "\[LessEqual]", 
         RowBox[{"Arg", "[", "z", "]"}], "\[LessEqual]", "\[Pi]"}], ",", 
        RowBox[{"Arg", "[", "z", "]"}], ",", 
        RowBox[{
         RowBox[{"Arg", "[", "z", "]"}], "+", 
         RowBox[{"2", "\[Pi]"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["Z", 
         RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
        "\[NotEqual]", "0"}], ",", 
       RowBox[{"Z", "=", 
        RowBox[{"Sort", "[", 
         RowBox[{"Z", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"arg", "[", "#1", "]"}], "<", 
            RowBox[{"arg", "[", "#2", "]"}]}], " ", "&"}]}], "]"}]}]}], "]"}],
      ";", " ", "\[IndentingNewLine]", 
     RowBox[{"W", "=", 
      RowBox[{"Union", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         SubscriptBox["Poles", 
          RowBox[{"\[LeftDoubleBracket]", 
           RowBox[{"i", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "Poles", "]"}]}], "}"}]}], "]"}], "]"}]}], 
     ";", " ", "\[IndentingNewLine]", 
     RowBox[{"Zdots", "=", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Prepend", "[", 
         RowBox[{
          RowBox[{"Prepend", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"Point", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Re", "[", 
                  SubscriptBox["Zeros", 
                   RowBox[{"\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "1", ",", "2"}], 
                    "\[RightDoubleBracket]"}]], "]"}], ",", 
                 RowBox[{"Im", "[", 
                  SubscriptBox["Zeros", 
                   RowBox[{"\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "1", ",", "2"}], 
                    "\[RightDoubleBracket]"}]], "]"}]}], "}"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "1", ",", 
                RowBox[{"Length", "[", "Zeros", "]"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"PointSize", "[", "0.04", "]"}]}], "]"}], ",", "Blue"}], 
         "]"}], "}"}], "]"}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{"Wdots", "=", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Prepend", "[", 
         RowBox[{
          RowBox[{"Prepend", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"Point", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Re", "[", 
                  SubscriptBox["Poles", 
                   RowBox[{"\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "1", ",", "2"}], 
                    "\[RightDoubleBracket]"}]], "]"}], ",", 
                 RowBox[{"Im", "[", 
                  SubscriptBox["Poles", 
                   RowBox[{"\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "1", ",", "2"}], 
                    "\[RightDoubleBracket]"}]], "]"}]}], "}"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "1", ",", 
                RowBox[{"Length", "[", "Poles", "]"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"PointSize", "[", "0.04", "]"}]}], "]"}], ",", "Red"}], 
         "]"}], "}"}], "]"}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{"circle", " ", "=", " ", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
        "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"poleplot", "=", 
      RowBox[{"Show", "[", 
       RowBox[{"circle", ",", "Zdots", ",", "Wdots", ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.05"}], ",", "1.1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.05"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"Axes", "\[Rule]", "True"}], ",", " ", 
        RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<Re(z)\>\"", ",", "\"\<Im(z)\>\""}], "}"}]}], ",", 
        RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", "poleplot", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Print", "[", "\"\<The transfer function is\>\"", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"\"\<H[z] = \>\"", ",", 
       RowBox[{"H", "[", "z", "]"}]}], " ", "]"}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", "\"\<The zeros of H[z] are\>\"", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "\[LessEqual]", 
        RowBox[{"Length", "[", "Z", "]"}]}], ",", 
       RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"Or", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], "]"}],
              "\[Equal]", "0"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], "]"}],
              "\[Equal]", "0"}]}], "]"}], ",", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{
             SubscriptBox["\"\<z\>\"", "i"], ",", "\"\<  =  \>\"", ",", " ", 
             RowBox[{"Abs", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], "]"}],
              ",", "\"\< \>\"", ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                SubscriptBox["Z", 
                 RowBox[{
                 "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
                "\[NotEqual]", "0"}], ",", 
               SuperscriptBox["\"\<\[ExponentialE]\>\"", 
                RowBox[{"Arg", "[", 
                 SubscriptBox["Z", 
                  RowBox[{
                  "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
                 "]"}]], ",", 
               "\"\<\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(0  \
\[ImaginaryI]\)]\)\>\""}], "]"}], ",", "\"\<  =  \>\"", ",", 
             SubscriptBox["Z", 
              RowBox[{
              "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
            "]"}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"And", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], "]"}],
              "\[NotEqual]", "0"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], "]"}],
              ">", "0"}]}], "]"}], ",", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{
             SubscriptBox["\"\<z\>\"", "i"], ",", "\"\<  =  \>\"", ",", " ", 
             RowBox[{"Abs", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], "]"}],
              ",", "\"\< \>\"", ",", 
             SuperscriptBox["\"\<\[ExponentialE]\>\"", 
              RowBox[{"\[ImaginaryI]", " ", 
               RowBox[{"Arg", "[", 
                SubscriptBox["Z", 
                 RowBox[{
                 "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
                "]"}]}]], ",", "\"\<  =  \>\"", ",", 
             RowBox[{"Re", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], "]"}],
              ",", "\"\< + \[ImaginaryI]\>\"", ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Abs", "[", 
                 RowBox[{"Im", "[", 
                  SubscriptBox["Z", 
                   RowBox[{
                   "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
                  "]"}], "]"}], "\[NotEqual]", "1"}], ",", 
               RowBox[{"Im", "[", 
                SubscriptBox["Z", 
                 RowBox[{
                 "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
                "]"}], ",", "\"\<\>\""}], "]"}]}], "  ", "]"}], ";"}]}], 
         "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"And", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], "]"}],
              "\[NotEqual]", "0"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], "]"}],
              "<", "0"}]}], "]"}], ",", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{
             SubscriptBox["\"\<z\>\"", "i"], ",", "\"\<  =  \>\"", ",", " ", 
             RowBox[{"Abs", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], "]"}],
              ",", "\"\< \>\"", ",", 
             SuperscriptBox["\"\<\[ExponentialE]\>\"", 
              RowBox[{"\[ImaginaryI]", " ", 
               RowBox[{"Arg", "[", 
                SubscriptBox["Z", 
                 RowBox[{
                 "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
                "]"}]}]], ",", "\"\<  =  \>\"", ",", 
             RowBox[{"Re", "[", 
              SubscriptBox["Z", 
               RowBox[{
               "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], "]"}],
              ",", "\"\< - \[ImaginaryI]\>\"", ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Abs", "[", 
                 RowBox[{"Im", "[", 
                  SubscriptBox["Z", 
                   RowBox[{
                   "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
                  "]"}], "]"}], "\[NotEqual]", "1"}], ",", 
               RowBox[{"-", 
                RowBox[{"Im", "[", 
                 SubscriptBox["Z", 
                  RowBox[{
                  "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
                 "]"}]}], ",", "\"\<\>\""}], "]"}]}], "  ", "]"}], ";"}]}], 
         "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", "\"\<The poles of H[z] are\>\"", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "\[LessEqual]", 
        RowBox[{"Length", "[", "W", "]"}]}], ",", 
       RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{
          SubscriptBox["\"\<p\>\"", "i"], ",", "\"\<  =  \>\"", ",", 
          RowBox[{"Abs", "[", 
           SubscriptBox["W", 
            RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
           "]"}], ",", "\"\< \>\"", ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             SubscriptBox["W", 
              RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]],
              "\[NotEqual]", "0"}], ",", 
            SuperscriptBox["\"\<\[ExponentialE]\>\"", 
             RowBox[{"Arg", "[", 
              SubscriptBox["W", 
               RowBox[{
               "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], 
              "]"}]], ",", 
            "\"\<\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(0  \[ImaginaryI]\
\)]\)\>\""}], "]"}], ",", "\"\<  =  \>\"", ",", 
          SubscriptBox["W", 
           RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}], 
         " ", "]"}], ";"}]}], " ", "]"}], ";"}]}], "  ", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.399484052109375*^9, 3.399484058609375*^9}, {
  3.400140323171875*^9, 3.4001403243125*^9}, {3.4418145221875*^9, 
  3.44181452459375*^9}}]
}, Closed]]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{913, 636},
WindowMargins->{{12, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageHeaderLines->{Inherited, False},
PrintingOptions->{"FirstPageFooter"->False,
"FirstPageHeader"->False,
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->False,
"PrintingMargins"->{{54, 54}, {36, 54}}},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 2963, 100, 245, "Text"],
Cell[4514, 148, 768, 30, 47, "Text"],
Cell[5285, 180, 6727, 233, 324, "Text"],
Cell[12015, 415, 3156, 112, 173, "Text"],
Cell[15174, 529, 2366, 82, 153, "Text"],
Cell[17543, 613, 1183, 40, 123, "Text"],
Cell[18729, 655, 2704, 101, 156, "Text"],
Cell[21436, 758, 1510, 28, 149, "Text",
 Evaluatable->False],
Cell[22949, 788, 746, 31, 36, "Text"],
Cell[23698, 821, 4987, 85, 154, "Text",
 Evaluatable->False],
Cell[28688, 908, 441, 19, 29, "Text"],
Cell[29132, 929, 6007, 101, 154, "Text",
 Evaluatable->False],
Cell[35142, 1032, 503, 21, 37, "Text"],
Cell[CellGroupData[{
Cell[35670, 1057, 204, 6, 37, "Subsection"],
Cell[35877, 1065, 4762, 178, 264, "Text"],
Cell[40642, 1245, 2569, 92, 217, "Text"],
Cell[43214, 1339, 746, 31, 36, "Text"],
Cell[43963, 1372, 625, 22, 37, "Text"],
Cell[44591, 1396, 2741, 91, 301, "Text"],
Cell[47335, 1489, 1101, 36, 71, "Text"],
Cell[48439, 1527, 441, 19, 29, "Text"],
Cell[48883, 1548, 902, 33, 37, "Text"],
Cell[49788, 1583, 2006, 72, 228, "Text"],
Cell[51797, 1657, 890, 31, 63, "Text"],
Cell[52690, 1690, 503, 21, 37, "Text"],
Cell[53196, 1713, 196, 4, 29, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[53429, 1722, 227, 6, 29, "Subsection"],
Cell[53659, 1730, 445, 17, 32, "Text"],
Cell[54107, 1749, 634, 26, 37, "Text"],
Cell[54744, 1777, 3590, 102, 373, "Input"],
Cell[58337, 1881, 3635, 102, 393, "Input"],
Cell[61975, 1985, 3135, 87, 313, "Input"],
Cell[65113, 2074, 746, 31, 36, "Text"],
Cell[65862, 2107, 799, 29, 29, "Text"],
Cell[66664, 2138, 3316, 85, 328, "Input"],
Cell[69983, 2225, 11411, 330, 737, "Input"],
Cell[81397, 2557, 746, 31, 36, "Text"],
Cell[82146, 2590, 908, 34, 37, "Text"],
Cell[83057, 2626, 3739, 96, 351, "Input"],
Cell[86799, 2724, 11920, 342, 814, "Input"],
Cell[98722, 3068, 503, 21, 37, "Text"]
}, Closed]],
Cell[99240, 3092, 1987, 75, 123, "Text"],
Cell[101230, 3169, 1538, 28, 149, "Text",
 Evaluatable->False],
Cell[102771, 3199, 927, 38, 47, "Text"],
Cell[103701, 3239, 6320, 106, 163, "Text",
 Evaluatable->False],
Cell[110024, 3347, 593, 24, 37, "Text"],
Cell[CellGroupData[{
Cell[110642, 3375, 216, 6, 37, "Subsection"],
Cell[110861, 3383, 3181, 118, 216, "Text"],
Cell[114045, 3503, 3163, 111, 293, "Text"],
Cell[117211, 3616, 927, 38, 47, "Text"],
Cell[118141, 3656, 3236, 109, 320, "Text"],
Cell[121380, 3767, 1408, 47, 81, "Text"],
Cell[122791, 3816, 593, 24, 37, "Text"],
Cell[123387, 3842, 201, 4, 29, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[123625, 3851, 228, 6, 29, "Subsection"],
Cell[123856, 3859, 530, 20, 38, "Text"],
Cell[124389, 3881, 540, 22, 37, "Text"],
Cell[124932, 3905, 3815, 106, 375, "Input"],
Cell[128750, 4013, 927, 38, 47, "Text"],
Cell[129680, 4053, 964, 35, 37, "Text"],
Cell[130647, 4090, 5050, 130, 480, "Input"],
Cell[135700, 4222, 11706, 333, 772, "Input"],
Cell[147409, 4557, 593, 24, 37, "Text"]
}, Closed]],
Cell[148017, 4584, 4933, 176, 347, "Text"],
Cell[152953, 4762, 3704, 132, 130, "Text"],
Cell[156660, 4896, 1980, 69, 199, "Text"],
Cell[158643, 4967, 2206, 73, 136, "Text"],
Cell[160852, 5042, 665, 24, 55, "Text"],
Cell[161520, 5068, 1278, 44, 137, "Text"],
Cell[162801, 5114, 1288, 34, 191, "Text"],
Cell[164092, 5150, 1075, 38, 87, "Text"],
Cell[CellGroupData[{
Cell[165192, 5192, 94, 2, 29, "Text"],
Cell[165289, 5196, 4557, 151, 258, "Text"],
Cell[169849, 5349, 1553, 49, 116, "Text"],
Cell[171405, 5400, 42, 0, 29, "Text"]
}, Open  ]],
Cell[171462, 5403, 1396, 43, 91, "Text"],
Cell[172861, 5448, 1501, 43, 145, "Text"],
Cell[174365, 5493, 3114, 113, 251, "Text"],
Cell[177482, 5608, 3793, 138, 294, "Text"],
Cell[181278, 5748, 2693, 93, 281, "Text"],
Cell[183974, 5843, 2564, 85, 155, "Text"],
Cell[186541, 5930, 2126, 78, 81, "Text"],
Cell[188670, 6010, 3291, 57, 197, "Text",
 Evaluatable->False],
Cell[191964, 6069, 506, 21, 35, "Text"],
Cell[CellGroupData[{
Cell[192495, 6094, 212, 6, 37, "Subsection"],
Cell[192710, 6102, 3610, 122, 242, "Text"],
Cell[196323, 6226, 2444, 77, 211, "Text"],
Cell[198770, 6305, 2576, 93, 142, "Text"],
Cell[201349, 6400, 670, 20, 113, "Text"],
Cell[202022, 6422, 506, 21, 35, "Text"],
Cell[202531, 6445, 201, 4, 29, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[202769, 6454, 232, 6, 29, "Subsection"],
Cell[203004, 6462, 1352, 48, 55, "Text"],
Cell[204359, 6512, 1633, 46, 201, "Input"],
Cell[205995, 6560, 990, 36, 41, "Text"],
Cell[206988, 6598, 1318, 38, 172, "Input"],
Cell[208309, 6638, 3205, 87, 329, "Input"],
Cell[211517, 6727, 193, 4, 72, "Input"],
Cell[211713, 6733, 2784, 78, 346, "Input"],
Cell[214500, 6813, 2783, 78, 346, "Input"],
Cell[217286, 6893, 1343, 49, 37, "Text"],
Cell[218632, 6944, 722, 24, 29, "Text"],
Cell[219357, 6970, 1967, 54, 201, "Input"],
Cell[221327, 7026, 824, 32, 41, "Text"],
Cell[222154, 7060, 1320, 38, 172, "Input"],
Cell[223477, 7100, 3579, 97, 427, "Input"],
Cell[227059, 7199, 3606, 99, 441, "Input"],
Cell[230668, 7300, 3663, 100, 441, "Input"],
Cell[234334, 7402, 1037, 31, 79, "Text"],
Cell[235374, 7435, 3800, 106, 367, "Input"],
Cell[239177, 7543, 194, 4, 72, "Input"]
}, Closed]],
Cell[239386, 7550, 2973, 107, 58, "Text"],
Cell[242362, 7659, 3632, 62, 197, "Text",
 Evaluatable->False],
Cell[245997, 7723, 507, 21, 35, "Text"],
Cell[CellGroupData[{
Cell[246529, 7748, 214, 6, 37, "Subsection"],
Cell[246746, 7756, 7320, 244, 350, "Text"],
Cell[254069, 8002, 2474, 78, 151, "Text"],
Cell[256546, 8082, 507, 21, 35, "Text"],
Cell[257056, 8105, 199, 4, 29, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[257292, 8114, 230, 6, 29, "Subsection"],
Cell[257525, 8122, 1762, 60, 29, "Text"],
Cell[259290, 8184, 3436, 89, 243, "Input"],
Cell[262729, 8275, 1484, 56, 59, "Text"],
Cell[264216, 8333, 1318, 38, 172, "Input"],
Cell[265537, 8373, 259, 11, 35, "Text"],
Cell[265799, 8386, 1745, 52, 236, "Input"],
Cell[267547, 8440, 264, 10, 37, "Text"],
Cell[267814, 8452, 5551, 149, 607, "Input"],
Cell[273368, 8603, 1245, 37, 121, "Text"],
Cell[274616, 8642, 5087, 140, 475, "Input"],
Cell[279706, 8784, 195, 4, 72, "Input"]
}, Closed]],
Cell[279916, 8791, 1393, 51, 76, "Text"],
Cell[281312, 8844, 3323, 57, 197, "Text",
 Evaluatable->False],
Cell[284638, 8903, 622, 25, 38, "Text"],
Cell[285263, 8930, 3213, 55, 197, "Text",
 Evaluatable->False],
Cell[288479, 8987, 912, 36, 37, "Text"],
Cell[CellGroupData[{
Cell[289416, 9027, 204, 6, 37, "Subsection"],
Cell[289623, 9035, 2925, 99, 191, "Text"],
Cell[292551, 9136, 2289, 80, 159, "Text"],
Cell[294843, 9218, 855, 27, 75, "Text"],
Cell[295701, 9247, 612, 25, 38, "Text"],
Cell[296316, 9274, 5493, 199, 338, "Text"],
Cell[301812, 9475, 1319, 43, 76, "Text"],
Cell[303134, 9520, 902, 36, 37, "Text"],
Cell[304039, 9558, 194, 4, 29, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[304270, 9567, 230, 6, 29, "Subsection"],
Cell[304503, 9575, 993, 38, 37, "Text"],
Cell[305499, 9615, 2010, 54, 226, "Input"],
Cell[307512, 9671, 1703, 64, 69, "Text"],
Cell[309218, 9737, 855, 27, 75, "Text"],
Cell[310076, 9766, 2551, 73, 291, "Input"],
Cell[312630, 9841, 193, 4, 72, "Input"],
Cell[312826, 9847, 612, 25, 38, "Text"],
Cell[313441, 9874, 183, 6, 65, "Text"],
Cell[313627, 9882, 2378, 63, 266, "Input"],
Cell[316008, 9947, 11426, 328, 809, "Input"],
Cell[327437, 10277, 414, 14, 35, "Text"],
Cell[327854, 10293, 2759, 76, 266, "Input"],
Cell[330616, 10371, 2585, 98, 67, "Text"],
Cell[333204, 10471, 1319, 43, 76, "Text"],
Cell[334526, 10516, 2977, 86, 291, "Input"],
Cell[337506, 10604, 195, 4, 72, "Input"],
Cell[337704, 10610, 902, 36, 37, "Text"],
Cell[338609, 10648, 183, 6, 65, "Text"],
Cell[338795, 10656, 2471, 65, 266, "Input"],
Cell[341269, 10723, 12458, 357, 807, "Input"]
}, Closed]],
Cell[353742, 11083, 1689, 59, 52, "Text"],
Cell[355434, 11144, 3315, 57, 197, "Text",
 Evaluatable->False],
Cell[358752, 11203, 842, 31, 38, "Text"],
Cell[CellGroupData[{
Cell[359619, 11238, 204, 6, 37, "Subsection"],
Cell[359826, 11246, 1541, 49, 139, "Text"],
Cell[361370, 11297, 2916, 103, 193, "Text"],
Cell[364289, 11402, 1544, 51, 111, "Text"],
Cell[365836, 11455, 883, 30, 53, "Text"],
Cell[366722, 11487, 364, 11, 37, "Text"],
Cell[367089, 11500, 360, 11, 37, "Text"],
Cell[367452, 11513, 842, 31, 38, "Text"],
Cell[368297, 11546, 198, 4, 29, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[368532, 11555, 232, 6, 29, "Subsection"],
Cell[368767, 11563, 883, 30, 53, "Text"],
Cell[369653, 11595, 364, 11, 37, "Text"],
Cell[370020, 11608, 360, 11, 37, "Text"],
Cell[370383, 11621, 3301, 90, 293, "Input"],
Cell[373687, 11713, 2772, 80, 295, "Input"],
Cell[376462, 11795, 191, 4, 72, "Input"],
Cell[376656, 11801, 842, 31, 38, "Text"],
Cell[377501, 11834, 169, 6, 65, "Text"],
Cell[377673, 11842, 2388, 63, 266, "Input"],
Cell[380064, 11907, 12421, 350, 807, "Input"]
}, Closed]],
Cell[392500, 12260, 2260, 73, 86, "Text"],
Cell[394763, 12335, 1457, 53, 79, "Text"],
Cell[CellGroupData[{
Cell[396245, 12392, 225, 5, 37, "Subsection"],
Cell[396473, 12399, 1025, 39, 37, "Text"],
Cell[397501, 12440, 1993, 54, 226, "Input"],
Cell[399497, 12496, 2563, 74, 292, "Input"],
Cell[402063, 12572, 188, 4, 72, "Input"],
Cell[402254, 12578, 169, 6, 65, "Text"],
Cell[402426, 12586, 2398, 64, 267, "Input"],
Cell[404827, 12652, 11428, 328, 810, "Input"],
Cell[416258, 12982, 436, 15, 35, "Text"],
Cell[416697, 12999, 2899, 80, 256, "Input"],
Cell[419599, 13081, 2977, 86, 291, "Input"],
Cell[422579, 13169, 193, 4, 72, "Input"],
Cell[422775, 13175, 169, 6, 65, "Text"],
Cell[422947, 13183, 2443, 64, 266, "Input"],
Cell[425393, 13249, 12461, 357, 807, "Input"]
}, Closed]],
Cell[437869, 13609, 226, 6, 62, "Text"],
Cell[438098, 13617, 560, 21, 35, "Text"],
Cell[CellGroupData[{
Cell[438683, 13642, 222, 5, 37, "Subsection"],
Cell[438908, 13649, 6093, 154, 383, "Input"],
Cell[445004, 13805, 1787, 51, 192, "Input"],
Cell[446794, 13858, 3190, 86, 305, "Input"],
Cell[449987, 13946, 193, 4, 72, "Input"],
Cell[450183, 13952, 169, 6, 65, "Text"],
Cell[450355, 13960, 2813, 74, 304, "Input"],
Cell[453171, 14036, 14987, 412, 986, "Input"],
Cell[468161, 14450, 14987, 411, 997, "Input"]
}, Closed]],
Cell[483163, 14864, 667, 10, 80, "Text"],
Cell[483833, 14876, 1793, 65, 110, "Text"],
Cell[CellGroupData[{
Cell[485651, 14945, 160, 5, 29, "Text"],
Cell[485814, 14952, 15223, 376, 910, "Input",
 InitializationCell->True]
}, Closed]]
}
]
*)

(* End of internal cache information *)
