(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    327891,       8418]
NotebookOptionsPosition[    322007,       8246]
NotebookOutlinePosition[    322590,       8269]
CellTagsIndexPosition[    322547,       8266]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[StyleBox["11.6 Two-Dimensional Electrostatics",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tA two-dimensional electrostatic field is produced by a system of charged \
wires, plates, and cylindrical conductors that are perpendicular to the z \
plane. The wires, plates, and cylinders are assumed to be so long that the \
effects at the ends can be neglected, as mentioned in Section 11.4.  This \
assumption results in an electric field  ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    StyleBox["E",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}],
   FontSize->14]]],
 "  that can be interpreted as the force acting on a unit positive charge \
placed at the point ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"x", 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->14,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "y"}], ")"}]]],
 ".  In the study of electrostatics the vector field  ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    StyleBox["E",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}],
   FontSize->14]]],
 "  is shown to be conservative and is derivable from a function  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]],
  AspectRatioFixed->True],
 ",  called the electrostatic potential, expressed as  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["E",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", " ", "grad"}], " ", "\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "  ", 
       SubscriptBox["\[Phi]", "x"]}], 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->14,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "-", " ", 
     RowBox[{"\[ImaginaryI]", "  ", 
      SubscriptBox["\[Phi]", "y"], 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->14,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]}]]],
 ".\n\n\tIf we make the additional assumption that there are no charges \
within the domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ",  then Gauss' Law for electrostatic fields implies that the line integral \
of the outward normal component of   ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    StyleBox["E",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}],
   FontSize->14]]],
 "  taken around any small rectangle lying inside ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " is identically zero.  A heuristic argument similar to the one for steady \
state temperatures with  ",
 Cell[BoxData[
  StyleBox[
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}],
   FontSize->14]]],
 "  replaced by   ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   StyleBox[
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}],
    FontSize->14]}]]],
 "  will show that the value of the line integral is  \n\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Phi]", "xx"], 
       RowBox[{"(", 
        RowBox[{"x", 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "+", "  ", 
      RowBox[{
       SubscriptBox["\[Phi]", "yy"], 
       RowBox[{"(", 
        RowBox[{"x", 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "y"}], ")"}]}]}], "]"}]}], 
   "\[CapitalDelta]x", " ", "\[CapitalDelta]y"}]]],
 ".  \n\nThis quantity is zero, so we conclude that  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   StyleBox[
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}],
    FontSize->14]}]]],
 "  is a harmonic function.  If we let  ",
 Cell[BoxData[
  RowBox[{"\[Psi]", 
   StyleBox[
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}],
    FontSize->14]}]]],
 "  be the harmonic conjugate, then  \n\n\t\t\t  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "+", "  ", 
    RowBox[{"\[ImaginaryI]", " ", "\[Psi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]]],
 " \n\nis the complex potential (not to be confused with the electrostatic \
potential).\n\nThe curves  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   SubscriptBox["K", "1"]}]]],
 "  are called the equipotential curves, and the curves  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   SubscriptBox["K", "2"]}]]],
 "  are called the lines of flux.  If a small test charge is allowed to move \
under the influence of the field   ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    StyleBox["E",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}],
   FontSize->14]]],
 ",  then it will travel along a line of flux.  Boundary value problems for \
the potential function ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " are mathematically the same as those for steady state heat flow, and they \
are realizations of the Dirichlet problem where the harmonic function is ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Example 11.18.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Consider two parallel conducting planes that pass perpendicular to the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane through the lines  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"a", "  ", "and", "  ", "x"}], "=", "b"}]}]]],
 ",  which are kept at the potentials  ",
 Cell[BoxData[
  StyleBox[
   SubscriptBox["U", "1"],
   FontSize->14]]],
 " and ",
 Cell[BoxData[
  SubscriptBox["U", "2"]]],
 ", respectively.  Then according to the result of Example 11.1, the \
electrical potential is \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    SubscriptBox["U", "1"], "  ", "+", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["U", "2"], " ", "-", " ", 
       SubscriptBox["U", "1"]}], 
      RowBox[{"b", "  ", "-", "  ", "a"}]], 
     RowBox[{"(", 
      RowBox[{"x", "-", "a"}], ")"}]}]}]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztnV1OGzEQxx2WtPEiVVUhwEMFOU371CPkIUJI4YFSUVQJKgTi4xRcg5tx
gO16vPHmYzZiA6oyM38Je83Ya/s3Mx5LWGZ/jC7Gx6eji5Oj0eD7+ejX+OTo
9+Db2XkpyjrOdbxz7mngQrkoi1VWlD9FHrIg+X/l+/Dohin0Q2kjlDaZ0k4q
7S1tt5v668UBHumRuUhJQ8fOypemZemNBfEXXtxv1ckeM432M9ximn5uNT2u
h37z3K7DYzOpeK7Rp1S7wY/mk122W82yfm//XfTmmabtzMr1sMSmD4y7ksdn
SRmNtbuzsvZr6ip1kIXSXe2W7pKnazDfAQP4dUXZKydB047zTvU50z1nj/du
9+YxspU1Xy5TN5x06V4oecqj7E9ZDimnPMrcYUHJU17JngtKOeWVrHim5Cmf
yA4pecqrMYqYcsqrubzE5CmvZMOYcspbW1w9/NxyVM97A0pQyqNc2HlKwlwq
5/TOY8iGoAQlKNePErFVCJt5TwUlKGVRIrYKYTPvqaAEpSxKxFYhbOY9VT3l
z7QeuWNfG39ZP+UpG46cbZyuNOiEO+dWG80bdOCxPJIaFlzBgkLqmFkfR9sg
t7EnglIZpdodypANQQlKUK4fJWKrEDbzngpKUMqiRGwVwmbeU0EJSlmUiK1C
2Mx7qnpKusZEl0tdt16PNa423r/06M5gTprEc4QJ6pCS14g/69SaAzLMbRkf
1xRBKZpSbVw2ZENQghKUoMQOgh0EngpKUGqhRGwVwmbeU0EJSlmUiK1C2Mx7
qnpKuoNEZwj1v7O0dk3xjB51VUgfeXIbt5E4hXD/SFRtHOcU0MOqqKrmncCC
NnA1EZRKKNVGbUM2BCUoQQlK7CDYQeCpoASlFkrEViFs5j0VlKCURYnYKoTN
vKeqp6Srics+xaiRd6oq/maB/Ioh5z+dqCUaL7uYd8to48O0i7z2yLnb6FCr
ybjvpb6lP0tjzHs7/y1Tejdfrew6/wCY8GnD\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{265, 155},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"11.18", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670668828125*^9, 3.50670668828125*^9}}],

Cell[TextData[{
 "This example is similar to Example 11.1 and  Example 11.14.  For \
illustration we use the boundary values  \n",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "y"}], ")"}]}], "=", "30"}], ",", "\n", 
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"1", ",", "y"}], ")"}]}], "=", 
    RowBox[{"-", "20."}]}]}]]],
 "\n\nEnter the formula for the electrical potential."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"U", "=", "0"}], ";", " ", 
    RowBox[{"Remove", "[", "U", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "a", ",", "b", ",", "c", ",", "x", ",", "y", ",", "cont", ",", 
      "\[Phi]"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["U", "1"], " ", "+", " ", 
      RowBox[{
       FractionBox[
        RowBox[{
         SubscriptBox["U", "2"], " ", "-", " ", 
         SubscriptBox["U", "1"]}], 
        RowBox[{"b", " ", "-", " ", "a"}]], " ", 
       RowBox[{"(", 
        RowBox[{"x", " ", "-", " ", "a"}], ")"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399550746453125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Enter the boundary values  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", 
    RowBox[{"-", "1"}]}], ",", "  ", 
   RowBox[{"b", "=", "1"}], ",", "  ", 
   RowBox[{
    SubscriptBox["U", "1"], "=", 
    RowBox[{
     RowBox[{"30", "  ", "and", "  ", 
      SubscriptBox["U", "2"]}], "=", 
     RowBox[{"-", "20"}]}]}]}]]],
 ",  and check out the formula."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", " ", "=", 
     RowBox[{"-", "1"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"b", " ", "=", " ", "1"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["U", "1"], " ", "=", " ", "30"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["U", "2"], " ", "=", " ", 
     RowBox[{"-", "20"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][-1,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][0,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"0", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][1,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"1", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39955074990625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the electrical potential."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"cont", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"c", ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{"-", "20"}], ",", "30", ",", "5"}], "}"}]}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"Contours", " ", "\[Rule]", " ", "cont"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "10"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39955075309375*^9, 3.3995507543125*^9}, {
  3.40018255934375*^9, 3.400182559625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Hence the electrical potential  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   RowBox[{"30", "-", 
    RowBox[{"25", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "x"}], ")"}]}]}]}]]],
 "  is harmonic in the horizontal strip  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "1"}], "<", 
   RowBox[{"Re", "[", "z", "]"}], "<", "1"}]]],
 "  and has the desired boundary values.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 11.19.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the electrical potential  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  in the region between two infinite coaxial cylinders  ",
 Cell[BoxData[
  RowBox[{"r", "=", 
   RowBox[{
    RowBox[{"a", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "r"}], "=", "b"}]}]]],
 ",  which are kept at potentials  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["U", "1"], "  ", "and", "  ", 
   SubscriptBox["U", "2"]}]]],
 ",  respectively.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{265, 155},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  The transformation  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"w", "  ", "=", "  ", 
    RowBox[{
     RowBox[{"u", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "v"}]}], " ", "=", " ", 
     RowBox[{"log", 
      RowBox[{"(", "z", ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"     ", 
   RowBox[{"=", " ", 
    RowBox[{"log", 
     RowBox[{"(", 
      RowBox[{"x", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"     ", 
   RowBox[{"=", "  ", 
    RowBox[{"ln", "|", 
     RowBox[{"x", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}], "|", " ", 
     RowBox[{
      RowBox[{"+", " ", "\[ImaginaryI]"}], " ", "arg", 
      RowBox[{"(", 
       RowBox[{"x", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]}]}]}]}]],
 "  \n\nmaps the annular region between the circles  ",
 Cell[BoxData[
  RowBox[{"r", "=", 
   RowBox[{
    RowBox[{"a", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "r"}], "=", "b"}]}]]],
 "  onto the infinite strip  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"ln", "  ", "a"}], " ", "<", " ", "u", " ", "<", " ", 
   RowBox[{"ln", " ", "b"}]}]]],
 "  in the w plane, as shown in Figure 11.36.  The potential  ",
 Cell[BoxData[
  RowBox[{"\[CapitalPhi]", 
   RowBox[{"(", 
    RowBox[{"u", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "v"}], ")"}]}]]],
 "  in the infinite strip has the boundary values  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPhi]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ln", "  ", "a"}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], " ", "=", " ", 
   SubscriptBox["U", "1"]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPhi]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ln", " ", "b"}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], " ", "=", " ", 
   SubscriptBox["U", "2"]}]]],
 "   for all  ",
 StyleBox["v",
  FontFamily->"Courier New"],
 ". \n\nIf we use the result of Example 11.18, the electrical potential  ",
 Cell[BoxData[
  RowBox[{"\[CapitalPhi]", 
   RowBox[{"(", 
    RowBox[{"u", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "v"}], ")"}]}]]],
 "  is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPhi]", 
    RowBox[{"(", 
     RowBox[{"u", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    SubscriptBox["U", "1"], "  ", "+", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["U", "2"], " ", "-", " ", 
       SubscriptBox["U", "1"]}], 
      RowBox[{
       RowBox[{"ln", " ", "b"}], "  ", "-", "  ", 
       RowBox[{"ln", "  ", "a"}]}]], 
     RowBox[{"(", 
      RowBox[{"u", "-", 
       RowBox[{"ln", "  ", "a"}]}], ")"}]}]}]}]],
  AspectRatioFixed->True],
 ".  \n\nBecause  ",
 Cell[BoxData[
  RowBox[{"u", "  ", "=", "  ", 
   RowBox[{"ln", "|", 
    RowBox[{"x", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]}], "|"}]}]]],
 ",  we can use this equation to conclude that the potential  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    SubscriptBox["U", "1"], "  ", "+", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["U", "2"], " ", "-", " ", 
       SubscriptBox["U", "1"]}], 
      RowBox[{
       RowBox[{"ln", " ", "b"}], "  ", "-", "  ", 
       RowBox[{"ln", "  ", "a"}]}]], 
     RowBox[{"(", 
      RowBox[{"ln", "|", 
       RowBox[{"x", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "|", " ", 
       RowBox[{
        RowBox[{"-", " ", "ln"}], "  ", "a"}]}], ")"}]}]}]}]],
  AspectRatioFixed->True],
 ".  \n\nThe equipotentials  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", "constant"}]]],
 "  are concentric circles centered on the origin, and the lines of flux are \
portions of rays emanating from the origin.  If  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["U", "2"], "<", 
   SubscriptBox["U", "1"]}]]],
 ",  then the situation is as illustrated in Figure 11.36."
}], "Text",
 CellChangeTimes->{{3.473798860109375*^9, 3.473798860671875*^9}}],

Cell[TextData[{
 "\n",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{643, 309},
  ImageMargins->0],
 " \n",
 "\t\t\t  Figure 11.36  ",
 "The electrical field in a coaxial cylinder, where ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["U", "2"], "<", 
   SubscriptBox["U", "1"]}]]],
 "."
}], "Text",
 CellChangeTimes->{{3.39955058809375*^9, 3.399550611640625*^9}, {
  3.50680208384375*^9, 3.5068020880625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"11.19", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670669234375*^9, 3.50670669234375*^9}}],

Cell[TextData[{
 "This example is similar to Example ",
 "11.",
 "3.  For illustration we use the boundary values  \n\n",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"0", "   ", "when"}], "   ", "|", "z", "|"}], "=", "1"}]}], ",",
    "\n", 
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"40", "   ", "when"}], "   ", "|", "z", "|"}], "=", "2."}]}]}]]],
 "\n\nEnter the formula for the electrical potential."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"R", "=", 
     RowBox[{"U", "=", "0"}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"R", ",", "U"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "a", ",", "b", ",", "c", ",", "x", ",", "y", ",", "cont", ",", 
      "\[Phi]"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"cont", ",", "\[Phi]"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{
      SubscriptBox["U", "1"], "+", 
      RowBox[{
       FractionBox[
        RowBox[{
         SubscriptBox["U", "2"], " ", "-", " ", 
         SubscriptBox["U", "1"]}], 
        RowBox[{
         RowBox[{"Log", "[", 
          SubscriptBox["R", "2"], "]"}], "-", 
         RowBox[{"Log", "[", 
          SubscriptBox["R", "1"], "]"}]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Log", "[", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}]], "]"}], "-", 
         RowBox[{"Log", "[", 
          SubscriptBox["R", "1"], "]"}]}], ")"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399550768921875*^9}],

Cell[TextData[{
 "Enter the boundary values  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "1"}], ",", "  ", 
   RowBox[{"b", "=", "2"}], ",", "  ", 
   RowBox[{
    SubscriptBox["U", "1"], "=", 
    RowBox[{
     RowBox[{"0", "  ", "and", "  ", 
      SubscriptBox["U", "2"]}], "=", "40"}]}]}]]],
 ",  and check out the formula."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["R", "1"], "  ", "=", " ", "1"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["R", "2"], "  ", "=", " ", "2"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["U", "1"], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["U", "2"], " ", "=", " ", "40"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][1,0] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"1", ",", "0"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][0,1] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"0", ",", "1"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][2,0] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"2", ",", "0"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][0,2] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"0", ",", "2"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39955077225*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the electrical potential."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"cont", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"0", "+", 
        RowBox[{"10", "k"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "4"}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"Contours", " ", "\[Rule]", " ", "cont"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "25"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399550775296875*^9, 3.399550777703125*^9}, {
  3.400182563375*^9, 3.400182563828125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Hence the electrical potential  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   FractionBox[
    RowBox[{"40", " ", 
     RowBox[{"Log", "[", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["x", "2"], " ", "+", " ", 
        SuperscriptBox["y", "2"]}]], "]"}]}], 
    RowBox[{"Log", "[", "2", "]"}]]}]]],
 "  is harmonic in the annulus  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"1", "<"}], "|", "z", "|", 
   RowBox[{"<", "2"}]}]]],
 "  and has the desired boundary values.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 11.20.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   Find the electrical potential  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  produced by two charged half-planes that are perpendicular to the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane and pass through the rays  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "<", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"y", "=", 
    RowBox[{
     RowBox[{"0", "  ", "and", "  ", "x"}], ">", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"y", "=", "0"}]}]]],
 "  where the planes are kept at the fixed potentials  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", 
    RowBox[{"-", "300"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      StyleBox["for",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "   ", "x"}], "<", 
     RowBox[{"-", "1"}]}], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->14,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontFamily->"Times New Roman",
     FontSize->14,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}]}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", "  ", "300"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "   ", "x"}], ">", 
    RowBox[{"1", 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[".",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}]}]}]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{350, 240},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  The result of Example 10.13 shows that the function  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"w", "  ", "=", "  ", 
    RowBox[{"u", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "v"}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", "  ", 
    RowBox[{"Arcsin", 
     RowBox[{"(", "z", ")"}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", " ", 
    RowBox[{"Arcsin", 
     RowBox[{"(", 
      RowBox[{"x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]}]}]}]],
 "  \n\nis a conformal mapping of the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane slit along the two rays  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "<", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"y", "=", 
    RowBox[{
     RowBox[{"0", "  ", "and", "  ", "x"}], ">", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"y", "=", "0"}]}]]],
 "  onto the vertical strip  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", 
    FractionBox["\[Pi]", "2"]}], " ", "<", " ", "u", " ", "<", " ", 
   FractionBox["\[Pi]", "2"]}]]],
 ". The new problem is to find the potential  ",
 Cell[BoxData[
  RowBox[{"\[CapitalPhi]", 
   RowBox[{"(", 
    RowBox[{"u", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "v"}], ")"}]}]]],
 "  that satisfies the boundary values  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalPhi]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "v"}], ")"}]}], " ", "=", " ", 
    RowBox[{"-", "300"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox["all",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "v"}], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->14,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontFamily->"Times New Roman",
     FontSize->14,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}]}], "\n", 
  RowBox[{"   ", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalPhi]", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "2"], 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->14,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "v"}], ")"}]}], " ", "=", "   ", "300"}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->14,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "   ", 
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox["all",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     RowBox[{"v", 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[".",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}]}]}]],
 "  \n\nFrom Example 11.1,\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPhi]", 
    RowBox[{"(", 
     RowBox[{"u", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox["600", "\[Pi]"], "u"}]}]],
  AspectRatioFixed->True],
 ".  \n\nAs in the discussion of Example 11.17, the solution in the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane is \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox["600", "\[Pi]"], "Re", 
     RowBox[{"(", 
      RowBox[{"Arcsin", 
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["600", "\[Pi]"], "Arcsin", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        SqrtBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "+", "1"}], ")"}], "2"], "+", 
          SuperscriptBox["y", "2"]}]], " ", "-", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "-", "1"}], ")"}], "2"], "+", 
          SuperscriptBox["y", "2"]}]]}], "2"], ")"}]}]}]}]}],
  AspectRatioFixed->True],
 ".  \n\n Several equipotential curves are shown in Figure 11.37."
}], "Text"],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\
eJzdfWusXcd13uF98fL9vHyTl5dvUny/r/imSFqRLKkpIqSvJFAert3WSOq4
UB+SdW3JiQLnRxAnblzUTWsHAWIkQYMkQBIDzg8DRX9YlOQ8HNthAomSLNmU
BNtxa1WOT/faZ759vr32t+fMHEou0APw8t45e8+s9a01a9bMrDVz30Pvf/dP
vfeh97/nJx7a+o73PfQz737PT/zs1ms//b6iaHRepzPv94t/D27tjBW/dzsd
/nGhW3w6o91v/p/vdj9/6+/sX2d3+XO0++tf+Vr3V//q5fKvs/ZzxIqOhG9/
/+br3Y/82UvlX4dD2Wdf/mb3w8++0P3c177VeyM8h7I9oezFb7/RDZ/O6fJn
lJDfuHGr+9jTz9v/VbX/6cuvlGX/89a3q+bxHJPEz50JZQUp3bmirCCrszeP
JHDwS3/xUlltwXFVrXFqZb/73GtRkqxp4Ip3DUnUNxRJY8yVcXtGtHYolH3s
iy9XVB0S1J9x1P/W377a2ZdH1V5XbUFCVS3LBM1/8sar3Ueeeq5GEj93Zyj7
45e+UZYVAujckUcSODC9Bqd3OjKL/6vmWXaHBJqzAfiCvBL0uR6pQ1HVq8W0
wGopRHknNWg42F8HBWEos67nmTJCwdT+PKrucNUWlNWqnXPNK5KAs4lvNpQV
mlSWFd91DuSRtN9VYdYA1RZcV5zGSDIxwWidJhbnAosH80gCB7AGhXJW1Zo8
H+sJT5J0wCFsfQzsQA/MGgxFUk+drIqglKDqV0wlrtcpUFT92pd6Xc+s9mkn
T6P0UB5VYAK916wBqv3Uja93H7n+XCm7GElzT9/sPvHszfKvU6K+w3kkHRJc
nRKyUyTtF7I7pYHPpAqPswaAKut3psBMgaIKHcRkh3dZQ48MQ9IY9xNj7KTr
ekZpK1Uj9tYpR5914KN5tBxxjX7si690QIiNfzAtipA7xHN49w9efL0yc8fy
SAIHH/nzlyo1PklShMTuiJAERAzDE6RHTzzzQvfRp0pJDkVVY2w6IRqMEcYM
4F2MyjbSHM+jCkzwIH5CiEWRtE88h3cxelt/PZFH0nHXlHXlE5XKxghhDI8H
uJ0PlknLCUK9XnO9U++LUMVGAu+ys3pyGJIajEGQbAAVVfACYVBNaB5xMwOn
8qg6KeSOanmI3xshiV0Gz47p5ek8ksABegdXiyHGZBcjiR0r1YGL94eiqlHL
USE+RdgeJz7D+RgRC0Zn86g6LeA+JsS3J0ISi++oKzMtuzOPpFnXFI9N7MfG
SGLxHXH9JgyamVThcTV6s8Mfo4onEHiXDcyZYUjquznBIByh1jA/8tN3LuP5
1hH3nGnj2Tyq/BTc/EFUy7PIGElqRYEHqnN5JIEDnm0edmRaWYyk5ty94V8O
RVVjtqmWJnYJwnYJBvAuDIIp6fk8qsAEzzb9As4gktSiAs82L+SRdF5U4ZdK
THljJFnfAJo8T8ds82IeSRcE0CDpMerlOwVJOx3CJji8y3ONoUhqKOVBonTO
UaCo4gHSrx6YNbiURxWY4NkhquVxI0YSj0MHRH2X80i6JLhCtTy6KpJ2ONn1
320An0kVHmcNOCBktyNCFcuO34WG3jUcSdxPDjjZGZmtJJV+O97g3nslj5C7
RBX7ncSsTBGyPZRhrmIS82sGxtjVPJKuCHj3kwjh92+PkNSc+TUGg6Goaqii
mtvGCFNzZR47rw2m6sa3vlPaZnsQTKj1Yp5CKpK2iefwLnsY1+i5P3rh9ZKK
WSZprOD+Fh43UK661kwx1Fx7W4QqBnSfwz54Y1dDsXUYK7bHX3/jzRpt492v
f+fNCmF70Sq8SsTUG6lPQWMEmrcKRvZRGVS2pzDjJdEYta29L7z2vwr3kkic
qPTMUAcjBRlQOedd73VyM3QVoTOiG3smbQLQa2ai7LIAxAi29wo1rNE6yX2i
pABvGOvFG7AnPElBozzYzEQI5sELzLI9AS5gYq7Xd0byOvRIqAUUzPXkBgZ4
4gcieBCIMcCDCvatnPW5TNqBpuxrq3o0j5HR0ILZAGhPQellapjWxvY4QE17
FC9bxbDtcTCDdVm3Pp7Hw1gEDjgVbONAiTFmmscUKy5YpYAA27jLWhkm8riY
EIpZtHLJEWaQ73FQmj8fY8A6JFRqt7MLwRxeDBhaMQxR6JWd+XmMzA9VYaeb
TELldrLt3O1EZIoR40bNn3n57mLgkA1iUc+CPC4mWyywtXDBYRhsq5qSTgtG
UBab4pptBSNuAFqYx8hCN9A9ev257qf++hZmSmxr1TQ/xgA/hwkdL1hdIE2w
bSka5TuL8rhYRFU9/vQLtaowD2Wrq2bhMVZYZjuF8StEfd57DNef737iy68s
yWNkiRbqOW1wdwnytgg2UMZ9yM/6DZZzEa1emsfIUt3NzjlKTA+YkjlHseKC
7dpOJ0gbSs6RMngLsyyPi2URu3fWkWimF+TwmBBjhceYHdr0Yr3JGf4VeYys
0IMQeGCDi+kYj86Kh81itAf/zeAePf6uzONipXYIzmiDC0bYZdocYYRdMD8n
NYN7Rre+Oo+HVRE4sFrNVneHKzP/P8YFe8LbnYist53RmjCVx8WU1koVNwMi
eK6gGNgUynjusV3b2tlIt1yTx8iaiLE4ra0uGOJZ2qYIQ2r+zlYXUVDOVK7L
Y2RtxHZju4itrlrOiHGhJtdsdcGFG7nW53Gx3o2icz1FOO0I43kprzEoBjaK
57ZpW3uKlAEmEW7EhjxGNkSqOkWQAvptAuaNEW5YbLxsgLJTGshNeVxs0kI9
qQ3ujKPNTFqMB95p9/NEM7gnIyq9OY+RzbqP+RAc0w1QwuOa4gIKweOkf9eW
FE6SJngLsyWPiy0Ru3eCQIVlATk8JmyIsMJuy1YyfrS4gHAGZ/i35jGCyt0g
dJzaJIOLynmAjrHBA75/tx9zo4fgmTxGZrRPgFAKNrhbnW6YXsW4gJ7YX35O
aOsKx3XT2/MY2BbB4pijzigGF7wzt15wsd5RbCo1TeJthMLUlaF4fEceI3Cf
nWKCB7a1aoIa40FNeHk59ihh6LvlzjwudgpjYaprVWE7nqyuXCyIsaJmis1o
woad3J3Hxa4WpTLwj7hWzeSqafY6wcU6wS24YJMLLnjYKgSVmTyB5VUeQovf
wQDvIW0hTZlzxCoGeAqLd8nIhq378doqOLyHzOSGvaRRvqqWiAiMrTwcxLjh
WayfTJnNQPyr24MYKsy/p1R+0wUb8by/DEp4fFZcrBV2ebOo7xC1D4uA9jNz
A/ZrQFRANSjhMW1thAseIzdp8R4UGgGHJDOj4EBETxEvwHoN95Mns63clPvQ
zD/eOKg7ZmZEPZTfGQmfVWD2BGTzFFaRjbknphpmUf0ssJ+3oe3jUOHuDYPt
t++ZEp5irIlwwVMMnkTVgwriY1VWVLoeQdG3eMRVs6AYK2pWxR4BOmSL85AV
nN3wajlIgNyeDU5ZrLcrHrAyw8rn5yP9XXDtyWVGmbe4ln4H3ywqKOEpxlSE
C+75QKAZYdBoeqiga40Ftox5CQaUsPWMccHWeD2JlyYt+7QyZMZpYxrvFHOv
bhNeHg9lig0sWfLQuEHAspdg9N0yM44aa2nOWOwVKgBKeIqxOsIFTzH8tKO/
tVxXqaKeoeKbtc320cOGu5o8xLjgKM112mLAIYWWBpXKjD/GArCpFI2e4IHN
ovK3Yzwo/53N9m7hLvjtlKwwXO3EYEOJByueAGFWvUqwgjLeKgMrPJhio9y5
cEOF7eoVrl2uVbP7oITtT4wLnmewnwtUwIXzpzMjfbHh7fyxXUSsd/Z4ahFj
gIcVvMuxlpgvKwc0MxIXMQ5Ko7C44DokhmsemhU3Kwl62AfvP/a3zxpKNVSk
rJ6oYFGF7SMo4f2MlREueHkXCLD93hFpPzOW9S4NCLjgsUp5rTEu2CWcIvE2
Nnq0RmTGwiJiT+npNt06Bm6eTCiGVrjnTAkBBvp1fx+u0UsTokKZkWvaYmwT
elASUU7iYmRzSDJY5mVOXqD0JvIdebS/Q2uTD3Bkr4kdwhURLtggr9bGYiai
TXfnMXJ3RJuwgM3TbozPbH9i3IA0HtvZimPV26nSPXlc3KNVya+T2zgFcbBL
uFwwgDJ2CcEA7/FsjSjVvXlc3KuVClywz+BdPRNXjAt+blVoxm25TUeU6p15
jLwzolR+1dtwWiWwjnHDzuEqUR92B5xS3Z/Hxf1aqbDIyi4hxMHavkwwgDLO
/FklxIvdOaVUD+Rx8YBWKr9iz/4GW6AYF2zRvF9iqIALpVH/YBAXY93/VlQP
H7ug/oGIUqmlPVDEo0IrN+XYAv7Z3mG316nSA8SawWC68fgzN7v/+7t/X886
6CVChMX8zoi1Gui0Go32+7Sa+RXXYPrVEK24Wiqe82On2e5NEU27j2QamKw4
sGf+9KvfKHmsMTzB2ldqXWCeef/twHuLxcPyIuxBRXwpphi77LKtcCppjsSm
iErCWtv5E3V2x8tnrW6D0/gq1LaeHqGC3SeZ/bKpR556nmX/AxGV5sgGqLQf
aE1Bl0bQ4I6Md1m5N8YHX8j98WdfrMk9ABHC4TPjzke7v33zte5//FJ7h7hb
d4gNukMsd1I2pY5hwibajzH9fXTdIeBbmWuqOsSn/uZWCUxmHDsCxklbJDBw
mF1v2UCvYyIGabOXs0SgssS9yyNvcyFN95trieRnhpMvTqjWwI7Nh/zKGbPH
q2QxaNh1WkY62FgsbfSjq4nAZAZ2LxugheiemPG6frRO87BMaEIMFt6p9Q5B
f5dX96O7EoFZngcM+yAxYC65fhTEtY5wxZQRnPHytkJlMTUNS7JM1AdUWFnR
jy4lorIqD5WpRFQ4h8KT5reETcBgj9d6Fkeg4bUehPQ7HVyrDdzFRGAy43XX
JQITW1ldoxlR7kgMG8ZwqcAawLiufD4RmMzI2Y2JwCCfgM1eQYpfyDO9X0pV
on8oQJCsw8ugS0V9a0gm3uifCYOqfWekwQt6LJBoSAGZzCDWLYnI4GAWt0Xl
19LMpwN3bE8XRZBh+8zvBs2rFiBbtqgIlIpymmR1MqMvZxIBOU3y4i2v/lZW
w7FT428MmNh4bvNsAON2UU8nApMZDIl1ZTP0BoLNhxkYo4KDq3lXtqDKb0ha
P1C+WgwQ1ig/PplPt1rIBFtoJxNR2ZWHyu4IKkauqdBn6dw9VuLiebWAuJgo
BVIKlYUOAbNAQJTnRFgdc133RCIgmSF1+xIBORaxd0hlcv1HjS0LI8DExioD
C8A4a38sEZjMuLYDicD4+MwwMMMVRF+xRTXPlEk7BgjnFCwictB/AIjzCY4k
ApIZY3Y4EZDDQkzF7ytJGyBlMMWrkTFAeOq8SNS3QigpPMhDiahknkF6LBEV
xPmxc1t8x6tpc0GsUBNeZF4gUEEZb+8DFaw5mtohX9LZsoOJgGQeW3kyEZD9
EeOvlkXAGS8pxVDhcIGFxGowUBUqbtzbn4hKZsjQbCIqCBkDR8HPBiAYJ5gp
Xl5uBaRct/SOio1ey0gMbEeshX2JWGQG7ZxNxAKxTjwZK8jws1qbES+kKqEw
CotJMVYvFPVhmcXNkvcmApIZOXMhEZDdgqriu2VCrGCKXbDJCCDs0i0Uyob5
MtuQAoHdiYBkHtl2OQEQGzwRMaNsyBIiDbtkCx1Sg1BhGwJ1gr3oL/OOVV0w
RPLsTEQlM+7iagQVnuogwMfZkCWOARsawBRHsrYCUtqQBQJWwODsx/ZEGDIj
H+5OhAGhKLzIVvzuXW6T7SRVCWgUDPOJIw8h977FET9kW6gJCwOPuYUBQyQz
+OBeIj82B0amIs8siu/gb7ABBFdsP+ZHEGH7AeTg1Vl9i3XTM6ESv03FYNyX
B8b91HoMjC2BIicjgAHRmN2dJBHPOcYVGGw28K6BiBneImdMg2ZOJ4AxcNe6
DsYPDgADq1DYZHY92A+r5p2CIXY7YmAY44h69Npi/QdgOBu6mR5tW1m0J/5h
HiA/FAGEFyyxMQljGQLu/eTEOvt8qhIDQwyQMGrXynj9DKcY8YSyKOc10dhS
64N5gPxwYrXrtZj8cMAawuHJEwIQlPH8BYCgmf6MsK+cYdlhfaIo/1EeIP8k
oRdiBwvhx2Hu4D1OZogXQWJg8CbF/N6oW7y2QBsrbCBY/7TK2rr3P82D4Ecc
BH6IMq1f4yAI/LKDbewaRb4zGEUxCNjMTgh9mBRgFLBxwlrML/jRPDB+LOLF
sHO+WlBFgLBOgCmYQcMzBohVh0F4otIJwMCzgaL21Y5e65FMrzVgMDyUB8OP
u2q9Sw50V2oY2HOCnZgggWE0iMEQngm+VVMv5muVXNXicLHwfjIPjJ9yqsb9
zgRV3z5uBYNHETDJRnNcgIEyGE0zR32d8BAEK70iQEBGvmHT/nkeBO+OWN9Q
ZfnEUg3BBOlDsOlgowBQaYGXuInNg2FD74SGYBmJzJtK9ifekwfDv2wxlTxL
XRKHAK/Zo2AIY/8gLVBlWCAzBRwXTdNUUNkImEp7/V/lgfHeAdWiWywSVBUA
jpNKwR6gjIfFGPPsbY4ROZiHKEAKshYHMZoicQdhMf50Hhg/E6qkSVmtz5n+
LiRq4AIW5WCG0zrADFTdbEYMCJ64jTkQuevAIvLSu5HjzZo9hz79r9uRGAtI
fPzjH3df1dH5Weo3bJRZTTDAoSeHbSXFDcp4/S+GDg8lYxG00Q9tnXCB0xHu
6ugw7x+MzJUrV6LI/BvSm2CoKr2BKvp5lFlPDwH3HsUuw6Lg82UGgVdCa3cy
jNHBKahgCY7iw7ePyL8NLRi32O1BCwV1E05WNpiN9YaSgh7uD9hMiUHA/Qtl
POTgFGk4MsHSjgepWTFLDR6XKce/u30o/n2AAgM5oDBYCorHhD0pfh91CBkx
Y9Vgq/pJDA12z33N/ecmKihgS0PXfkSgMCmsxoEeMgWm9nnttde6Tz75ZPfY
sWPdFStWlEB9+tOf7mwObxa/d7dt22b/CpNV1FOU3bhxo6ptpPw5Xj73rne9
q6zL/rc6RsvvJso28B2+L8pGhRweCTxa52A5BJUcdfBZX0QZO/1pQuB50xip
M8z7iOupNuzioHAkRpOSdD4QkQArICQwWSJjyNs/+92esv9NEp/5zGc2hZc/
//nPQ4QB8IkSRCvHp3jchATMTWZWhI/VXFQxQgoRSOqgjOXwgcAmy2EuGDAA
jpU3hooXcL2tH2QhVBkb2BFXnxnskUAn7/6GM1o6c9niMEwNeig4nrLyBx98
cCK8bDqMm70n7OfKALp1guK5CnQTa/HwaOgj6Gf2sUeLpoKBGi+btTJ8CmF0
PlQysKDGXFijKQXFczQIhac5o5lgc5nvaWb8RwPYYZ4JZSnbHykXuHrOA5Qo
XwCGgoHNWmsfQ674bibgbIptArCPycp+L8qAM762r6y2opYKZ6uRWzCcn3CK
1VuJ6Csg8ByprEquGseQNVXttTbJ8Ro1CYcAlMcFoOMBkxZDvjrgbWppmBS8
F60VX4zRe8I4j6R8bSKzSu0LJbLiu1X2e/mUEzqE9fDDD1eyDIKrhGWNB9mW
7xZ1Vt/Ze1RfKcgPB9DpHMdKZKNDC4+jhSA8njaNBBeF/GbexSuHlyeE5MZC
hxgwCKwKkjBAaeQtjX8hDRj8YOCrr4OFH0n5OkGOrbZvefnF/Er/7EvYwPB3
0NGxqo3wP0SJInz+x9e+WYiyt5JlYH7omZvdJ79QCqC0Ox+4/jzkYMU/94W6
bP6zGG9U2aB3IVcq6/5h6LS/15teFXI1Mke7n/jy1yxDsCbXlNEEPYOQ7zlm
BSymDxjh68PFWDVchPKyeJ79Ns+K5lVSDW01pBrKe17egkp4Vq1JwpoG2W+R
ED/4zAvdj/zFV0sUP/rFwqN4qhLiL/75i91fcIL4xFdulTl1LDBVNuhdCJHK
un/44jfKO6R/57lXy9lXTIgDRqR1gftgnSps+0POWDXkhPIgq+K3eVbUl5UB
Hvp81RTZgenQA/FYoRqV64YRr3i8MqzeeBYGM8l4wt17+42nTftGwtM0Fey1
1XMnkJVpD30oYkMHWK+15WMTFSZ4NIgNkgIsXDzPSoO4um7ihIHRnG3rZTbp
mQl92MoZYvJTOsM6Ko/TNBRiKv7/f+urwOPDM2GtTfkqidJqtYzjAVuzimai
rB5YyFBn1etooCJZFr/Ns6IgS7U8sDnoCnvjRBxmrcG3L//CJHg4B78Xr0Cn
fkOefP7RqJDx2+PfL+A5cCVZSjgpHZoPRsQ7YNBZTdoPtxTSg0EjDQmI37ZE
x0r4oU6F2oz058vzMX0uu7V97P8wh+6wD8VqG7q4Wsfg+TOW1uacKHld1C81
vJ3zZ94dGxF0Gk02pVPTN4h4wFi1JkBiBjVoQiXaMBbVRMuGt/hdG16Ilqxi
Zwv1PBOX6YZVYoMjet7bvDQVTjP1y1Bv/dIU71bzegu2fbE0Za3xMqnJUi1N
jQsMaCRbF76GD4EPuzGp3s0FgSeWXM268E5FWOrzS65hk8IvjFagDb3k6i0i
3rWuOh5oNEvMkIZtif8gUFULHKtCmcEYDExlVPxYyB59qqOv4H04OL7YM/Tb
ZDZz9Tul1Qp/p36oHpfd7lq/lY062Yb4vQmBNu3OqGV+hfbqgKxpJCYxWGUo
pr08YRbWfICxH2lHnDeYfj2ccOO3KnwYlm2dvl0bTByLjzI+xAcbTCYt3v4J
gRZqgwlwswnGcG5QYzg3re07Y7e5yKSwfh/x6HfEjX7sqPJWJxbSvs9bnWij
H/3bVBHeg4xsdSoksB3uQ1B4h30hoYC9taJ8vGc3iyd9vMegTXAeilQHx3M0
lwzBCfMhLq9uZfeIbIAr3t9LIovtq6u4CAoH4ADT73NchFIERAJmxkX8C9cl
fDwdAsm+z1EznOTdAsbSAIaPWWAVzoyYeTdV6QOzEJu2LA4E7IBJ8fYjqPox
eI0G+SSStvhKQy8zggqxdIMCyb4PsXQcm8kmsgUQzt2MBSC/Kw+QH6dqfaQa
GyFEWrr4z5RIy36cXHukJULUY5GWDhBEWvooKg4zzIy0/DGiPBbUi+jblnBk
pR1vTfStg2DKdejHHATW5zIjb/9ZxIfgGFYfkR2C0ieFPqj0hLc6Irt4Z42j
vC10OjMi+x8nVosofU5Ep5QFlcPBw2RKlH6V/NKI0qd1z3VEr8pmRER2ZpT+
D7cMR9zbNhAE8CsHZG3wyl0MAs7Z99MFG0V81kZwaZG1MahDZ2Zt/FBkIAUY
mzRFPilU5fQwk205PQANZc1c7Xo6UVE330Sj8jcARmZOD7K+2nKnMKTy0ZvQ
IKQp+tSvfqif0P4WVFTqFzsanPpFHZQvY27L4DMSM1O/7h+ACsZVJAa6LGs+
zQSOJwDhMwligPBy2aSoD4C4UWw6AghTnnkw771UbQyQrZoqnzbKybC8AhMD
hJf1fRKuadxiLYvYoU9Meeap0XcnVovMYpcLxwcTtmUWm+eVklncDziuB1dy
ZrHPeN+WqOA/kIfK1URUkHbO5rVgW52E5dPOOck2Le3ciEBqCd4IRnVHIgyZ
lwVcjsDAVonPJEDfhlFdQtqgziSYY74VFh19JgGPu3wmASUX70pEJfNSiwsJ
qJhlw9EVnP9dUIs5JWdb89EVsCG5R1dwtvVS3fSeREAyb145mwjIXi0mf7gJ
H1DC6z+5h5vg3f6RonUN9RdyDkLlXB4qs4mo4Pgbd5hWy6m36uCw2JFA7I/g
Xc4aWK5bvyMRk8xLuE4mYrI/Ii5/UBKfyJd6UBLKeAXW7WYBGKesBxKBybwn
7lgiMHykFu37q1PX+Ugt+Om5R2rxSYgrqGmyKYcSAcm8wvBwIiA4ec0dacUn
r9WPoKgzGjt5jYFjBUO345PX/O16hxNRybxn80AiKnwfp/NNGtdA/caQp/Sh
n/EpfRjgcUof3g3H8RxNROVgHir7ElHB/Z4ctF+QsUowwCfmDHuOIwMMQNy5
XscTAcm8anl3IiAnHFVzT9fS6fmYwdwTP9n5XyLqWxU0VJ3JfSIRlcz7wHdE
UDHSgApOh3XnPvt7iEysS1zZMKfDcgoTnw7rTrisRpRBqGTeWD+TWC0fJuyH
5MTDhBkJhQ67+X4K1b/Uqz4HLcieTeRgWx4wWxKrxbHTLhQPC8F8bC4fHQ03
P/fYaSyxfa664rZxbO6ZRMqn8wDZmFgtTigHR2FIXuOY4lPG2c1POaHcNv78
u9WVdS0nXp915Ps5Pbp/5unk6xJRORchjQ+0p/7jD7Q36mIH2nNAt7+N5beq
KysbvtJ5AjI2WmQeaD+VCAxuH3VKzFelov9gpsijcsrtB/0t5Xr/ASCu615M
BCRy9QECIi3yJkToyeTmlYkgXRKiK97xF/zyxVQ8Usduz+CR2l+VZn2K7xTx
bu6lRKQit2cAKUMJYcUKKT5UhdBSYF1u6WpGScvVzGCcB/Lci1i4q+HoMGcD
70rEK3IHSypebDLrO4ZjvENk31/RPRBXHHEPzL3Hh4d0f6Bv36Y0zmmOrb8y
TuoSn0hifSp2k63YqVM8G8d++7uh+rPn+gHXKXdD2STV37bFd0Px9jPcsWuJ
6Km7oSJJwAgJRHJAOHsAIYGnBJDjBOQn//pW96NfekUCeTdx4/3exCvIDKjY
FWQ8m1dnbeP0Q+f18/6I2sj+6F++XNsTTE2oLiO8Sx0Nsa8hncFCM+tvbAi1
WJgx0jvHQgYOH/cwSq3Vs1+yYulHIrr/gaf8ea365iJ4inx3PDoAHxEwzDV6
GM8hL3dt0T2hA2Ov/eeffbH76FPPVSINgRLqFr2YuBZUSWIhP6KyISi3tAYc
CmHiNIh7Iu2llVGGSy0TxouqJRsYeWkQ1SDT9E5tmuDc8tpE2iWPHEPKy41Y
McHGOk/oYZD4sN56JxpnoZSM2SWP80ltI4nzyDPr9YXeTw5/hnrTmQQd4Kgy
T5BxvaDKZ0L/ogGjyocaD/U10q6XkRaEFLgqw6bZYZvh7LU0g4lGdppdbVoA
q4R+X8SMbiIZQGYrqQzakHuvKWsSjtR1NvS+VvH3bOjvPf96kEqvGyZl3Y9W
X/WShnq9LBi2VvFzVq6NXVXZPPtznpUjl7SvBfgoLdgSKjSz4IXNmjEe9NPq
qOeTTjbySf97SLII3eKBiKXd7CytSdpLhmc/LNXmHbxcy2ZtX/lC4CDL8g7e
1994s5LfsNn1EBi6PZc1DzbSgm3kfoY0xKI8T7ArmUoeEviUH6Qk2sekX50o
0+zVtXxmneb9g9pm+1uj++vJ9Sl/7NZoXthfKSzBloj1VudvJ+bgTwWpGDa1
xML5wY2x5/0xMaEXlomjxXe10RcpxWr0bTXIK0hf6icr9Y7u4LOagpjak12b
xymY6B6IWF6+vy6UV/LjBS11+bqfkPfvhKrfIj6tLa+KjkrM9EaeqA096oAr
Vv3QEVW/DBItng4SNTsN95c7QZv7Ox2qsY5dp2O8oXnxNGUtufsj1hULpDxj
Bfq8NqskhzJeKeBeC19qWtvZ+4eXXKt9nQg/7XlOGw2zA57fMUqh2vGeJEsh
GtCVNsCVsn8mpaAdMwF6yryvBBdspRRcMwlZW8v7tLXc6mRhPQZbN7xqEZMZ
J8Zg585NP6cjBlOF4CUm4K8NbONsvwq0kX5udHUWk/czqnZYSmrNYzOVgUBV
Gaf3m8iccQx+TE1S6myMeyPGcaszcLa2gZVjXiuJiYvXSvwdjmZYZ7RxvDci
pgFJ9OsCzwZU8M0DgGOVcWwxitU5MA2jGJOUoV9vqNdRjJ4+3X2RcIcK84ma
mNSRF7EZ/VbqBZQWvNpJzySwQkiKV7+wCOPvlTRDOqONobobZkCKPOaISsV5
aIDUUI2TWuNomIZzwlLD+LQl0Ga0hKWdKv+2MGXj9ArczQGpz2qlpmX1Educ
HOU15cpsIIvJiRdfVgvRF7/PRAzg3UJe7eng82sM24eBAb6mrSFVvNN60EvD
2d8ZdAXiNb23f3bi0vxQi9V6GwtmV8m68W6DWTfIonmLcj2LPyYLXniZEvVt
F9at+F7dMNUug7FKR4Mej5Qn5LSvMNbnXfFDWiJHIVwhm0NbD7WQc4y8QfGA
Ae9brYzgx/tg/i5oexf4sc0p6lGh0irHfipomOknFqTC8XDVyXwYTfogRheg
FFB3BSrdBuAO6rBQEjDJ838FEMp4N3UNlcHj3U4K7jcAM69zu9TSVz5XXeHW
13eT11pBYowVZhmssGexM6DYsi2XyMXFUItTWlRO82pjdI3Qw1URHliv17rn
bOqPZtym9eU8HrDr7vQJIfO8ErTWCcZ0TDGAMjZsa0V9KlsA+pQZed4WVGH6
tMvphGHHQQVzjmzFCo+Xa7V4d2mVupDHyFkh1KJxDuTD0gHCMOCeDeKBfbN1
TpSmi7t105n3eZ7RMKBybFMGm+LjFsxHWS14QBnPBFRgyO6IHpzNY2Q2op17
nFoYpBAHzxljrPBzPhghjHB7dN/MvHL2tLYTyHZgF2KDgDnGA0+41ov6kOjh
DGRmsgDiMJ1K7dWg8dVooG1K8MCTS3Sf9U6uZnr3RlQq8yLkE6EqdpWhUohd
Zm3e4Mjph/ppVtiarSd0qMPtEypVIJSZpXA81OKmZ4hOZquCLWAeDGI8cODN
BidKs3p3BAzV5DTztm6EgbvlAOThOPvuiTHdWBNhhFd0AQIPQWBELYZk5kgc
EZhgCoY7vZtb5vV4QsUKh67C6/Jb+p+trjOvT0CLuo/lcXFY13LAEWa4byKm
vMeqGGB3cKMTb1jH2x/BMDM542BEspy4AWeUd2S9w6u44efwLi9zITfI6fXh
PC4ORDraATIutArkgwrYaWRGyrJywxHblny6Hch3xuVQHvnQSWfoDokGQQSr
eSvZrttsEkgUv0MFlKU/kMfIvsj4c0hIH9yw/VkX4YbtGd7FGG7aiW7pRt/9
eVy0eAKo3HVG0MGDgeIBZTy4bHbPGV9oxrlAmdk0ewQSBWWwDmwRsdXHI3KM
AR7h8S5b7MOkBOyM9rNpk7nYFakKrPA4hb0vnmbEWGG/a4sTbxhKj2ggM9N4
Wua/Rx0d5jSAB55mrBc8oIz9X4iDnZqjWpt35zHg76oPPQuVO88NPPC8IcYD
P4d32bk82mJX+jPzZEa2RawdnACeKm0VMMdY4WnGNKFDXj98Odz5FMz9jjxG
WrYdjjs6bGoDHjiJdIPgQU2ppt27Vt/xyHCbmbA0TZJ1PkDlubtdzK1OStZq
jBs+sMG/awb3OJHgXaCZPG62CGDgmMHh5/hSVM9jQowVHmPwLrqdkYvcSLil
gcWteVxsdrUE/UQePBtcPuAFeG6MMMADPb+LkJ6ToncCwC15XGyM2IyTjmxr
2m9B2RijWEEZD5czDhqzuyojs5D55jwuEDLP1htd7ZTQgJKL0l3dFKGdV0W3
ET8oA+1ueyEzywzTerckdNoBbToDIngdOcYAr0u3bLmcavEd2FwkMrJWVOWX
VZq7W/W5heJGTQ3V7tus9kEyc9uQsOd8kFkN33ZBW4wH5nW7kPAstS4y5rLy
8xpuCBbpWIdBBM9Avb/NDPBzO4h59CxeY/Vzm0hSneJC5ZFDNe90eDI5jLFi
ZXPV+TltHLYVq91uljmVRztOM3VuxxnR4E6SClSolWwq4401huFMxO2IJOsp
LpZH3I6zQvggh8evLRFWeDxkGKCcZ6h973OszGNlmUAFQyZY4Y4IctiXUKyg
jH0TzAKcrcBGkHM7VuQxog7EKn7HCUZsEHcRpHOOXsUDj+k7RX3YklNux7I8
LtTBb5DsOQ0fuOFZa4wbVq5dQsLnteexNI+RRYGRP7HL1p6uRzmcJ/yh0nxw
GfRqWnCBMj5PAO9ylwMXMDSPXH+++/G/elllT0a48Ad6Ptq7pw07nWxeMCPm
gMsYAzxp3UWigfm7QJrw4Wdu1qz8ojwuJqkq74BcEE1jdUJN5BQrPGndLaBB
8IBzQFQuZub98jihWmaz19cVCgZ3C3p97Kz9pSbteJd19iK1Tk7JgsF8DboA
fEIgVrSC3HNeYdgj9CnGFD/HW9VkUS62GKHP0Z30t8EcbgZS/sslJ6L+1mq9
y8c4ZBMCdNhcX3adOowUE7fPGW6Scd7NZQdzWIkAbbyMOCP4QhkbeL8tb4Yb
ZwAoByeW/Jl/HXuP9wXMe/lP+UMINOKFi72OelOsGOc8UONdNvZ8+gH0G+2P
Rjgf6hp0XPJl4X+Ifgt5OY1YSouztH+1WEodCIcwbMZUOGWAk5dRsKHOvlYM
Tvbd9pISwv5f0Wo8ko3kgKy46fByI/5+hHMzABI+tavlR/lq+SqEGRhar8Dd
nb8bLrE2HviQVyzg7HNlvK6gQGRffp8Tig16V4IhF06hIbgwCtyAHLPWdJel
bYh2mjen2e9FXa1ZhB2dx/L177zZ8EyhMDICo97NFaTbRDf3QSKmq1edZxqe
HZA6jWhVU0LgYo/0rz4dqr8m31XdquWFd8n5FiTf8vfGVfL96Pm+qTGdu1Xp
3DUHuI0o5c5fOavfHoGej2jeR9KkjV6gz77W62+8mZjBjNy6Ro5acl9vpivn
XPc+UUumomd6dndBrWlLPQkh8xUZnU7fD6DLjPtpE9/6TgmNgYSzXNiLwQ4s
J57HJMJrlHiXN6uv0XN/+tVvBE3tyWLYbGRkaTQTCfPNRzMJeWAmWJZZw3iJ
7mr8QvdIvOOBMa8plv1zTftldzhrzmuSLCm1xnmHe85GERVWn5hM3NprMm1H
M784+YLvJuZj1Rku9mh1M556NIZ73SXcL8CMgc7CUYFfVyOgJ6YBN0HPsBLN
/N/4Rd1bBYaQNI7BsfeQkwg1pxw7PkvAW6dmXkXdhdzvrBOvGyv4+TnEH7nQ
B5Un8dZcuV0XTY4hUFmi7IHFpABp4RNOqSl/Txyr2y4agA96QCi3ksIO0Vkg
QQ7eiIlggC1WnSC3+w+Pth5uKEkxzVtVmTiNUL4DZI0AZgx0jonDu+ylqsya
zIuqlbnPMQKtebbNy6p7aaDQ5crH6R14IA5lSkl+UymDWNjhaESgx67Ozgjy
vL2r4jKL31VK0IC0WeSfK9Bz+nxjjN0dquIzOHjCgSRMXEuetECg0rJUTGx9
lq9QRRmvGkAi7GgqSNW0vx3H/N7ccB4vCOaRz+UiKg9Sn5xzvCr+eXZ60D1n
Q+OlRP6nQn9CLnvA4S3oTwMxqEdkHnTdypRiVwQAXvE4JOpTCWoqLRTWC/Pw
J92Vy5n6HskMPS/EdEioveJ6l1D7g1qTMhPazjk8+yHFdWWMUcVRaSrkecgc
OzfkgSpOCIpRxSvUeJcNeWbi3FkCBVUcdszyXhKTtJtIx2bAIc1l5uU1iEFg
B+qIY7a/aaKp4ucOO/BMHTJJwjnrMqhY708pqhjTI+456zqZ6YKIMeHp1hHR
1B5Bktpa9FHl/QiH7IuHeNp9VMgkRhJv3CJs260MZGbz+eAu0wAECfNmVowq
3sw66spsWWnIBEO34+cjyU18ewVVKOOtKLzLi46zw1BV31z10dQc/69IYgvb
EleemcPoI1bNIBwn8WH0iFHFo9ExB7LN+IZKq6zv1hx31Zru74uQxG7BccFi
ZoIkSOL9uONCdoqkfUJ2x6kMunAyjyTfvCFyQgguRhLHuPpI8tBphsrBrPde
VMEzG7+EyFTxTAnv8tZ2JkncT+auV2YOtfAyhKIKZTxzPuGw/80br+bmeMKg
/EIhpkeuP1fTgNhaK5cx6Xj38adf6D56vVeWmbDps4X+S4H/SSe7/lKYJomf
OxmA/5N+P2YzPMSFYTAopwQAiiq13gqOmvk/ySSxK0aW95RoLUYVU+8HBzOl
mWmqPhXShihUy13KJ+AySbxvw6MoLT5kpp1insb+PcaD//qVV7qPPPVcLZGW
qULZB5++2X3i2Zu1UbSZ0piZCduYCJ1mEVyvU6Co+rUvvVLZ/dPuOZ6rZV4B
x5PS0058vPKhSOLRcVbUl3n/mlde4wrV8pivSEIZD0WnNfCZCbRqn5CD2+cc
BYoqHrP5mimAPFROb6OrzArxHYpQxeIDRzwDzczRVdEFdwrxKZIOkfhwyums
4LIAMDPr1juN/aj1ehoaKPjkjVdLI8FlvIBwpwOvf6hEdiKwm4GCKl5AAAUf
++LLDaw4dRDvqgimLKrqM1C+AcyvVbD4eO0DEzC8q2LUMu8fZJ/zLMnOrwoo
kvg5kEQz0BSSvvu975Vk2Tbr7vLnaHm2ukWJ2F9n7eeIFR0J315/9e+6v/yX
L5V/HQ5lFsvwkT97sfvCt9/ovRGeQ9meUPbG33/PE1L+8Qe3//vFwBAHJ94j
ys6LspOi7HIo49upfrLeFC/m3iPKzouyk6IMTfGhpv9fN3Wu/K81AGu6/Hq+
Cpgsq7bF3nKLIGyQ4SMWhVfFW9pCX+N4Zrxd1DzgpMtl8cqn4m+vi7/dWxzv
rXTjwNOwID7oBM7N4euWS4gQ39Yej6quDZmshZ0IqGd7sj1b/jcwvGs6NNTc
ylVXw4zz1TDY+uioiM7lac0DIoMH4RiounhlwEUzS9MaWR2vZW1OLaNV9Ehf
TOPQlbLW0EolQtp67Gwsf/Y34sOBu+oseTSnBNO8TaR+lHNLlO2pumYMG2zW
HtSl7pEZq+oPm4Wj9Dp2/aEtw5K0KNSJrV2TDQ4Ex7nXtatqRvlU6c7ijOY7
4tIGPve3fnZqvZ2p22SzH3fJp50biBHm1pc/0y6Far2WYr77gmXedgVKkHdH
Cdyp4oBoumnROkhVl9k0TsLu1MN6lqc1u0k0y1oFo1u8xlEyocZKqwa0giuC
mifU16ubSqsOdsMe8weHg5EI0dAWPBq7VQo3piix8C0qqWJxSjEg1myla73S
1TDi8ic8g4DzljtBVJQwVGVoYkY5rqCDfXM08WTvyHTach/lCyQqHRrQPHSI
L2kbFdVNpVUHHeKIEOiQVQf3qIqSqLfidYhhTtEh3P1B17kMElOe6mQNbaCG
ooG4LhXZuOw2ycBwBjLMNPM9Mhg7AOKYe76brjkDx7RmVFC9nUSVGnCR1oLy
fY7Y4iDdGJ85ypY1vM0PgPMNNOjGSui9uVfNu4qEaU5HWqTrg6ItLktrqjeM
LSwRBcqGqrmGIZ+GUYop04CWYIZSdWZAdauDaO0RDGf43RggIxpVjZQLuZQd
gjzogpscDRgiTh8DFLlKgwLFl6e1hstZrFbYaR7/67cY6UFoQBOrEqubSqsO
gxDiZ3vTnLQmNgT+3KVdqfOsySB4TB0a9+Ho0YeXU0S8qoqa5ht3QBHnVMGi
DYhTXxFvGRc/wqZyVOogt3NJvOrVidWsiVezhqrBHGE0seqNoeqWu71QtZpI
N2HvJ74keqtquS4m6ebtSBN8O1L5icyUV4vmpqnqMHZUFA+aki4X9a1OfHe9
eBfBxOh51mXaL3eq18dXfcGmor6m9BbW3A370FU8g2CMCG9AeH3LPUkp4cBT
orWeqkxy7G2JB94PbjanSqAvrBDVYa2TJgLlJ7y3Ubyyjig3qdESTjU1Uc3D
qLC0EEotsWu5t2dBbY7Zht3pusA4fHkrEVK3E/ouJWS4qdjlNaL+XQHTllXe
leKVAUvOG8Urm+OvTBOTuLprLZXVx3R9xU8saDusGpe0DLnz05n3fwEbARRc
\
\>"], "Graphics",
  ImageSize->{435, 341},
  ImageMargins->0],
 "  \n\n",
 "\t\t\tFigure 11.37  ",
 "The electric field produced by two charged half-planes \n\t\t\t\t\tthat are \
perpendicular to the complex plane. "
}], "Text",
 CellChangeTimes->{{3.399550616765625*^9, 3.3995506290625*^9}, 
   3.50680218234375*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"11.20", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.5067066985*^9, 3.5067066985*^9}}],

Cell["Enter the formula for the electrical potential.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y", ",", "cont", ",", "\[Phi]"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      FractionBox["600", "\[Pi]"], " ", 
      RowBox[{"Re", "[", 
       RowBox[{"ArcSin", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"\[Phi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      FractionBox["600", "\[Pi]"], " ", 
      RowBox[{"ArcSin", "[", 
       FractionBox[
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x", "+", "1"}], ")"}], "2"], " ", "+", " ", 
           SuperscriptBox["y", "2"]}]], " ", "-", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x", "-", "1"}], ")"}], "2"], " ", "+", " ", 
           SuperscriptBox["y", "2"]}]]}], "2"], "]"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399550802515625*^9},
 AspectRatioFixed->True],

Cell["Check out the formula at some boundary values.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][-1,0] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "0"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][-1,0] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "0"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \[Phi][0,1] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"0", ",", "1"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \[Phi][1,0] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"1", ",", "0"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \[Phi][1,0] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"2", ",", "0"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399550806984375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the electrical potential."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      FractionBox["600", "\[Pi]"], " ", 
      RowBox[{"Re", "[", 
       RowBox[{"ArcSin", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cont", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "300"}], " ", "+", " ", 
        RowBox[{"60", "k"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"Contours", " ", "\[Rule]", " ", "cont"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "50"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3995508096875*^9, 3.399550811703125*^9}, {
  3.400182567609375*^9, 3.400182567890625*^9}},
 AspectRatioFixed->True],

Cell["\<\
The following commands will graph the contours as parametric curves.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"X", ",", "Y", ",", "z", ",", "Z", ",", "w"}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"F", ",", "solset"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      FractionBox["600", "\[Pi]"], " ", 
      RowBox[{"ArcSin", "[", "z", "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"w", " ", "\[Equal]", " ", 
        RowBox[{"F", "[", "z", "]"}]}], ",", "z"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Z", "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], ",", 
       RowBox[{"w", "\[Rule]", 
        RowBox[{"u", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "v"}]}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Re", "[", 
       RowBox[{"Z", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Im", "[", 
       RowBox[{"Z", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Z = \>\"", ",", 
      RowBox[{"Z", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Z = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"Z", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<X = \>\"", ",", 
      RowBox[{"X", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y = \>\"", ",", 
      RowBox[{"Y", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399550820078125*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "k", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"X", "[", 
           RowBox[{
            RowBox[{"k", " ", "60"}], ",", "v"}], "]"}], ",", 
          RowBox[{"Y", "[", 
           RowBox[{
            RowBox[{"k", " ", "60"}], ",", "v"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"-", "5"}], ",", "5", ",", "2"}], "}"}]}], "]"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"v", ",", 
         RowBox[{"-", "500"}], ",", "500"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"eqns", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"X", "[", 
           RowBox[{
            RowBox[{"k", " ", "60"}], ",", "v"}], "]"}], ",", 
          RowBox[{"Y", "[", 
           RowBox[{
            RowBox[{"k", " ", "60"}], ",", "v"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"-", "4"}], ",", "4", ",", "2"}], "}"}]}], "]"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"v", ",", 
         RowBox[{"-", "500"}], ",", "500"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "2"}], "]"}]}], "}"}]}]}], "]"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399550824171875*^9, 3.399550825359375*^9}, {
  3.400403287847875*^9, 3.400403296566625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Hence the electrical potential  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   FractionBox[
    RowBox[{"600", " ", 
     RowBox[{"Re", "[", 
      RowBox[{"ArcSin", "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], "\[Pi]"]}]]],
 "  is harmonic in plane slit along the rays  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "<", 
    RowBox[{"-", "1"}]}], ",", 
   RowBox[{"y", "=", 
    RowBox[{
     RowBox[{"0", "  ", "and", "  ", "x"}], ">", "1"}]}], ",", 
   RowBox[{"y", "=", "0"}]}]]],
 "  and has the desired boundary values.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 11.21.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the electrical potential  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  in the disk  ",
 Cell[BoxData[
  RowBox[{"D", ":", 
   RowBox[{"|", "z", "|", 
    RowBox[{"<", "1"}]}]}]]],
 "  that satisfies the boundary values\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", "80"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       StyleBox["for",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "   ", "x"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}], "=", 
     RowBox[{
      RowBox[{"z", "  ", 
       StyleBox["on",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "  ", 
       SubscriptBox["C", "1"]}], "=", 
      RowBox[{"{", 
       RowBox[{"z", "=", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], " ", ":", " ", 
         RowBox[{"0", "<", "\[Theta]", "<", 
          FractionBox["\[Pi]", "2"]}]}]}], "}"}]}]}], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->14,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontFamily->"Times New Roman",
     FontSize->14,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}]}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", "  ", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     RowBox[{
      StyleBox["for",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "   ", "x"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]}], "=", 
    RowBox[{
     RowBox[{"z", "  ", 
      StyleBox["on",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      SubscriptBox["C", "2"]}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"z", "=", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], " ", ":", " ", 
         RowBox[{
          FractionBox["\[Pi]", "2"], "<", "\[Theta]", "<", 
          RowBox[{"2", "\[Pi]"}]}]}]}], "}"}], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[".",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}]}]}]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{350, 240},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  The mapping  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}]}], 
     RowBox[{"(", 
      RowBox[{"z", "-", "1"}], ")"}]]}]}]]],
 "  is a one-to-one conformal mapping of ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " onto the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]]],
 "  with the property that ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " is mapped onto the negative ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " axis and ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 " is mapped onto the positive ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " axis.  The potential ",
 Cell[BoxData[
  RowBox[{"\[CapitalPhi]", 
   RowBox[{"(", 
    RowBox[{"u", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "v"}], ")"}]}]]],
 " in the upper half-plane that satisfies the new boundary values \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalPhi]", 
     RowBox[{"(", 
      RowBox[{"u", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", "80"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{"for", "   ", "u"}], "<", "0"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalPhi]", 
     RowBox[{"(", 
      RowBox[{"u", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", "  ", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{"for", "   ", "u"}], ">", "0"}], ","}]]],
 "  \n\n is given by  \n \n",
 StyleBox[" (11-29)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPhi]", 
    RowBox[{"(", 
     RowBox[{"u", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox["80", "\[Pi]"], "Arg", 
     RowBox[{"(", "w", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox["80", "\[Pi]"], "Arctan", 
     RowBox[{"(", 
      FractionBox["v", "u"], ")"}]}]}]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text"],

Cell[TextData[{
 "A straightforward calculation shows that  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"w", "  ", "=", "  ", 
    RowBox[{
     RowBox[{"u", "+", 
      RowBox[{"\[ImaginaryI]", " ", "v"}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"S", 
       RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}], "-", "\[ImaginaryI]"}], 
         ")"}]}], 
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}], "-", "1"}], ")"}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"y", "-", "1"}], ")"}]}]}], ")"}]}], 
     RowBox[{"(", 
      RowBox[{"x", "-", "1", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"y", "-", "1"}], ")"}]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"x", "-", "1", "-", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", "-", "1", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"x", "-", "1", "-", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "x"}], "+", 
      SuperscriptBox["x", "2"], "-", 
      RowBox[{"2", " ", "y"}], "+", 
      SuperscriptBox["y", "2"], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["x", "2"], "-", 
         SuperscriptBox["y", "2"]}], ")"}]}]}], 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "x"}], "+", 
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"]}]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "1"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"y", "-", "1"}], ")"}], "2"], "-", "1", "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["x", "2"], "-", 
         SuperscriptBox["y", "2"]}], ")"}]}]}], 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "x"}], "+", 
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"]}]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"   ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "1"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y", "-", "1"}], ")"}], "2"], "-", "1"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "1"}], ")"}], "2"], "+", 
       SuperscriptBox["y", "2"]}]], " ", "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      FractionBox[
       RowBox[{" ", 
        RowBox[{"1", "-", 
         SuperscriptBox["x", "2"], "-", 
         SuperscriptBox["y", "2"]}]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "-", "1"}], ")"}], "2"], "+", 
        SuperscriptBox["y", "2"]}]]}]}]}]}]}]],
 " "
}], "Text"],

Cell[TextData[{
 "\n\nWe substitute the real and imaginary parts,  ",
 Cell[BoxData[
  RowBox[{"u", "=", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "1"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"y", "-", "1"}], ")"}], "2"], "-", "1"}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "1"}], ")"}], "2"], "+", 
      SuperscriptBox["y", "2"]}]]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"v", "=", 
   RowBox[{
    RowBox[{"v", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"1", "-", 
       SuperscriptBox["x", "2"], "-", 
       SuperscriptBox["y", "2"]}]}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "1"}], ")"}], "2"], "+", 
      SuperscriptBox["y", "2"]}]]}]}]]],
 "  from this equation, into Equation ",
 StyleBox[" (11-29)",
  FontColor->RGBColor[0, 0, 1]],
 " to obtain the desired solution:   \n\n \t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox["80", "\[Pi]"], "Arctan", 
    RowBox[{"(", 
     FractionBox[
      RowBox[{"1", "-", 
       SuperscriptBox["x", "2"], "-", 
       SuperscriptBox["y", "2"]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "1"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y", "-", "1"}], ")"}], "2"], "-", "1"}]], ")"}]}]}]],
  AspectRatioFixed->True],
 ".  \n\nThe level curve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPhi]", 
    RowBox[{"(", 
     RowBox[{"u", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], "=", "\[Alpha]"}]],
  AspectRatioFixed->True],
 "  in the upper half-plane is a ray emanating from the origin, and the \
preimage  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", "\[Alpha]"}]],
  AspectRatioFixed->True],
 "  in the unit disk is an arc of a circle that passes through the points  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"1", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "z"}], "=", "\[ImaginaryI]"}]}]]],
 ".  Several level curves are illustrated in Figure 11.38."
}], "Text"],

Cell[TextData[{
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{683, 296},
  ImageMargins->0],
 "  \n\n",
 "\t\t\t  Figure 11.38  ",
 "The potentials  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"\[CapitalPhi]", 
   RowBox[{"(", 
    RowBox[{"u", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "v"}], ")"}]}]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.399550638*^9, 3.3995506464375*^9}, {
  3.506802229640625*^9, 3.50680223403125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"11.21", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.5067067033125*^9, 3.5067067033125*^9}}],

Cell["\<\
Construct the solution with a conformal mapping.  This example is similar to \
Example 11.8.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"u", "=", 
     RowBox[{"U", "=", 
      RowBox[{"v", "=", 
       RowBox[{"V", "=", 
        RowBox[{"w", "=", 
         RowBox[{"W", "=", 
          RowBox[{"x", "=", 
           RowBox[{"X", "=", 
            RowBox[{"y", "=", 
             RowBox[{"Y", "=", 
              RowBox[{"z", "=", 
               RowBox[{"Z", "=", "0"}]}]}]}]}]}]}]}]}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{
     "u", ",", "U", ",", "v", ",", "V", ",", "w", ",", "W", ",", "x", ",", 
      "X", ",", "y", ",", "Y", ",", "z", ",", "Z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "\[Phi]"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "\[ImaginaryI]"}], ")"}]}], 
      RowBox[{"z", " ", "-", " ", "1"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"W", " ", "=", "  ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"U", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Re", "[", "W", "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"V", " ", "=", " ", 
      RowBox[{"Together", "[", 
       RowBox[{"ComplexExpand", "[", 
        RowBox[{
         RowBox[{"Im", "[", "W", "]"}], ",", 
         RowBox[{"TargetFunctions", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      FractionBox["80", "\[Pi]"], " ", 
      RowBox[{"ArcTan", "[", 
       FractionBox["V", "U"], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = u + \[ImaginaryI] v = \>\"", ",", 
      RowBox[{"U", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "V"}]}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\[Phi][x,y] = \!\(\*FractionBox[\(80\), \(\[Pi]\)]\) \
ArcTan[\!\(\*FractionBox[\(v\), \(u\)]\)]\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39955083809375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the temperature.  For computational purposes we \
use the following formula   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["80", "\[Pi]"], " ", 
    RowBox[{"ArcTan", "[", 
     FractionBox[
      RowBox[{"1", " ", "-", " ", 
       SuperscriptBox["x", "2"], " ", "-", " ", 
       SuperscriptBox["y", "2"]}], 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{"2", " ", "x"}], " ", "+", " ", 
       SuperscriptBox["x", "2"], " ", "-", " ", 
       RowBox[{"2", " ", "y"}], " ", "+", " ", 
       SuperscriptBox["y", "2"]}]], "]"}]}], "=", 
   RowBox[{
    FractionBox[
     RowBox[{"-", "80"}], "\[Pi]"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"-", "\[Pi]"}], "2"], "+", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         SuperscriptBox["x", "2"], "-", 
         SuperscriptBox["y", "2"]}], ",", 
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "x"}], "+", 
         SuperscriptBox["x", "2"], "-", 
         RowBox[{"2", " ", "y"}], "+", 
         SuperscriptBox["y", "2"]}]}], "]"}]}], ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{
      FractionBox[
       RowBox[{"-", "80"}], "\[Pi]"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"-", "\[Pi]"}], "2"], "+", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"1", "-", 
           SuperscriptBox["x", "2"], "-", 
           SuperscriptBox["y", "2"]}], ",", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "x"}], "+", 
           SuperscriptBox["x", "2"], "-", 
           RowBox[{"2", " ", "y"}], "+", 
           SuperscriptBox["y", "2"]}]}], "]"}]}], ")"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cont", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"10", "k"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "8"}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"Contours", " ", "\[Rule]", " ", "cont"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "60"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39955084203125*^9, 3.399550843375*^9}, {
  3.400182572265625*^9, 3.400182572515625*^9}},
 AspectRatioFixed->True],

Cell["\<\
The following commands will graph the contours as parametric curves.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"u", "=", 
     RowBox[{"v", "=", 
      RowBox[{"w", "=", 
       RowBox[{"X", "=", 
        RowBox[{"Y", "=", 
         RowBox[{"z", "=", 
          RowBox[{"Z", "=", "0"}]}]}]}]}]}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{
     "u", ",", "v", ",", "w", ",", "X", ",", "Y", ",", "z", ",", "Z"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "F", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "\[ImaginaryI]"}], ")"}]}], 
      RowBox[{"z", " ", "-", " ", "1"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"w", " ", "\[Equal]", " ", 
        RowBox[{"F", "[", "z", "]"}]}], ",", "z"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Z", "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], ",", 
       RowBox[{"w", "\[Rule]", 
        RowBox[{"u", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "v"}]}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"Z", "[", 
          RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", "\n", "           ", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Re", ",", " ", "Im"}], "}"}]}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Im", "[", 
         RowBox[{"Z", "[", 
          RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", "\n", "           ", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Re", ",", " ", "Im"}], "}"}]}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", 
      SubscriptBox["solset", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Z = \>\"", ",", 
      RowBox[{"Z", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<X = \>\"", ",", 
      RowBox[{"X", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y = \>\"", ",", 
      RowBox[{"Y", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39955084709375*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"n", " ", "=", " ", "8"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", "k", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "r_", "]"}], " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"X", "[", 
       RowBox[{
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", 
          FractionBox[
           RowBox[{"k", " ", "\[Pi]"}], "n"], "]"}]}], ",", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", 
          FractionBox[
           RowBox[{"k", " ", "\[Pi]"}], "n"], "]"}]}]}], "]"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "r_", "]"}], " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Y", "[", 
       RowBox[{
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", 
          FractionBox[
           RowBox[{"k", " ", "\[Pi]"}], "n"], "]"}]}], ",", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", 
          FractionBox[
           RowBox[{"k", " ", "\[Pi]"}], "n"], "]"}]}]}], "]"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqns", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "[", "r", "]"}], ",", 
          RowBox[{"y", "[", "r", "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", "n", ",", "2"}], "}"}]}], "]"}], "]"}]}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.05", ",", "40"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "[", "r", "]"}], ",", 
          RowBox[{"y", "[", "r", "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"n", "-", "1"}], ",", "2"}], "}"}]}], "]"}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.05", ",", "40"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39955085096875*^9, 3.399550854*^9}, {
  3.40040330320725*^9, 3.400403310285375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Hence the electrical potential  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   RowBox[{
    FractionBox["80", "\[Pi]"], " ", 
    RowBox[{"ArcTan", "[", 
     FractionBox[
      RowBox[{"1", "-", 
       SuperscriptBox["x", "2"], "-", 
       SuperscriptBox["y", "2"]}], 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", "x"}], "+", 
       SuperscriptBox["x", "2"], "-", 
       RowBox[{"2", " ", "y"}], "+", 
       SuperscriptBox["y", "2"]}]], "]"}]}]}]]],
 "  is harmonic in the disk |z| < 1 and has the desired boundary values.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the electrical potential  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  in the crescent-shaped region that lies inside the disk ",
 Cell[BoxData[
  RowBox[{"D", ":", 
   RowBox[{"|", 
    RowBox[{"z", "-", "2"}], "|", 
    RowBox[{"<", " ", "2"}]}]}]]],
 "  and outside the circle ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{"z", "-", "1"}], "|"}], "=", " ", "1"}]]],
 "  that satisfies the following boundary values shown in Figure 11.41: \n\n\t\
\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", "100"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "   ", "|", 
     RowBox[{"z", "-", "2"}], "|"}], "=", "2"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   RowBox[{
    RowBox[{"z", "\[NotEqual]", "0"}], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->14,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontFamily->"Times New Roman",
     FontSize->14,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}]}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", "  ", "50"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "   ", "|", 
     RowBox[{"z", "-", "1"}], "|"}], "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   RowBox[{"z", "\[NotEqual]", 
    RowBox[{"0", 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[".",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}]}]}]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{265, 155},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  The result of Example 10.7 shows that the function  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"w", "  ", "=", "  ", 
    RowBox[{
     RowBox[{"u", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "v"}]}], "  ", "=", "  ", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{"4", "-", "z"}], ")"}]}], "z"]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{"4", "-", "x", "-", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], 
     RowBox[{"(", 
      RowBox[{"x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]]}]}]}]],
 "  \n\nis a conformal mapping of the crescent-shaped region that lies inside \
the disk ",
 Cell[BoxData[
  RowBox[{"D", ":", 
   RowBox[{"|", 
    RowBox[{"z", "-", "2"}], "|", 
    RowBox[{"<", " ", "2"}]}]}]]],
 "  and outside the circle ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{"z", "-", "1"}], "|"}], "=", " ", "1"}]]],
 "  onto the horizontal strip  ",
 Cell[BoxData[
  RowBox[{"0", " ", "<", " ", "v", " ", "<", " ", "1"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{207, 207},
  ImageMargins->0],
 "  \n\n\t\tFigure 11.41  The electrical potential ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " inside ",
 Cell[BoxData[
  RowBox[{"D", ":", 
   RowBox[{"|", 
    RowBox[{"z", "-", "2"}], "|", 
    RowBox[{"<", " ", "2"}]}]}]]],
 "  and outside ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{"z", "-", "1"}], "|"}], "=", " ", "1"}]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.399550651546875*^9, 3.399550663625*^9}, {
  3.5068022598125*^9, 3.5068022649375*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Revisit and Explore Solution 10.7.",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["Example 10.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the bilinear transformation ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " that maps the crescent-shaped region that lies inside the disk ",
 Cell[BoxData[
  RowBox[{"D", ":", 
   RowBox[{"|", 
    RowBox[{"z", "-", "2"}], "|", 
    RowBox[{"<", " ", "2"}]}]}]]],
 "  and outside the circle ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{"z", "-", "1"}], "|"}], "=", " ", "1"}]]],
 "  onto a horizontal strip."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{695, 175},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  For convenience we choose  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], "=", "4"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["z", "2"], "=", 
    RowBox[{"2", "+", 
     RowBox[{"2", "\[ImaginaryI]"}]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["z", "3"], "=", "0"}]}]]],
 "  and the image values  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["w", "2"], "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["w", "3"], "=", "\[Infinity]"}]}]]],
 ",  respectively.  The ordered triple  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], "=", 
    RowBox[{"-", "4"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["z", "2"], "=", 
    RowBox[{"2", "+", 
     RowBox[{"2", "\[ImaginaryI]"}]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["z", "3"], "=", "0"}]}]]],
 "  gives the circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", 
     RowBox[{"z", "-", "2"}], "|"}]}], "=", " ", "2"}]]],
 "  a positive orientation and the disk  ",
 Cell[BoxData[
  RowBox[{"D", ":", 
   RowBox[{"|", 
    RowBox[{"z", "-", "2"}], "|", 
    RowBox[{"<", " ", "2"}]}]}]]],
 "  has a left orientation.  The image points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["w", "2"], "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["w", "3"], "=", "\[Infinity]"}]}]]],
 "  all lie on the extended ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " axis, and they determine a left orientation for the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]]],
 ".  Therefore we can use the second implicit formula (Equation ",
 StyleBox["(10-21)",
  FontColor->RGBColor[0, 0, 1]],
 ") to write  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "4"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", " ", "+", " ", 
       RowBox[{"2", "\[ImaginaryI]"}], " ", "-", " ", "0"}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "0"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"2", " ", "+", " ", 
       RowBox[{"2", "\[ImaginaryI]"}], " ", "-", " ", "4"}], ")"}]}]], " ", 
   "=", " ", 
   FractionBox[
    RowBox[{"w", " ", "-", " ", "0"}], 
    RowBox[{"1", " ", "-", " ", "0"}]]}]]],
 ",  \n\nwhich determines a mapping of the disk  ",
 Cell[BoxData[
  RowBox[{"D", ":", 
   RowBox[{"|", 
    RowBox[{"z", "-", "2"}], "|", 
    RowBox[{"<", " ", "2"}]}]}]]],
 "  onto the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]]],
 ".  Use the fact that ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{" ", 
     RowBox[{"2", " ", "+", " ", 
      RowBox[{"2", "\[ImaginaryI]"}]}]}], 
    RowBox[{
     RowBox[{"-", "2"}], " ", "+", " ", 
     RowBox[{"2", "\[ImaginaryI]"}]}]], " ", "=", 
   RowBox[{"-", "\[ImaginaryI]"}]}]]],
 "  to simplify the preceding equation and get \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"z", " ", "-", " ", "4"}], 
     RowBox[{"z", " "}]], 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"2", " ", "+", " ", 
       RowBox[{"2", "\[ImaginaryI]"}]}]}], 
     RowBox[{
      RowBox[{"-", "2"}], " ", "+", " ", 
      RowBox[{"2", "\[ImaginaryI]"}]}]]}], " ", "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"z", " ", "-", " ", "4"}], 
      RowBox[{"z", " "}]], 
     RowBox[{"(", 
      RowBox[{"-", "\[ImaginaryI]"}], ")"}]}], " ", "=", "  ", 
    FractionBox["w", "1"]}]}]]],
 " \n\nwhich can be written in the form  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "=", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]z"}], " ", "+", " ", "\[ImaginaryI]4"}], 
     RowBox[{"z", " "}]]}]}]],
  AspectRatioFixed->True],
 ". "
}], "Text"],

Cell[TextData[{
 "A straightforward calculation shows that the points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "4"], "=", 
    RowBox[{"1", "-", "\[ImaginaryI]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["z", "5"], "=", "2"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["z", "6"], "=", 
    RowBox[{"1", "+", "\[ImaginaryI]"}]}]}]]],
 "  are mapped onto the points  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "4"], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"S", 
      RowBox[{"(", 
       SubscriptBox["z", "4"], ")"}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"S", 
       RowBox[{"(", 
        RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}]}], "  ", "=", "  ", 
      RowBox[{
       RowBox[{"-", "2"}], "+", "\[ImaginaryI]"}]}]}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox["  ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["w", "5"], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"S", 
      RowBox[{"(", 
       SubscriptBox["z", "5"], ")"}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"S", 
       RowBox[{"(", "2", ")"}]}], "  ", "=", "  ", "\[ImaginaryI]"}]}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[
    RowBox[{
     StyleBox["  ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  "}]], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["w", "6"], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"S", 
      RowBox[{"(", 
       SubscriptBox["z", "6"], ")"}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"S", 
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}]}], "  ", "=", "  ", 
      RowBox[{"2", "+", "\[ImaginaryI]"}]}]}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox["  ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]]],
 "  \n\nrespectively.  The points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "4"], "=", 
    RowBox[{
     RowBox[{"-", "2"}], "+", "\[ImaginaryI]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["w", "5"], "=", "\[ImaginaryI]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["w", "6"], "=", 
    RowBox[{"2", "+", "\[ImaginaryI]"}]}]}]]],
 "  lie on the horizontal line  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "1"}]]],
 "  in the upper half-plane.  Therefore the crescent-shaped region is mapped \
onto the horizontal strip  ",
 Cell[BoxData[
  RowBox[{"0", "<", 
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], "<", "1"}]]],
 ",  as shown in Figure 10.7. "
}], "Text"],

Cell[TextData[{
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{702, 243},
  ImageMargins->0],
 StyleBox["\n\n",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t     Figure 10.7  ",
 "The mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "=", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]z"}], " ", "+", " ", "\[ImaginaryI]4"}], 
     RowBox[{"z", " "}]]}]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text",
 CellChangeTimes->{{3.39949666084375*^9, 3.39949667153125*^9}, {
  3.506802287859375*^9, 3.5068022935*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 10.7.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Enter three points and their images and solve for  w = S(z).  For \
convenience we choose  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], "=", "4"}], ",", " ", 
   RowBox[{
    SubscriptBox["z", "2"], "=", 
    RowBox[{"2", "+", 
     RowBox[{"2", "\[ImaginaryI]"}]}]}], ",", " ", 
   RowBox[{
    SubscriptBox["z", "3"], "=", "0"}]}]],
  AspectRatioFixed->True],
 "  which are mapped onto the points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "0"}], ",", " ", 
   RowBox[{
    SubscriptBox["w", "2"], "=", "1"}], ",", " ", 
   RowBox[{
    SubscriptBox["w", "3"], "=", "\[Infinity]"}]}]],
  AspectRatioFixed->True],
 ",  respectively.  In this case we remove the terms involving  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "3"], " ", "=", " ", "\[Infinity]"}]],
  AspectRatioFixed->True],
 ",  in the implicit formula, because this implies that  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     SubscriptBox["w", "2"], " ", "-", " ", 
     SubscriptBox["w", "3"]}], 
    RowBox[{"w", " ", "-", " ", 
     SubscriptBox["w", "3"]}]], "=", 
   RowBox[{
    FractionBox[
     RowBox[{
      SubscriptBox["w", "2"], " ", "-", " ", "\[Infinity]"}], 
     RowBox[{"w", " ", "-", " ", "\[Infinity]"}]], "=", "1"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"S", "=", 
     RowBox[{"T", "=", 
      RowBox[{"w", "=", 
       RowBox[{"W", "=", 
        RowBox[{"z", "=", 
         RowBox[{"Z", "=", "0"}]}]}]}]}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"S", ",", "T", ",", "w", ",", "W", ",", "z", ",", "Z"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"formula", ",", "Iden", ",", "solset"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"formula", " ", "=", " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SubscriptBox["z", "1"]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["z", "2"], "-", 
          SubscriptBox["z", "3"]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SubscriptBox["z", "3"]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["z", "2"], "-", 
          SubscriptBox["z", "1"]}], ")"}]}]], " ", "\[Equal]", " ", 
      FractionBox[
       RowBox[{"w", "-", 
        SubscriptBox["w", "1"]}], 
       RowBox[{
        SubscriptBox["w", "2"], "-", 
        SubscriptBox["w", "1"]}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "formula", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], " ", "=", " ", "4"}], ";"}], "   ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], " ", "=", " ", 
     RowBox[{"2", "+", 
      RowBox[{"2", "\[ImaginaryI]"}]}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], " ", "=", " ", "0"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "1"], " ", "=", " ", "0"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "2"], " ", "=", " ", "1"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "3"], " ", "=", " ", "\[Infinity]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Substitute the values\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"], ",", 
      "\"\<,    \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["z", "2"], ",", 
      "\"\<,   \!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["w", "1"], ",", 
      "\"\<,    \!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["w", "2"], ",", 
      "\"\<,       \!\(\*SubscriptBox[\(w\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["w", "3"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "formula", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{"formula", ",", "w"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S(z) = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399496295609375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Check our work and look at the images of  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], ",", " ", 
   SubscriptBox["z", "2"], ",", " ", 
   SubscriptBox["z", "3"]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["z", "2"], ",", 
      "\"\<,    \!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["w", "1"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["w", "2"], ",", 
      "\"\<,        \!\(\*SubscriptBox[\(w\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["w", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\!\(\*SubscriptBox[\(z\), \(1\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "1"], "]"}], ",", 
      "\"\<,   S[\!\(\*SubscriptBox[\(z\), \(2\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "2"], "]"}], ",", 
      "\"\<,     S[\!\(\*SubscriptBox[\(z\), \(3\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "3"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399496300015625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "And we need to look at the images of three more points;   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "4"], "=", 
    RowBox[{"1", "-", "\[ImaginaryI]"}]}], ",", " ", 
   RowBox[{
    SubscriptBox["z", "5"], "=", "2"}], ",", " ", 
   RowBox[{
    SubscriptBox["z", "6"], "=", 
    RowBox[{"1", "+", "\[ImaginaryI]"}]}]}]],
  AspectRatioFixed->True],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "4"], "=", 
    RowBox[{
     RowBox[{"-", "2"}], "+", "\[ImaginaryI]"}]}], ",", " ", 
   RowBox[{
    SubscriptBox["w", "5"], "=", "\[ImaginaryI]"}], ",", " ", 
   RowBox[{
    SubscriptBox["w", "6"], "=", 
    RowBox[{"2", "+", "\[ImaginaryI]"}]}]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["z", "4"], " ", "=", "  ", 
     RowBox[{"1", "-", "\[ImaginaryI]"}]}], ";", "     ", 
    RowBox[{
     SubscriptBox["z", "5"], " ", "=", " ", "2"}], ";", "    ", 
    RowBox[{
     SubscriptBox["z", "6"], " ", "=", " ", 
     RowBox[{"1", "+", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "4"], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", "2"}], "+", "\[ImaginaryI]"}]}], ";", "   ", 
    RowBox[{
     SubscriptBox["w", "5"], " ", "=", " ", "\[ImaginaryI]"}], ";", "   ", 
    RowBox[{
     SubscriptBox["w", "6"], " ", "=", " ", 
     RowBox[{"2", "+", "\[ImaginaryI]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["z", "4"], ",", 
      "\"\<,       \!\(\*SubscriptBox[\(z\), \(5\)]\) = \>\"", ",", 
      SubscriptBox["z", "5"], ",", 
      "\"\<,       \!\(\*SubscriptBox[\(z\), \(6\)]\) = \>\"", ",", 
      SubscriptBox["z", "6"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(w\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["w", "4"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(w\), \(5\)]\) = \>\"", ",", 
      SubscriptBox["w", "5"], ",", 
      "\"\<,       \!\(\*SubscriptBox[\(w\), \(6\)]\) = \>\"", ",", 
      SubscriptBox["w", "6"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\!\(\*SubscriptBox[\(z\), \(4\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "4"], "]"}], ",", 
      "\"\<,   S[\!\(\*SubscriptBox[\(z\), \(5\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "5"], "]"}], ",", 
      "\"\<,    S[\!\(\*SubscriptBox[\(z\), \(6\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "6"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399496301984375*^9},
 AspectRatioFixed->True],

Cell["\<\
To illustrate the mapping, consider the inverse image of the horizontal \
strip.  We will need to use the inverse function.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "w_", "]"}], " ", "=", " ", "w"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{"formula", ",", "z"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"T", "[", "w_", "]"}], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = T[w] = \>\"", ",", 
      RowBox[{"T", "[", "w", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[S[z]] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"S", "[", "z", "]"}], "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{"T", "[", 
        RowBox[{"S", "[", "z", "]"}], "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[T[w]] = \>\"", ",", 
      RowBox[{"S", "[", 
       RowBox[{"T", "[", "w", "]"}], "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{"S", "[", 
        RowBox[{"T", "[", "w", "]"}], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399496304640625*^9},
 AspectRatioFixed->True],

Cell["Now plot the graphs using T[w] then the identity map.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zdots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Cyan", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}]}], "}"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"wdots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Cyan", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zplane", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"T", "   ", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "9"}], ",", "9", ",", "0.3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.005", ",", "0.995", ",", "0.09"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.05"}], ",", "4.05"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.05"}], ",", "2.05"}], "}"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "4", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"2", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"wplane", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"Iden", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "9"}], ",", "9", ",", "0.9"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.005", ",", "0.995", ",", "0.09"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9"}], ",", "9"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        FractionBox["1", "3"]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "9"}], ",", "9", ",", "3"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"zplane", ",", "zdots", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "4.05"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.05"}], ",", "2.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"2", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The the crescent-shaped region that lies inside\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<the disk |z-2| < 2 and outside the circle |z-1| = 1.\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"wplane", ",", "wdots", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "3"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9", ",", "3"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image is the horizontal strip 0 < v < 1,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\>\"", ",", 
      SubscriptBox["z", "1"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "1"], "]"}], ",", "\[IndentingNewLine]", 
      "\"\<,      S[\>\"", ",", 
      SubscriptBox["z", "2"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "2"], "]"}], ",", "\[IndentingNewLine]", 
      "\"\<,   S[\>\"", ",", 
      SubscriptBox["z", "3"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "3"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\>\"", ",", 
      SubscriptBox["z", "4"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "4"], "]"}], ",", "\[IndentingNewLine]", 
      "\"\<,   S[\>\"", ",", 
      SubscriptBox["z", "5"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "5"], "]"}], ",", "\[IndentingNewLine]", 
      "\"\<,   S[\>\"", ",", 
      SubscriptBox["z", "6"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "6"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399496306859375*^9, 3.39949635546875*^9}, {
  3.400182577125*^9, 3.40018257734375*^9}, {3.400403317972875*^9, 
  3.40040335445725*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We have constructed the transformation ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"S", "[", "z", "]"}], "=", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], " ", "+", " ", "z"}], ")"}]}], "z"]}]}]}]]],
 "  and see that the image of the crescent-shaped region that lies inside the \
disk ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", "2"}], "|", 
   RowBox[{"<", " ", "2"}]}]]],
 "  and outside the circle ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{"z", "-", "1"}], "|"}], "=", " ", "1"}]]],
 "  is the horizontal strip  ",
 Cell[BoxData[
  RowBox[{"0", "<", "v", "<", "1"}]]],
 ".  "
}], "Text"]
}, Open  ]]
}, Closed]],

Cell[TextData[{
 "\tThe new problem in the w plane is to find the potential  ",
 Cell[BoxData[
  RowBox[{"\[CapitalPhi]", 
   RowBox[{"(", 
    RowBox[{"u", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "v"}], ")"}]}]]],
 "  that satisfies the boundary values  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalPhi]", 
     RowBox[{"(", 
      RowBox[{"u", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], " ", "=", " ", "100"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox["all",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "u"}], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->14,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontFamily->"Times New Roman",
     FontSize->14,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}]}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalPhi]", 
     RowBox[{"(", 
      RowBox[{"u", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "1"}], ")"}]}], " ", "=", "   ", "50"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   RowBox[{
    StyleBox["for",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox["all",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", 
    RowBox[{"u", 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[".",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}]}]}]],
 "  \n\t\t\t\nIn the w plane the solution is\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalPhi]", 
     RowBox[{"(", 
      RowBox[{"u", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "v"}], ")"}]}], "  ", "=", "  ", 
    RowBox[{"100", "  ", "+", "  ", 
     RowBox[{
      FractionBox[
       RowBox[{"50", " ", "-", " ", "100"}], 
       RowBox[{"1", " ", "-", "  ", "0"}]], 
      RowBox[{"(", 
       RowBox[{"v", "-", "0"}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{"=", "  ", 
    RowBox[{"100", " ", "-", " ", 
     RowBox[{"50", " ", "v"}]}]}]}]}],
  AspectRatioFixed->True]
}], "Text"],

Cell[TextData[{
 "A straightforward calculation shows that  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"w", "  ", "=", "  ", 
    RowBox[{
     RowBox[{"u", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "v"}]}], "  ", "=", "  ", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{"4", "-", "x", "-", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]]}]}], 
   "\n"}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{"4", "-", "x", "-", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"x", "-", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"x", "-", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{
      RowBox[{"4", " ", "y"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", "x"}], "-", 
         SuperscriptBox["x", "2"], "-", 
         SuperscriptBox["y", "2"]}], ")"}]}]}], 
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"]}]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"4", " ", "y"}], 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"]}]], "  ", "+", "  ", 
     RowBox[{"\[ImaginaryI]", 
      FractionBox[
       RowBox[{
        RowBox[{"4", " ", "x"}], "-", 
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["y", "2"]}], 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"]}]]}]}]}]}]}]],
 "  \n\nWe substitute the imaginary part,  ",
 Cell[BoxData[
  RowBox[{"v", "=", 
   RowBox[{
    RowBox[{"v", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
    FractionBox[
     RowBox[{
      RowBox[{"4", " ", "x"}], "-", 
      SuperscriptBox["x", "2"], "-", 
      SuperscriptBox["y", "2"]}], 
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"]}]]}]}]]],
 "  from this equation, into  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPhi]", 
    RowBox[{"(", 
     RowBox[{"u", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], " ", "=", " ", 
   RowBox[{"100", " ", "-", " ", 
    RowBox[{"50", " ", "v"}]}]}]],
  AspectRatioFixed->True],
 "  to obtain the desired solution:   \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
    RowBox[{"100", "  ", "-", "  ", 
     RowBox[{"50", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"4", " ", "x"}], "-", 
         SuperscriptBox["x", "2"], "-", 
         SuperscriptBox["y", "2"]}], 
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["y", "2"]}]], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{"=", "   ", 
    RowBox[{"150", "  ", "-", "  ", 
     FractionBox[
      RowBox[{"200", "x"}], 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"]}], " "}]]}]}]}]}],
  AspectRatioFixed->True],
 "   "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "1."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706708640625*^9, 3.506706708640625*^9}}],

Cell["Construct the solution with a conformal mapping.  ", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"z", "=", "0"}], ";", " ", 
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "U", ",", "V", ",", "\[Phi]"}], "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{"4", "-", "z"}], ")"}]}], "z"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"W", " ", "=", "  ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"U", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Re", "[", "W", "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"V", " ", "=", " ", 
      RowBox[{"Together", "[", 
       RowBox[{"ComplexExpand", "[", 
        RowBox[{
         RowBox[{"Im", "[", "W", "]"}], ",", 
         RowBox[{"TargetFunctions", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"100", "  ", "+", "  ", 
      RowBox[{
       FractionBox[
        RowBox[{"50", " ", "-", " ", "100"}], 
        RowBox[{"1", " ", "-", "  ", "0"}]], 
       RowBox[{"(", 
        RowBox[{"V", "-", "0"}], ")"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = u + \[ImaginaryI] v = \>\"", ",", 
      RowBox[{"U", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "V"}]}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\[Phi][x,y] = 100  +  \!\(\*FractionBox[\(50\\\  - \\\ 100\), \(1\\\
\  - \\\ \\\ 0\)]\)(v-0)\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", 
     RowBox[{"Expand", "[", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399551005890625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the equipotentials. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"150", "-", 
      FractionBox[
       RowBox[{"200", "x"}], 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["y", "2"]}], " "}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cont", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"50", "+", 
        RowBox[{"5", "k"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"Contours", " ", "\[Rule]", " ", "cont"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotPoints", "\[Rule]", "60"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The contours are\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], 
   " "}]}]], "Input",
 CellChangeTimes->{{3.39955101075*^9, 3.399551011953125*^9}, {
  3.40018258240625*^9, 3.400182582671875*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the electrical potential  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  in the semi-infinite strip ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}], "<", "x", "<", 
    FractionBox["\[Pi]", "2"]}], ",", 
   RowBox[{"y", ">", "0"}]}]]],
 " that has the boundary values shown in Figure 11.42:\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"  ", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "2"], 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", "       ", "0"}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "   ", 
    RowBox[{
     RowBox[{"for", "   ", "y"}], ">", "0"}], ",", "\[IndentingNewLine]", 
    "    ", 
    RowBox[{
     RowBox[{"\[Phi]", 
      RowBox[{"(", 
       RowBox[{"y", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "0"}], ")"}]}], " ", "=", "     ", "50"}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "   ", 
    RowBox[{
     RowBox[{"for", "   ", "-", 
      FractionBox["\[Pi]", "2"]}], "<", "x", "<", 
     FractionBox["\[Pi]", "2"]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Phi]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}], 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", "   ", "100"}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "   ", 
    RowBox[{
     RowBox[{"for", "   ", "y"}], "<", "0."}]}]}]]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{542, 189},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  The result of Example 10.13 shows that the function  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"w", "  ", "=", "  ", 
    RowBox[{
     RowBox[{"u", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "v"}]}], "  ", "=", "  ", 
     RowBox[{"sin", " ", "z"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"sin", " ", "x", " ", "cosh", " ", "y"}], "  ", "+", "  ", 
     RowBox[{
     "\[ImaginaryI]", " ", "cos", " ", "x", "  ", "sinh", " ", "y"}]}]}]}]}]],
 "   \n\nis a conformal mapping of the semi-infinite strip  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}], "<", "x", "<", 
    FractionBox["\[Pi]", "2"]}], ",", 
   RowBox[{"y", ">", "0"}]}]]],
 "  onto the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "\tThe new problem in the w plane is to find the electrical potential  ",
 Cell[BoxData[
  RowBox[{"\[CapitalPhi]", 
   RowBox[{"(", 
    RowBox[{"u", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "v"}], ")"}]}]]],
 "  that satisfies the boundary values  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalPhi]", 
     RowBox[{"(", 
      RowBox[{"u", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], " ", "=", "     ", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{"for", "   ", "u"}], ">", "1"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalPhi]", 
     RowBox[{"(", 
      RowBox[{"u", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], " ", "=", "   ", "50"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{"for", "   ", "-", "1"}], "<", "u", "<", "1"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalPhi]", 
     RowBox[{"(", 
      RowBox[{"u", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], " ", "=", " ", "100"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{"for", "   ", "u"}], "<", 
    RowBox[{"-", "1."}]}]}]]],
 " "
}], "Text"],

Cell[TextData[{
 "This is a three-value Dirichlet problem in the upper half-plane defined by  \
",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]]],
 ".  For the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " plane, the solution in Equation ",
 StyleBox["(11-5)",
  FontColor->RGBColor[0, 0, 1]],
 " becomes  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalPhi]", 
     RowBox[{"(", 
      RowBox[{"u", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "v"}], ")"}]}], "  ", "=", "  ", 
    RowBox[{
     SubscriptBox["a", "2"], "  ", "+", "  ", 
     RowBox[{
      FractionBox["1", "\[Pi]"], 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "1"}], "2"], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", 
           RowBox[{"k", "-", "1"}]], "-", 
          SubscriptBox["a", "k"]}], ")"}], " ", "Arg", " ", 
        RowBox[{"(", 
         RowBox[{"w", "-", 
          SubscriptBox["u", "k"]}], ")"}]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", 
    RowBox[{"(", 
     RowBox[{"u", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    SubscriptBox["a", "2"], "  ", "+", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["a", "0"], "-", 
       SubscriptBox["a", "1"]}], "\[Pi]"], " ", "Arg", " ", 
     RowBox[{"(", 
      RowBox[{"w", "-", 
       SubscriptBox["u", "1"]}], ")"}]}], " ", "+", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["a", "1"], "-", 
       SubscriptBox["a", "2"]}], "\[Pi]"], " ", "Arg", " ", 
     RowBox[{"(", 
      RowBox[{"w", "-", 
       SubscriptBox["u", "2"]}], ")"}]}]}]}]}]],
 "\n\nHere we have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["a", "0"], "=", "100"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["a", "1"], "=", "50"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{"and", "  ", 
     SubscriptBox["a", "2"]}], "=", "0"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{"and", "  ", 
     SubscriptBox["u", "2"]}], "=", "1"}]}]]],
 ",  which we substitute into the above equation for  ",
 Cell[BoxData[
  RowBox[{"\[CapitalPhi]", 
   RowBox[{"(", 
    RowBox[{"u", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "v"}], ")"}]}]]],
 "  to obtain  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalPhi]", 
     RowBox[{"(", 
      RowBox[{"u", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "v"}], ")"}]}], "  ", "=", "  ", 
    RowBox[{"0", " ", "+", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"100", "-", "50"}], "\[Pi]"], " ", "Arg", " ", 
      RowBox[{"(", 
       RowBox[{"w", "-", 
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]}], ")"}]}], " ", "+", "  ", 
     RowBox[{
      FractionBox[
       RowBox[{"50", "-", "0"}], "\[Pi]"], " ", "Arg", " ", 
      RowBox[{"(", 
       RowBox[{"w", "-", "1"}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{"=", "   ", 
    RowBox[{
     RowBox[{
      FractionBox["50", "\[Pi]"], " ", "Arg", " ", 
      RowBox[{"(", 
       RowBox[{"w", "+", "1"}], ")"}]}], "  ", "+", "  ", 
     RowBox[{
      FractionBox["50", "\[Pi]"], " ", "Arg", " ", 
      RowBox[{"(", 
       RowBox[{"w", "-", "1"}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["50", "\[Pi]"], " ", "Arg", " ", 
      RowBox[{"(", 
       RowBox[{"u", "+", "1", "+", 
        RowBox[{"\[ImaginaryI]", " ", "v"}]}], ")"}]}], "  ", "+", "  ", 
     RowBox[{
      FractionBox["50", "\[Pi]"], " ", "Arg", " ", 
      RowBox[{"(", 
       RowBox[{"u", "-", "1", "+", 
        RowBox[{"\[ImaginaryI]", " ", "v"}]}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["50", "\[Pi]"], " ", "Arctan", " ", 
      RowBox[{"(", 
       FractionBox["v", 
        RowBox[{"u", "+", "1"}]], ")"}]}], "  ", "+", "  ", 
     RowBox[{
      FractionBox["50", "\[Pi]"], " ", "Arctan", " ", 
      RowBox[{"(", 
       FractionBox["v", 
        RowBox[{"u", "-", "1"}]], ")"}]}]}]}]}]}]],
 "    "
}], "Text"],

Cell[TextData[{
 "Now make the substitutions  ",
 Cell[BoxData[
  RowBox[{"u", " ", "=", " ", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
    RowBox[{"sin", " ", "x", " ", "cosh", " ", "y"}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"v", " ", "=", " ", 
   RowBox[{
    RowBox[{"v", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
    RowBox[{"cos", " ", "x", "  ", "sinh", " ", "y"}]}]}]]],
 "  to get the solultion  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  in the z plane  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"50", " "}], "\[Pi]"], "Arg", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"sin", 
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]}], ")"}]}], "  ", 
    "+", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"50", " "}], "\[Pi]"], "Arg", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"sin", 
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]}], ")"}]}]}]}]]],
 " \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox["50", "\[Pi]"], " ", "Arctan", " ", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"cos", " ", "x", "  ", "sinh", " ", "y"}], 
       RowBox[{"1", "+", 
        RowBox[{"sin", " ", "x", " ", "cosh", " ", "y"}]}]], ")"}]}], "  ", 
    "+", "  ", 
    RowBox[{
     FractionBox["50", "\[Pi]"], " ", "Arctan", " ", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"cos", " ", "x", "  ", "sinh", " ", "y"}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"sin", " ", "x", " ", "cosh", " ", "y"}]}]], ")"}]}]}]}]]]
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{260, 220},
  ImageMargins->0],
 " \n\n",
 "\t\t\tFigure 11.42  ",
 "The electrical potential ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " in the semi-infinite strip ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}], "<", "x", "<", 
    FractionBox["\[Pi]", "2"]}], ",", 
   RowBox[{"y", ">", "0"}]}]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.399550671234375*^9, 3.399550681078125*^9}, 
   3.506802327203125*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "2."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670671315625*^9, 3.50670671315625*^9}}],

Cell["\<\
Enter the boundary values in the w plane and construct the Dirichlet sum.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"u", "=", 
      RowBox[{"v", "=", 
       RowBox[{"w", "=", "0"}]}]}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"a", ",", "u", ",", "v", ",", "w"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "u", ",", "v", ",", "w", ",", "\[Phi]"}], "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "1"], " ", "=", " ", 
     RowBox[{"-", "1"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "2"], " ", "=", "  ", "1"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "0"], " ", "=", "  ", "100"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "1"], " ", "=", "  ", "50"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "2"], " ", "=", "  ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"w", " ", "=", " ", 
     RowBox[{"u", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "v"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], "=", 
     RowBox[{
      SubscriptBox["a", "2"], "+", 
      RowBox[{
       FractionBox["1", "\[Pi]"], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "0"], "-", 
         SubscriptBox["a", "1"]}], ")"}], 
       RowBox[{"Arg", "[", 
        RowBox[{"w", "-", 
         SubscriptBox["x", "1"]}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "\[Pi]"], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "1"], "-", 
         SubscriptBox["a", "2"]}], ")"}], 
       RowBox[{"Arg", "[", 
        RowBox[{"w", "-", 
         SubscriptBox["x", "2"]}], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[CapitalPhi][u,v] = \>\"", ",", 
      RowBox[{"\[CapitalPhi]", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399551023109375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "First use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the solution."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"cont", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"k", ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "100", ",", "10"}], "}"}]}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox["\[Pi]", "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", "0.000001", ",", "2"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", "cont"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[CapitalPhi][u,v] = \>\"", ",", 
      RowBox[{"\[CapitalPhi]", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The contours are\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"\[CapitalPhi]", "[", 
       RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399551026515625*^9, 3.399551027984375*^9}, {
  3.400182588390625*^9, 3.400182588609375*^9}}],

Cell[TextData[{
 "Then use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a 3D plot of the solution."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", "0.00001", ",", "2"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "16"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\"", ",", "\"\<\[CapitalPhi]\>\""}], 
       "}"}]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[CapitalPhi][u,v] = \>\"", ",", 
      RowBox[{"\[CapitalPhi]", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3995510319375*^9, 3.399551033484375*^9}, {
  3.40018259321875*^9, 3.40018259340625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "The function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", 
    RowBox[{"u", ",", "v"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     FractionBox["50", "\[Pi]"], " ", "Arctan", " ", 
     RowBox[{"(", 
      FractionBox["v", 
       RowBox[{"u", "+", "1"}]], ")"}]}], "  ", "+", "  ", 
    RowBox[{
     FractionBox["50", "\[Pi]"], " ", "Arctan", " ", 
     RowBox[{"(", 
      FractionBox["v", 
       RowBox[{"u", "-", "1"}]], ")"}]}]}]}]]],
 " is harmonic in the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "z", "]"}], ">", "0"}]]],
 ",  and takes on the desired boundary values."
}], "Text"],

Cell["\<\
Construct the solution in the z plane with a conformal mapping.  \
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"z", "=", "0"}], ";", " ", 
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "\[Phi]", ",", "\[CapitalPhi]"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Sin", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"50", " "}], "\[Pi]"], 
       RowBox[{"Arg", "[", 
        RowBox[{"u", "-", "1", "+", 
         RowBox[{"\[ImaginaryI]", " ", "v"}]}], "]"}]}], "+", 
      RowBox[{
       FractionBox[
        RowBox[{"50", " "}], "\[Pi]"], 
       RowBox[{"Arg", "[", 
        RowBox[{"u", "+", "1", "+", 
         RowBox[{"\[ImaginaryI]", " ", "v"}]}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"W", " ", "=", "  ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"U", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Re", "[", "W", "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"V", " ", "=", " ", 
      RowBox[{"Together", "[", 
       RowBox[{"ComplexExpand", "[", 
        RowBox[{
         RowBox[{"Im", "[", "W", "]"}], ",", 
         RowBox[{"TargetFunctions", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"U", ",", "V"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = u + \[ImaginaryI] v = \>\"", ",", 
      RowBox[{"U", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "V"}]}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[CapitalPhi][u,v] = \>\"", ",", 
      RowBox[{"\[CapitalPhi]", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[x,y] = \>\"", ",", "U"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v[x,y] = \>\"", ",", "V"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<\[Phi][x,y] = \[CapitalPhi][u(x,y),v(x,y)]\>\"", "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\[Phi][x,y] = \[CapitalPhi][\>\"", ",", "U", ",", "\"\<,\>\"", ",", 
      "V", ",", "\"\<]\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", 
     RowBox[{"Expand", "[", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399551037359375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the equipotentials. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"cont", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"k", ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "100", ",", "10"}], "}"}]}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox["\[Pi]", "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0.001", ",", "2"}], "}"}], ",", 
     RowBox[{"Contours", " ", "\[Rule]", " ", "cont"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotPoints", "\[Rule]", "60"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The contours are\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], 
   " "}]}]], "Input",
 CellChangeTimes->{{3.39955104109375*^9, 3.399551042546875*^9}, {
  3.40018260046875*^9, 3.400182600671875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Then use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a 3D plot of the solution."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox["\[Pi]", "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0.001", ",", "2"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "16"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\"", ",", "\"\<\[Phi]\>\""}], 
       "}"}]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399551052484375*^9, 3.3995510540625*^9}, 
   3.4001826055*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "The function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"50", " "}], "\[Pi]"], "Arg", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"sin", 
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]}], ")"}]}], " ", "+",
     " ", 
    RowBox[{
     FractionBox[
      RowBox[{"50", " "}], "\[Pi]"], "Arg", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"sin", 
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]}], ")"}]}]}]}]]],
 " is harmonic in the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 ",  and takes on the desired boundary values."
}], "Text"]
}, Closed]],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",
 InitializationCell->True]
}, Closed]]
},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{979, 616},
WindowMargins->{{2, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 123, 2, 29, "Text"],
Cell[1674, 50, 10248, 338, 419, "Text",
 Evaluatable->False],
Cell[11925, 390, 1384, 49, 94, "Text",
 Evaluatable->False],
Cell[13312, 441, 1180, 22, 169, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[14517, 467, 231, 6, 37, "Subsection"],
Cell[14751, 475, 497, 16, 100, "Text"],
Cell[15251, 493, 1085, 32, 149, "Input"],
Cell[16339, 527, 434, 16, 29, "Text",
 Evaluatable->False],
Cell[16776, 545, 1275, 38, 212, "Input"],
Cell[18054, 585, 141, 5, 29, "Text"],
Cell[18198, 592, 1685, 48, 192, "Input"],
Cell[19886, 642, 462, 16, 29, "Text"]
}, Closed]],
Cell[20363, 661, 1081, 38, 44, "Text",
 Evaluatable->False],
Cell[21447, 701, 2884, 50, 169, "Text",
 Evaluatable->False],
Cell[24334, 753, 6290, 207, 448, "Text"],
Cell[30627, 962, 24176, 406, 362, "Text"],
Cell[CellGroupData[{
Cell[54828, 1372, 231, 6, 37, "Subsection"],
Cell[55062, 1380, 644, 22, 118, "Text"],
Cell[55709, 1404, 1566, 48, 173, "Input"],
Cell[57278, 1454, 392, 14, 29, "Text",
 Evaluatable->False],
Cell[57673, 1470, 1539, 45, 252, "Input"],
Cell[59215, 1517, 141, 5, 29, "Text"],
Cell[59359, 1524, 1724, 49, 192, "Input"],
Cell[61086, 1575, 565, 20, 50, "Text"]
}, Closed]],
Cell[61666, 1598, 4198, 148, 100, "Text",
 Evaluatable->False],
Cell[65867, 1748, 4433, 75, 254, "Text",
 Evaluatable->False],
Cell[70303, 1825, 7794, 263, 528, "Text"],
Cell[78100, 2090, 18200, 305, 412, "Text"],
Cell[CellGroupData[{
Cell[96325, 2399, 223, 6, 37, "Subsection"],
Cell[96551, 2407, 63, 0, 29, "Text"],
Cell[96617, 2409, 1939, 59, 216, "Input"],
Cell[98559, 2470, 62, 0, 29, "Text"],
Cell[98624, 2472, 1340, 39, 172, "Input"],
Cell[99967, 2513, 141, 5, 29, "Text"],
Cell[100111, 2520, 2131, 62, 228, "Input"],
Cell[102245, 2584, 138, 4, 29, "Text",
 Evaluatable->False],
Cell[102386, 2590, 2749, 80, 328, "Input"],
Cell[105138, 2672, 3395, 101, 252, "Input"],
Cell[108536, 2775, 662, 22, 39, "Text"]
}, Closed]],
Cell[109213, 2800, 4869, 164, 97, "Text",
 Evaluatable->False],
Cell[114085, 2966, 5060, 86, 254, "Text",
 Evaluatable->False],
Cell[119148, 3054, 3453, 122, 195, "Text"],
Cell[122604, 3178, 3979, 126, 352, "Text"],
Cell[126586, 3306, 3865, 131, 201, "Text"],
Cell[130454, 3439, 26017, 447, 349, "Text"],
Cell[CellGroupData[{
Cell[156496, 3890, 229, 6, 37, "Subsection"],
Cell[156728, 3898, 116, 3, 29, "Text"],
Cell[156847, 3903, 3226, 95, 362, "Input"],
Cell[160076, 4000, 1206, 38, 61, "Text"],
Cell[161285, 4040, 2376, 69, 228, "Input"],
Cell[163664, 4111, 138, 4, 29, "Text",
 Evaluatable->False],
Cell[163805, 4117, 3570, 104, 370, "Input"],
Cell[167378, 4223, 3168, 95, 264, "Input"],
Cell[170549, 4320, 620, 19, 43, "Text"]
}, Closed]],
Cell[171184, 4342, 4301, 150, 100, "Text",
 Evaluatable->False],
Cell[175488, 4494, 4185, 71, 169, "Text",
 Evaluatable->False],
Cell[179676, 4567, 1223, 39, 161, "Text"],
Cell[180902, 4608, 8908, 165, 260, "Text"],
Cell[CellGroupData[{
Cell[189835, 4777, 101, 1, 29, "Text"],
Cell[189939, 4780, 633, 23, 47, "Text",
 Evaluatable->False],
Cell[190575, 4805, 7565, 127, 189, "Text",
 Evaluatable->False],
Cell[198143, 4934, 4426, 157, 306, "Text"],
Cell[202572, 5093, 4474, 154, 196, "Text"],
Cell[207049, 5249, 16921, 290, 303, "Text"],
Cell[CellGroupData[{
Cell[223995, 5543, 110, 2, 29, "Text"],
Cell[224108, 5547, 1369, 46, 56, "Text",
 Evaluatable->False],
Cell[225480, 5595, 4071, 117, 490, "Input"],
Cell[229554, 5714, 260, 10, 29, "Text",
 Evaluatable->False],
Cell[229817, 5726, 1387, 32, 112, "Input"],
Cell[231207, 5760, 804, 29, 29, "Text",
 Evaluatable->False],
Cell[232014, 5791, 2094, 51, 152, "Input"],
Cell[234111, 5844, 193, 5, 29, "Text",
 Evaluatable->False],
Cell[234307, 5851, 1716, 47, 232, "Input"],
Cell[236026, 5900, 115, 2, 29, "Text",
 Evaluatable->False],
Cell[236144, 5904, 10566, 287, 665, "Input"],
Cell[246713, 6193, 750, 27, 55, "Text"]
}, Open  ]]
}, Closed]],
Cell[247490, 6224, 5016, 170, 200, "Text"],
Cell[252509, 6396, 4383, 145, 391, "Text"],
Cell[CellGroupData[{
Cell[256917, 6545, 225, 5, 37, "Subsection"],
Cell[257145, 6552, 66, 0, 29, "Text"],
Cell[257214, 6554, 3606, 105, 423, "Input"],
Cell[260823, 6661, 136, 5, 29, "Text"],
Cell[260962, 6668, 2034, 60, 231, "Input"]
}, Closed]],
Cell[263011, 6731, 3110, 104, 127, "Text",
 Evaluatable->False],
Cell[266124, 6837, 23043, 381, 203, "Text",
 Evaluatable->False],
Cell[289170, 7220, 951, 30, 146, "Text"],
Cell[290124, 7252, 2593, 86, 104, "Text"],
Cell[292720, 7340, 5905, 200, 331, "Text"],
Cell[298628, 7542, 3287, 112, 117, "Text"],
Cell[301918, 7656, 4159, 87, 279, "Text"],
Cell[CellGroupData[{
Cell[306102, 7747, 223, 5, 37, "Subsection"],
Cell[306328, 7754, 97, 2, 29, "Text"],
Cell[306428, 7758, 2117, 66, 268, "Input"],
Cell[308548, 7826, 135, 5, 29, "Text"],
Cell[308686, 7833, 1761, 49, 208, "Input"],
Cell[310450, 7884, 129, 5, 29, "Text"],
Cell[310582, 7891, 1055, 28, 92, "Input"],
Cell[311640, 7921, 653, 22, 38, "Text"],
Cell[312296, 7945, 89, 2, 29, "Text"],
Cell[312388, 7949, 4590, 134, 488, "Input"],
Cell[316981, 8085, 136, 5, 29, "Text"],
Cell[317120, 8092, 1740, 49, 212, "Input"],
Cell[318863, 8143, 129, 5, 29, "Text"],
Cell[318995, 8150, 1055, 30, 106, "Input"],
Cell[320053, 8182, 923, 34, 53, "Text"]
}, Closed]],
Cell[320991, 8219, 435, 8, 26, "Text"],
Cell[CellGroupData[{
Cell[321451, 8231, 407, 7, 29, "Text"],
Cell[321861, 8240, 130, 3, 31, "Input",
 InitializationCell->True]
}, Closed]]
}
]
*)

(* End of internal cache information *)
