(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    382181,      10584]
NotebookOptionsPosition[    373714,      10344]
NotebookOutlinePosition[    374298,      10367]
CellTagsIndexPosition[    374255,      10364]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[StyleBox["11.9  The Schwarz-Christoffel Transformation",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tIn Chapter 10 we mentioned the Riemann mapping theorem:  If ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " is any simply connected domain in the plane (other than the entire plane \
itself), then there exists a one-to-one conformal mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  that maps ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " onto the unit disk  ",
 Cell[BoxData[
  RowBox[{"|", "w", "|", 
   RowBox[{"<", "1"}]}]]],
 ".  The Mobius transformation ",
 Cell[BoxData[
  RowBox[{"w", "=", " ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "=", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "z"}], ")"}]}], 
     RowBox[{"1", "-", "z"}]]}]}]]],
 " is a one-to-one conformal mapping of the unit disk  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", "1"}]}]]],
 "  onto the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]]],
 ", and the inverse is ",
 Cell[BoxData[
  RowBox[{"z", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["S", 
      RowBox[{"-", "1"}]], 
     RowBox[{"(", "w", ")"}]}], "=", 
    FractionBox[
     RowBox[{"w", "-", "\[ImaginaryI]"}], 
     RowBox[{"w", "+", "\[ImaginaryI]"}]]}]}]]],
 ".  Hence the Riemann mapping theorem could have been stated:  If ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " is any simply connected domain in the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 "-plane, then there exists a one-to-one conformal mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  that maps the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 " onto ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  In this section we will introduce the Schwarz-Christoffel formula for \
constructing a conformal mapping from the upper half plane onto a region ",
 StyleBox["G",
  FontFamily->"Courier New"],
 " bounded by a polygonal curve.  At the end of this section we will \
introduce the remarkable mappings of the unit disk onto an equilateral \
triangle and a square. "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{648, 175},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\tTo proceed further, we must review the rotational effect of a conformal \
mapping ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " at a point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  If the contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " has the parameterization  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "y", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 ",  then a vector ",
 Cell[BoxData["\[ScriptCapitalT]"]],
 " tangent to ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " at the point ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{"z", 
    RowBox[{"(", 
     SubscriptBox["t", "0"], ")"}]}]}]]],
 " is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"\[ScriptCapitalT]", "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"z", "'"}], 
     RowBox[{"(", 
      SubscriptBox["t", "0"], ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "'"}], 
      RowBox[{"(", 
       SubscriptBox["t", "0"], ")"}]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"y", "'"}], 
      RowBox[{"(", 
       SubscriptBox["t", "0"], ")"}]}]}]}]}]]],
 ".  \n\nThe image of ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a contour ",
 StyleBox["K",
  FontFamily->"Courier New"],
 " given by  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"x", 
        RowBox[{"(", "t", ")"}]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       RowBox[{"y", 
        RowBox[{"(", "t", ")"}]}]}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "v", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"x", 
        RowBox[{"(", "t", ")"}]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       RowBox[{"y", 
        RowBox[{"(", "t", ")"}]}]}], ")"}]}]}]}]]],
 ",  and a vector ",
 StyleBox["T",
  FontFamily->"Courier New"],
 " tangent to ",
 StyleBox["K",
  FontFamily->"Courier New"],
 " at the point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "0"], "=", 
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 "  is \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"T", " ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "'"}], 
     RowBox[{"(", 
      SubscriptBox["t", "0"], ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}], 
     RowBox[{"z", "'"}], 
     RowBox[{"(", 
      SubscriptBox["t", "0"], ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "If the angle of inclination of  ",
 Cell[BoxData["\[ScriptCapitalT]"]],
 "  is  ",
 Cell[BoxData[
  RowBox[{"\[Beta]", "=", 
   RowBox[{"Arg", " ", 
    RowBox[{"z", "'"}], 
    RowBox[{"(", 
     SubscriptBox["t", "0"], ")"}]}]}]]],
 ",  then the angle of inclination of ",
 StyleBox["T",
  FontFamily->"Courier New"],
 " is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Arg", " ", "T"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"Arg", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"f", "'"}], 
       RowBox[{"(", 
        SubscriptBox["z", "0"], ")"}], 
       RowBox[{"z", "'"}], 
       RowBox[{"(", 
        SubscriptBox["t", "0"], ")"}]}], ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"Arg", " ", 
      RowBox[{"f", "'"}], 
      RowBox[{"(", 
       SubscriptBox["z", "0"], ")"}]}], "  ", "+", "  ", "\[Beta]"}]}]}]]],
 ".  \n\nHence the angle of inclination of the tangent  ",
 Cell[BoxData["\[ScriptCapitalT]"]],
 "  to ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " is rotated through the angle  ",
 Cell[BoxData[
  RowBox[{"Arg", " ", 
   RowBox[{"f", "'"}], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 "  to obtain the angle of inclination of the tangent ",
 StyleBox["T",
  FontFamily->"Courier New"],
 " to ",
 StyleBox["K",
  FontFamily->"Courier New"],
 " at the point ",
 Cell[BoxData[
  SubscriptBox["w", "0"]]],
 "."
}], "Text"],

Cell[TextData[{
 "\tMany applications involving conformal mappings require the construction \
of a one-to-one conformal mapping from the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 "  onto a domain ",
 StyleBox["G",
  FontFamily->"Courier New"],
 " in the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 "-plane where the boundary consists of straight line segments.  Let's \
consider the case where ",
 StyleBox["G",
  FontFamily->"Courier New"],
 " is the interior of a polygon ",
 StyleBox["P",
  FontFamily->"Courier New"],
 " with vertices  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["w", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["w", "n"]}]]],
 "  specified in the positive sense (counterclockwise).  We want to find a \
function  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  with the property  \n\n",
 StyleBox["(11-38)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "k"], "=", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", 
       SubscriptBox["x", "n"], ")"}], "  ", "for", "  ", "k"}], "=", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "2", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"n", "-", "1"}]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "n"], "=", 
   RowBox[{"f", 
    RowBox[{"(", "\[Infinity]", ")"}]}]}]]],
 "\n\n\t\t\twhere\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["x", "1"], "<", 
     SubscriptBox["x", "2"], "<"}], "..."}], "<", 
   SubscriptBox["x", 
    RowBox[{"n", "-", "1"}]], "<", "\[Infinity]"}]]],
 ".  \n\nTwo German mathematicians ",
 StyleBox[ButtonBox["Herman Amandus Schwarz",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Schwarz.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " (1843-1921) and ",
 StyleBox[ButtonBox["Elwin Bruno Christoffel",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/\
Christoffel.html"], None}],
  FontVariations->{"Underline"->True}],
 " (1829-1900) independently discovered a method for finding f, and that is \
our next theorem."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Theorem 11.6 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Schwarz-Christoffel Formula",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/Schwarz-ChristoffelMapping.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 StyleBox["P",
  FontFamily->"Courier New"],
 " be a polygon in the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " plane with vertices  ",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    SubscriptBox["w", "1"],
    FontSize->14], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[
    SubscriptBox["w", "2"],
    FontSize->14], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[
    SubscriptBox["w", "n"],
    FontSize->14]}]]],
 "  and exterior angles  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    StyleBox["\[Alpha]",
     FontSize->14], "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox[
    StyleBox["\[Alpha]",
     FontSize->14], "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox[
    StyleBox["\[Alpha]",
     FontSize->14], "n"]}]]],
 ",  where  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Pi]"}], "<", 
   SubscriptBox[
    StyleBox["\[Alpha]",
     FontSize->14], "k"], "<", "\[Pi]"}]]],
 ".  There exists a one-to-one conformal mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  from the upper half plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 "  onto ",
 StyleBox["G",
  FontFamily->"Courier New"],
 " that satisfies the boundary conditions  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["w", "k"], "=", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", 
       SubscriptBox["x", "k"], ")"}], "   ", 
      StyleBox["for",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "   ", "k"}], "=", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "2", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{"n", "-", 
     RowBox[{"1", "    ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      SubscriptBox["w", "n"]}]}], "=", 
    RowBox[{"f", 
     RowBox[{"(", "\[Infinity]", ")"}]}]}]}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      StyleBox["where",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "   ", 
      SubscriptBox[
       StyleBox["x",
        FontSize->14], "1"]}], "<", 
     SubscriptBox[
      StyleBox["x",
       FontSize->14], "2"], "<"}], "..."}], "<", 
   SubscriptBox[
    StyleBox["x",
     FontSize->14], 
    RowBox[{"n", "-", "1"}]], "<", 
   RowBox[{"\[Infinity]", "."}]}]}]],
 "  \n\nThe derivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " is   \n\n",
 StyleBox["(11-39)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], " ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"A", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", 
         SubscriptBox["x", "1"]}], ")"}], 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", 
         SubscriptBox["x", "2"]}], ")"}], 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]]}], "..."}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", 
       SubscriptBox["x", 
        RowBox[{"n", "-", "1"}]]}], ")"}], 
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["\[Alpha]", 
        RowBox[{"n", "-", "1"}]]}], "/", "\[Pi]"}]]}]}]]],
 "  \n\nand the function ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " can be expressed as an indefinite integral,  \n\n",
 StyleBox["(11-40)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"B", " ", "+", " ", 
    RowBox[{"A", 
     RowBox[{
      StyleBox["\[Integral]",
       FontSize->18], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SubscriptBox["x", "1"]}], ")"}], 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SubscriptBox["x", "2"]}], ")"}], 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], 
       "\[CenterEllipsis]", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SubscriptBox["x", 
           RowBox[{"n", "-", "1"}]]}], ")"}], 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["\[Alpha]", 
           RowBox[{"n", "-", "1"}]]}], "/", "\[Pi]"}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}]]],
 " \n\nwhere ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["B",
  FontFamily->"Courier New"],
 " are suitably chosen constants.  Two of the points  ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox[
    StyleBox["x",
     FontSize->14], "k"], "}"}]]],
 "  may be chosen arbitrarily, and the constants ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["B",
  FontFamily->"Courier New"],
 " determine the size and position of ",
 StyleBox["P",
  FontFamily->"Courier New"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{614, 314},
  ImageMargins->0],
 "  \n\n",
 "\t\tFigure 11.70  ",
 "A Schwarz-Christoffel mapping with ",
 Cell[BoxData[
  RowBox[{"n", "=", "5"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "+", 
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "+", 
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "+", 
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "4"]}], ">", "\[Pi]"}]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.399556518015625*^9, 3.399556518203125*^9}, {
   3.39955657071875*^9, 3.39955657621875*^9}, 3.506803488046875*^9}],

Cell[TextData[{
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{625, 300},
  ImageMargins->0],
 "   \n\n",
 "\t\t     Figure 11.71  ",
 "A Schwarz-Christoffel mapping with ",
 Cell[BoxData[
  RowBox[{"n", "=", "5"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "+", 
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "+", 
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "+", 
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "4"]}], "\[LessEqual]", "\[Pi]"}]]]
}], "Text",
 CellChangeTimes->{{3.399556516875*^9, 3.399556517015625*^9}, {
  3.3995565859375*^9, 3.399556591546875*^9}, {3.5068032810625*^9, 
  3.506803284875*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 11.6 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
 "\tEquation ",
 StyleBox["(11-40)",
  FontColor->RGBColor[0, 0, 1]],
 " gives a representation for f in terms of an indefinite integral.  Note \
that these integrals do not represent elementary functions unless the image \
is an infinite region.  Also, the integral will involve a multivalued \
function, and we must select a specific branch to fit the boundary values \
specified in the problem.  Table 11.2 is useful for our purposes."
}], "Text"],

Cell["\<\
\tThe following table of integrals is useful for hand computations and are \
compatible with the versions used in the textbook.  Occasionally they have \
been adjusted by a constant of integration which could be changed for \
indefinite integrands.  Also, depending on which quadrant you use it might be \
necessary to use various combinations of the branches of the multivalued \
terms. \
\>", "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[BoxData[
  RowBox[{"  ", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Integral]", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["z", "2"]}], ")"}], 
         FractionBox["1", "2"]]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
     RowBox[{"Arcsin", " ", "z"}]}], "\n", "  ", 
    RowBox[{
     RowBox[{"\[Integral]", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
         FractionBox["1", "2"]]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"Log", 
       RowBox[{"(", 
        RowBox[{"z", "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
          FractionBox["1", "2"]]}], ")"}]}], " ", "-", " ", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "2"]}]}], "\n", "  ", 
    RowBox[{
     RowBox[{"\[Integral]", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
         FractionBox["1", "2"]]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
     RowBox[{"\[ImaginaryI]", " ", "Arcsin", " ", "z"}]}]}]}]], "Input"],
 "\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"          ", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Integral]", " ", 
      RowBox[{
       FractionBox[
        SuperscriptBox["1", 
         StyleBox["1",
          FontColor->GrayLevel[1]]], 
        RowBox[{
         SuperscriptBox["z", "2"], "+", "1"}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
     RowBox[{"Arctan", " ", "z"}]}], "\[IndentingNewLine]", "\n", 
    "          ", 
    RowBox[{
     RowBox[{"\[Integral]", " ", 
      RowBox[{
       FractionBox[
        SuperscriptBox["1", 
         StyleBox["1",
          FontColor->GrayLevel[1]]], 
        RowBox[{
         SuperscriptBox["z", "2"], "+", "1"}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
     RowBox[{
      FractionBox["\[ImaginaryI]", "2"], "Log", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", "+", "z"}], 
        RowBox[{"\[ImaginaryI]", "-", "z"}]], ")"}]}]}]}]}]], "Input"],
 "\n\t\t\t\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"\[Integral]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"z", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
        FractionBox["1", "2"]]}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"-", " ", "Arcsin"}], 
    RowBox[{"(", 
     FractionBox["1", "z"], ")"}]}]}], "\n", 
  RowBox[{
   RowBox[{"\[Integral]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"z", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
        FractionBox["1", "2"]]}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{"\[ImaginaryI]", " ", "Log", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["1", "z"], " ", "+", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox["z", "2"]], "-", "1"}], ")"}], 
       FractionBox["1", "2"]]}], ")"}]}]}]}], "Input"],
 "\n\t\t\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{"  ", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Integral]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"z", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          FractionBox["1", "2"]]}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"-", " ", "2"}], " ", "Arctanh", 
      RowBox[{"(", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        FractionBox["1", "2"]], ")"}]}]}], "\n", "  ", 
    RowBox[{
     RowBox[{"\[Integral]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"z", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          FractionBox["1", "2"]]}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
     RowBox[{"Log", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"1", "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          FractionBox["1", "2"]]}], 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          FractionBox["1", "2"]]}]], ")"}]}]}]}]}]], "Input"],
 "\n\t\t\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Integral]", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["z", "2"]}], ")"}], 
        FractionBox["1", "2"]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", "z", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["z", "2"]}], ")"}], 
        FractionBox["1", "2"]]}], "  ", "+", "  ", 
      RowBox[{
       FractionBox["1", "2"], "Arcsin", " ", "z"}]}]}], "\n", " ", 
    RowBox[{
     RowBox[{"\[Integral]", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["z", "2"]}], ")"}], 
        FractionBox["1", "2"]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{
       FractionBox["\[ImaginaryI]", "2"], "z", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
        FractionBox["1", "2"]]}], "  ", "-", "  ", 
      RowBox[{
       FractionBox["\[ImaginaryI]", "2"], " ", "Log", 
       RowBox[{"(", 
        RowBox[{"z", " ", "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
          FractionBox["1", "2"]]}], ")"}]}]}]}]}]}]], "Input"]
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 StyleBox["Table 11.2",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Indefinite integrals."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["Exploration",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706872203125*^9, 3.50670687221875*^9}}],

Cell["\<\
\tThe following table of integrals is useful for hand computations and are \
compatible with the versions used in the textbook.  Occasionally they have \
been adjusted by a constant of integration which could be changed for \
indefinite integrands.  Also, depending on which quadrant you use it might be \
necessary to use various combinations of the branches of the multivalued \
terms. \
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{"ArcSin", "[", "z", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      "\"\<\[Integral]\!\(\*FractionBox[\(1\), SuperscriptBox[\((1 - \
\*SuperscriptBox[\(z\), \(2\)])\), FractionBox[\(1\), \(2\)]]]\)\
\[DifferentialD]z  \[Equal]  ArcSin[z]\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399556609390625*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"Log", "[", 
       RowBox[{"z", "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
         FractionBox["1", "2"]]}], "]"}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "2"]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      "\"\<\[Integral]\!\(\*FractionBox[\(1\), \
SuperscriptBox[\((\*SuperscriptBox[\(z\), \(2\)] - 1)\), FractionBox[\(1\), \
\(2\)]]]\)\[DifferentialD]z  \[Equal]  Log[z+(\!\(\*SuperscriptBox[\(z\), \(2\
\)]\)-1\!\(\*SuperscriptBox[\()\), FractionBox[\(1\), \
\(2\)]]\)]-\!\(\*FractionBox[\(\[ImaginaryI]\\\ \[Pi]\), \(2\)]\)\>\""}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"Together", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "z", "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3995566105*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"ArcSin", "[", "z", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      "\"\<\[Integral]\!\(\*FractionBox[\(1\), \
SuperscriptBox[\((\*SuperscriptBox[\(z\), \(2\)] - 1)\), FractionBox[\(1\), \
\(2\)]]]\)\[DifferentialD]z  \[Equal]  \[ImaginaryI] ArcSin[z]\>\""}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f'[z] = \!\(\*FractionBox[\(\((\(-\[ImaginaryI]\))\)\\\ \
\[ImaginaryI]\), \(\(\\\ \)\(SqrtBox[\(-1\)] \*SqrtBox[\(1 - \
\*SuperscriptBox[\(z\), \(2\)]\)]\)\)]\)\>\"", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f'[z] = \!\(\*FractionBox[\(1\), \(\(\\\ \
\)\(SqrtBox[\*SuperscriptBox[\(z\), \(2\)] - 1]\)\)]\)\>\"", " ", "]"}], 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399556611875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{"ArcTan", "[", "z", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      "\"\<\[Integral]\!\(\*FractionBox[\(1\), \(\*SuperscriptBox[\(z\), \
\(2\)] + 1\)]\)\[DifferentialD]z  \[Equal]  ArcTan[z]\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3995566135*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      FractionBox["\[ImaginaryI]", "2"], 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", "+", "z"}], 
        RowBox[{"\[ImaginaryI]", "-", "z"}]], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      "\"\<\[Integral]\!\(\*FractionBox[\(1\), \(\*SuperscriptBox[\(z\), \
\(2\)] + 1\)]\)\[DifferentialD]z  \[Equal]  \!\(\*FractionBox[\(\[ImaginaryI]\
\), \(2\)]\)Log[\!\(\*FractionBox[\(\[ImaginaryI] + z\), \(\[ImaginaryI] - \
z\)]\)]\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"Together", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "z", "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      FractionBox[
       RowBox[{"Numerator", "[", 
        RowBox[{"Together", "[", 
         RowBox[{
          RowBox[{"f", "'"}], "[", "z", "]"}], "]"}], "]"}], 
       RowBox[{"ComplexExpand", "[", 
        RowBox[{"Denominator", "[", 
         RowBox[{"Together", "[", 
          RowBox[{
           RowBox[{"f", "'"}], "[", "z", "]"}], "]"}], "]"}], "]"}]]}], " ", 
     "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3995566150625*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", " ", 
     RowBox[{"-", 
      RowBox[{"ArcSin", "[", 
       FractionBox["1", "z"], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      "\"\<\[Integral]\!\(\*FractionBox[\(1\), \(z \
\*SuperscriptBox[\((\*SuperscriptBox[\(z\), \(2\)] - 1)\), FractionBox[\(1\), \
\(2\)]]\)]\)\[DifferentialD]z  \[Equal]  - ArcSin[\!\(\*FractionBox[\(1\), \
\(z\)]\)]\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      FractionBox[
       RowBox[{"Numerator", "[", 
        RowBox[{
         RowBox[{"f", "'"}], "[", "z", "]"}], "]"}], 
       RowBox[{"Map", "[", 
        RowBox[{"PowerExpand", ",", 
         RowBox[{"Denominator", "[", 
          RowBox[{
           RowBox[{"f", "'"}], "[", "z", "]"}], "]"}]}], "]"}]]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399556616859375*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"Log", "[", 
       RowBox[{
        FractionBox["1", "z"], " ", "+", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", 
            SuperscriptBox["z", "2"]], "-", "1"}], ")"}], 
         FractionBox["1", "2"]]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      "\"\<\[Integral]\!\(\*FractionBox[\(1\), \(z \
\*SuperscriptBox[\((\*SuperscriptBox[\(z\), \(2\)] - 1)\), FractionBox[\(1\), \
\(2\)]]\)]\)\[DifferentialD]z  \[Equal]  \[ImaginaryI] Log[\!\(\*FractionBox[\
\(1\), \(z\)]\) + (\!\(\*FractionBox[\(1\), SuperscriptBox[\(z\), \(2\)]]\)-1\
\!\(\*SuperscriptBox[\()\), FractionBox[\(1\), \(2\)]]\)]\>\""}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      FractionBox[
       RowBox[{"Numerator", "[", 
        RowBox[{"Together", "[", 
         RowBox[{
          RowBox[{"f", "'"}], "[", "z", "]"}], "]"}], "]"}], 
       RowBox[{"Map", "[", 
        RowBox[{"PowerExpand", ",", 
         RowBox[{"Denominator", "[", 
          RowBox[{"Together", "[", 
           RowBox[{
            RowBox[{"f", "'"}], "[", "z", "]"}], "]"}], "]"}]}], "]"}]]}], 
     " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f'[z] = \!\(\*FractionBox[\(1\), \(z\\\ \
\*SqrtBox[\(\*SuperscriptBox[\(z\), \(2\)] - 1\)]\)]\)\>\"", " ", "]"}], 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399556618546875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"-", " ", "2"}], " ", 
      RowBox[{"ArcTanh", "[", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        FractionBox["1", "2"]], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      "\"\<\[Integral]\!\(\*FractionBox[\(1\), \(z \*SuperscriptBox[\((z + 1)\
\), FractionBox[\(1\), \(2\)]]\)]\)\[DifferentialD]z  \[Equal]  -2 \
ArcTanh[(z+1\!\(\*SuperscriptBox[\()\), FractionBox[\(1\), \(2\)]]\)]\>\""}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399556621546875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"1", "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         FractionBox["1", "2"]]}], 
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         FractionBox["1", "2"]]}]], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      "\"\<\[Integral]\!\(\*FractionBox[\(1\), \(z \*SuperscriptBox[\((z + 1)\
\), FractionBox[\(1\), \(2\)]]\)]\)\[DifferentialD]z  \[Equal]  \
Log[\!\(\*FractionBox[\(1 - \*SuperscriptBox[\((z + 1)\), FractionBox[\(1\), \
\(2\)]]\), \(1 + \*SuperscriptBox[\((z + 1)\), FractionBox[\(1\), \
\(2\)]]\)]\)]\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"Together", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "z", "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      FractionBox[
       RowBox[{"Numerator", "[", 
        RowBox[{"Together", "[", 
         RowBox[{
          RowBox[{"f", "'"}], "[", "z", "]"}], "]"}], "]"}], 
       RowBox[{"FullSimplify", "[", 
        RowBox[{"Denominator", "[", 
         RowBox[{"Together", "[", 
          RowBox[{
           RowBox[{"f", "'"}], "[", "z", "]"}], "]"}], "]"}], "]"}]]}], " ", 
     "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399556629*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", " ", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", "z", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["z", "2"]}], ")"}], 
        FractionBox["1", "2"]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"ArcSin", "[", "z", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      "\"\<\[Integral](1-\!\(\*SuperscriptBox[\(z\), \
\(2\)]\)\!\(\*SuperscriptBox[\()\), FractionBox[\(1\), \(2\)]]\)\
\[DifferentialD]z  \[Equal]  \!\(\*FractionBox[\(1\), \(2\)]\) z \
(1-\!\(\*SuperscriptBox[\(z\), \(2\)]\)\!\(\*SuperscriptBox[\()\), \
FractionBox[\(1\), \(2\)]]\)+\!\(\*FractionBox[\(1\), \
\(2\)]\)ArcSin[z]\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"Together", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "z", "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39955663075*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", " ", 
     RowBox[{
      RowBox[{
       FractionBox["\[ImaginaryI]", "2"], "z", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
        FractionBox["1", "2"]]}], "-", 
      RowBox[{
       FractionBox["\[ImaginaryI]", "2"], " ", 
       RowBox[{"Log", "[", 
        RowBox[{"z", " ", "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
          FractionBox["1", "2"]]}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      "\"\<\[Integral](1-\!\(\*SuperscriptBox[\(z\), \
\(2\)]\)\!\(\*SuperscriptBox[\()\), FractionBox[\(1\), \(2\)]]\)\
\[DifferentialD]z  \[Equal]\!\(\*FractionBox[\(\[ImaginaryI]\), \(2\)]\)z (\!\
\(\*SuperscriptBox[\(z\), \(2\)]\)-1\!\(\*SuperscriptBox[\()\), \
FractionBox[\(1\), \(2\)]]\)-\!\(\*FractionBox[\(\[ImaginaryI]\), \(2\)]\) \
Log[z +(\!\(\*SuperscriptBox[\(z\), \(2\)]\)-1\!\(\*SuperscriptBox[\()\), \
FractionBox[\(1\), \(2\)]]\)]\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\\n\>\"", ",", "\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{"Together", "[", 
        RowBox[{
         RowBox[{"f", "'"}], "[", "z", "]"}], "]"}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f'[z] = \!\(\*SqrtBox[\(1 - \*SuperscriptBox[\(z\), \
\(2\)]\)]\)\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399556632640625*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 11.26.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the Schwarz-Christoffel formula to verify that  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{"Arcsin", " ", "z"}]}]}]]],
 "  maps the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 "  onto the semi infinite strip  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"-", "\[Pi]"}], "2"], "<", "u", "<", 
    FractionBox["\[Pi]", "2"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   RowBox[{"v", ">", "0"}]}]]],
 "  shown in Figure 11.72."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{358, 175},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\t\t\tFigure 11.72  ",
 "The region with ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", 
    FractionBox["\[Pi]", "2"]}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    FractionBox["\[Pi]", "2"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", 
    FractionBox["\[Pi]", "2"]}]}]]],
 "."
}], "Text",
 CellChangeTimes->{3.5068033090625*^9}],

Cell[TextData[{
 "Solution.  If we choose  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "1"}]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", 
    FractionBox["\[Pi]", "2"]}]}]]],
 ",  then the exterior angles are  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    FractionBox["\[Pi]", "2"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", 
    FractionBox["\[Pi]", "2"]}]}]]],
 ",  and Equation ",
 StyleBox["(11-39)",
  FontColor->RGBColor[0, 0, 1]],
 " for ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " becomes  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "1"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]]}]}], " ", 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         FractionBox["\[Pi]", "2"], ")"}]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         FractionBox["\[Pi]", "2"], ")"}]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", " ", 
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
       FractionBox["1", "2"]]]}]}]}]}]],
 " "
}], "Text"],

Cell[TextData[{
 "Then, using Table 11.2, the indefinite integral becomes \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"\[Integral]", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
         FractionBox["1", "2"]]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "+", "  ", "B"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "\[Cross]", "\[ImaginaryI]"}], " ", "Arcsin", " ", "z"}], 
     "  ", "+", "  ", "B"}]}]}]}],
  AspectRatioFixed->True],
 "  \n\nUsing the image values  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}]}], " ", "=", " ", 
   RowBox[{"-", 
    FractionBox["\[Pi]", "2"]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "1", ")"}]}], " ", "=", " ", 
   FractionBox["\[Pi]", "2"]}]]],
 ", we obtain the system   \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "\[Cross]", "\[ImaginaryI]"}], " ", "Arcsin", " ", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"-", "\[Pi]"}], "2"], ")"}]}], "  ", "+", "  ", "B"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"  ", 
   RowBox[{
    FractionBox["\[Pi]", "2"], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "\[Cross]", "\[ImaginaryI]"}], " ", "Arcsin", 
      RowBox[{"(", 
       FractionBox["\[Pi]", "2"], ")"}]}], "  ", "+", "  ", "B"}]}]}]}]],
 " \n\nand simplifies to be \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], "A"}], "  ", "+", "  ", "B"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"  ", 
   RowBox[{
    FractionBox["\[Pi]", "2"], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["\[Pi]", "2"], "\[ImaginaryI]", " ", "A"}], "  ", "+", "  ",
      "B"}]}]}]}]],
 " \n\nwhich we can solve to obtain  ",
 Cell[BoxData[
  RowBox[{"B", "=", 
   RowBox[{
    RowBox[{"0", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "A"}], "=", 
    RowBox[{"-", "\[ImaginaryI]"}]}]}]]],
 ".  Hence the required function is \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"Arcsin", " ", "z"}]}]]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"11.26", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706877359375*^9, 3.506706877359375*^9}}],

Cell[TextData[{
 "Enter the formula ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{" ", "A"}], 
    SqrtBox[
     RowBox[{
      SuperscriptBox["z", "2"], " ", "-", " ", "1"}]]]}]],
  AspectRatioFixed->True],
 " and integrate it to construct  f(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"A", ",", "B", ",", "f", ",", "f1", ",", "z"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], " ", "=", 
     FractionBox[
      RowBox[{" ", "A"}], 
      SqrtBox[
       RowBox[{
        SuperscriptBox["z", "2"], " ", "-", " ", "1"}]]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"B", " ", "+", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         RowBox[{" ", "A"}], 
         SqrtBox[
          RowBox[{
           SuperscriptBox["z", "2"], " ", "-", " ", "1"}]]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = B + \[Integral] \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3995566841875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "   No matter how tempting the integrand  ",
 Cell[BoxData[
  RowBox[{"B", "+", 
   RowBox[{"A", " ", 
    RowBox[{"Log", "[", 
     RowBox[{"z", "+", 
      SqrtBox[
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["z", "2"]}]]}], "]"}]}]}]]],
 "  may seem, the logarithm does not have the proper branch cut for this \
problem, and we must use the familiar integrand  ",
 Cell[BoxData[
  RowBox[{"B", " ", "+", " ", 
   RowBox[{"A", "  ", 
    RowBox[{"ArcSin", "[", "z", "]"}]}]}]]],
 ".  Switching the order of terms in the square root will solve this problem."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"eq1", ",", "eq2", ",", "f", ",", "f1", ",", "F"}], "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox["A", 
      SqrtBox[
       RowBox[{"1", " ", "-", " ", 
        SuperscriptBox["z", "2"]}]]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"B", " ", "+", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox["A", 
         SqrtBox[
          RowBox[{"1", " ", "-", " ", 
           SuperscriptBox["z", "2"]}]]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = B + \[Integral] \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399556687875*^9},
 AspectRatioFixed->True],

Cell["Now solve for the coefficients  A  and  B.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eq1", " ", "=", " ", 
     RowBox[{
      RowBox[{"F", "[", 
       RowBox[{"-", "1"}], "]"}], " ", "\[Equal]", 
      FractionBox[
       RowBox[{" ", 
        RowBox[{"-", "\[Pi]"}]}], "2"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eq2", " ", "=", " ", 
     RowBox[{
      RowBox[{"F", "[", "1", "]"}], " ", "\[Equal]", "  ", 
      FractionBox["\[Pi]", "2"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"eq1", ",", "eq2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"A", ",", "B"}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"F", "[", "z", "]"}], ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq1", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq2", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<f[z] = B + A ArcSin[z]\>\"", "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399556690578125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph conformal mapping  w = f(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "0.25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.000001", ",", "4.000001", ",", "0.25"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "\[Pi]"}], "2"], ",", 
          FractionBox["\[Pi]", "2"], ",", 
          FractionBox["\[Pi]", "4"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image of the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<is the semi infinite strip \!\(\*FractionBox[\(-\[Pi]\), \(2\)]\)< \
u < \!\(\*FractionBox[\(\[Pi]\), \(2\)]\), v > 0,\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399556693625*^9, 3.399556698109375*^9}, 
   3.4001926108125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "We see that  w = Arcsin(z)  maps the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "z", "]"}], ">", "0"}]]],
 "  onto the semi infinite strip  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"-", "\[Pi]"}], "2"], "<", "u", "<", 
    FractionBox["\[Pi]", "2"]}], ",", " ", 
   RowBox[{"v", ">", "0"}]}]]],
 "."
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 11.27.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the Schwarz Christoffel formula to verify that  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
     FractionBox["1", "2"]]}]}]]],
 "  maps the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 "  onto the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]]],
 "  slit along the line segment from  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", "=", 
    RowBox[{
     RowBox[{"0", "  ", "to", "  ", 
      SubscriptBox["w", "2"]}], "=", "\[ImaginaryI]"}]}], " "}]]],
 ".  ",
 " (Use the principal square root throughout.)"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  If we choose  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "3"], "=", "1"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", 
    RowBox[{"-", "d"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", "\[ImaginaryI]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "3"], "=", "d"}]}]]],
 ",  then the formula\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "1"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "3"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "0"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}]}]}]],
 "\n\nwill determine a mapping ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " from the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 "  onto the portion of the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]]],
 "  that lies outside the triangle with vertices  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", 
    RowBox[{"-", "d"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", "\[ImaginaryI]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "3"], "=", "d"}]}]]],
 "  as indicated in Figure 11.73(a).  If we let ",
 Cell[BoxData[
  RowBox[{"d", "\[Rule]", "0"}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "1"], "\[Rule]", 
   RowBox[{
    RowBox[{"0", "  ", "and", "  ", 
     SubscriptBox["w", "3"]}], "\[Rule]", "0"}]}]]],
 ", and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "\[Rule]", 
    FractionBox["\[Pi]", "2"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "\[Rule]", 
    RowBox[{"-", "\[Pi]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "3"], "\[Rule]", 
    FractionBox["\[Pi]", "2"]}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{508, 123},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\t\t\tFigure 11.73   ",
 "The region with ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "\[Rule]", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", "\[ImaginaryI]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "3"], "\[Rule]", "0"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "\[Rule]", 
    FractionBox["\[Pi]", "2"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "\[Rule]", 
    RowBox[{"-", "\[Pi]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "3"], "\[Rule]", 
    FractionBox["\[Pi]", "2"]}]}]]],
 "."
}], "Text",
 CellChangeTimes->{3.506803330390625*^9}],

Cell[TextData[{
 "\tThe limiting formula for the derivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " becomes    \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"-", "\[Pi]"}], ")"}]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], "1"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", " ", "z", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", " ", 
     FractionBox["z", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
       FractionBox["1", "2"]]]}]}]}]}]],
 "\n\nwhich will determine a mapping ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " from the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 "  onto the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]]],
 "  slit along the line segment from  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", "=", 
    RowBox[{
     RowBox[{"0", "  ", "to", "  ", 
      SubscriptBox["w", "2"]}], "=", "\[ImaginaryI]"}]}], " "}]]],
 " as indicated in Figure 11.73(b).  An easy integration reveals that ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " is given by  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox["z", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
          FractionBox["1", "2"]]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "+", "  ", "B"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"A", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
       FractionBox["1", "2"]]}], "  ", "+", "  ", "B"}]}]}]}],
  AspectRatioFixed->True],
 "  \n\nand the boundary values  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     RowBox[{"\[PlusMinus]", "1"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"0", "  ", "and", "  ", "f", 
     RowBox[{"(", "0", ")"}]}], "=", "\[ImaginaryI]"}]}]]],
 "  lead to system of equations \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"A", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\[PlusMinus]", "1"}], ")"}], "2"], "-", "1"}], ")"}], 
      FractionBox["1", "2"]]}], " ", "+", " ", "B"}], " ", "=", " ", "0"}]],
  AspectRatioFixed->True],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"A", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"0", "-", "1"}], ")"}], 
      FractionBox["1", "2"]]}], " ", "+", " ", "B"}], " ", "=", " ", 
   "\[ImaginaryI]"}]],
  AspectRatioFixed->True],
 "\n\nthe solution is easily found to be ",
 Cell[BoxData[
  RowBox[{"A", "=", 
   RowBox[{
    RowBox[{"1", "  ", "and", "  ", "B"}], "=", "0"}]}]]],
 " and the desired function  is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
    FractionBox["1", "2"]]}]],
  AspectRatioFixed->True],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"11.27", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.5067068818125*^9, 3.5067068818125*^9}}],

Cell[TextData[{
 "Enter the formula ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{" ", 
     RowBox[{"A", " ", "z"}]}], 
    RowBox[{
     SqrtBox[
      RowBox[{"z", " ", "+", " ", "1"}]], " ", 
     SqrtBox[
      RowBox[{"z", " ", "-", " ", "1"}]]}]]}]],
  AspectRatioFixed->True],
 " and integrate it to construct  f(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f1", ",", "A", ",", "B", ",", "z", ",", "F"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], " ", "=", 
     FractionBox[
      RowBox[{" ", 
       RowBox[{"A", " ", "z"}]}], 
      RowBox[{
       SqrtBox[
        RowBox[{"z", " ", "+", " ", "1"}]], " ", 
       SqrtBox[
        RowBox[{"z", " ", "-", " ", "1"}]]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"B", " ", "+", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         RowBox[{" ", 
          RowBox[{"A", " ", "z"}]}], 
         RowBox[{
          SqrtBox[
           RowBox[{"z", " ", "+", " ", "1"}]], " ", 
          SqrtBox[
           RowBox[{"z", " ", "-", " ", "1"}]]}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = B + \[Integral] \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399556710875*^9},
 AspectRatioFixed->True],

Cell["\<\
This is one, formula for the integral.   However, we will use the following \
form of the integral to continue the computations.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f1", ",", "F"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"A", " ", "z"}], 
      SqrtBox[
       RowBox[{
        SuperscriptBox["z", "2"], " ", "-", " ", "1"}]]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"B", " ", "+", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         RowBox[{"A", " ", "z"}], 
         SqrtBox[
          RowBox[{
           SuperscriptBox["z", "2"], " ", "-", " ", "1"}]]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = B + \[Integral] \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39955671396875*^9},
 AspectRatioFixed->True],

Cell["Now solve for the coefficients  A  and  B.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eq1", " ", "=", " ", 
     RowBox[{
      RowBox[{"F", "[", "1", "]"}], "\[Equal]", "0"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eq2", " ", "=", " ", 
     RowBox[{
      RowBox[{"F", "[", "0", "]"}], "\[Equal]", "\[ImaginaryI]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{"solset", " ", "=", " ", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"eq1", ",", "eq2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"A", ",", "B"}], "}"}]}], "]"}]}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"F", "[", "z", "]"}], ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq1", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq2", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f[z] = B + A \!\(\*SqrtBox[\(\*SuperscriptBox[\(z\), \(2\)] - \
1\)]\)\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39955671678125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph conformal mapping  w = f(z).  We will need to use two branches of \
f(z) to form the graph."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f1", ",", "f2", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], " ", "=", "   ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["z", "2"], " ", "-", " ", "1"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f2", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox[
       RowBox[{"1", " ", "-", " ", 
        SuperscriptBox["z", "2"]}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"gr1", " ", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f1", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "3", ",", "0.2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "1.00001", ",", "0.1"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1.5"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"gr2", " ", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f2", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", "0", ",", "0.2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "1.00001", ",", "0.1"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1.5"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image of the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<is upper half plane Im[w] > 0 slit\>\"", "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<along the line segment from w = 0 to \!\(\*SubscriptBox[\(w\), \
\(2\)]\) = \[ImaginaryI],\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399556719546875*^9, 3.3995567221875*^9}, {
  3.400404443421875*^9, 3.40040445184375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We see that  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["z", "2"], "-", "1"}]]}]]],
 "  maps the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "z", "]"}], ">", "0"}]]],
 "  onto the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "w", "]"}], ">", "0"}]]],
 "  slit along the line segment from  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", "=", 
    RowBox[{
     RowBox[{"0", "  ", "to", "  ", 
      SubscriptBox["w", "2"]}], "=", "\[ImaginaryI]"}]}], " "}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\n",
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Alternately, we could just use the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", " ", 
   RowBox[{"\[ImaginaryI]", " ", 
    SqrtBox[
     RowBox[{"1", " ", "-", " ", 
      SuperscriptBox["z", "2"]}]]}]}]]],
 ". "
}], "Text",
 CellChangeTimes->{{3.39955958034375*^9, 3.39955962575*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f0", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f0", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox[
       RowBox[{"1", " ", "-", " ", 
        SuperscriptBox["z", "2"]}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"gr0", " ", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f0", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", "3", ",", "0.2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "1.00001", ",", "0.1"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1.5"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"gr0", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image of the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<is upper half plane Im[w] > 0 slit\>\"", "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<along the line segment from w = 0 to \!\(\*SubscriptBox[\(w\), \
\(2\)]\) = \[ImaginaryI],\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  w = f[z] = \>\"", ",", 
      RowBox[{"f0", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399556719546875*^9, 3.3995567221875*^9}, {
  3.399559643453125*^9, 3.399559684484375*^9}, {3.400404459234375*^9, 
  3.40040446625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We see that  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"\[ImaginaryI]", " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["z", "2"]}]]}]}]]],
 "  maps the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "z", "]"}], ">", "0"}]]],
 "  onto the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "w", "]"}], ">", "0"}]]],
 "  slit along the line segment from  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", "=", 
    RowBox[{
     RowBox[{"0", "  ", "to", "  ", 
      SubscriptBox["w", "2"]}], "=", "\[ImaginaryI]"}]}], " "}]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.3995597036875*^9, 3.3995597036875*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 11.28.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "\[Pi]"], "Arcsin", " ", "z"}], " ", "+", " ", 
     RowBox[{
      FractionBox["\[ImaginaryI]", "\[Pi]"], "Arcsin", 
      FractionBox["1", "z"]}], " ", "+", " ", 
     FractionBox[
      RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], "2"], " "}]}]}]]],
 "  maps the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 "  onto the right angle channel in the first quadrant, which is bounded by \
the coordinate axes and the rays  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "\[GreaterEqual]", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"y", "=", 
    RowBox[{
     RowBox[{"1", "  ", "and", "  ", "y"}], "\[GreaterEqual]", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"x", "=", "1"}]}]]],
 ", as depicted in Figure 11.74(b).",
 " "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  If we choose  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "3"], "=", "1"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", "d"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "3"], "=", 
    RowBox[{"1", "+", "\[ImaginaryI]"}]}]}]]],
 ",  then the formula  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     SubscriptBox["A", "1"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "1"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "3"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}], 
   "\n"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SubscriptBox["A", "1"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "0"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}], 
   "\n"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SubscriptBox["A", "1"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}]}]}]],
 "\n\nwill determine a mapping ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " of the upper half-plane onto the domain indicated in Figure 11.74(a).  \
With  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    StyleBox["\[Alpha]",
     FontSize->14], "1"], "=", 
   FractionBox["\[Pi]", "2"]}]]],
 ",  we let ",
 Cell[BoxData[
  RowBox[{"d", "\[Rule]", "\[Infinity]"}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    StyleBox["\[Alpha]",
     FontSize->14], "2"], "\[Rule]", "\[Pi]"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    StyleBox["\[Alpha]",
     FontSize->14], "3"], "\[Rule]", 
   RowBox[{"-", 
    FractionBox["\[Pi]", "2"]}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{304, 175},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\t\t\tFigure 11.74  ",
 "The region with ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", 
    RowBox[{"\[Rule]", "\[Infinity]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "3"], "=", 
    RowBox[{"1", "+", "\[ImaginaryI]"}]}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    FractionBox["\[Pi]", "2"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "\[Rule]", "\[Pi]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "3"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}]}]}]]],
 "."
}], "Text",
 CellChangeTimes->{3.506803352234375*^9}],

Cell[TextData[{
 "\tThe limiting formula for the derivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " becomes   \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     SubscriptBox["A", "1"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}], 
   "\n"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SubscriptBox["A", "1"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{
       RowBox[{"-", "\[Pi]"}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], ")"}]}], "/", "\[Pi]"}]]}]}], 
   "\n"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SubscriptBox["A", "1"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{"-", "1"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      FractionBox["1", "2"]]}]}], "\n"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SubscriptBox["A", "1"], " ", 
     FractionBox["1", "z"], 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       FractionBox["1", "2"]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], 
       FractionBox["1", "2"]]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SubscriptBox["A", "1"], " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", "1"}], ")"}], 
        FractionBox["1", "2"]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", "1"}], ")"}], 
        FractionBox["1", "2"]]}], 
      RowBox[{"z", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        FractionBox["1", "2"]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", "1"}], ")"}], 
        FractionBox["1", "2"]]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SubscriptBox["A", "1"], " ", 
     FractionBox[
      RowBox[{"z", "-", "1"}], 
      RowBox[{"z", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
        FractionBox["1", "2"]]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", " ", 
     FractionBox[
      RowBox[{"z", "-", "1"}], 
      RowBox[{"z", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["z", "2"]}], ")"}], 
        FractionBox["1", "2"]]}]]}]}]}]}]],
 "\n\nwhere  ",
 Cell[BoxData[
  RowBox[{"A", " ", "=", " ", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", 
    SubscriptBox["A", "1"]}]}]]],
 ", which will determine a mapping ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " from the upper half plane onto the channel as indicated in Figure \
11.74(b).  "
}], "Text"],

Cell[TextData[{
 "\tUsing integrals in Table 11.2, we obtain \n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         RowBox[{"z", "-", "1"}], 
         RowBox[{"z", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SuperscriptBox["z", "2"]}], ")"}], 
           FractionBox["1", "2"]]}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "+", "  ", "B"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox["z", 
         RowBox[{"z", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SuperscriptBox["z", "2"]}], ")"}], 
           FractionBox["1", "2"]]}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "-", "   ", 
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"z", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SuperscriptBox["z", "2"]}], ")"}], 
           FractionBox["1", "2"]]}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "+", " ", "B"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox["z", "2"]}], ")"}], 
          FractionBox["1", "2"]]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "-", "   ", 
     RowBox[{"A", " ", "\[ImaginaryI]", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"z", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
           FractionBox["1", "2"]]}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "+", " ", "B"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"A", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Arcsin", " ", "z"}], " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "Arcsin", 
         RowBox[{"(", 
          FractionBox["1", "z"], ")"}]}]}], ")"}]}], "  ", "+", "  ", 
     "B"}]}]}]}],
  AspectRatioFixed->True],
 "   "
}], "Text"],

Cell[TextData[{
 "\tIf we use the principal branch of the inverse sine function, then the \
boundary values  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"0", "  ", "and", "  ", "f", 
     RowBox[{"(", "1", ")"}]}], "=", 
    RowBox[{"1", "+", "\[ImaginaryI]"}]}]}]]],
 "  lead to the system  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"A", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "2"]}], ")"}]}], "+", "B"}], 
   "=", "0"}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"A", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "2"], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "2"]}], ")"}]}], "+", "B"}], 
   "=", 
   RowBox[{"1", "+", "\[ImaginaryI]"}]}]]],
 ",  \n\nwhich we can solve to obtain ",
 Cell[BoxData[
  RowBox[{"A", "=", 
   RowBox[{
    RowBox[{
     FractionBox["1", "\[Pi]"], "  ", "and", "  ", "B"}], "=", 
    FractionBox[
     RowBox[{"1", "+", "\[ImaginaryI]"}], "2"]}]}]]],
 ".  Hence the required solution is \n \n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "\[Pi]"], "Arcsin", " ", "z"}], " ", "+", " ", 
     RowBox[{
      FractionBox["\[ImaginaryI]", "\[Pi]"], "Arcsin", 
      FractionBox["1", "z"]}], " ", "+", " ", 
     FractionBox[
      RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], "2"], " "}]}]}]]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"11.28", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706886046875*^9, 3.506706886046875*^9}}],

Cell[TextData[{
 "Enter the formula ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{"A", " ", 
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "1"}], ")"}]}], 
    RowBox[{"z", " ", 
     SqrtBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], " ", "-", " ", "1"}], ")"}]]}]]}]],
  AspectRatioFixed->True],
 " and integrate it to construct  f(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f1", ",", "A", ",", "B", ",", "z", ",", "F"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"A", " ", 
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "1"}], ")"}]}], 
      RowBox[{"z", " ", 
       SqrtBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], " ", "-", " ", "1"}], ")"}]]}]]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"B", " ", "+", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         RowBox[{"A", " ", 
          RowBox[{"(", 
           RowBox[{"z", " ", "-", " ", "1"}], ")"}]}], 
         RowBox[{"z", " ", 
          SqrtBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z", "2"], " ", "-", " ", "1"}], ")"}]]}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = B + \[Integral] \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399556735375*^9},
 AspectRatioFixed->True],

Cell["\<\
This is one, formula for the integral.   However, we will use the following \
form of the integral to continue the computations.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"A", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"ArcSin", "[", "z", "]"}], " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"ArcSin", "[", 
           FractionBox["1", "z"], "]"}]}]}], ")"}]}], " ", "+", " ", "B"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39955673853125*^9},
 AspectRatioFixed->True],

Cell["Now solve for the coefficients  A  and  B.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eq1", " ", "=", " ", 
     RowBox[{
      RowBox[{"F", "[", 
       RowBox[{"-", "1"}], "]"}], " ", "\[Equal]", " ", "0"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"eq2", " ", "=", " ", 
     RowBox[{
      RowBox[{"F", "[", "1", "]"}], "  ", "\[Equal]", " ", 
      RowBox[{"1", "+", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"F", "[", 
           RowBox[{"-", "1"}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"F", "[", "1", "]"}], "\[Equal]", 
          RowBox[{"1", "+", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"A", ",", "B"}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"F", "[", "z", "]"}], ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq1", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq2", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f[z] = B + A (ArcSin[z] + \[ImaginaryI] \
ArcSin[\!\(\*FractionBox[\(1\), \(z\)]\)])\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39955674634375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph conformal mapping  w = f(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00001", ",", "4.00001", ",", "0.2"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1.35"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "0.5"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image of the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<is the channel in the right half plane bounded by the\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<coordinate axes and rays x \[GreaterEqual] 0, y = 1 and y \
\[GreaterEqual] 1, x = 1.\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399556748625*^9, 3.399556753953125*^9}, 
   3.400192618359375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "We see that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", "=", 
    RowBox[{
     RowBox[{
      FractionBox["1", "\[Pi]"], 
      RowBox[{"ArcSin", "[", "z", "]"}]}], "+", 
     RowBox[{
      FractionBox["\[ImaginaryI]", "\[Pi]"], 
      RowBox[{"ArcSin", "[", 
       FractionBox["1", "z"], "]"}]}], "+", 
     FractionBox[
      RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], "2"]}]}], " "}]]],
 "  maps the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "z", "]"}], ">", "0"}]]],
 "  onto the channel in the right half plane bounded by the coordinate axes \
and rays  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "\[GreaterEqual]", "0"}], ",", 
   RowBox[{"y", "=", 
    RowBox[{
     RowBox[{"1", "  ", "and", "  ", "y"}], "\[GreaterEqual]", "1"}]}], ",", 
   RowBox[{"x", "=", "1"}]}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{"w", "  ", "=", "  ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "\[Pi]"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
       FractionBox["1", "2"]]}], " ", "+", " ", 
     RowBox[{
      FractionBox["1", "\[Pi]"], "Log", 
      RowBox[{"(", 
       RowBox[{"z", "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
         FractionBox["1", "2"]]}], ")"}]}], " ", "-", " ", 
     "\[ImaginaryI]"}]}]}]]],
 "  maps the upper half-plane onto the domain indicated in Figure 11.77.  \n\
Hint: Set  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "1"}]}]]],
 "  and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", 
    RowBox[{"-", "\[ImaginaryI]"}]}]}]]],
 ". "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{445, 175},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\t\t\tFigure 11.77  ",
 "The region with ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", 
    RowBox[{"-", "\[ImaginaryI]"}]}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", 
    FractionBox["\[Pi]", "2"]}]}]]],
 "."
}], "Text",
 CellChangeTimes->{3.506803372703125*^9}],

Cell[TextData[{
 "Solution.  The exterior angles are  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", 
    FractionBox["\[Pi]", "2"]}]}]]],
 ",  and the formula for the derivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " is  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "1"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], ")"}]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         FractionBox["\[Pi]", "2"], ")"}]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      FractionBox["1", "2"]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"A", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        FractionBox["1", "2"]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", "1"}], ")"}], 
        FractionBox["1", "2"]]]}], "  ", "=", "  ", 
     RowBox[{"A", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         FractionBox["1", "2"]], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         FractionBox["1", "2"]]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         FractionBox["1", "2"]], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", "1"}], ")"}], 
         FractionBox["1", "2"]]}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     FractionBox[
      RowBox[{"z", "+", "1"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        FractionBox["1", "2"]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", "1"}], ")"}], 
        FractionBox["1", "2"]]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["z", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
         FractionBox["1", "2"]]], "+", 
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
         FractionBox["1", "2"]]]}], ")"}]}]}]}]}]],
 " \nintegrate and get \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"A", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
      FractionBox["1", "2"]]}], "  ", "+", "  ", 
    RowBox[{"A", " ", "Log", 
     RowBox[{"(", 
      RowBox[{"z", "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
        FractionBox["1", "2"]]}], ")"}]}]}]}]]],
 "\n\t\t\t\nuse the conditions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}]}], "=", "0"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "1", ")"}]}], "=", 
   RowBox[{"-", "\[ImaginaryI]"}]}]]],
 "  and solve the resulting system for ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["B",
  FontFamily->"Courier New"],
 ".  The desired result is\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox["1", "\[Pi]"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
      FractionBox["1", "2"]]}], " ", "+", " ", 
    RowBox[{
     FractionBox["1", "\[Pi]"], "Log", 
     RowBox[{"(", 
      RowBox[{"z", "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
        FractionBox["1", "2"]]}], ")"}]}], " ", "-", " ", 
    "\[ImaginaryI]"}]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "1."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670689175*^9, 3.50670689175*^9}}],

Cell[TextData[{
 "Enter the formula ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], "[", "z", "]"}]],
  AspectRatioFixed->True],
 " and integrate it to construct  f(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f1", ",", "A", ",", "B", ",", "z", ",", "F"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], " ", "=", "   ", 
     RowBox[{
      RowBox[{"A", " ", 
       FractionBox["z", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
         FractionBox["1", "2"]]]}], " ", "+", " ", 
      RowBox[{"A", " ", 
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
         FractionBox["1", "2"]]]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"B", " ", "+", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{"A", 
        RowBox[{"(", "  ", 
         RowBox[{
          FractionBox["z", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
            FractionBox["1", "2"]]], "+", 
          FractionBox["1", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
            FractionBox["1", "2"]]]}], ")"}], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = B + \[Integral] \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3995568099375*^9},
 AspectRatioFixed->True],

Cell["\<\
We will use this form of the integral to continue the computations.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"B", "+", 
      RowBox[{"A", " ", 
       RowBox[{"(", 
        RowBox[{
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["z", "2"]}]], "+", 
         RowBox[{"Log", "[", 
          RowBox[{"z", "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["z", "2"]}]]}], "]"}]}], ")"}]}]}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3995568131875*^9},
 AspectRatioFixed->True],

Cell["Now solve for the coefficients  A  and  B.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eq1", " ", "=", " ", 
     RowBox[{
      RowBox[{"F", "[", 
       RowBox[{"-", "1"}], "]"}], " ", "\[Equal]", " ", "0"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"eq2", " ", "=", " ", 
     RowBox[{
      RowBox[{"F", "[", "1", "]"}], "  ", "\[Equal]", 
      RowBox[{"-", " ", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"eq1", ",", "eq2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"A", ",", "B"}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"F", "[", "z", "]"}], ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq1", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq2", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Expand", "[", 
      RowBox[{"f", "[", "z", "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399556816421875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph conformal mapping  w = f(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        SqrtBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["z", "2"]}]], "\[Pi]"]}], "+", 
      FractionBox[
       RowBox[{"Log", "[", 
        RowBox[{"z", "-", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["z", "2"]}]]}], "]"}], "\[Pi]"], "-", 
      "\[ImaginaryI]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f2", "[", "z_", "]"}], "=", 
     RowBox[{
      FractionBox[
       SqrtBox[
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["z", "2"]}]], "\[Pi]"], "+", 
      FractionBox[
       RowBox[{"Log", "[", 
        RowBox[{"z", "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["z", "2"]}]]}], "]"}], "\[Pi]"], "-", 
      "\[ImaginaryI]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graph1", " ", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f1", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "7.00001"}], ",", 
         RowBox[{"-", "0.00001"}], ",", "0.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "2.00001", ",", "0.2"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graph2", " ", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f2", ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "3.00001", ",", "0.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "2.00001", ",", "0.2"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0.6"}], "}"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the upper half plane Im[z] > 0 under the mapping\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399556829625*^9, 3.39955683615625*^9}, 
   3.399559727890625*^9, {3.400192628703125*^9, 3.400192630125*^9}, {
   3.400404475515625*^9, 3.400404484921875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "\n",
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Alternately, we could just use the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"\[ImaginaryI]", 
      SqrtBox[
       RowBox[{"1", "-", 
        SuperscriptBox["z", "2"]}]]}], "\[Pi]"], "+", 
    FractionBox[
     RowBox[{"Log", "[", 
      RowBox[{"z", "+", 
       RowBox[{"\[ImaginaryI]", 
        SqrtBox[
         RowBox[{"1", "-", 
          SuperscriptBox["z", "2"]}]]}]}], "]"}], "\[Pi]"], "-", 
    "\[ImaginaryI]"}]}]]],
 ". "
}], "Text",
 CellChangeTimes->{{3.39955958034375*^9, 3.39955962575*^9}, {
  3.3995599688125*^9, 3.399559970015625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f0", "[", "z_", "]"}], "=", 
     RowBox[{
      FractionBox[
       RowBox[{"\[ImaginaryI]", 
        SqrtBox[
         RowBox[{"1", "-", 
          SuperscriptBox["z", "2"]}]]}], "\[Pi]"], "+", 
      FractionBox[
       RowBox[{"Log", "[", 
        RowBox[{"z", "+", 
         RowBox[{"\[ImaginaryI]", 
          SqrtBox[
           RowBox[{"1", "-", 
            SuperscriptBox["z", "2"]}]]}]}], "]"}], "\[Pi]"], "-", 
      "\[ImaginaryI]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graph0", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f0", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "7"}], ",", "3", ",", "0.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "2.00001", ",", "0.2"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph0", ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0.6"}], "}"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the upper half plane Im[z] > 0 under the mapping\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[z] = \>\"", ",", 
      RowBox[{"f0", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399556829625*^9, 3.39955683615625*^9}, 
   3.399559727890625*^9, {3.399559764703125*^9, 3.399559863078125*^9}, {
   3.400192636703125*^9, 3.400192637515625*^9}, {3.400404490671875*^9, 
   3.40040449565625*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{"w", "  ", "=", "  ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["2", "\[Pi]"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
       FractionBox["1", "2"]]}], "  ", "+", " ", 
     RowBox[{
      FractionBox["2", "\[Pi]"], "Arcsin", 
      RowBox[{"(", 
       FractionBox["1", "z"], ")"}]}]}]}]}]]],
 "  maps the upper half-plane onto the domain indicated in Figure 11.78.   \n\
Hint: Set  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "3"], "=", "1"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "d"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "3"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["let",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", "d"}], "\[Rule]", "\[Infinity]"}]}]}]]]
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{455, 175},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\t\t\tFigure 11.78  ",
 "The region with ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "3"], "=", "1"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", "\[Pi]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "3"], "=", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}]}]}]]],
 "."
}], "Text",
 CellChangeTimes->{3.506803389765625*^9}],

Cell[TextData[{
 "Solution.  The exterior angles are  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", "\[Pi]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "3"], "=", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}]}]}]]],
 ",  and the formula for the derivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " is  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "1"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "3"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], ")"}]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "0"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", "\[Pi]", ")"}]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], ")"}]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"A", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], 
       FractionBox["1", "2"]], 
      SuperscriptBox[
       RowBox[{"(", "z", ")"}], 
       RowBox[{"-", "1"}]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       FractionBox["1", "2"]]}], "  ", "=", "  ", 
     RowBox[{"A", " ", 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
       FractionBox["1", "2"]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"A", " ", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
        FractionBox["1", "2"]], "z"]}], "  ", "=", "  ", 
     RowBox[{"A", " ", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
         FractionBox["1", "2"]], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
         FractionBox["1", "2"]]}], 
       RowBox[{"z", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
         FractionBox["1", "2"]]}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"A", " ", 
      FractionBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
       RowBox[{"z", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
         FractionBox["1", "2"]]}]]}], "  ", "=", "  ", 
     RowBox[{"A", " ", 
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "3"], "-", "z"}], 
       RowBox[{
        SuperscriptBox["z", "2"], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
         FractionBox["1", "2"]]}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"A", " ", 
      FractionBox["z", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
        FractionBox["1", "2"]]]}], " ", "-", " ", 
     RowBox[{"A", " ", 
      FractionBox["1", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           FractionBox["1", 
            SuperscriptBox["z", "2"]]}], ")"}], 
         FractionBox["1", "2"]], " ", 
        SuperscriptBox["z", "2"]}]]}]}]}]}]}]],
 "  \nintegrate and get \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"A", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
      FractionBox["1", "2"]]}], "  ", "+", "  ", 
    RowBox[{
     RowBox[{"A", "\[Cross]", "Arcsin"}], 
     RowBox[{"(", 
      FractionBox["1", "z"], ")"}]}]}]}]]],
 "\n\t\t\t\nuse the conditions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}]}], "=", 
   RowBox[{"-", "1"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "1", ")"}]}], "=", "1"}]]],
 "  and solve the resulting system for ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["B",
  FontFamily->"Courier New"],
 ".  The desired result is\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox["2", "\[Pi]"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
      FractionBox["1", "2"]]}], "  ", "+", " ", 
    RowBox[{
     FractionBox["2", "\[Pi]"], "Arcsin", 
     RowBox[{"(", 
      FractionBox["1", "z"], ")"}]}]}]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "2."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670689653125*^9, 3.50670689653125*^9}}],

Cell[TextData[{
 "Enter the formula ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], "[", "z", "]"}]],
  AspectRatioFixed->True],
 " and integrate it to construct  f(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"A", ",", "B", ",", "z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f1", ",", "F"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], " ", "=", "   ", 
     RowBox[{
      RowBox[{"A", " ", 
       FractionBox["z", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
         FractionBox["1", "2"]]]}], " ", "-", " ", 
      RowBox[{"A", " ", 
       FractionBox["1", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "-", 
            FractionBox["1", 
             SuperscriptBox["z", "2"]]}], ")"}], 
          FractionBox["1", "2"]], " ", 
         SuperscriptBox["z", "2"]}]]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"B", " ", "+", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{"A", 
        RowBox[{"(", "  ", 
         RowBox[{
          FractionBox["z", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
            FractionBox["1", "2"]]], "-", " ", 
          FractionBox["1", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox["1", 
                SuperscriptBox["z", "2"]]}], ")"}], 
             FractionBox["1", "2"]], " ", 
            SuperscriptBox["z", "2"]}]]}], ")"}], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = B + \[Integral] \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399556849171875*^9},
 AspectRatioFixed->True],

Cell["\<\
We will use this form of the integral to continue the computations.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"B", "+", 
      RowBox[{"A", " ", 
       RowBox[{"(", 
        RowBox[{
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["z", "2"]}]], "+", 
         RowBox[{"ArcSin", "[", 
          FractionBox["1", "z"], "]"}]}], ")"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3995568519375*^9},
 AspectRatioFixed->True],

Cell["Now solve for the coefficients  A  and  B.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eq1", " ", "=", " ", 
     RowBox[{
      RowBox[{"F", "[", 
       RowBox[{"-", "1"}], "]"}], " ", "\[Equal]", " ", 
      RowBox[{"-", "1"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eq2", " ", "=", " ", 
     RowBox[{
      RowBox[{"F", "[", "1", "]"}], "  ", "\[Equal]", " ", "1"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"eq1", ",", "eq2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"A", ",", "B"}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"F", "[", "z", "]"}], ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq1", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq2", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Expand", "[", 
      RowBox[{"f", "[", "z", "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399556855078125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph conformal mapping  w = f(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["z", "2"]}]]}], "\[Pi]"]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"ArcSin", "[", 
         FractionBox["1", "z"], "]"}]}], "\[Pi]"]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f2", "[", "z_", "]"}], "=", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["z", "2"]}]]}], "\[Pi]"], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"ArcSin", "[", 
         FractionBox["1", "z"], "]"}]}], "\[Pi]"]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graph1", " ", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f1", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3.00001"}], ",", "0.00001", ",", "0.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "1.20001", ",", "0.12"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graph2", " ", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f2", ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "3.00001", ",", "0.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "1.20001", ",", "0.12"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "0.75"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0.75"}], "}"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the upper half plane Im[z] > 0 under the mapping\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " "}]}]], "Input",
 CellChangeTimes->{{3.3995568584375*^9, 3.399556864515625*^9}, {
  3.4001926426875*^9, 3.400192643265625*^9}, {3.400404503859375*^9, 
  3.4004045130625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "\n",
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Alternately, we could just use the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", "\[ImaginaryI]", 
      SqrtBox[
       RowBox[{"1", "-", 
        SuperscriptBox["z", "2"]}]]}], "\[Pi]"], "+", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"ArcSin", "[", 
       FractionBox["1", "z"], "]"}]}], "\[Pi]"]}]}]]],
 ". "
}], "Text",
 CellChangeTimes->{{3.39955958034375*^9, 3.39955962575*^9}, {
   3.3995599688125*^9, 3.399559970015625*^9}, 3.3995601615625*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f0", "[", "z_", "]"}], "=", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", 
        SqrtBox[
         RowBox[{"1", "-", 
          SuperscriptBox["z", "2"]}]]}], "\[Pi]"], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"ArcSin", "[", 
         FractionBox["1", "z"], "]"}]}], "\[Pi]"]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graph0", " ", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f0", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", "3", ",", "0.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "1.20001", ",", "0.12"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph0", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "0.75"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0.75"}], "}"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the upper half plane Im[z] > 0 under the mapping\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[z] = \>\"", ",", 
      RowBox[{"f0", "[", "z", "]"}]}], "]"}], ";"}], " "}]}]], "Input",
 CellChangeTimes->{{3.3995568584375*^9, 3.399556864515625*^9}, {
  3.399560011984375*^9, 3.399560113578125*^9}, {3.4001926484375*^9, 
  3.40019264875*^9}, {3.400404520765625*^9, 3.40040452559375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"4", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], 
       RowBox[{"1", "/", "4"}]]}], " ", "+", " ", 
     RowBox[{"log", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         RowBox[{"1", "/", "4"}]], "-", "1"}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         RowBox[{"1", "/", "4"}]], "+", "1"}]]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "log", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         RowBox[{"1", "/", "4"}]]}], 
       RowBox[{"\[ImaginaryI]", "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         RowBox[{"1", "/", "4"}]]}]]}]}]}]}]]],
 "  maps the upper half-plane onto the domain indicated in Figure 11.84.  \n\
Hint: Set  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "0"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", 
    RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "d"}], "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["let",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", "d"}], "\[Rule]", "\[Infinity]"}]}]}]]],
 ".  Use the change of variable  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "+", "1"}], "=", 
   SuperscriptBox["s", "4"]}]]],
 "  in the resulting integral."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{313, 175},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\t\t\tFigure 11.84  The region with ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "0"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "4"]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", "\[Pi]"}]}]]],
 "."
}], "Text",
 CellChangeTimes->{{3.506803407734375*^9, 3.5068034125625*^9}}],

Cell[TextData[{
 "Solution.  The exterior angles are  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "4"]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", "\[Pi]"}]}]]],
 ",  and the formula for the derivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " is  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "1"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "4"]}], ")"}]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "0"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", "\[Pi]", ")"}]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      FractionBox["1", "4"]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{"-", "1"}]]}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], 
       FractionBox["1", "4"]], "z"]}]}]}]}]],
 "   \nintegrate \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", " ", 
   RowBox[{"B", " ", "+", " ", 
    RowBox[{"A", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         FractionBox["1", "4"]], "z"], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}]],
  AspectRatioFixed->True],
 "\n\t\t\t\nuse the substitutions \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"z", "+", "1"}], "  ", "=", "  ", 
   SuperscriptBox["s", "4"]}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"z", "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["s", "4"], "-", "1"}]}]}], "\[IndentingNewLine]", 
  RowBox[{"   ", 
   RowBox[{
    RowBox[{"\[DifferentialD]", "z"}], "  ", "=", "  ", 
    RowBox[{"4", " ", 
     SuperscriptBox["s", "3"], 
     RowBox[{"\[DifferentialD]", "s"}]}]}]}]}]],
 "  \nand get\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Integral]", 
     RowBox[{
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        FractionBox["1", "4"]], "z"], 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{"\[Integral]", 
     RowBox[{
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         SuperscriptBox["s", "4"], ")"}], 
        RowBox[{"1", "/", "4"}]], 
       RowBox[{
        SuperscriptBox["s", "4"], "-", "1"}]], "4", " ", 
      SuperscriptBox["s", "3"], 
      RowBox[{"\[DifferentialD]", "s"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                            ", 
   RowBox[{"=", "   ", 
    RowBox[{"\[Integral]", 
     RowBox[{
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox["s", "4"]}], 
       RowBox[{
        SuperscriptBox["s", "4"], "-", "1"}]], 
      RowBox[{"\[DifferentialD]", "s"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"4", " ", "s"}], " ", "-", " ", 
     RowBox[{"2", " ", "Arctan", " ", "s"}], " ", "+", " ", 
     RowBox[{"Log", 
      RowBox[{"(", 
       RowBox[{"s", "-", "1"}], ")"}]}], " ", "-", " ", 
     RowBox[{"Log", 
      RowBox[{"(", 
       RowBox[{"s", "+", "1"}], ")"}]}]}]}]}]}],
  AspectRatioFixed->True],
 "  \n\nUse the identity  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", " ", "2"}], "ArcTan", " ", "s"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], 
     FractionBox["\[ImaginaryI]", "2"], "Log", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", "+", "s"}], 
       RowBox[{"\[ImaginaryI]", "-", "s"}]], ")"}]}], " ", "=", " ", 
    RowBox[{"\[ImaginaryI]", " ", "Log", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", "-", "s"}], 
       RowBox[{"\[ImaginaryI]", "+", "s"}]], ")"}]}]}]}]]],
 "  and write the integral as\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Integral]", 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], 
       FractionBox["1", "4"]], "z"], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"4", " ", "s"}], "  ", "+", "  ", 
    RowBox[{"Log", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"s", "-", "1"}], 
       RowBox[{"s", "+", "1"}]], ")"}]}], "  ", "+", "  ", 
    RowBox[{"\[ImaginaryI]", " ", "Log", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", "-", "s"}], 
       RowBox[{"\[ImaginaryI]", "+", "s"}]], ")"}]}]}]}]],
  AspectRatioFixed->True],
 " \n\nNow use the substitution ",
 Cell[BoxData[
  RowBox[{"s", "\[Rule]", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"z", "+", "1"}], ")"}], 
    FractionBox["1", "4"]]}]]],
 " and get \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"B", " ", "+", " ", 
     RowBox[{"A", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          FractionBox["1", "4"]], "z"], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], 
   "  "}], "\[IndentingNewLine]", 
  RowBox[{"=", "  ", 
   RowBox[{"B", " ", "+", " ", 
    RowBox[{"A", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         RowBox[{"1", "/", "4"}]]}], " ", "+", " ", 
       RowBox[{"Log", 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "+", "1"}], ")"}], 
           RowBox[{"1", "/", "4"}]], "-", "1"}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "+", "1"}], ")"}], 
           RowBox[{"1", "/", "4"}]], "+", "1"}]]}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "Log", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", "-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "+", "1"}], ")"}], 
           RowBox[{"1", "/", "4"}]]}], 
         RowBox[{"\[ImaginaryI]", "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "+", "1"}], ")"}], 
           RowBox[{"1", "/", "4"}]]}]]}]}], ")"}]}]}]}]}],
  AspectRatioFixed->True],
 "\n\t\t\t\nuse the conditions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "0", ")"}]}], " ", "=", " ", "0"}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "1", ")"}]}], "=", 
   RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]}]]],
 "  and solve the resulting system for ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["B",
  FontFamily->"Courier New"],
 ".  The desired result is\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"4", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", "z"}], ")"}], 
      RowBox[{"1", "/", "4"}]]}], "+", 
    RowBox[{"Log", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        RowBox[{"1", "/", "4"}]], "-", "1"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        RowBox[{"1", "/", "4"}]], "+", "1"}]]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "Log", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        RowBox[{"1", "/", "4"}]]}], 
      RowBox[{"\[ImaginaryI]", "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        RowBox[{"1", "/", "4"}]]}]]}]}]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "3."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.5067069010625*^9, 3.5067069010625*^9}}],

Cell[TextData[{
 "Enter the formula ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], "[", "z", "]"}]],
  AspectRatioFixed->True],
 " and integrate it to construct  f(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f1", ",", "A", ",", "B", ",", "z", ",", "F"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], " ", "=", "  ", 
     RowBox[{"A", 
      RowBox[{"(", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         FractionBox["1", "4"]], "z"], ")"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"B", " ", "+", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{"A", 
        RowBox[{"(", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "+", "1"}], ")"}], 
           FractionBox["1", "4"]], "z"], ")"}], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = B + \[Integral] \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39955687528125*^9},
 AspectRatioFixed->True],

Cell["\<\
This is one, formula for the integral.   However, we will use the following \
form of the integral to continue the computations.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"B", " ", "+", " ", 
      RowBox[{"A", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "z"}], ")"}], 
           RowBox[{"1", "/", "4"}]]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"Log", "[", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "+", "z"}], ")"}], 
              RowBox[{"1", "/", "4"}]]}], 
            RowBox[{"\[ImaginaryI]", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "+", "z"}], ")"}], 
              RowBox[{"1", "/", "4"}]]}]], "]"}]}], "+", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", "z"}], ")"}], 
             RowBox[{"1", "/", "4"}]]}], 
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", "z"}], ")"}], 
             RowBox[{"1", "/", "4"}]]}]], "]"}]}], ")"}]}]}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399556878359375*^9},
 AspectRatioFixed->True],

Cell["Now solve for the coefficients  A  and  B.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eq1", " ", "=", " ", 
     RowBox[{
      RowBox[{"F", "[", 
       RowBox[{"-", "1"}], "]"}], " ", "\[Equal]", " ", 
      RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eq2", " ", "=", " ", 
     RowBox[{
      RowBox[{"F", "[", "0", "]"}], "  ", "\[Equal]", " ", 
      InterpretationBox[
       RowBox[{"-", "\[Infinity]"}],
       DirectedInfinity[-1]]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"eq1", ",", "eq2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"A", ",", "B"}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"F", "[", "z", "]"}], ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq1", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq2", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<We will use the replacements A\[Rule]1,B\[Rule]0\>\"", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"F", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"A", "\[Rule]", "1"}], ",", 
         RowBox[{"B", "\[Rule]", "0"}]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3995568825*^9, 3.399556886046875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph conformal mapping  w = f(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", " ", 
     RowBox[{
      RowBox[{"4", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "z"}], ")"}], 
        RowBox[{"1", "/", "4"}]]}], "+", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "z"}], ")"}], 
          RowBox[{"1", "/", "4"}]]}], 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "z"}], ")"}], 
          RowBox[{"1", "/", "4"}]]}]], "]"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", "-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "z"}], ")"}], 
           RowBox[{"1", "/", "4"}]]}], 
         RowBox[{"\[ImaginaryI]", "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "z"}], ")"}], 
           RowBox[{"1", "/", "4"}]]}]], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "8", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00001", ",", "4.00001", ",", "0.2"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "3.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "4.3"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          FractionBox["\[Pi]", "2"], ",", "\[Pi]"}], "}"}]}], "}"}]}]}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the upper half plane Im[z] > 0 under the mapping\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39955688890625*^9, 3.39955691009375*^9}, {
  3.400192653578125*^9, 3.400192653796875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We are done!\n\nAside.  If you prefer you can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s integrand for calculating f[z]."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         FractionBox["1", "4"]], "z"], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "8", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00001", ",", "4.00001", ",", "0.2"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "3.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "4.3"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          FractionBox["\[Pi]", "2"], ",", "\[Pi]"}], "}"}]}], "}"}]}]}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the upper half plane Im[z] > 0 under the mapping\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39955691203125*^9, 3.399556915328125*^9}, {
  3.400192658609375*^9, 3.4001926588125*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{"w", "  ", "=", "  ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"-", "\[ImaginaryI]"}], "2"], 
     SuperscriptBox["z", 
      FractionBox["1", "2"]], 
     RowBox[{"(", 
      RowBox[{"z", "-", "3"}], ")"}]}]}]}]]],
 "  maps the upper half-plane onto the domain indicated in Figure 11.85.   \n\
Hint: Set  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "1"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", 
    RowBox[{"-", "d"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["let",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", "d"}], "\[Rule]", "0"}]}]}]]],
 ". "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{401, 175},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\t\t\tFigure 11.85  ",
 "The region with ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "1"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    FractionBox["\[Pi]", "2"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", 
    RowBox[{"-", "\[Pi]"}]}]}]]],
 "."
}], "Text",
 CellChangeTimes->{3.506803433671875*^9}],

Cell[TextData[{
 "Solution.  The exterior angles are  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    FractionBox["\[Pi]", "2"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", 
    RowBox[{"-", "\[Pi]"}]}]}]]],
 ",  and the formula for the derivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " is  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "1"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "0"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"-", "\[Pi]"}], ")"}]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", " ", 
     SuperscriptBox["z", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], "1"]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", " ", 
     SuperscriptBox["z", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]], 
     RowBox[{"(", 
      RowBox[{"z", "-", "1"}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z", 
        FractionBox["1", "2"]], " ", "-", " ", 
       SuperscriptBox["z", 
        RowBox[{"-", 
         FractionBox["1", "2"]}]]}], ")"}]}]}]}]}]],
 " \nintegrate and get \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{"B", "  ", "+", "  ", 
    RowBox[{"A", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["2", "3"], 
        SuperscriptBox["z", 
         RowBox[{"3", "/", "2"}]]}], " ", "-", " ", 
       RowBox[{"2", " ", 
        SuperscriptBox["z", 
         FractionBox["1", "2"]]}]}], ")"}]}]}]}]],
  AspectRatioFixed->True],
 "\n\t\t\t\nuse the conditions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "0", ")"}]}], " ", "=", " ", "0"}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "1", ")"}]}], "=", "\[ImaginaryI]"}]]],
 "  and solve the resulting system for ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["B",
  FontFamily->"Courier New"],
 ".  The desired result is\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox[
     RowBox[{"-", "\[ImaginaryI]"}], "2"], 
    SuperscriptBox["z", 
     FractionBox["1", "2"]], 
    RowBox[{"(", 
     RowBox[{"z", "-", "3"}], ")"}]}]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "4."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670690453125*^9, 3.50670690453125*^9}}],

Cell[TextData[{
 "Enter the formula ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], "[", "z", "]"}]],
  AspectRatioFixed->True],
 " and integrate it to construct  f(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f1", ",", "A", ",", "B", ",", "z", ",", "F"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], " ", "=", "  ", 
     RowBox[{"A", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", 
         FractionBox["1", "2"]], "-", 
        SuperscriptBox["z", 
         RowBox[{"-", 
          FractionBox["1", "2"]}]]}], ")"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"B", " ", "+", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{"A", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", 
           FractionBox["1", "2"]], "-", 
          SuperscriptBox["z", 
           RowBox[{"-", 
            FractionBox["1", "2"]}]]}], ")"}], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = B + \[Integral] \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399556939421875*^9},
 AspectRatioFixed->True],

Cell["\<\
This is one, formula for the integral.   However, we will use the following \
form of the integral to continue the computations.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"B", " ", "+", " ", 
      RowBox[{"A", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SqrtBox["z"]}], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           SuperscriptBox["z", 
            RowBox[{"3", "/", "2"}]]}], "3"]}], ")"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3995569428125*^9},
 AspectRatioFixed->True],

Cell["Now solve for the coefficients  A  and  B.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eq1", " ", "=", " ", 
     RowBox[{
      RowBox[{"F", "[", "0", "]"}], " ", "\[Equal]", " ", "0"}]}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{"eq2", " ", "=", " ", 
     RowBox[{
      RowBox[{"F", "[", "1", "]"}], "  ", "\[Equal]", " ", 
      "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"eq1", ",", "eq2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"A", ",", "B"}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"F", "[", "z", "]"}], ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq1", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq2", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399556946109375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph conformal mapping  w = f(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      FractionBox[
       RowBox[{"-", "\[ImaginaryI]"}], "2"], 
      SuperscriptBox["z", 
       FractionBox["1", "2"]], 
      RowBox[{"(", 
       RowBox[{"z", "-", "3"}], ")"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "4", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00001", ",", "2.00001", ",", "0.2"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "2", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "3", ",", "3"}], "]"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the upper half plane Im[z] > 0 under the mapping\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399556949109375*^9, 3.39955695375*^9}, {
  3.400192663265625*^9, 3.400192663484375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the Schwarz Christoffel formula to show that  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{"B", " ", "+", " ", 
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         RowBox[{" ", "1"}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "+", "1"}], ")"}], 
           FractionBox["2", "3"]], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], 
           FractionBox["2", "3"]]}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}]}]],
  AspectRatioFixed->True],
 "  will map the upper-half-plane onto an equilateral triangle. \nHint: For \
convenience we have chosen  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "1"}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztndmTJ0dxx5v5/WZmZ3b2PrXX7KFjJaHDXAIMBiQM5jYGcelAq5WQBEhg
cYTt8PXgCD/7DMC3HeGwn3jx//fzdnVVZR2frM6enhlhwgSama2uqq7K/OZR
WVnVX7jz49dfffPOj9+4e+f6p9++88PX37j7o+uf+sHb94oW7+q6tT/ouu6X
17v+79W9P/2P1b3/Dz/+qP/RFx9GwSv9r0U/guv9X2v9Xzf6v5axbL3/6+Px
r9349EZscTP28v5Y7z/jXyeHV73qfrlanR9Ed839XGZl4b1F1VtQ9jSU7ULZ
DX7NTaj6ASj7Lyjzk3o5zvIGVKJ50EtpHta21+IInpo29OcjI9eYPJdihXXo
5WJ8uoSn9zWf0nyJfjTfqzzYJ5svbJDhbvFI8KfA0gQjHZnWXkv+9//74LSp
vRIFtBDV4q9nmk/lr6fiX/8d/zo9vEoUy0kYz2vvXKX/ibj4ZV/D/XV8eP5s
/2ujL73XfiDwyv33NJRd63+u9f84C09PQNkxY70z2tsMo+qns3o4IUF48B5f
tkrIcjTWW8WyTai3CfU2oN4RqHcU6j0ZwKLA9Dlos2hqCHnfRWi7AW1pTjTW
LSONNqAe0Wgd6q3P6I/msQX1Wrzu4L1p24vQlqzREto+7p+Eth6PT/4KwfHx
FI5hjP3v0/8Px183OD5RwNGz+4lfITg+xkM8q4PxISPwThpH8OsMspNQjwD1
ENQj8Ky86njM+P5TroYv89rwRP9zzcicR+MrF9CiobIOAyWOW9swxePGsqP9
T8LLHP5egHq3od6TUG8tkvtRaOFYcATmcQQqW+G9Mbyy7nS9/0ktHo6DXMI7
zhweJtzr12HoG77MVfQNrIpzv9XHmjbIRQq+tMXOIQBtGXn4MLRw/yILMgdo
1J+bvqu2gBYPxUHSOxpAuw3VL0A9Apob0jFNMRyGYaJ6VoIu4ugJ73NQ9BuN
0adlD/Q/l31TUphzAKQaYlftYeP4Gp6NFTY7cYqkMgkixCorlLJJdJ37fdz9
3D/YEFtcf5swS2csjs+A0nu0WTpZvxlZugZtt6HtcuCHkKTzYx3iHcusTNEm
DqzObsSA04oAd24+fNxwnRkn+7kDLazwibBYid1rQSqly3Ggn9X1JYvlmLet
qXarE/xebeaOQdeGvxQ7uj0AOPFTbFpnmdULfRyDPhZREVyJYyJHdSJozkeA
EGGtAHGDWy+4akFEWbZf9sqNhRYeVkjtRLqcN8LnfVCPaOXgmHk91QQ3Uubu
2XwttV7ovSQkNPrz0+B1cpiOomBPGCHn4HW0L7B6x4eDMQeRRMmPgeoE1FuL
FCIP0Qo0x2anE84PfyU+UfW2RUrJvbgJusfEIQTql4B5LrYgf24i9LYjYQnv
RGwhYmGbFpoln+ZXVcqe/Lo1zYxZYUmGdDHQotbP1kCDI6Fz0MjmEErfr7HE
Efh0RCnZOldlgh9bEVFd5qnEWWi2ezuO9EwcPcn24H0NW81FFxSLWEZ0kner
LhaXqV0jcRqjVumO9b+d50T+oXvR0ZK+E3BXCnn/bJlqhDHcnYhkopigFXc7
kXOkgVMGhFZETke6LFIFIqY83YwYK15+LMLrRBzkceigAa9M+aUCcNaMLMWG
qYHQrfASz1MNE3s2uZ3T2vbAkOdNx04fIetcJHwwWlHdI64+AP0egzKyuhlD
fXmled1AJuh+xaZkqq9SvoVhI3Egk0ATvagj8v7+Z2bcMhSDiC9TtVr7qpVb
EYKcgXJRxg7YD1Tq8SYHuTjbcbb6fk01W0fKW1D/KXir1yj3irahhTwtqFfC
w4vgnqmyjGBs4DCUZWqvYn+mudOu7tMhuBtRQoaNdgKEM4ViIw8l2cmotIe6
8/HOYJN3XKy7Tqpg0oJRLOQ1I1jF6JGzInZbjaqsacI3f78lEcOBaEQz0rRE
Lok5npoG5MsDLBXPm4AsvgbNdydIZ242VCVmXeJkYuZ1SBnnm8IDRZuzfSSH
fBnJQHwj+G5HUl+CFh+EFiebAD0anxIYlxG+pKHKFv2zHVDbyrJ7oSkiaxhY
dodPQ4tLOl7PRzTpTgNaio7jmUcjU6wLQr+ZUNPKooT7ZxuaPlI9DDc+ctsl
EEcAuQ9aHI/0I/f9Q9DiNEGAyU+TyqBSCVAZDklpVou/2EJvDVVpV8McNBLS
WV1IHEJkvgA9n4yUPWNA5jDtjhf7shVINjObgqdFDL6sVhUdx0wUQaesl70j
4RWRcytClkZ/NELWoDLPxq7Inf2whlaHKgLoVsTGFqHa6wkKgFjtStZBJRuu
Lu37pcs6j+2O8HdZx59s5RIlsw1N/xJarG/EYZL0kAZdZHK8Km3HdKxNqUd2
TM3nCTwvfBNXQINNl6+BKUTbi7EXMnW/qaG06JlgcSQHzTLVeXshodjC7bxn
WdC5v85Bf1d06DniOdV3RRPiGJxKAEKu6loclzVi5P5lVfUHjb9kCrVCpqVp
nTaUdk9ab9FkUObKjMHwVBhCLhCujh7xrev3/z4SZ01vJ3FUF11JL4Wwtgxi
5aGQ/vQgflFjm3vfTWh4Mg6Mhk2aNDEzEHTIwtQmQ0P5K2pAWF12qisW8Tka
WjBjnatGMnwjUpLE8qNGnMsSwbo1Rm8T62Rdxau7ZrpbwNuSxAPqgxYe4hzT
pIjoVxNkOwl9ECodawppFgPzMyeLJtwvFNxoQG8MtpVsdT4TzQDv0oJHV4CY
fBRGRSCUYActvyRB8GNGUNd8rcy9ojlzFHW89llE7qv7bUuN9rWkjA1DCZ6r
RCct6WH7XBzaI1BJIh20/SF7XAUcGbsdO4ch0kHOoQF9VgNH4qBqF3U7uR0T
IkNE0W/x92gRejti6SPwlKyCGBjydFJEhJ7QchdR1zEqk4JcAhoyYvq6ehSm
Ong3qjB92RCa7r4ewUPjowxfUTW0IyD+OimOFOmlMq7s3VLTD3NwrXJGja2t
x/kaMLyIsFA1QGbW0rZ0LECWGRTyUreKVNNZKdSumLSHEYcMzKCumLwJZer4
1F27Bo6fjYQnWSEc174h6IgVr7irFKmM+uwjiaSHBtaF3xxsV9vjA4Pp1Sk/
vDJBjMtSUM0oW2iGn3LTZQOL9hZIyRCVVWuOrm8Hh7Cy+vOgn4oXL70V+ayC
VKEndRO7GNXu0OrbUP02EcLzioLsglsK+UhKOBFCyY62p3UcuByEya94vw+X
9X7CNDmJ2BJ+JLRE7yKh+ATUIz9Rdb1q58pE93AzTDVvxaIT/fcsLSvvBPJa
oq68EaaRD9bVoc5J4silvK4L0cORk7SH5/5FYinrKYIHWWDrxn1pbQetXVum
SY4U6cW2ulIP+Kg7XBciJR+Bp3Pwn+/YrVbTDG7HxxCJzltAZx38VYzQkiLt
X0Uj2gc0u9iLswiXBm6sOP9eYlxq6IQgY8ewDa8pjAIPKFVpNOziW6tJHWrk
43gk0+Vk5AmjSJc/DR3R8qB1XprEdiqpM3KNqNbSDvjpqSbAsV9dPhkmRbwg
73O4hKV7CarfarLuQmRdmSng58YZeavGclY5vOY2oCctPqle5kNXCFWCEap1
IZ/yVGxGGRgi8w9Ap8/MwDQlm6hsEz9dPM5WxLoFYv+fqyT73DTEfG+sIv6+
Qzde14aG9GykAblxkn11rJzvAG3LuUsvA5MQusd6qcYOdRsRRGXWEmul5btr
RoejxTe4Bc0+CS1aMcIxDSwyVIgeao4uMT7TIE71Kv22DMKXS0NiCZUm4wac
JIAWjcOOZXcHql+LUycrcgZaEN6qvO7QyU4Ek3qmJXUOlHnu92qHnEoVW8ni
omKUeqTSX2CosMwV7ULb354hCHMStdXlZ8dLZx3+1nrrpR315siGNytIrApj
otDIGXhqKPZd3VpUc5COxLaFplbPvVsXXERGqwxRPYaRMi2x+soOVFVGTg29
kva6ZePqKrT4FLSwnnbXt0Aq1dCKZ6bWX92JzTa2fa9qwnbFoU6LgK68+rGe
E7HmWd3SxeVS5AfFaI5HyKt5J4qk16aQrSwJqRpCVffND1x2VmxCiSqqRRWV
QAIkTj1FG8SIX4a2n4YW1juOLGLj/1MzDKy7j8mqkddq6lo6cQh0JnWNxbgB
SdZriu4fIPAyVL8QyUT7crRvQwiSVV1770yN6ahKRFVPdFR+mb7DRNDs6pm9
+AnWpaRsLVBujxwdo4D078wQFiuUMhhqhr/raie766IPVmpL0T7JM9+m/0nr
pwIG4dV7ynjZPymRyzzoBJFcq0DyQkMiZUtqSg0ISvSj9TZP64UmFo451pS3
cgvWeybqEFXvQkJZrZjLmEMtZy/OQ4vPGMVyzu69rmjq5Uh0wde8FKkVms9y
+ZS1YcuI2IY8Pl3rPRlDoDF+oCGtLjyjlPLNOJ12hq5ya1rjTOuklFyhqkFA
rX5bFs0JotM6NMYrWtV+qkeHZfVCfJZsRhKxs7EtRW4+ewgiFty6dInTsc9U
kTIxTFOFjQjpelaj9mLqwvvniNro9vK4qEk8mQKorYTZykOtMrVXrKXVROFq
Ol2RhmqTHqs0sqNesGd6UnJ1qcQq5O5VaUlyIxQpSHG5Kej9OaNYzYlsqnk0
ik1uyVEZp/bl9Fo9ybbyKggF8zOHxo3XcI5h+AQP68rOb7Mzdlb5UedQ4ySU
URqtqisT7bPfsVNtrdba9EtVwQ6UyXqGPQDFH70vNqOk2M8fgmSoeOL9HMWO
BFIMpdUCR81WUdMfJw11/6EvUear0NCxM7tZNEVB0lX/jFZI6nWLK3ti/n7L
gWKGeEVDidHbNKkONcG5wKdcHbvnsqNGiVNfgMHsJedsKs5Yu0fDyYFTMa/e
mSnEIi1biBHgzmQ5YOXefssQaePhsrX4zcTKf3MDvg6icp7RcryBDPHsC9eG
EhGtEz0kMeIjVJSu24VdMfY+jnOT8+kr0na7kWi0WPySkfWOcu4uSev6r0Xr
FAfNBc96VpxJQkKe9BltTU/L+qi0cvbtlzF5uK3Lg2RJ3CgGKfLAPFdvFFcU
4RhurXsMVpdWlxcW5NZWe0oT3TMfnzcxWE2VqyM0vsbN+JTGokpPOEyeorME
uv8vO046JkBiUGhBA9aoFptK45KHa5UY16XblzB5LZ0/bkwrey8439FgKF98
qGctYZtGIuGKHfypa6yUsvr2DcvxVkD/RJlICWjdMrIadbIK1La6p2pQr7ci
6YloX4aOHFIcC61iSzhSN74YpoloZBPwxB+ebaLY5HUWdZkaP1FN5TKVmL0Y
UlkhEwkeTkWJk5JuRpmgQVJSSCvfoZI2JWBIW3gtO6EuDKelg69n3kBL4FrC
q+ZHqZvarUvoxsyxepyhaCsGip4q8sdh+NlJtNkGdVMcc6rlzl8AZreZmaRS
LMUojC7XPOsnqQydGBBEVKTZy+FrSfcBhLeMr6QUBes1FuUGR//7KE2Bl/iK
v7IQkrf2v1ntTDtdUA2zTH6TGem+ZEY1Ne1DgoD3l8i596+vQtmk87Zq/E9d
toc96gD3OMgFybq3RV3nbxEMkE8ERjLXKKaXyYZpSjOVRzq64QuW0fVLqUxy
QuqSEuNUb78oo91VOQM4tpkXJDosWMl0jD/LMU0xDtWfy9IweA4kdurlkQYj
dhOY+FVou98Bt7Yxcb0krpWyaXk0I2sAW/Y7eS6mtWJK5/NMrNA/KFFK63lR
eiUOmAC/G4HRuiszLcNrp+vErv63nFgYPePtO9svyYloKJBJ9SSTs5T+/jfF
2FYdGmP1WknXeRrokSHe+/srhyAtEnWc6sysl1RPBGQQg2UpRHUClGl4exQR
az0yuV5E7hq7oBR4YjqVSWp2CGuXOO7/HfZNCrQN4rOJTQLxR5OvbNvU5IZ3
vM+AG+lBkfD8hAq0rrR+fp74QHOhJY8VQocOXU/ptYSZieby24H9v4qIXhd9
gs6y4HqnxI/0zruHWdwZJtjx7u/lQnDGIXOi2WJSJtyIDhEvgNoeSMqI+B+t
YxqtFNvKmDtSUWpvy7tO33oFyiRvgKRwjpd3GAj2K6Qoc4kXEezebH/vQMZs
MHpe6l6CR+Tg3wdl5P1IDod6mpk/S2NDB5Xpq2h7OCLatvFEldD7aKIKy4F6
gb+a6qF+PJB8i6ItffiEvHDat5qj59vep3/snYruvQlbEkNmetGcmPljwyhe
jLyh+AAdRiGvhWbMt4nbODJ157ZF/f434VgxQs1iNmflwYiG8FgvBBi72a9F
lEkMcpAk/SaXI84Xj2pZte2txzxxKk+AeU5PNUlVYCQb3T7L2/ORrORF0EmW
Mwry+n9TWr7VShxpIJoPiSo8a21ZiROR8EmUYGtriWesaxAlbWjcyyWCnWoM
4RzUJ8ZJ0uQX5yI9+1LuflkFBf3o8nlepn7fYfiq6v3Z1qzQxweuPQePyGOg
CzTPDUTp+BCMNf9AvWs2FbXQgMRV99C6MrVm4a2SLlsjxqHLLz4O5S3fdYwm
pyIV6bOpRHdauFIGuBVLtItgxfAk0VsXf+FoRtPUTsVW/ndUlmoC1Jw017XA
l+Rt4XnXvlwi7eaJocE3I5ZpmUNSIideTsPTlmOTvp4wmSl53173HpcZ3bsJ
CWKRZOZMIutmAvFQvZLZ0ZDcNaK6HMIguVFcs2XXzXN+VPyle7iJqlr1AZWU
7vF5KTLFczUPan5Ewk6Vhph8Ax4R/EmILqTYW0VBpTVViDWT+1VeJedBXH2O
bnjQupLQ26ns0ZjMSD227at6RRzBT9p6x8+U7BodjqDDeYr4EA8oHEhnXkvI
eCJbs+bn+UersPw8kip0kpcqiwjEii6MkeS6OdZyspUeqffkMMavRayQB073
qdFpWDUsXLSVUHHDMmWdumq6OzfiN3bZMdkt1pLFv6vVWPKsddO2fE5lND3C
g4cWsJR4QdQlJ5C4JanMquSpt4TNgaZk5apKP8kn2FPGngxeyXVuvNs6A6KI
Si8vUs8a2UXsV+/qNMhLBh0PsfbHx1V9JPllmPRRiknKJXlWkrNLd/Up5Bde
p16j6VqSCbduCsxhw3CH0IZmJaw6SvcCZXUROx9eoxw2X0tUEpurlS0HHaSv
azlrG3lfMuj9pEFK3nu/3zv88cMmNOj+ZnXHxODrrDpM+iu+LZRYGGVb6Cgy
oZSaUN4KoEsilHtOo2vfZkJBm9GrYH3ZxdgzqZW7ETnWxfckJ23MQAW8LEtZ
yqlbjUMnuOy6WS3IpHMYkyzp2ogMEKJJGmiviNStmvTg2E+r6+1cKBJ/d6ck
rPAkkYKKRxxXFdlrmDZFFRH2WwRJy2jNQ2R4FdpaVeCoPHiQT930r8uUtdaI
1PAJ2dG78Noy0FkuiZojU+8ZRvz7DeaPSU1LQY5JzXqErjVrWnwg0SeDGtqK
REfp8f2Ky7aI1mIhTCZHktM2SQ5IhlomdkyGiAXfgbbTZAh8pVXrPEI7K3IR
GJn36epYBCdxpzarTlJBtIqN+OizDUtRz5uYt6E6UY+ERXbtrCIiBqPL41WN
T0t2DbeYTMig6EprHjnYJqaaelOl2g6voXGT4MhcaNlP4kIkfQ3aThIX2gLT
k+vGb5rq6t1pX9UbjP6vpeit4Xn1xtDNIqX+2IRUX3GiBPxInf+4BByPbKWX
kgTsRAlQvzS5XkA3DigITmoKqqhw5wNh0pX69T7XH+GRP67QSVB9DLxEvzf2
yqpsRlbXQM26Kx2c+F+3P/ez2Q6WZr2o4QDr8up9Q4MfBwyB4bkMzU7F8VqB
S04d2f9yp77/bzN5kSC168JCox5G4yucK/aN6UDecRgL7VdcalDv+1OwO8lc
cz1xEUJdcQS8HJRuyLjr0spyzZUxa1VFy011QlJjYKWSB/hPYKwE7DPFq/r/
CNMUEHSvzy4mqd0AcGw58XvVWEHXy96N1KKNwfpY+dbwQMd2Tri3VL7lPm6i
j1QPVfXcljTTGHARH6EUuNKrqJ/lBqKF/lotmyxIYmjFNoxD9f3De38K1eku
zDOeQIU4k1VWPwy9karhlMWbA4z7TvKbLEK3W/3f27EP6zeXw1Ky4CpdVE2J
5W9qyFtoYqcT33S/MO0W0uVF43pyo3rmyVq6657mKzUCs7cAaRZeANiRhtRh
p/lN+kFeimk0rj0LwYiuTOVfi8jciC1ovrT7RdpQcgZJf56BFhLi/qHnbIqO
hH6tk5IySVIjpjsrOn8WvFxy+f9oxabfP8M7R9ZM+hFvdPhYvfcyeTFOu2mN
L613crWgDWqmiFbiqWxnspfa5ozZDR62LjsYU5Nyxw8tRAiUchcjKYS3GkjU
F8JMH8sZxmg8yWRmJ0jFRra3BlOqq2ukLII5phBbKvtDw1+0wKeX00cDSU9K
mJWmSlZ6DLyJWV6EhyluVzl2y3Kh2j6C18eLOr79k8BLgk4ipZp/hKN9pa5r
OtaukzUjTa3qMhRngAxSYTmTv7dg1lNDbxTOJVGnRQLxT/b66KVq4hetmtAU
eV8glgWIk8KQLBX13p0RXA9v6/hAEYk/5aASZt5sQFXlqpqYI6sjyTSbjVTu
pWvo68Sdss/sgzoOaQOIAorqCYelxjrCg2jpYjFAAloYnByFvHqtQNyxM6N6
sK5a61RA2gvVI3pOClTpKU7WY9Zt/1e31zAYV42mZO9FeB3qWuNLHrW0c0zW
jw60E2qpnvsXLbQJxMtIGeX2lGEyR7JG4CIoQG4rC9oGI40viRpEWjVV1VCP
aD8N4fZTyKs8wz50pRxYnpaYoSqbqmo1BLKFLWCrCX3Ui3eQKc1IroCjwCmB
nVS5G8imNqSd+FQuNljMALTvYit2i7dx+Wdk9ijhlLSxfAqMrNH3jAhdiH0d
AVJnP+aW5JBY0Sk2r/9vNNxRGL7py7gGEn8A1Wk7nRY2VgXs2p7pgiuRBF+2
cNIF8qJIF3VdPw7RZ/tHpM0JXqQKyWUgKowBLZRPDTimZerRo/LLo/1/W4A7
uom8ZeZbXkr4z/2bvZQPDxXegt6I/OSx0aF1AhKxhFbSwzss+UCKnaib1ngc
n5b1DAq5moRSMs5E4hKl/e/yarJ0XmGl3CJX6yKUKUqvbJvWI+DqXq62VSXM
Dc8/MvzrTehKvvhFORuESzK6VlzKVvqEQ/S4Q+hn2zW+omAAIzkaVpUpcyEz
8N3hqeKG6OqxSvdquXgpTlacgmhdVmWuYF3Z5LjqyyYOCH904PD3YTgEPILM
fgNU/zpXfld1wiT0+v1jsmKSRr7fKKXNUMIE4dXqQVoNux5YtH+wQMcubwW1
lu1j+J+aUpLW8+r1e1D9QhwcTcaKXlqoEnrFcyJr5cPriYh7IKvjsyoUki4C
Ldl5Aq3kNNEVZ9+dxKo6/p0qWDpU36VHCQsVp1+wroTf+ZKi9jEqq8XwuPsu
VL/UfMEc3LVuLB3zb4LfQj6Y7ueMY5LqESbJpbYqUkfMy1B5GhzHnbtSwCJe
kusEgKxLEvvYVk+wsirDj+pguxLBRuI6E1hsJkPIwIokVbuphmMOfmRP/do+
AIaQPja3oNcK+oRLXlLtv0i1RFq/9YVh2ziZPx8f/noDml1LX+nHR8qKLlEk
TMlFy7Q8neMHqEQnH1odmsE+ntE6JWhNSHiv+rMoYNEn48pevXtNvcYEWQHH
bGxc+63hBa+rMOM1DaVfWOEmQdqisq7C9g99ctBpDtxOxSmQUpyEObWXUTdA
TSGz4qy92b3ndU3H8/nYMPrXoNtdbfquGtkOK9Zkt4SGNPYhoJwV4+Qht6N1
IRVt2pEjQBA8HulDb9Uh2Pb09UTsKuCkee79Q7Ijyg2nSJ+GB6cy0+OLvjZK
+NqM9KNgghVfsj9GA26VjeGLDA31py7/3ahoP5sQRvk025FCxM5RJecdk0kb
snLuevSb4BmqpPv+mVy+NuFkWmWNvAP2KlS/Dt3W1EpbUFoX6TU5qk6Tta70
rMcpWleUs6xYU4UIT9IL7cHtQovXjfNomaXULwp3BvZ/dxGhK3LhJcHDvys8
TI8NhTLii9VxacCM1JZ8eYdYocOsWuQshREcfWl9k3JsohuNfnfi24mVVjDJ
spRazPH6g7lL6wUXKSF8RdCNRGOFto4Can5WEnmqXmc9bP2JocErUJ201Mkm
8VX4uBalTdRA0rJSNUiqmZ+KL6ThKLfFc2XSKZNgoGbkq/PJDnaPtaCFozWf
9OlpjD87DG7V6Xkzjozn4rStrFVXIK4Xea+6tnJP6YDKHJOgmsrMf6xcuaJF
ajBC2arQv3tR+p55d43MozvzlhpNHe3dLj2N5vRB8JdmvKk5MYI1EjvCwXWo
Rzho7aIWilm2Fgofk462IwrC5Mbv4lAw8My+YGC1utgXUWbSqWJ8foytr75X
OEIlVnWprh7c2KijOWxOCexpjo6JeoclsVf1ucmPJDHx7Hx5Bjspf4KW/q0P
yY/pxemxISItLYWt1voi1Jsm4eOLbDcjJ7Ck1SUG2Io4ujI/HrImnxwYfgeG
fgOqWxlOskSbPq10UJp0695k6y1jc1hM381tXZuUkt8ap5OAqrors9AMz5jp
C+UToUCyT/t/Vij467u7ePGp2LZQjUBd7nR5vSmnsykIRp7iHHa/7gdRGEwr
N0idORSspzwt+MfmxxpIIdfhU8O/XoLqJPdWZhNhWx8lTq0fcVwO5RWdUoo2
hQmtJ0mncd8a5GTF5sY+VM+jjCGQ0dJuYwBoMJakmK7XsjLWeh5tI5WPnLuK
4FBojTx9GqmVuzehHqly3f+owv36xVbVhgHNpsHOb0N1klMrO4lIZG1ob0ci
BIRJNRV4j6Oie/HmCGZmhX352OVNodwqg5/WmUYySJfYWMljPUWnepAG9pFN
obQpK/uskqeGHAvD0bpPLpZ1HGumdYFn34tGmSP2Wcnj0OPsW+uA4hjTdM96
HFSUcmNlGsmcHiFsfRgJDPnItwPG2Th8Z6F7AarfhOqkOs9DvXONyehfhaJY
zDgTyTYStIiJdC+TVfKC91LOsf+3uGTkgxFkW7GkMXf5QJlYWWWKU1j5d8LP
IfMJPM0oUESfSZoveMwz2YxWcxqSD6ZwH2RpPjMQ7nkjd0hTEndS0oRyK2to
EVAFmBWWUHSDWHJrEkuSep3PZch21CqBXxdGVeFa4sJnD4YLsomikHMv6zH5
dqKVAVY9RgxQLw7fiiZXDbR4qj4HXdyC6kRVmmK4kTFTEx3C23q/Ep1D7+Q7
bHshsBXhlWrveGuuml7H8efPHQzRKeRHFsh6GLx1G1Bl5bIdpoNkRjhzRdqb
KCD4b1loYM+3oPr9M9gjSoHCXNZroFr3+lVuRvYJ3DGm0CXAOlM4C1DN8iDM
0TGjLny9fPjqr4H8dIKFIiHkedJayXpbJjFC/fyVYSwUfJzGkjzMZl33kkSr
ef+fPxjeSKRckoCt9+jS+Mlzlfj5HOrfD/VISxH11RvXsvmmT78wkPsb0NkD
M8gtK09yckgoojZB10y9VJkIoC6qaFVjZQFlCtEIrA4cLSC+OJ8Z6jfG1G+V
k28n1ymletP8DS9R1PLtAuv3h67MEAnJv24tqcdWPp4LXzdy4QrUIy6IuaQo
A4V7xJuu6w0aePhf40s2qzSHiwSLXAsrC0gk5NuP1qAbseBLB8MCWilS+IBc
WplOQWRyBhXnkcZEfViZ8gDUI7mQrzyrN7K4p2T8PCu+Bq960MiKS574mTvn
MVkfuq68BJseOhE4HKoOInI5vmm/CU3ol2y2Bc/Z4YK8g9/dfzIPKmLlsp8X
USJVE0sx16tD23sF9MKr0MuDUI8odTKOKow4jJfXWF8epvQsdE/0oZTv+yIU
bjBW1NujXD83YnOyu3No0cqs2GcaXIiT8AgNDXahsiTQkGIQpUKrXqKHey/Z
fKr8kJF4BBYq+71hun9qJNTZiHwyGlehxTIipZ1WSP4WUyuMgEzUNWjx1/PJ
82zEx0NQiQglKcRkW0htOCdgPSVFZQ/5Uykr9tbb6cdEqAdiC7qmlE77UdlX
BpJ9PfKJ1qdEMgnTEFJIuxyLJAuVvbZcpHprjFCSI0brACLUzTg3+gzRREJ9
K3Z2HSqRApLv9tHCloy3NUmt/Z1MMoVEnt04o7fhKQWpqOyrA3leiJ2RNiDy
yGKXLBcp2jnkkS9Z0XpjF1pcjjP6KTylMVPZYO66l2JnFNol8mzFFtb4pDVZ
RI29uiIK7xF5LsYWfzifPHdjZ9ZkemevnO9FO+Fkc6w75mrShnsbhaZJIZyL
M/oTeEo+NJUNDvVwDnyR2ohx8ihQs87YWu9ipAytgIgyp+Nk/nw+Zd6InZHq
dlrP7aMSgkl1jO1Dl23Telfj22jaJ+JI/wKetgK3adkQUxguUHS7lxQ9vy8O
ZBJP9kgKUk8ESTcg1QNyk/nL+ZT5SezMEXyn/4sCtkQF2n217k+TaSQqbMRR
nYgj/Sto29pRScuGaGvnlMzJ/gmhmvLVyO2iWDgF/kkgKRvzdBzVL6BFa0s1
LftmMkXDS2myZPP3e7L03p8d3rQpx4O24Mg5ImeLwGZ978+hrJWlk5Z9a9q0
bzWouZdpEycoz+SApv3H8OgWvJ6mTStOcgFo5UHhbnovTZtku/W95rTsuWnT
pjUqaXcyM7QypUW/ldwHNG3aqqBpkyNqnbZs5lCQjyb7D1BGrgeVPT9tsrRF
QvtLFOmmgA1Fzq3T/scG3sbKXpg27QcjT6wByauBl0k998p7JbeNKDqgCdKO
QxWSu/cXeWFpzKkbeugeNk7nnxqCMlb24rTp3E7r+fLdkemEskOcDtlRgl8K
mFCXpnMlwtQLVujEOqd/hjLrfWPf1udELCIpd0OnaBjpTlo+Uaeksv4FylpX
DqVlL02bJ5UtIp9IT8pmEpmR1jt+haYoVoy8HNkrom17VQMXvfwrlJFBobI7
+hRb9ictk5g3rVYkN4I8XurvHZ4iOdISt6aAw5n4lJZwtCCgnZ9/gzLTPWv3
/ntZnyJt8l2HMr8L2/mNgP4vlAm3JHexNArh/x+Z7Kk4CWvOiXyokoKOu1B2
G3r5d/eTr2mjt97Vp0rOE5nx83Gq8cAGZjgdifVa28fkIKSj+g/3U/1IYFr8
ij43MtPkNTtzeD41lmMtDnfMtKzZjW07/ybepCXVRP09Am3/rv/pslCOFYBL
f7+mT+YReBGtyK/HF9EUSBoJXDSFv897TlJqmpOh3AOaDMXQSGBJyqityoWC
03Kfk7Tt0q8bvz5tHhTlJYwTOilO/ii0/ZtIdplH+L1RzHGoaZjMo/By0qxE
WJoMtX03tP3bYjIJE/TJJKqy/1cDa3OmRfylrVGa1s8a01prTkvK/LT+zDgt
iuETfKgtbeU8pk4rH2Y8qJTEcUyTeDe8lHZTiL7Ulvyfx6Htz2GYR+cPnV5P
NHwM6pGfSkP/BQzzJ/ow57zqcahHRxLUYW73g3xLH9zjA25WfP/4E9DiCahH
ixhq634OItJ17/pfBxMd0Q==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{632, 175},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  The exterior angles of an equilateral triangle are  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    FractionBox[
     RowBox[{"2", "\[Pi]"}], "3"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", 
    FractionBox[
     RowBox[{"2", "\[Pi]"}], "3"]}]}]]],
 ",  and the formula for the derivative  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " is  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "1"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{"2", "\[Pi]"}], "3"], ")"}]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{"2", "\[Pi]"}], "3"], ")"}]}], "/", "\[Pi]"}]]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]}], ")"}], 
      RowBox[{"-", 
       FractionBox["2", "3"]}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{"-", 
       FractionBox["2", "3"]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{"-", 
       FractionBox["2", "3"]}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{"-", 
       FractionBox["2", "3"]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", " ", 
     FractionBox[
      RowBox[{" ", "1"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        FractionBox["2", "3"]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", "1"}], ")"}], 
        FractionBox["2", "3"]]}]], " "}]}]}]}]],
 " \nintegrate and get \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{"B", "  ", "+", "  ", 
    RowBox[{"A", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       FractionBox[
        RowBox[{" ", "1"}], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          FractionBox["2", "3"]], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", "1"}], ")"}], 
          FractionBox["2", "3"]]}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}]],
  AspectRatioFixed->True]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "5."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706908125*^9, 3.506706908125*^9}}],

Cell[TextData[{
 "We shall investigate three cases of this formula.\n\n(i)\t",
 Cell[BoxData[
  RowBox[{"A", " ", "=", " ", 
   RowBox[{
    RowBox[{"1", "   ", "and", "   ", "B"}], " ", "=", " ", "0"}]}]],
  AspectRatioFixed->True],
 "\n\n(ii)\t",
 Cell[BoxData[
  RowBox[{"A", " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"\[Pi]", "/", "6"}]}]], "   ", "and", "   ", "B"}], " ", "=", 
    " ", "0"}]}]],
  AspectRatioFixed->True],
 "\n\n(iii)\t",
 Cell[BoxData[
  RowBox[{"A", " ", "=", " ", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"Gamma", "[", 
        FractionBox["5", "6"], "]"}]}], 
      RowBox[{
       SqrtBox["\[Pi]"], " ", 
       RowBox[{"Gamma", "[", 
        FractionBox["1", "3"], "]"}]}]], "   ", "and", "   ", "B"}], " ", "=",
     " ", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], "+", 
     RowBox[{"\[ImaginaryI]", 
      FractionBox[
       SqrtBox["3"], "2"]}]}]}]}]],
  AspectRatioFixed->True]
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       FractionBox[
        RowBox[{" ", "1"}], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          FractionBox["2", "3"]], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", "1"}], ")"}], 
          FractionBox["2", "3"]]}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00001", ",", "4.00001", ",", "0.5"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}]}], "}"}]}]}], "]"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the upper half plane Im[z] > 0 under the mapping\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The complete image is an equilateral triangle.\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39955696334375*^9, 3.399556964765625*^9}, {
  3.400192668046875*^9, 3.400192668234375*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"\[Pi]", "/", "6"}]}]], 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         RowBox[{" ", "1"}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "+", "1"}], ")"}], 
           FractionBox["2", "3"]], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], 
           FractionBox["2", "3"]]}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00001", ",", "4.00001", ",", "0.5"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}]}], "}"}]}]}], "]"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the upper half plane Im[z] > 0 under the mapping\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The complete image is an equilateral triangle.\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3995569751875*^9, 3.399556979140625*^9}, {
  3.4001926733125*^9, 3.400192673703125*^9}},
 AspectRatioFixed->True],

Cell["\<\
For our next construction we will start with the unit disk and map it onto \
the upper half plane, then onto the triangle.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], "=", "z"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"tri", "=", 
    RowBox[{"PolarMap", "[", 
     RowBox[{"Iden", ",", 
      RowBox[{"{", 
       RowBox[{"0.0", ",", "0.99999999999999", ",", "0.0999999999999995"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        FractionBox["0", "12"], ",", 
        FractionBox[
         RowBox[{"24", "\[Pi]"}], "12"], ",", 
        FractionBox["\[Pi]", "12"]}], "}"}], ",", 
      RowBox[{"Ticks", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Start with the unit circle |z| < 1.\>\"", "]"}], ";"}],
    " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3995569869375*^9, 3.399557001515625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox["3"]}], 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "z"}], ")"}]}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", "z"}]]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"tri", "=", 
    RowBox[{"PolarMap", "[", 
     RowBox[{"S", ",", 
      RowBox[{"{", 
       RowBox[{"0.0", ",", "0.99999999999999", ",", "0.0999999999999995"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        FractionBox["0", "12"], ",", 
        FractionBox[
         RowBox[{"24", "\[Pi]"}], "12"], ",", 
        FractionBox["\[Pi]", "12"]}], "}"}], ",", 
      RowBox[{"Ticks", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"3", ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "4.35"}], ",", "4.35"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "4.35"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", 
       FractionBox["1", "2"]}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the the unit disk |z| < 1 under the mapping\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<w = S[z] = \>\"", ",", 
     RowBox[{"S", "[", "z", "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<is the upper half-plane  Im[w] > 0.\>\"", "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    S[0] = \>\"", ",", 
      RowBox[{"S", "[", "0", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3995570084375*^9, 3.399557025140625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"Gamma", "[", 
          FractionBox["5", "6"], "]"}]}], 
        RowBox[{
         SqrtBox["\[Pi]"], " ", 
         RowBox[{"Gamma", "[", 
          FractionBox["1", "3"], "]"}]}]], 
       RowBox[{"\[Integral]", 
        RowBox[{
         FractionBox[
          RowBox[{" ", "1"}], 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z", "+", "1"}], ")"}], 
            FractionBox["2", "3"]], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z", "-", "1"}], ")"}], 
            FractionBox["2", "3"]]}]], 
         RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], "=", 
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["3"]}], 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "z"}], ")"}]}], 
        RowBox[{
         RowBox[{"-", "1"}], "+", "z"}]]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tri", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"F", ",", 
       RowBox[{"{", 
        RowBox[{"0.0", ",", "0.99999999999999", ",", "0.0999999999999999"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["0", "12"], ",", 
         FractionBox[
          RowBox[{"24", "\[Pi]"}], "12"], ",", 
         FractionBox["\[Pi]", "12"]}], "}"}], ",", 
       RowBox[{"Ticks", "\[Rule]", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
          RowBox[{"{", 
           SqrtBox["3"], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"poly", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             SqrtBox["3"]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"tri", ",", "poly"}], "]"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the upper half plane Im[z] > 0 under the mapping\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<w = f[z] = \>\"", ",", 
     RowBox[{"f", "[", "z", "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<This a familiar equilateral triangle.\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The center is  \!\(\*SubscriptBox[\(w\), \(0\)]\) =   \[ImaginaryI]\
\!\(\*FractionBox[SqrtBox[\(3\)], \(3\)]\)  = \>\"", ",", 
      RowBox[{"Chop", "[", 
       RowBox[{"N", "[", 
        RowBox[{"\[ImaginaryI]", 
         FractionBox[
          SqrtBox["3"], "3"]}], "]"}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<               \!\(\*SubscriptBox[\(w\), \(0\)]\) =  \
f[\[ImaginaryI]\!\(\*SqrtBox[\(3\)]\)] = \>\"", ",", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{"f", "[", 
        RowBox[{"\[ImaginaryI]", 
         SqrtBox["3"]}], "]"}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<               \!\(\*SubscriptBox[\(w\), \(0\)]\) =  \
f[\[ImaginaryI]\!\(\*SqrtBox[\(3\)]\)] = \>\"", ",", 
      RowBox[{"Chop", "[", 
       RowBox[{"N", "[", 
        RowBox[{"FullSimplify", "[", 
         RowBox[{"f", "[", 
          RowBox[{"\[ImaginaryI]", 
           SqrtBox["3"]}], "]"}], "]"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399557029609375*^9, 3.39955703546875*^9}, {
  3.40040453284375*^9, 3.4004045420625*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the Schwarz Christoffel formula to show that  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{"B", " ", "+", " ", 
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         RowBox[{" ", "1"}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "+", "1"}], ")"}], 
           FractionBox["1", "2"]], 
          SuperscriptBox["z", 
           FractionBox["1", "2"]], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], 
           FractionBox["1", "2"]]}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}]}]],
  AspectRatioFixed->True],
 "  will map the upper-half-plane onto a square. \nHint: For convenience we \
have chosen  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "3"], "=", "1"}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{605, 175},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  The exterior angles of a square are  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    FractionBox["\[Pi]", "2"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", 
    FractionBox["\[Pi]", "2"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", 
    FractionBox["\[Pi]", "2"]}]}]]],
 ",  and the formula for the derivative  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " is  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "1"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "3"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]}], ")"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "0"}], ")"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]], 
     SuperscriptBox["z", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", " ", 
     FractionBox[
      RowBox[{" ", "1"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        FractionBox["1", "2"]], 
       SuperscriptBox["z", 
        FractionBox["1", "2"]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", "1"}], ")"}], 
        FractionBox["1", "2"]]}]], " "}]}]}]}]],
 " \nintegrate and get \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{"B", "  ", "+", "  ", 
    RowBox[{"A", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       FractionBox[
        RowBox[{" ", "1"}], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          FractionBox["1", "2"]], 
         SuperscriptBox["z", 
          FractionBox["1", "2"]], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", "1"}], ")"}], 
          FractionBox["1", "2"]]}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}]],
  AspectRatioFixed->True],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "6."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670691271875*^9, 3.50670691271875*^9}}],

Cell[TextData[{
 "We shall investigate two cases of this formula.\n\n(i)\t",
 Cell[BoxData[
  RowBox[{"A", " ", "=", " ", 
   RowBox[{
    RowBox[{"1", "   ", "and", "   ", "B"}], " ", "=", " ", "0"}]}]],
  AspectRatioFixed->True],
 "\n\n(ii)\t",
 Cell[BoxData[
  RowBox[{"A", " ", "=", " ", 
   RowBox[{
    RowBox[{"0.38137988175090654", "   ", "and", "   ", "B"}], " ", "=", " ", 
    "1"}]}]],
  AspectRatioFixed->True]
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       FractionBox[
        RowBox[{" ", "1"}], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          FractionBox["1", "2"]], 
         SuperscriptBox["z", 
          FractionBox["1", "2"]], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", "1"}], ")"}], 
          FractionBox["1", "2"]]}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00001", ",", "4.00001", ",", "0.5"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "0", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "3", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the upper half plane Im[z] > 0 under the mapping\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The complete image is a square.\>\"", "]"}], 
    ";"}], " "}]}]], "Input",
 CellChangeTimes->{{3.399557063046875*^9, 3.399557066484375*^9}, {
  3.400192678515625*^9, 3.400192678734375*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       FractionBox[
        RowBox[{" ", "1"}], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          FractionBox["1", "2"]], 
         SuperscriptBox["z", 
          FractionBox["1", "2"]], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", "1"}], ")"}], 
          FractionBox["1", "2"]]}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], "=", 
     RowBox[{"f", "[", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "z"}], ")"}]}], 
        RowBox[{
         RowBox[{"-", "1"}], "+", "z"}]]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"graph", "=", 
    RowBox[{"PolarMap", "[", 
     RowBox[{"F", ",", 
      RowBox[{"{", 
       RowBox[{"0.0", ",", "0.99999999999999", ",", "0.0999999999999995"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"2", "\[Pi]"}], ",", 
        FractionBox["\[Pi]", "12"]}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "3"}], ",", "0", ",", "1"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the upper half plane Im[z] > 0 under the mapping\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The complete image is a square.\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399557099765625*^9, 3.39955710584375*^9}}],

Cell["\<\
For our last construction we will start with the unit disk and map it onto \
the upper half plane, then onto the square.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], "=", "z"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"Iden", ",", 
     RowBox[{"{", 
      RowBox[{"0.0", ",", "0.99999999999999", ",", "0.0999999999999995"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"2", "\[Pi]"}], ",", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}]}], "]"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Start with the unit circle |z| < 1.\>\"", "]"}], ";"}],
    " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399557141984375*^9, 3.39955714675*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], "=", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "z"}], ")"}]}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", "z"}]]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"S", ",", 
     RowBox[{"{", 
      RowBox[{"0.0", ",", "0.99999999999999", ",", "0.0999999999999999"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"2", "\[Pi]"}], ",", 
       FractionBox["\[Pi]", "12"]}], "}"}], ",", 
     RowBox[{"Ticks", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"2", ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4.375"}], ",", "4.375"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "4.375"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the the unit disk |z| < 1 under the mapping\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<w = S[z] = \>\"", ",", 
     RowBox[{"S", "[", "z", "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<is the upper half-plane  Im[w] > 0.\>\"", "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    S[0] = \>\"", ",", 
      RowBox[{"S", "[", "0", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399557150375*^9, 3.399557151890625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"1", "+", " ", 
      RowBox[{"0.38137988175090654", 
       RowBox[{"\[Integral]", 
        RowBox[{
         FractionBox[
          RowBox[{" ", "1"}], 
          RowBox[{
           SqrtBox["z"], 
           SqrtBox[
            RowBox[{"z", "+", "1"}]], 
           SqrtBox[
            RowBox[{"z", "-", "1"}]]}]], 
         RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], "=", 
     RowBox[{"f", "[", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "z"}], ")"}]}], 
        RowBox[{
         RowBox[{"-", "1"}], "+", "z"}]]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"square", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"F", ",", 
       RowBox[{"{", 
        RowBox[{"0.0", ",", "0.99999999999999", ",", "0.0999999999999999"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"2", "\[Pi]"}], ",", 
         FractionBox["\[Pi]", "12"]}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"polysqr", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"square", ",", "polysqr", ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}]}], "]"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the upper half plane Im[z] > 0 under the mapping\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<w = f[z] = \>\"", ",", 
     RowBox[{"f", "[", "z", "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<This a familiar square.\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The center is  \!\(\*SubscriptBox[\(w\), \(0\)]\) = \
\!\(\*FractionBox[\(1 + \[ImaginaryI]\), \(2\)]\) = \>\"", ",", 
      RowBox[{"Chop", "[", 
       RowBox[{"N", "[", 
        FractionBox[
         RowBox[{"1", "+", "\[ImaginaryI]"}], "2"], "]"}], "]"}]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<               \!\(\*SubscriptBox[\(w\), \(0\)]\) = \
f[\[ImaginaryI]] = \>\"", ",", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{"f", "[", "\[ImaginaryI]", "]"}], "]"}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399557157546875*^9, 3.399557164171875*^9}, {
  3.4004045496875*^9, 3.400404554671875*^9}}]
}, Closed]],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",
 InitializationCell->True]
}, Closed]]
},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{967, 614},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->False,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 132, 2, 29, "Text"],
Cell[1683, 50, 2266, 74, 137, "Text"],
Cell[3952, 126, 17361, 287, 189, "Text",
 Evaluatable->False],
Cell[21316, 415, 3159, 123, 155, "Text"],
Cell[24478, 540, 1457, 56, 101, "Text"],
Cell[25938, 598, 3615, 126, 227, "Text",
 Evaluatable->False],
Cell[29556, 726, 7912, 297, 293, "Text",
 Evaluatable->False],
Cell[37471, 1025, 25533, 436, 367, "Text"],
Cell[63007, 1463, 23762, 406, 353, "Text"],
Cell[CellGroupData[{
Cell[86794, 1873, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[86938, 1879, 171, 4, 29, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[87124, 1886, 466, 9, 65, "Text"],
Cell[87593, 1897, 412, 7, 65, "Text"],
Cell[88008, 1906, 6340, 211, 625, "Text"],
Cell[94351, 2119, 144, 6, 29, "Text"],
Cell[CellGroupData[{
Cell[94520, 2129, 173, 4, 37, "Subsection"],
Cell[94696, 2135, 412, 7, 65, "Text"],
Cell[95111, 2144, 951, 26, 166, "Input"],
Cell[96065, 2172, 1604, 45, 206, "Input"],
Cell[97672, 2219, 1477, 40, 255, "Input"],
Cell[99152, 2261, 899, 25, 149, "Input"],
Cell[100054, 2288, 1898, 53, 225, "Input"],
Cell[101955, 2343, 1483, 41, 219, "Input"],
Cell[103441, 2386, 2142, 58, 273, "Input"],
Cell[105586, 2446, 1165, 32, 179, "Input"],
Cell[106754, 2480, 2113, 59, 277, "Input"],
Cell[108870, 2541, 1616, 45, 188, "Input"],
Cell[110489, 2588, 2166, 58, 222, "Input"]
}, Closed]],
Cell[112670, 2649, 964, 35, 50, "Text",
 Evaluatable->False],
Cell[113637, 2686, 6735, 113, 189, "Text",
 Evaluatable->False],
Cell[120375, 2801, 1053, 43, 35, "Text"],
Cell[121431, 2846, 3715, 141, 275, "Text"],
Cell[125149, 2989, 2917, 99, 467, "Text"],
Cell[CellGroupData[{
Cell[128091, 3092, 233, 6, 37, "Subsection"],
Cell[128327, 3100, 330, 13, 42, "Text"],
Cell[128660, 3115, 1587, 48, 262, "Input"],
Cell[130250, 3165, 739, 23, 60, "Text",
 Evaluatable->False],
Cell[130992, 3190, 1548, 46, 262, "Input"],
Cell[132543, 3238, 104, 2, 29, "Text",
 Evaluatable->False],
Cell[132650, 3242, 1881, 55, 299, "Input"],
Cell[134534, 3299, 127, 5, 29, "Text"],
Cell[134664, 3306, 1744, 48, 206, "Input"],
Cell[136411, 3356, 385, 14, 35, "Text"]
}, Closed]],
Cell[136811, 3373, 989, 36, 55, "Text",
 Evaluatable->False],
Cell[137803, 3411, 5787, 213, 202, "Text"],
Cell[143593, 3626, 6263, 105, 137, "Text",
 Evaluatable->False],
Cell[149859, 3733, 1636, 63, 35, "Text"],
Cell[151498, 3798, 5489, 193, 610, "Text"],
Cell[CellGroupData[{
Cell[157012, 3995, 229, 6, 37, "Subsection"],
Cell[157244, 4003, 407, 16, 42, "Text"],
Cell[157654, 4021, 1761, 54, 262, "Input"],
Cell[159418, 4077, 198, 5, 29, "Text",
 Evaluatable->False],
Cell[159619, 4084, 1569, 47, 262, "Input"],
Cell[161191, 4133, 104, 2, 29, "Text",
 Evaluatable->False],
Cell[161298, 4137, 1776, 52, 286, "Input"],
Cell[163077, 4191, 190, 6, 29, "Text"],
Cell[163270, 4199, 3536, 100, 289, "Input"],
Cell[166809, 4301, 583, 23, 37, "Text"],
Cell[167395, 4326, 391, 14, 55, "Text"],
Cell[167789, 4342, 2689, 76, 241, "Input"],
Cell[170481, 4420, 684, 25, 37, "Text"]
}, Closed]],
Cell[171180, 4448, 1533, 52, 53, "Text",
 Evaluatable->False],
Cell[172716, 4502, 4313, 161, 184, "Text"],
Cell[177032, 4665, 5194, 88, 189, "Text",
 Evaluatable->False],
Cell[182229, 4755, 1679, 65, 35, "Text"],
Cell[183911, 4822, 4211, 148, 472, "Text"],
Cell[188125, 4972, 2679, 85, 301, "Text"],
Cell[190807, 5059, 1688, 59, 163, "Text"],
Cell[CellGroupData[{
Cell[192520, 5122, 233, 6, 37, "Subsection"],
Cell[192756, 5130, 455, 17, 53, "Text"],
Cell[193214, 5149, 1873, 57, 280, "Input"],
Cell[195090, 5208, 198, 5, 29, "Text",
 Evaluatable->False],
Cell[195291, 5215, 688, 21, 108, "Input"],
Cell[195982, 5238, 104, 2, 29, "Text",
 Evaluatable->False],
Cell[196089, 5242, 2108, 62, 288, "Input"],
Cell[198200, 5306, 127, 5, 29, "Text"],
Cell[198330, 5313, 1973, 55, 192, "Input"],
Cell[200306, 5370, 853, 29, 55, "Text"]
}, Closed]],
Cell[201174, 5402, 1670, 62, 61, "Text"],
Cell[202847, 5466, 5869, 99, 189, "Text",
 Evaluatable->False],
Cell[208719, 5567, 1033, 42, 35, "Text"],
Cell[209755, 5611, 5888, 213, 536, "Text"],
Cell[CellGroupData[{
Cell[215668, 5828, 217, 5, 37, "Subsection"],
Cell[215888, 5835, 185, 7, 29, "Text"],
Cell[216076, 5844, 2227, 67, 295, "Input"],
Cell[218306, 5913, 137, 4, 29, "Text",
 Evaluatable->False],
Cell[218446, 5919, 809, 27, 109, "Input"],
Cell[219258, 5948, 104, 2, 29, "Text",
 Evaluatable->False],
Cell[219365, 5952, 1977, 59, 272, "Input"],
Cell[221345, 6013, 127, 5, 29, "Text"],
Cell[221475, 6020, 3397, 101, 275, "Input"],
Cell[224875, 6123, 711, 25, 66, "Text"],
Cell[225589, 6150, 2444, 71, 204, "Input"]
}, Closed]],
Cell[228048, 6224, 2877, 103, 58, "Text"],
Cell[230928, 6329, 5405, 91, 189, "Text",
 Evaluatable->False],
Cell[236336, 6422, 1635, 65, 35, "Text"],
Cell[237974, 6489, 6992, 251, 544, "Text"],
Cell[CellGroupData[{
Cell[244991, 6744, 223, 5, 37, "Subsection"],
Cell[245217, 6751, 185, 7, 29, "Text"],
Cell[245405, 6760, 2529, 76, 330, "Input"],
Cell[247937, 6838, 137, 4, 29, "Text",
 Evaluatable->False],
Cell[248077, 6844, 688, 22, 109, "Input"],
Cell[248768, 6868, 104, 2, 29, "Text",
 Evaluatable->False],
Cell[248875, 6872, 1965, 59, 272, "Input"],
Cell[250843, 6933, 127, 5, 29, "Text"],
Cell[250973, 6940, 3164, 95, 248, "Input"],
Cell[254140, 7037, 629, 21, 64, "Text"],
Cell[254772, 7060, 2267, 66, 180, "Input"]
}, Closed]],
Cell[257054, 7129, 3057, 106, 58, "Text"],
Cell[260114, 7237, 7199, 121, 189, "Text",
 Evaluatable->False],
Cell[267316, 7360, 1015, 40, 35, "Text"],
Cell[268334, 7402, 9386, 320, 938, "Text"],
Cell[CellGroupData[{
Cell[277745, 7726, 221, 5, 37, "Subsection"],
Cell[277969, 7733, 185, 7, 29, "Text"],
Cell[278157, 7742, 1701, 51, 300, "Input"],
Cell[279861, 7795, 198, 5, 29, "Text",
 Evaluatable->False],
Cell[280062, 7802, 1608, 48, 118, "Input"],
Cell[281673, 7852, 104, 2, 29, "Text",
 Evaluatable->False],
Cell[281780, 7856, 2489, 73, 312, "Input"],
Cell[284272, 7931, 127, 5, 29, "Text"],
Cell[284402, 7938, 2754, 83, 216, "Input"],
Cell[287159, 8023, 169, 5, 65, "Text"],
Cell[287331, 8030, 1953, 58, 230, "Input"]
}, Closed]],
Cell[289299, 8091, 2109, 76, 58, "Text"],
Cell[291411, 8169, 5430, 92, 189, "Text",
 Evaluatable->False],
Cell[296844, 8263, 977, 40, 35, "Text"],
Cell[297824, 8305, 3861, 142, 424, "Text"],
Cell[CellGroupData[{
Cell[301710, 8451, 223, 5, 37, "Subsection"],
Cell[301936, 8458, 185, 7, 29, "Text"],
Cell[302124, 8467, 1754, 53, 251, "Input"],
Cell[303881, 8522, 198, 5, 29, "Text",
 Evaluatable->False],
Cell[304082, 8529, 720, 23, 118, "Input"],
Cell[304805, 8554, 104, 2, 29, "Text",
 Evaluatable->False],
Cell[304912, 8558, 1586, 47, 232, "Input"],
Cell[306501, 8607, 127, 5, 29, "Text"],
Cell[306631, 8614, 1652, 47, 190, "Input"]
}, Closed]],
Cell[308298, 8664, 1351, 47, 74, "Text",
 Evaluatable->False],
Cell[309652, 8713, 13734, 228, 189, "Text",
 Evaluatable->False],
Cell[323389, 8943, 3370, 122, 316, "Text"],
Cell[CellGroupData[{
Cell[326784, 9069, 219, 5, 37, "Subsection"],
Cell[327006, 9076, 1080, 38, 164, "Text"],
Cell[328089, 9116, 2051, 60, 229, "Input"],
Cell[330143, 9178, 2198, 64, 229, "Input"],
Cell[332344, 9244, 146, 3, 29, "Text"],
Cell[332493, 9249, 1300, 37, 155, "Input"],
Cell[333796, 9288, 2281, 66, 261, "Input"],
Cell[336080, 9356, 4736, 140, 441, "Input"]
}, Closed]],
Cell[340831, 9499, 1676, 59, 74, "Text",
 Evaluatable->False],
Cell[342510, 9560, 13888, 230, 189, "Text",
 Evaluatable->False],
Cell[356401, 9792, 4092, 149, 315, "Text"],
Cell[CellGroupData[{
Cell[360518, 9945, 223, 5, 37, "Subsection"],
Cell[360744, 9952, 435, 14, 101, "Text"],
Cell[361182, 9968, 2047, 60, 209, "Input"],
Cell[363232, 10030, 2365, 71, 266, "Input"],
Cell[365600, 10103, 144, 3, 29, "Text"],
Cell[365747, 10108, 1135, 33, 152, "Input"],
Cell[366885, 10143, 2107, 61, 238, "Input"],
Cell[368995, 10206, 3688, 108, 323, "Input"]
}, Closed]],
Cell[372698, 10317, 435, 8, 26, "Text"],
Cell[CellGroupData[{
Cell[373158, 10329, 407, 7, 29, "Text"],
Cell[373568, 10338, 130, 3, 31, "Input",
 InitializationCell->True]
}, Closed]]
}
]
*)

(* End of internal cache information *)
