(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    208532,       6110]
NotebookOptionsPosition[    203806,       5973]
NotebookOutlinePosition[    204389,       5996]
CellTagsIndexPosition[    204346,       5993]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[StyleBox["11.10  Image of a Fluid Flow",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tWe have already examined several two-dimensional fluid flows and have \
discovered that the image of a flow under a conformal transformation is a \
flow.   The conformal mapping ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "v", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]]],
 ",  which is obtained by using the Schwarz-Christoffel formula, allows us to \
find the streamlines for flows in domains in the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " plane that are bounded by straight-line segments.\n\n\tThe first technique \
is finding the image of a fluid flowing horizontally from left to right \
across the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 ".  The image of the streamline  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "\[Infinity]"}], "<", "t", "<", "\[Infinity]"}], ",", " ", 
   RowBox[{"y", "=", "c"}]}]]],
 "  is a streamline given by the parametric equations \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", " ", "=", " ", 
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{"t", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "c"}], ")"}], "   ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman"], 
   StyleBox[",",
    FontFamily->"Times New Roman"], "\[IndentingNewLine]", "\n", 
   RowBox[{"v", " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"v", 
       RowBox[{"(", 
        RowBox[{"t", 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "c"}], ")"}], "   ", 
       StyleBox["for",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}], "  ", "-", "\[Infinity]"}], "<", "t", "<", 
     RowBox[{"\[Infinity]", 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[".",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}]}]]],
 "  \n\nand is oriented in the positive sense (counterclockwise).  The \
streamline  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", " ", "=", " ", 
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{"t", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   RowBox[{"v", " ", "=", " ", 
    RowBox[{"v", 
     RowBox[{"(", 
      RowBox[{"t", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}]}]}]]],
 "  for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Infinity]"}], "<", "t", "<", "\[Infinity]"}]]],
 "  is considered to be the boundary wall for a containing vessel for the \
fluid flow."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Example 11.29.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the mapping  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    FractionBox["1", "\[Pi]"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
       FractionBox["1", "2"]], "+", 
      RowBox[{"Log", 
       RowBox[{"(", 
        RowBox[{"z", "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
          FractionBox["1", "2"]]}], ")"}]}]}], ")"}]}]}]]],
 "  maps the upper half plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 "  onto the domain in the w-plane that lies above the boundary curve \
consisting of the rays  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "\[LessEqual]", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"v", "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", "u"}], "\[GreaterEqual]", "0"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"v", "=", "0"}]}]]],
 " and the segment  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{"-", "1"}], "\[LessEqual]", "v", "\[LessEqual]", "0"}]}]]],
 "   (see Figure 11.87)."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{575, 178},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
\t\t\tFigure 11.87  (a) Flow over a step.                                     \
         (b) Flow around a blunt object.\
\>", "Text",
 CellChangeTimes->{{3.506803664546875*^9, 3.506803677296875*^9}}],

Cell[TextData[{
 "Hint:  Set  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "1"}]}]]],
 "  and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", 
    RowBox[{"-", "\[ImaginaryI]"}]}]}]]],
 ".  In the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 "-plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "\[ImaginaryI]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", "0"}]}]]],
 ", and the exterior angles are  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", 
    FractionBox["\[Pi]", "2"]}]}]]],
 ",  and the formula for the derivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " is  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "1"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]]}]}], " ", 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], ")"}]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         FractionBox["\[Pi]", "2"], ")"}]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      FractionBox["1", "2"]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]]}]}], "\[IndentingNewLine]"}], "\n", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], 
       FractionBox["1", "2"]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       FractionBox["1", "2"]]]}]}]}]}]],
 "\n"
}], "Text"],

Cell[TextData[{
 "Integrate and get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"B", "  ", "+", "  ", 
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          FractionBox["1", "2"]], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", "1"}], ")"}], 
          FractionBox["1", "2"]]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{"B", "  ", "+", " ", 
     RowBox[{"A", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
         FractionBox["1", "2"]], "+", 
        RowBox[{"Log", 
         RowBox[{"(", 
          RowBox[{"z", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
            FractionBox["1", "2"]]}], ")"}]}]}], ")"}]}]}]}]}]}]],
 " \n\nSolve for the coefficients A and B and obtain \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", " ", 
    RowBox[{
     FractionBox["1", "\[Pi]"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
        FractionBox["1", "2"]], "+", 
       RowBox[{"Log", 
        RowBox[{"(", 
         RowBox[{"z", "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
           FractionBox["1", "2"]]}], ")"}]}]}], ")"}]}]}]}]]]
}], "Text"],

Cell[TextData[{
 "It maps the upper half-plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 "  onto the domain in the w plane that lies above the boundary curve \
consisting of the rays  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "\[LessEqual]", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"v", "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", "u"}], "\[GreaterEqual]", "0"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"v", "=", "0"}]}]]],
 " and the segment  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{"-", "1"}], "\[LessEqual]", "v", "\[LessEqual]", "0"}]}]]],
 ".  Furthermore, the image of horizontal streamlines in the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane are curves in the w plane given by the parametric equation \n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"w", "  ", "=", "  ", 
    RowBox[{
     RowBox[{"u", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "v"}]}], "  ", "=", "  ", 
     RowBox[{"f", 
      RowBox[{"(", 
       RowBox[{"t", "+", 
        RowBox[{"\[ImaginaryI]", " ", "c"}]}], ")"}]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", "\[Pi]"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"t", "+", 
             RowBox[{"\[ImaginaryI]", " ", "c"}]}], ")"}], "2"], "-", "1"}], 
         ")"}], 
        FractionBox["1", "2"]], "+", 
       RowBox[{"Log", 
        RowBox[{"(", 
         RowBox[{"t", "+", 
          RowBox[{"\[ImaginaryI]", " ", "c"}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"t", "+", 
                RowBox[{"\[ImaginaryI]", " ", "c"}]}], ")"}], "2"], "-", 
             "1"}], ")"}], 
           FractionBox["1", "2"]]}], ")"}]}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", "\[Pi]"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", " ", 
         RowBox[{
          SuperscriptBox["t", "2"], "-", 
          SuperscriptBox["c", "2"], "-", "1", "+", " ", 
          RowBox[{"\[ImaginaryI]", " ", "2", "c", " ", "t"}]}], ")"}], 
        FractionBox["1", "2"]], "+", 
       RowBox[{"Log", 
        RowBox[{"(", 
         RowBox[{"t", "+", 
          RowBox[{"\[ImaginaryI]", " ", "c"}], "+", 
          SuperscriptBox[
           RowBox[{"(", " ", 
            RowBox[{
             SuperscriptBox["t", "2"], "-", 
             SuperscriptBox["c", "2"], "-", "1", "+", " ", 
             RowBox[{"\[ImaginaryI]", " ", "2", "c", " ", "t"}]}], ")"}], 
           FractionBox["1", "2"]]}], ")"}]}]}], ")"}]}]}]}]}]],
 "\n\nfor  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Infinity]"}], "<", "t", "<", "\[Infinity]"}]]],
 ".  The new flow is that of a step in the bed of a deep stream and is \
illustrated in Figure 11.87(a).  The function ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " is also defined for values of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " in the lower half-plane, and the images of horizontal streamlines that lie \
above or below the ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " axis are mapped onto streamlines that flow past a long rectangular \
obstacle, which is illustrated in Figure 11.87(b)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"11.29", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670696721875*^9, 3.50670696721875*^9}}],

Cell[TextData[{
 "Use the Schwarz Christoffel formula, enter the formula  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      FractionBox["1", "2"]]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "1"}], ")"}], 
     FractionBox["1", "2"]]]}]],
  AspectRatioFixed->True],
 "  and integrate it to construct  f(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"A", ",", "B", ",", "z", ",", "f", ",", "f1", ",", "F"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"A", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        FractionBox["1", "2"]]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       FractionBox["1", "2"]]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"B", " ", "+", " ", 
      RowBox[{"A", 
       RowBox[{"\[Integral]", 
        RowBox[{
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "+", "1"}], ")"}], 
           FractionBox["1", "2"]], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], 
           FractionBox["1", "2"]]], 
         RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = B + \[Integral] \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399544971953125*^9},
 AspectRatioFixed->True],

Cell["\<\
This is one, formula for the integral.   However, we will use the following \
form of the integral to continue the computations.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"A", " ", 
       RowBox[{"(", 
        RowBox[{"z", " ", "+", " ", "1"}], ")"}]}], 
      SqrtBox[
       RowBox[{
        SuperscriptBox["z", "2"], " ", "-", " ", "1"}]]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"B", " ", "+", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         RowBox[{"A", " ", 
          RowBox[{"(", 
           RowBox[{"z", " ", "+", " ", "1"}], ")"}]}], 
         SqrtBox[
          RowBox[{
           SuperscriptBox["z", "2"], " ", "-", " ", "1"}]]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = B + \[Integral] \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3995449754375*^9},
 AspectRatioFixed->True],

Cell["Now solve for the coefficients  A  and  B.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eq1", " ", "=", " ", 
     RowBox[{
      RowBox[{"F", "[", 
       RowBox[{"-", "1"}], "]"}], " ", "\[Equal]", "  ", "0"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"eq2", " ", "=", "  ", 
     RowBox[{
      RowBox[{"F", "[", "1", "]"}], " ", "\[Equal]", " ", 
      RowBox[{"-", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"eq1", ",", "eq2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"A", ",", "B"}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"F", "[", "z", "]"}], ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq1", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq2", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f[z] = B + A \!\(\*SqrtBox[\(\(-1\) + \*SuperscriptBox[\(z\), \
\(2\)]\)]\)+ A Log[z+\!\(\*SqrtBox[\(\(-1\) + \*SuperscriptBox[\(z\), \
\(2\)]\)]\)]\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39954497834375*^9},
 AspectRatioFixed->True],

Cell["\<\
Unfortunately, the branch cuts don't work out right and we will have to do \
this one by hand.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"F", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"A", "\[Rule]", 
          FractionBox["1", "\[Pi]"]}], ",", 
         RowBox[{"B", "\[Rule]", "0"}]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399544981421875*^9},
 AspectRatioFixed->True],

Cell["\<\
Using this formula in the book we form the two branches of the function.  \
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"f1", ",", "f2"}], "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"f1", "[", "z_", "]"}], " ", "=", " ", 
    FractionBox[
     RowBox[{" ", 
      RowBox[{
       SqrtBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "-", "1"}], ")"}]], "+", 
       RowBox[{"Log", "[", 
        RowBox[{"z", "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}]]}], "]"}]}]}], "\[Pi]"]}], 
   ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"f2", "[", "z_", "]"}], " ", "=", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       SqrtBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "-", "1"}], ")"}]]}], "+", 
      RowBox[{"Log", "[", 
       RowBox[{"z", "-", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["z", "2"], "-", "1"}]]}], "]"}]}], "\[Pi]"]}], ";"}],
   " ", "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<\!\(\*SubscriptBox[\(f\), \(1\)]\)[z] = \>\"", ",", 
     RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<\!\(\*SubscriptBox[\(f\), \(2\)]\)[z] = \>\"", ",", 
     RowBox[{"f2", "[", "z", "]"}]}], "]"}], ";"}], 
  " "}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{3.399544985078125*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph conformal mapping  w = f(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", " ", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f1", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "2", ",", "0.25"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "1.20001", ",", "0.2"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"g2", " ", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f2", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6.00001"}], ",", 
         RowBox[{"-", "0.00001"}], ",", "0.25"}], "}"}], ",", 
       RowBox[{"{", " ", 
        RowBox[{"0.00001", ",", "1.20001", ",", "0.2"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"g1", ",", "g2", ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "0.5"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image of the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<is the domain that lies above the boundary curve consisting\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<of the rays u\[LessEqual]0,v=1 and u\[GreaterEqual]0,v=0 and the \
segment u=0,-1\[LessEqual]v\[LessEqual]0,\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399544987796875*^9, 3.39954499015625*^9}, {
   3.39954555025*^9, 3.399545577421875*^9}, 3.400193297078125*^9, {
   3.40040586121875*^9, 3.400405876625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "\n",
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Another version of the graph can be made with the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], " ", "=", 
   FractionBox[
    RowBox[{
     RowBox[{"\[ImaginaryI]", 
      SqrtBox[
       RowBox[{"1", "-", 
        SuperscriptBox["z", "2"]}]]}], "+", 
     RowBox[{"Log", "[", 
      RowBox[{"z", "+", 
       RowBox[{"\[ImaginaryI]", 
        SqrtBox[
         RowBox[{"1", "-", 
          SuperscriptBox["z", "2"]}]]}]}], "]"}]}], "\[Pi]"]}]],
  CellChangeTimes->{{3.399544987796875*^9, 3.39954499015625*^9}, {
   3.39954555025*^9, 3.399545577421875*^9}, {3.399545711203125*^9, 
   3.39954576765625*^9}, {3.39954589696875*^9, 3.399545938703125*^9}},
  AspectRatioFixed->True],
 ".  \n"
}], "Text",
 CellChangeTimes->{{3.399546018015625*^9, 3.399546038171875*^9}, {
  3.399560564390625*^9, 3.399560568890625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f0", "[", "z_", "]"}], " ", "=", 
     FractionBox[
      RowBox[{
       RowBox[{"\[ImaginaryI]", 
        SqrtBox[
         RowBox[{"1", "-", 
          SuperscriptBox["z", "2"]}]]}], "+", 
       RowBox[{"Log", "[", 
        RowBox[{"z", "+", 
         RowBox[{"\[ImaginaryI]", 
          SqrtBox[
           RowBox[{"1", "-", 
            SuperscriptBox["z", "2"]}]]}]}], "]"}]}], "\[Pi]"]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f0", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6.0"}], ",", "2", ",", "0.25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00001", ",", "1.20001", ",", "0.2"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image of the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<is the domain that lies above the boundary curve consisting\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<of the rays u\[LessEqual]0,v=1 and u\[GreaterEqual]0,v=0 and the \
segment u=0,-1\[LessEqual]v\[LessEqual]0,\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  w = f[z] = \>\"", ",", 
      RowBox[{"f0", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399544987796875*^9, 3.39954499015625*^9}, {
  3.39954555025*^9, 3.399545577421875*^9}, {3.399545711203125*^9, 
  3.39954576765625*^9}, {3.39954589696875*^9, 3.399545938703125*^9}, {
  3.400193302453125*^9, 3.40019330265625*^9}, {3.40040588496875*^9, 
  3.400405887921875*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f0", "[", "z_", "]"}], " ", "=", 
     FractionBox[
      RowBox[{
       RowBox[{"\[ImaginaryI]", 
        SqrtBox[
         RowBox[{"1", "-", 
          SuperscriptBox["z", "2"]}]]}], "+", 
       RowBox[{"Log", "[", 
        RowBox[{"z", "+", 
         RowBox[{"\[ImaginaryI]", 
          SqrtBox[
           RowBox[{"1", "-", 
            SuperscriptBox["z", "2"]}]]}]}], "]"}]}], "\[Pi]"]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f0", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f0", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "9"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f0", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f0", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "9"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.2"}], ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", "boundary", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1.6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1.8", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image of the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under w = f[z] = \>\"", ",", 
      RowBox[{"f0", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399544998421875*^9, 3.3995450020625*^9}, {
  3.3995455884375*^9, 3.3995456408125*^9}, {3.399546136984375*^9, 
  3.399546201140625*^9}, {3.4001933075625*^9, 3.400193307796875*^9}, {
  3.400405894359375*^9, 3.400405903140625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We have shown that the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{
     FractionBox["1", "\[Pi]"], 
     RowBox[{"(", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["z", "2"], "-", "1"}]], "+", 
       RowBox[{"Log", "[", 
        RowBox[{"z", "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}]]}], "]"}]}], ")"}]}], "-", 
    "\[ImaginaryI]"}]}]]],
 "  maps the upper half plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "z", "]"}], ">", "0"}]]],
 "  onto the domain in the w-plane that lies above the boundary curve \
consisting of the rays  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "\[LessEqual]", "0"}], ",", 
   RowBox[{"v", "=", 
    RowBox[{
     RowBox[{"1", "  ", "and", "  ", "u"}], "\[GreaterEqual]", "0"}]}], ",", 
   RowBox[{"v", "=", "0"}]}]]],
 " and the segment  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "=", "0"}], ",", 
   RowBox[{
    RowBox[{"-", "1"}], "\[LessEqual]", "v", "\[LessEqual]", "0"}]}]]],
 ".    "
}], "Text"],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Here is another function that produces the desired result.  The graph is \
drawn parametrically in this case."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"\[ImaginaryI]", 
        SqrtBox[
         RowBox[{"1", " ", "-", " ", 
          SuperscriptBox["z", "2"]}]]}], " ", "+", " ", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "2"], " ", "-", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"ArcSin", "[", "z", "]"}]}]}], "\[Pi]"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "9"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "9"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.1"}], ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", "boundary", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1.6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1.8", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image of the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399546929078125*^9, 3.399546934234375*^9}, {
  3.39954700840625*^9, 3.39954700853125*^9}, {3.400193312296875*^9, 
  3.400193312515625*^9}, {3.400405909453125*^9, 3.400405916625*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"\[ImaginaryI]", 
        SqrtBox[
         RowBox[{"1", " ", "-", " ", 
          SuperscriptBox["z", "2"]}]]}], " ", "+", " ", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "2"], " ", "-", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"ArcSin", "[", "z", "]"}]}]}], "\[Pi]"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "9"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "9"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns3", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", "+", 
             RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph3", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "9"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns4", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", "+", 
             RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph4", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns4", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "9"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.1"}], ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.1"}], ",", 
             RowBox[{"-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{
    "graph1", ",", "graph2", ",", "graph3", ",", "graph4", ",", "boundary", 
     ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.6"}], ",", "1.6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["3.2", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The image of the z-plane,\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.39954694025*^9, {3.39954698471875*^9, 3.399547002171875*^9}, {
   3.40019331775*^9, 3.4001933180625*^9}, {3.400405922515625*^9, 
   3.40040594440625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Also, we have shown that the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   FractionBox[
    RowBox[{
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "2"], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        SuperscriptBox["z", "2"]}]]}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"ArcSin", "[", "z", "]"}]}]}], "\[Pi]"]}]]],
 "  maps the upper half plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "z", "]"}], ">", "0"}]]],
 "  onto the domain in the w-plane that lies above the boundary curve \
consisting of the rays  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "\[LessEqual]", "0"}], ",", 
   RowBox[{"v", "=", 
    RowBox[{
     RowBox[{"1", "  ", "and", "  ", "u"}], "\[GreaterEqual]", "0"}]}], ",", 
   RowBox[{"v", "=", "0"}]}]]],
 " and the segment  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "=", "0"}], ",", 
   RowBox[{
    RowBox[{"-", "1"}], "\[LessEqual]", "v", "\[LessEqual]", "0"}]}]]],
 ".    "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use Figure 11.88 to find the flow over the vertical segment from ",
 Cell[BoxData[
  RowBox[{"0", " ", 
   StyleBox["to",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "\[ImaginaryI]"}]]],
 "."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{576, 178},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\t\t\t\t\tFigure 11.88  ",
 "Flow over the vertical segment from ",
 Cell[BoxData[
  RowBox[{"0", " ", 
   StyleBox["to",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "\[ImaginaryI]"}]]],
 "."
}], "Text",
 CellChangeTimes->{{3.506803706578125*^9, 3.5068037130625*^9}}],

Cell[TextData[{
 "Solution.  Set  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "3"], "=", "1"}]}]]],
 ".  In the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 "-plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", "\[ImaginaryI]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "3"], "=", "0"}]}]]],
 ", and the exterior angles are  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    FractionBox["\[Pi]", "2"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", 
    RowBox[{"-", "\[Pi]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "3"], "=", 
    FractionBox["\[Pi]", "2"]}]}]]],
 ",  and the formula for the derivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " is  \n\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "1"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "3"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "0"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"-", "\[Pi]"}], ")"}]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], "1"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", " ", "z", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", " ", 
     FractionBox["z", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
       FractionBox["1", "2"]]]}]}]}]}]]
}], "Text"],

Cell[TextData[{
 "Integrate and get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"B", "  ", "+", "  ", 
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox["z", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
          FractionBox["1", "2"]]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{"B", "  ", "+", "  ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
      FractionBox["1", "2"]]}]}]}]}]],
 " \n\nSolve for the coefficients A and B and obtain \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
    FractionBox["1", "2"]]}]]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "1."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670697121875*^9, 3.506706971234375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<B + A \[Integral]\!\(\*FractionBox[\(z\), \
SuperscriptBox[\((\*SuperscriptBox[\(z\), \(2\)] - 1)\), FractionBox[\(1\), \
\(2\)]]]\)\[DifferentialD]z = \>\"", ",", 
     RowBox[{"B", "  ", "+", "  ", 
      RowBox[{"A", " ", 
       RowBox[{"\[Integral]", 
        RowBox[{
         FractionBox["z", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
           FractionBox["1", "2"]]], 
         RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3995607045*^9, 3.399560705796875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
      FractionBox["1", "2"]]}], " ", ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[-1] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"-", "1"}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[0] = \>\"", ",", 
      RowBox[{"f", "[", "0", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[1] = \>\"", ",", 
      RowBox[{"f", "[", "1", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3995607101875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
      FractionBox["1", "2"]]}], " ", ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Re", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", "+", 
             RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}]}], 
         ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns3", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph3", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns4", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Re", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", "+", 
             RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}]}], 
         ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph4", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns4", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{
    "graph1", ",", "graph2", ",", "graph3", ",", "graph4", ",", "boundary", 
     ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1.4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1.5", "4"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the flow across the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399560661609375*^9, 3.3995606624375*^9}, 
   3.399560715828125*^9, {3.400193322859375*^9, 3.400193323078125*^9}, {
   3.400405949765625*^9, 3.400405964875*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use Figure 11.89 to find the flow around an infinitely long rectangular \
barrier."
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztXVuLHUUQnpzrXpLdTbIJaiSsCiooiIiIiAg+RBD0zR+wBCGBRGOyiRpD
1EfFCyqKiAgi+OCDoE/+rPyD9cz0nJ4zfap7qqdqqvvM6WCy43RNX76v6uvL
TPe+dXh05d3rh0dXLx8evHHz8MaVq5dvHVx6/+bs1vBElp04yLLs34Msvz6e
XZb/HM/+O34s/ye/w3P9X/7jbJ77O+rGP/mPaX7jrL56WyX9nf8Y5jeKh0f5
1Zsq6S99Yze/2sprvKvvXVJGf+obm9poS19t6tTXlfkfurgyaXbvoro3f7BI
fU2Z/57/GGjzwui0znNPZ7Gp7V5VD/6mc5pqo21Vrdm9gb7a1qlTncUrKotf
9Y2pLrsoZ5LfO6+vyrJrWbyssvilnkVhtKGr/7iu4waQxUsqi5+BLKb6waL6
+xq6ItsJkNmLKrOfbJkNdC0m+b19fbWhU6FsX1DZ/lj8KCpUXOV/x4B5heOB
vpo6C3heFfCD02hS958z+b0tfW/ifPY5VcD3QAtGtqIqGsf5vTP6qqLRWqhR
xrOq+O9sxWdFE0xQl7MtHn207vPWikyA0p5RFfm2bg4Vb0VpUi9+H+DeWvwY
KG2kny0r9433g1AjhvVqDrW/D+uNgJ515wzB87Sq+tfNyFlTq0LHytPmjj6u
C9i4bofIGUp9SlX4K6RHjoBCoXuFSBb9zkhfbWjUoScgNK1sG3ZPqkZ86aQL
enDoLL5KnWj8q+ifOAGASnM7b9mILwg4DG3+P9BMGCpRdeJVlzpxNgLyioF3
nDyhGntv/qDycESzq+ZYUxGgGIG9GGPLImptLLYGVmk37LY0GucVPJ+Uj2cL
D2ZlX2SNcrcnQ6mDemrlLCMtliPAz1tib0XIqlEbMAzn1MV9/QSi52oZRJDd
wCfY9poDC4sV1g4rGlXkVXZnFbS3FfWzP7ph4LCGAq0BmTXYKkCLJwoJ3tNX
w3qqNT9EaksY9dBnHrz3BPzS7h+jmt2xI24HQB4PIf29oocnarD9dqUSld25
BdiHNZ/1Gw6gIR6bEBc21RCgNMuUWVZ53b6WgCLbSn5HZc0WyzpuEm5Eu9wj
OT0GnkP4OSEMOCCsQh3yzXJAXxvGV42pwIRKtXqfu0ds2Z9fUC36TAxOKLDH
pjctuOaSp1Vzop0Fz7AQMZjXutYtdzM2QKD9iKrApxGiDcZ1CWoxNdrRVxZQ
GxUHIerYHg9qHTQse1jV4D6QJAc4po8CYC1F+YJy8ApFA/ZmpQ+Au+qcs2v5
j908YQt4EHvP3jUujSAulr4MebFTZtppMEUfINgKqNRUIrur0yt3mAL5UHzW
Opz1kWRAeWdXp7IHxw/ye7P/ya/yvyeLfytPXbQfNhYbnqL8T23a205RKMFm
VxRYAAbzhhiiUUJrZ2lYYykCycf2sQ6CsNMYCkHNfrwUPktZO8MHIgZmIEZ2
yuH7XSCJslRFifzm8Fny+0XxmbOzjWQMmvtm8OQUO3zAth7r6xBx+6qiH68I
cRaU/YizPM4TbRLjiXKN7CMkaZSlRl8ttMw3LBJpl8MWHDUHGdaOoo4QX2dU
TT8k8CUfZC7l7CTSRh1FGhZOiLnTqgZ3gCTrG18R5siDe+/Qw5fIPd2mELhn
J5DSv1Ga2DYGiKHnimqO0KO81YBGJiVzt5FZyImmb+jBaR7x18xcu65PgsVd
VdMjZhZDxN9i/s3x59+1YqnEThUo02JISndUTW8BSdi+kHvA3FbTYqGSEpUU
Kk/ZqQwblVjvD0MrdnWF8nKUIrYlrTcFaPXzcN8o8e0yadNCrOthXRmrclha
T6oWfUCglfutmF+0dkex78CVO1opIrytanoDSMJ+NdJNtPaDVspMkkLrlp1W
ighbv61sGa3tRsa0vlXCDSkUYwW5pPh9Qhbc76zogmy383kVsuhGkBJgOx2J
iMZytanofg9IkhBq7AQpLN187oh1b8o4B6uwDuolhl6QHQWymKiXiHrKJ5Tl
9zrXkZRKiHyXo/NVoZ6CM5a3qZ16bi/DejcFstipx7q6RNSX1F8jeE+oqI+J
ekr9QkW9GsvpRdEuaeZeemmyi5FmCn4QHxDNxoJo09SdO3IpkzcJSikRiaWe
EjrQ7OqkndKYorQNtJKUYpdiJKLUWN/uMkr7Qim38HJHqbG2LU0p9zJKTJRi
OxruKA1MKXZCsG6UYpeXoCg11rG5KJX4BjkmSilqQ5mrQjg7KMVmEUp4m+y6
opQyJuCeg0J2xhp0U5RSvj7gjtK+UModpQ5KuaOUe9ExdkolXghCdsbrgjZR
2mdKKR1DhJRSojTUF5YUSiVGstjhEYVSY3m/KQvK633uKG2y64rSUMKLnYF4
Ukp5i5MopQ17sHbGm5g2ESkhsrHTx/3SjGEnASXS+kKVxGKd5+4ASlRhRZFL
PGOkijL0g6LKeMkVQ1S1iT4OqrijntIveW7O8DrYfM2p4p5QOTZcYKniDnQK
FKGo4p5mQ/kx7I3hXp/rM1UUV/fc7xITVU2Q+VIlMS3uiCpo3wqWKooAUkaA
3FRh1yPlprt1u006VdxR1UaIuqIq1JKwgyrs9iBu7+kzVRT87L/OgZ0qinav
IlUSAujYfiMRVVzzL0mquPtmCGeIKsd2mUSVzIIR1s6xvQXLNndf1aZPC00V
xTWxOE/8qOKuUuxUcY94KVHloIpSlMTry1BUcS8YYUOipOrIy3z1aeEeGkDt
gH49F5Tfjh8F3BHURvdjpICCi3GUHxe0lJWJ2CnAfo6CFSfjxbm0ELWBQpIC
iithhchzd6hEVx6KAokZveduzkTBylDALVixU8DdF3hugOWevvSFAkoUGN8G
JAr4ojlCCri0tqcUYPf4+k26V4sCbleCBqWOPblYCiSEKHYKuPsCxx5a7NRi
FSngFhisHfTbL43PHxIFUVGALYqbKm4KQk25sHaObcIUaLv0MkkKKG8ssVFg
fDESgxCFokCiHZ4UUAJu3SigCJFjJzQ2CqSjZZUpgKLA+MimTVGJAjwudjsS
BdKCFZoCijo4KIA2e2Oz6DMF3O2FhMj42EVaiNpQxUEBt4tQhKikAPrVmAlu
Gty7ftBK636M0NpFAoQW+lWg2CwoVW+KgtDQ+nWBdTvjk6p1hpZi54AWOuDC
PkxP0Jp2G4Cd4+wQCWibqu4LbdiZIQlaiW6MG9pQWus4RmUDWaW+QMuttQ5o
uQWhL9BicXGcKJOgTdDGDS10YgtWa7vs7kJDS+nGHNBSvJbLu2OEFouL45wh
bkFo491dQcvdjgRtCGihc3y4tTZBy+K1WI2KHVqK1jpOn5LoxprsOKCljGAS
tDFDC53uBGltgpYFWmwWXY4kJKHlbq/jTLJQ3ZgEtBLdWIK2a2ihM7+gLKAX
FQlaGBfHcWrc2tMXaLHde4LWCS3kjdj8ErSd2TkO7aNoLZbtvkBrby8aWkpR
bbqJGKHFam1H0HLZdQUthfoEbSzQQofO+WlKP6HFtteeHxpaOovxQsvd3hLa
Oz2Bkbt+UH57CbKWkN0Gkii6sKaQYbPgkmZfyCSG31B7jb0CXQZmKMi4u4QE
WYJMDDLohFlsbPcZsk3AznEoLzaLvkCGdRFPyLA9ZuyQ+a1gJ8h4IIPOCcYW
1WfIICFyHK28ipBRvAfbXgbIuAK4K8i45d8BGaXHXAPIoKOGKYEZO2QULXOc
zsytZZsNdqEhw9olyBJkYpBBpxVDTexSXn0h45Z1yA7SMscBz9gsYoKMMgjC
uognZF06fleQcdslyBJkYpBBx3RT5H9NIaPIf18gg9rrOAw+QZYg44UsO/E/
PljWaQ==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{288, 178},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
\t\t\tFigure 11.89  Flow around an infinitely long rectangular barrier.\
\>", "Text",
 CellChangeTimes->{3.506803744296875*^9}],

Cell[TextData[{
 "Solution.  Set  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "1"}]}]]],
 ".  In the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 "-plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", 
    RowBox[{"-", "1"}]}]}]]],
 ", and the exterior angles are  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}]}]}]]],
 ",  and the formula for the derivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " is  \n\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "1"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], ")"}]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], ")"}]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      FractionBox["1", "2"]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      FractionBox["1", "2"]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
      FractionBox["1", "2"]]}]}]}]}]]
}], "Text"],

Cell[TextData[{
 "Integrate and get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{"B", "  ", "+", "  ", 
    RowBox[{"A", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
        FractionBox["1", "2"]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SubscriptBox["B", "1"], "  ", "+", "  ", 
     RowBox[{
      SubscriptBox["A", "1"], " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["z", "2"]}], 
         SuperscriptBox[")", 
          FractionBox["1", "2"]]}], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SubscriptBox["B", "1"], "  ", "+", "  ", 
     RowBox[{
      SubscriptBox["A", "1"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", "z", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["z", "2"]}], 
          SuperscriptBox[")", 
           FractionBox["1", "2"]]}]}], "+", 
        RowBox[{
         FractionBox["1", "2"], "Arczin", " ", "z"}]}], ")"}]}]}]}]}]}]],
 "  \n\nSolve for the coefficients ",
 Cell[BoxData[
  SubscriptBox["A", "1"]]],
 " and ",
 Cell[BoxData[
  SubscriptBox["B", "1"]]],
 " and obtain \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", " ", 
      FractionBox["2", "\[Pi]"]}], "z", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SuperscriptBox["z", "2"]}], 
      SuperscriptBox[")", 
       FractionBox["1", "2"]]}]}], " ", "-", " ", 
    RowBox[{
     FractionBox["2", "\[Pi]"], "Arcsin", " ", "z"}]}]}]]],
 " "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "2."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506706976953125*^9, 3.50670697696875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<B + A \[Integral](1-\!\(\*SuperscriptBox[\(z\), \
\(2\)]\)\!\(\*SuperscriptBox[\()\), FractionBox[\(1\), \(2\)]]\)\
\[DifferentialD]z = \>\"", ",", 
    RowBox[{"B", "  ", "+", "  ", 
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["z", "2"]}], ")"}], 
         FractionBox["1", "2"]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.399560743796875*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "\[Pi]"]}], "z", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["z", "2"]}], ")"}], 
       FractionBox["1", "2"]]}], "-", 
     RowBox[{
      FractionBox["2", "\[Pi]"], 
      RowBox[{"ArcSin", "[", "z", "]"}]}]}]}], " ", ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\< f[z] = \>\"", ",", 
     RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<f[-1] = \>\"", ",", 
     RowBox[{"f", "[", 
      RowBox[{"-", "1"}], "]"}]}], " ", "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\< f[1] = \>\"", ",", 
     RowBox[{"f", "[", "1", "]"}]}], " ", "]"}], ";"}], 
  " "}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["2", "\[Pi]"]}], "z", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["z", "2"]}], ")"}], 
        FractionBox["1", "2"]]}], "-", 
      RowBox[{
       FractionBox["2", "\[Pi]"], 
       RowBox[{"ArcSin", "[", "z", "]"}]}]}]}], " ", ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Re", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", "+", 
             RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}]}], 
         ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns3", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph3", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns4", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Re", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", "+", 
             RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}]}], 
         ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph4", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns4", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1", ",", "5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "5"}], "}"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{
    "graph1", ",", "graph2", ",", "graph3", ",", "graph4", ",", "boundary", 
     ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.2"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "1"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "5", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the flow across the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39956074775*^9, 3.39956075071875*^9}, {
  3.400193328140625*^9, 3.400193328390625*^9}, {3.4004059705625*^9, 
  3.400405985359375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use Figure 11.90 to find the flow around"
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{767, 178},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
\t\t\tFigure 11.90  (a) Flow around one inclined segment in the upper \
half-plane.
\t\t\t\t\t(b) Flow around two inclined segments forming a \"V\" in the plane.\
\>", "Text",
 CellChangeTimes->{3.5068037725*^9}],

Cell[TextData[{
 "Solution.  Set  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"1", "-", "\[Alpha]"}], "\[Alpha]"]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "3"], "=", "1"}]}]]],
 ".  In the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 "-plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", "\[Pi]"}]]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "3"], "=", "0"}]}]]],
 ", and the exterior angles are  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", "\[Alpha]\[Pi]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", 
    RowBox[{"-", "\[Pi]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "3"], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", "\[Pi]"}]}]}]]],
 ",  and the formula for the derivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " is  \n\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "1"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "3"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"(", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"1", "-", "\[Alpha]"}], "\[Alpha]"]}], ")"}]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", 
        FractionBox[
         RowBox[{"1", "-", "\[Alpha]"}], "\[Alpha]"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", 
        FractionBox[
         RowBox[{"1", "-", "\[Alpha]"}], "\[Alpha]"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"\[Alpha]", " ", "\[Pi]"}], ")"}]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"-", "\[Pi]"}], ")"}]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", "\[Pi]"}], ")"}]}], 
       "/", "\[Pi]"}]]}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", 
        FractionBox[
         RowBox[{"1", "-", "\[Alpha]"}], "\[Alpha]"]}], ")"}], 
      RowBox[{"-", "\[Alpha]"}]], " ", 
     RowBox[{"(", "z", ")"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{"\[Alpha]", "-", "1"}]]}]}]}]}]]
}], "Text"],

Cell[TextData[{
 "Integrate and get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"B", "  ", "+", "  ", 
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", 
           FractionBox[
            RowBox[{"1", "-", "\[Alpha]"}], "\[Alpha]"]}], ")"}], 
         RowBox[{"-", "\[Alpha]"}]], " ", 
        RowBox[{"(", "z", ")"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", "1"}], ")"}], 
         RowBox[{"\[Alpha]", "-", "1"}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{"B", "+", 
     RowBox[{"A", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "z"}], ")"}], "\[Alpha]"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", 
         FractionBox[
          RowBox[{"1", "-", "\[Alpha]"}], "\[Alpha]"]}], ")"}], 
       RowBox[{"-", "\[Alpha]"}]], " ", 
      RowBox[{"(", 
       RowBox[{"z", "-", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Alpha]"}], "\[Alpha]"]}], 
       ")"}]}]}]}]}]}]],
 " \n\nSolve for the coefficients A and B and obtain \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "1"}], ")"}], "\[Alpha]"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{"\[Alpha]", " ", "z"}], 
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Alpha]"}], ")"}]]}], ")"}], 
     RowBox[{"1", "-", "\[Alpha]"}]]}]}]]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "3."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.5067069805*^9, 3.5067069805*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<B + A \[Integral](z+\!\(\*FractionBox[\(1 - \[Alpha]\), \(\[Alpha]\)]\
\)\!\(\*SuperscriptBox[\()\), \
\(-\[Alpha]\)]\)(z)(-1+z\!\(\*SuperscriptBox[\()\), \(\[Alpha] - 1\)]\)\
\[DifferentialD]z = \>\"", ",", 
    RowBox[{"B", "  ", "+", "  ", 
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", 
           FractionBox[
            RowBox[{"1", "-", "\[Alpha]"}], "\[Alpha]"]}], ")"}], 
         RowBox[{"-", "\[Alpha]"}]], 
        RowBox[{"(", "z", ")"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "z"}], ")"}], 
         RowBox[{"\[Alpha]", "-", "1"}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.3995607625*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Alpha]", " ", "=", " ", 
   FractionBox["1", "4"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["\[Alpha]", 
        RowBox[{"1", "-", "\[Alpha]"}]], ")"}], 
      RowBox[{"1", "-", "\[Alpha]"}]], 
     RowBox[{"\[Integral]", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", 
          FractionBox[
           RowBox[{"1", "-", "\[Alpha]"}], "\[Alpha]"]}], ")"}], 
        RowBox[{"-", "\[Alpha]"}]], 
       RowBox[{"(", "z", ")"}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "z"}], ")"}], 
        RowBox[{"\[Alpha]", "-", "1"}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\< f[z] = \>\"", ",", 
     RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<f[-\!\(\*FractionBox[\(1 - \[Alpha]\), \(\[Alpha]\)]\)] = \>\"", ",", 
     RowBox[{"f", "[", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"1", "-", "\[Alpha]"}], "\[Alpha]"]}], "]"}]}], " ", "]"}], 
   ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\< f[0] = \>\"", ",", 
     RowBox[{"f", "[", "0", "]"}]}], " ", "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\< f[1] = \>\"", ",", 
     RowBox[{"Simplify", "[", 
      RowBox[{"f", "[", "1", "]"}], "]"}]}], " ", "]"}], ";"}], 
  " "}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Alpha]", " ", "=", " ", 
     FractionBox["1", "4"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], "\[Alpha]"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox[
          RowBox[{"\[Alpha]", " ", "z"}], 
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Alpha]"}], ")"}]]}], ")"}], 
       RowBox[{"1", "-", "\[Alpha]"}]]}]}], " ", ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4.75"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "   ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns3", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph3", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4.75"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"\[Alpha]", " ", "\[Pi]"}], "]"}], ",", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Alpha]", " ", "\[Pi]"}], "]"}]}], "}"}]}], "}"}], 
         "]"}]}], "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph3", ",", "boundary", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.75"}], ",", "1.75"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.001"}], ",", "1.0"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2.5"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "5", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the flow across the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39956076615625*^9, 3.399560767734375*^9}, 
   3.399560814375*^9, 3.39956085890625*^9, {3.40019333384375*^9, 
   3.400193334109375*^9}, {3.40040599128125*^9, 3.40040599865625*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Alpha]", " ", "=", " ", 
     FractionBox["1", "4"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], "\[Alpha]"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox[
          RowBox[{"\[Alpha]", " ", "z"}], 
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Alpha]"}], ")"}]]}], ")"}], 
       RowBox[{"1", "-", "\[Alpha]"}]]}]}], " ", ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4.75"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "   ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", "+", 
             RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}]}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4.75"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "   ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns3", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph3", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4.75"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns4", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", "+", 
             RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}]}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph4", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns4", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4.75"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"\[Alpha]", " ", "\[Pi]"}], "]"}], ",", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Alpha]", " ", "\[Pi]"}], "]"}]}], "}"}]}], "}"}], 
         "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"-", "\[Alpha]"}], " ", "\[Pi]"}], "]"}], ",", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"-", "\[Alpha]"}], " ", "\[Pi]"}], "]"}]}], "}"}]}], 
          "}"}], "]"}]}], "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{
    "graph1", ",", "graph2", ",", "graph3", ",", "graph4", ",", "boundary", 
     ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.75"}], ",", "1.75"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.85"}], ",", "0.85"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1.7", "2.5"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "5", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image of the flow across the z-plane,\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39956077240625*^9, 3.399560819640625*^9}, 
   3.399560869375*^9, {3.4001933395625*^9, 3.4001933401875*^9}, {
   3.400406003734375*^9, 3.40040601871875*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Alpha]", " ", "=", " ", 
     FractionBox["1", "3"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], "\[Alpha]"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox[
          RowBox[{"\[Alpha]", " ", "z"}], 
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Alpha]"}], ")"}]]}], ")"}], 
       RowBox[{"1", "-", "\[Alpha]"}]]}]}], " ", ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4.75"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "   ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns3", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph3", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4.75"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"\[Alpha]", " ", "\[Pi]"}], "]"}], ",", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Alpha]", " ", "\[Pi]"}], "]"}]}], "}"}]}], "}"}], 
         "]"}]}], "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph3", ",", "boundary", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.75"}], ",", "1.75"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.001"}], ",", "1.0"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2.5"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "5", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the flow across the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39956076615625*^9, 3.399560767734375*^9}, 
   3.399560814375*^9, 3.39956085890625*^9, {3.399560897828125*^9, 
   3.399560918875*^9}, {3.40019334590625*^9, 3.400193346359375*^9}, {
   3.40040602440625*^9, 3.40040603153125*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Alpha]", " ", "=", " ", 
     FractionBox["1", "3"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], "\[Alpha]"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox[
          RowBox[{"\[Alpha]", " ", "z"}], 
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Alpha]"}], ")"}]]}], ")"}], 
       RowBox[{"1", "-", "\[Alpha]"}]]}]}], " ", ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4.75"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "   ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", "+", 
             RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}]}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4.75"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "   ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns3", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph3", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4.75"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns4", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", "+", 
             RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}]}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph4", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns4", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4.75"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"\[Alpha]", " ", "\[Pi]"}], "]"}], ",", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Alpha]", " ", "\[Pi]"}], "]"}]}], "}"}]}], "}"}], 
         "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"-", "\[Alpha]"}], " ", "\[Pi]"}], "]"}], ",", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"-", "\[Alpha]"}], " ", "\[Pi]"}], "]"}]}], "}"}]}], 
          "}"}], "]"}]}], "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{
    "graph1", ",", "graph2", ",", "graph3", ",", "graph4", ",", "boundary", 
     ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.75"}], ",", "1.75"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.15"}], ",", "1.15"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1.7", "2.5"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "5", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image of the flow across the z-plane,\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39956077240625*^9, 3.39956079465625*^9}, {
  3.39956093453125*^9, 3.3995609394375*^9}, {3.4001933529375*^9, 
  3.400193353140625*^9}, {3.400406037203125*^9, 3.400406054171875*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use Figure 11.91 to find the flow over a dam. "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{461, 178},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
\t\t\t\tFigure 11.91  Flow over a dam. \
\>", "Text",
 CellChangeTimes->{{3.50680379421875*^9, 3.50680379840625*^9}}],

Cell[TextData[{
 "Solution.  Set  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "1"}]}]]],
 ".  In the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 "-plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", "\[ImaginaryI]"}]}]]],
 ", and the exterior angles are  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    FractionBox["\[Pi]", "2"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", 
    RowBox[{"-", "\[Pi]"}]}]}]]],
 ",  and the formula for the derivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " is  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "1"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]]}]}], " ", 
   "\n"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "0"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"-", "\[Pi]"}], ")"}]}], "/", "\[Pi]"}]]}]}], 
   "\n"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", " ", 
     SuperscriptBox["z", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], "1"]}]}], 
   "\n"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", " ", 
     SuperscriptBox["z", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]], 
     RowBox[{"(", 
      RowBox[{"z", "-", "1"}], ")"}]}]}], "\n"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z", 
        FractionBox["1", "2"]], " ", "-", " ", 
       SuperscriptBox["z", 
        RowBox[{"-", 
         FractionBox["1", "2"]}]]}], ")"}]}]}]}]}]]
}], "Text"],

Cell[TextData[{
 "Integrate and get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"B", "  ", "+", "  ", 
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", 
           FractionBox["1", "2"]], " ", "-", " ", 
          SuperscriptBox["z", 
           RowBox[{"-", 
            FractionBox["1", "2"]}]]}], ")"}], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{"B", "+", 
     RowBox[{"A", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SqrtBox["z"]}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["z", 
           RowBox[{"3", "/", "2"}]]}], "3"]}], ")"}]}]}]}]}]}]],
 " \n\nSolve for the coefficients A and B and obtain \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"-", "\[ImaginaryI]"}], "2"], 
    SuperscriptBox["z", 
     FractionBox["1", "2"]], 
    RowBox[{"(", 
     RowBox[{"z", "-", "3"}], ")"}]}]}]]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "4."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670698409375*^9, 3.50670698409375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<B + A \[Integral](\!\(\*SuperscriptBox[\(z\), FractionBox[\(1\), \
\(2\)]]\) - \!\(\*SuperscriptBox[\(z\), \(-\*FractionBox[\(1\), \(2\)]\)]\))\
\[DifferentialD]z = \>\"", ",", 
    RowBox[{"B", "  ", "+", "  ", 
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", 
           FractionBox["1", "2"]], " ", "-", " ", 
          SuperscriptBox["z", 
           RowBox[{"-", 
            FractionBox["1", "2"]}]]}], ")"}], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.399560959640625*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"-", "\[ImaginaryI]"}], "2"], 
     SuperscriptBox["z", 
      FractionBox["1", "2"]], 
     RowBox[{"(", 
      RowBox[{"z", "-", "3"}], ")"}]}]}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<f[z] = \>\"", ",", 
     RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<f[0] = \>\"", ",", 
     RowBox[{"f", "[", "0", "]"}]}], " ", "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<f[1] = \>\"", ",", 
     RowBox[{"f", "[", "1", "]"}]}], " ", "]"}], ";"}], 
  " "}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      FractionBox[
       RowBox[{"-", "\[ImaginaryI]"}], "2"], 
      SuperscriptBox["z", 
       FractionBox["1", "2"]], 
      RowBox[{"(", 
       RowBox[{"z", "-", "3"}], ")"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns3", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.075", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph3", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph3", ",", "boundary", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.6"}], ",", "1.35"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "4"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the flow across the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399560963421875*^9, 3.399560965234375*^9}, {
  3.400193357890625*^9, 3.40019335809375*^9}, {3.400406060375*^9, 
  3.400406068953125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use Figure 11.92 to find the flow around"
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{643, 178},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
\t\t\tFigure 11.92  (a) Flow up an inclined step
\t\t\t\t\t(b) Flow around a pointed object.\
\>", "Text",
 CellChangeTimes->{3.50680381784375*^9}],

Cell[TextData[{
 "Solution.  Set  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "1"}]}]]],
 ".  In the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 "-plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", "\[ImaginaryI]"}]}]]],
 ", and the exterior angles are  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    FractionBox["\[Pi]", "4"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "4"]}]}]}]]],
 ",  and the formula for the derivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " is  \n\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "1"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "0"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         FractionBox["\[Pi]", "4"], ")"}]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "4"]}], ")"}]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{"-", 
       FractionBox["1", "4"]}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      FractionBox["1", "4"]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", " ", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       FractionBox["1", "4"]], 
      SuperscriptBox["z", 
       FractionBox["1", "4"]]]}]}]}]}]]
}], "Text"],

Cell[TextData[{
 "Integrate and get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"B", "  ", "+", "  ", 
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", "1"}], ")"}], 
          FractionBox["1", "4"]], 
         SuperscriptBox["z", 
          FractionBox["1", "4"]]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{"B", " ", "+", " ", 
     RowBox[{"A", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", "1"}], ")"}], 
          FractionBox["1", "4"]], " ", 
         SuperscriptBox["z", 
          FractionBox["3", "4"]]}], "-", 
        RowBox[{
         FractionBox["1", "2"], "Arctan", 
         RowBox[{"(", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             FractionBox["1", "z"]}], ")"}], 
           FractionBox["1", "4"]], ")"}]}], "+", 
        RowBox[{
         FractionBox["1", "4"], "Log", 
         FractionBox[
          RowBox[{"1", "-", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", 
              FractionBox["1", "z"]}], ")"}], 
            FractionBox["1", "4"]]}], 
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", 
              FractionBox["1", "z"]}], ")"}], 
            FractionBox["1", "4"]]}]]}]}], ")"}]}]}]}]}]}]],
 " \n\nSolve for the coefficients A and B and obtain \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", " ", 
   RowBox[{"\[ImaginaryI]", " ", "+", " ", 
    RowBox[{
     FractionBox["1", "\[Pi]"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", "1"}], ")"}], 
         FractionBox["1", "4"]], " ", 
        SuperscriptBox["z", 
         FractionBox["3", "4"]]}], "-", 
       RowBox[{"2", "Arctan", 
        RowBox[{"(", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "-", 
            FractionBox["1", "z"]}], ")"}], 
          FractionBox["1", "4"]], ")"}]}], "+", 
       RowBox[{"Log", 
        FractionBox[
         RowBox[{"1", "-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             FractionBox["1", "z"]}], ")"}], 
           FractionBox["1", "4"]]}], 
         RowBox[{"1", "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             FractionBox["1", "z"]}], ")"}], 
           FractionBox["1", "4"]]}]]}]}], ")"}]}]}]}]]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "5."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670698865625*^9, 3.50670698865625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"\[ImaginaryI]", " ", "+", " ", 
      RowBox[{
       FractionBox["1", "\[Pi]"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], 
           FractionBox["1", "4"]], " ", 
          SuperscriptBox["z", 
           FractionBox["3", "4"]]}], "-", 
         RowBox[{"2", 
          RowBox[{"ArcTan", "[", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", 
              FractionBox["1", "z"]}], ")"}], 
            FractionBox["1", "4"]], "]"}]}], "+", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"1", "-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox["1", "z"]}], ")"}], 
             FractionBox["1", "4"]]}], 
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox["1", "z"]}], ")"}], 
             FractionBox["1", "4"]]}]], "]"}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"MapAll", "[", 
       RowBox[{"FullSimplify", ",", 
        RowBox[{"Together", "[", " ", 
         RowBox[{
          RowBox[{"f", "'"}], "[", "z", "]"}], "]"}]}], "]"}]}], " ", "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399560978203125*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[0] = \>\"", ",", 
      RowBox[{"Chop", "[", 
       RowBox[{"f", "[", 
        RowBox[{"0", "+", 
         RowBox[{"0.000000000000001", "\[ImaginaryI]"}]}], "]"}], "]"}]}], 
     " ", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[1] = \>\"", ",", 
      RowBox[{"Chop", "[", 
       RowBox[{"f", "[", 
        RowBox[{"1", "+", 
         RowBox[{"0.00000000001", "\[ImaginaryI]"}]}], "]"}], "]"}]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3995609820625*^9, 3.39956098525*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"\[ImaginaryI]", " ", "+", " ", 
      RowBox[{
       FractionBox["1", "\[Pi]"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], 
           FractionBox["1", "4"]], " ", 
          SuperscriptBox["z", 
           FractionBox["3", "4"]]}], "-", 
         RowBox[{"2", 
          RowBox[{"ArcTan", "[", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", 
              FractionBox["1", "z"]}], ")"}], 
            FractionBox["1", "4"]], "]"}]}], "+", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"1", "-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox["1", "z"]}], ")"}], 
             FractionBox["1", "4"]]}], 
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox["1", "z"]}], ")"}], 
             FractionBox["1", "4"]]}]], "]"}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "8", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00001", ",", "4.00001", ",", "0.2"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "3.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "4.3"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          FractionBox["\[Pi]", "2"], ",", "\[Pi]"}], "}"}]}], "}"}]}]}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the upper half plane Im[z] > 0 under the mapping\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39956098828125*^9, 3.399560992140625*^9}, {
  3.400193363125*^9, 3.400193363328125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"\[ImaginaryI]", " ", "+", " ", 
      RowBox[{
       FractionBox["1", "\[Pi]"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], 
           FractionBox["1", "4"]], " ", 
          SuperscriptBox["z", 
           FractionBox["3", "4"]]}], "-", 
         RowBox[{"2", 
          RowBox[{"ArcTan", "[", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", 
              FractionBox["1", "z"]}], ")"}], 
            FractionBox["1", "4"]], "]"}]}], "+", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"1", "-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox["1", "z"]}], ")"}], 
             FractionBox["1", "4"]]}], 
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox["1", "z"]}], ")"}], 
             FractionBox["1", "4"]]}]], "]"}]}], ")"}]}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.1", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.1", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "3"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", "boundary", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "2.3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2.4", "5"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the flow across the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399561011859375*^9, 3.39956101384375*^9}, {
  3.400193368625*^9, 3.40019336884375*^9}, {3.40040607453125*^9, 
  3.400406082640625*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"\[ImaginaryI]", " ", "+", " ", 
      RowBox[{
       FractionBox["1", "\[Pi]"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], 
           FractionBox["1", "4"]], " ", 
          SuperscriptBox["z", 
           FractionBox["3", "4"]]}], "-", 
         RowBox[{"2", 
          RowBox[{"ArcTan", "[", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", 
              FractionBox["1", "z"]}], ")"}], 
            FractionBox["1", "4"]], "]"}]}], "+", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"1", "-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox["1", "z"]}], ")"}], 
             FractionBox["1", "4"]]}], 
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox["1", "z"]}], ")"}], 
             FractionBox["1", "4"]]}]], "]"}]}], ")"}]}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.1", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.1", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns3", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", "+", 
             RowBox[{"\[ImaginaryI]", " ", "0.1", "k"}]}], "]"}], "]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph3", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns4", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", "+", 
             RowBox[{"\[ImaginaryI]", " ", "0.1", "k"}]}], "]"}], "]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph4", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns4", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "3"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "1"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{
    "graph1", ",", "graph2", ",", "graph3", ",", "graph4", ",", "boundary", 
     ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.3"}], ",", "2.3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["4.6", "5"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image of the flow across the z-plane,\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3995610231875*^9, 3.399561027296875*^9}, {
  3.40019337328125*^9, 3.4001933735*^9}, {3.400406087828125*^9, 
  3.40040610171875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We could let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " do the integral."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<B + A \[Integral]\!\(\*FractionBox[SuperscriptBox[\((z - 1)\), \
FractionBox[\(1\), \(4\)]], SuperscriptBox[\(z\), FractionBox[\(1\), \(4\)]]]\
\)\[DifferentialD]z = \>\"", ",", 
     RowBox[{"B", "  ", "+", "  ", 
      RowBox[{"A", " ", 
       RowBox[{"\[Integral]", 
        RowBox[{
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], 
           FractionBox["1", "4"]], 
          SuperscriptBox["z", 
           FractionBox["1", "4"]]], 
         RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], "]"}], ";"}]}]], "Input",
 CellChangeTimes->{3.39956103725*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", "2.8483970453558163"}], " ", "+", " ", 
    RowBox[{
     FractionBox["4", "\[Pi]"], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "z"], 
      RowBox[{
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\[Xi]", "-", "1"}], ")"}], 
         FractionBox["1", "4"]], 
        SuperscriptBox["\[Xi]", 
         FractionBox["1", "4"]]], 
       RowBox[{"\[DifferentialD]", "\[Xi]"}]}]}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", "2.8483970453558163"}], " ", "+", " ", 
    RowBox[{
     FractionBox["4", "\[Pi]"], 
     RowBox[{"\[Integral]", 
      RowBox[{
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", "1"}], ")"}], 
         FractionBox["1", "4"]], 
        SuperscriptBox["z", 
         FractionBox["1", "4"]]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<f[z] = \>\"", ",", 
     RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<f[0] = \>\"", ",", 
     RowBox[{"Chop", "[", 
      RowBox[{"f", "[", 
       RowBox[{"0", "+", 
        RowBox[{"0.0", "\[ImaginaryI]"}]}], "]"}], "]"}]}], " ", "]"}], ";"}],
   " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<f[1] = \>\"", ",", 
     RowBox[{"Chop", "[", 
      RowBox[{"f", "[", 
       RowBox[{"1", "+", 
        RowBox[{"0.00000000001", "\[ImaginaryI]"}]}], "]"}], "]"}]}], " ", 
    "]"}], ";"}], " "}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{3.399561039625*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", 
     RowBox[{
      RowBox[{"-", "1"}], "+", " ", 
      RowBox[{
       FractionBox["4", "\[Pi]"], 
       RowBox[{"\[Integral]", 
        RowBox[{
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], 
           FractionBox["1", "4"]], 
          SuperscriptBox["z", 
           FractionBox["1", "4"]]], 
         RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "8", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00001", ",", "4.00001", ",", "0.2"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "3.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "4.3"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          FractionBox["\[Pi]", "2"], ",", "\[Pi]"}], "}"}]}], "}"}]}]}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the upper half plane Im[z] > 0 under the mapping\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399561042515625*^9, 3.3995610606875*^9}, {
  3.40019337825*^9, 3.40019337846875*^9}}],

Cell["Which is the same as our solution.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"\[ImaginaryI]", " ", "+", " ", 
      RowBox[{
       FractionBox["1", "\[Pi]"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], 
           FractionBox["1", "4"]], " ", 
          SuperscriptBox["z", 
           FractionBox["3", "4"]]}], "-", 
         RowBox[{"2", 
          RowBox[{"ArcTan", "[", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", 
              FractionBox["1", "z"]}], ")"}], 
            FractionBox["1", "4"]], "]"}]}], "+", 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"1", "-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox["1", "z"]}], ")"}], 
             FractionBox["1", "4"]]}], 
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox["1", "z"]}], ")"}], 
             FractionBox["1", "4"]]}]], "]"}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "8", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00001", ",", "4.00001", ",", "0.2"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "3.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "4.3"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          FractionBox["\[Pi]", "2"], ",", "\[Pi]"}], "}"}]}], "}"}]}]}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the upper half plane Im[z] > 0 under the mapping\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39956106990625*^9, 3.3995610734375*^9}, {
  3.400193383796875*^9, 3.400193384015625*^9}}]
}, Closed]],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",
 InitializationCell->True]
}, Closed]]
},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{956, 610},
WindowMargins->{{2, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 116, 2, 29, "Text"],
Cell[1667, 50, 4948, 156, 248, "Text",
 Evaluatable->False],
Cell[6618, 208, 2231, 79, 64, "Text",
 Evaluatable->False],
Cell[8852, 289, 6760, 114, 192, "Text",
 Evaluatable->False],
Cell[15615, 405, 210, 4, 29, "Text"],
Cell[15828, 411, 3836, 147, 273, "Text"],
Cell[19667, 560, 1936, 64, 245, "Text"],
Cell[21606, 626, 4477, 140, 268, "Text"],
Cell[CellGroupData[{
Cell[26108, 770, 231, 6, 37, "Subsection"],
Cell[26342, 778, 501, 18, 61, "Text"],
Cell[26846, 798, 1909, 58, 302, "Input"],
Cell[28758, 858, 198, 5, 29, "Text",
 Evaluatable->False],
Cell[28959, 865, 1612, 48, 242, "Input"],
Cell[30574, 915, 104, 2, 29, "Text",
 Evaluatable->False],
Cell[30681, 919, 1952, 56, 286, "Input"],
Cell[32636, 977, 165, 5, 29, "Text",
 Evaluatable->False],
Cell[32804, 984, 663, 20, 108, "Input"],
Cell[33470, 1006, 145, 4, 29, "Text",
 Evaluatable->False],
Cell[33618, 1012, 1493, 51, 216, "Input"],
Cell[35114, 1065, 127, 5, 29, "Text"],
Cell[35244, 1072, 2364, 63, 212, "Input"],
Cell[37611, 1137, 944, 28, 84, "Text"],
Cell[38558, 1167, 2033, 56, 224, "Input"],
Cell[40594, 1225, 4364, 128, 307, "Input"],
Cell[44961, 1355, 1072, 38, 64, "Text"],
Cell[46036, 1395, 285, 9, 65, "Text",
 Evaluatable->False],
Cell[46324, 1406, 4304, 124, 306, "Input"],
Cell[50631, 1532, 6717, 198, 386, "Input"],
Cell[57351, 1732, 1027, 34, 67, "Text"]
}, Closed]],
Cell[58393, 1769, 471, 16, 26, "Text"],
Cell[58867, 1787, 5800, 98, 192, "Text",
 Evaluatable->False],
Cell[64670, 1887, 448, 15, 29, "Text"],
Cell[65121, 1904, 6255, 226, 387, "Text"],
Cell[71379, 2132, 1095, 37, 233, "Text"],
Cell[CellGroupData[{
Cell[72499, 2173, 224, 5, 37, "Subsection"],
Cell[72726, 2180, 737, 20, 112, "Input"],
Cell[73466, 2202, 1066, 32, 162, "Input"],
Cell[74535, 2236, 6151, 182, 365, "Input"]
}, Closed]],
Cell[80701, 2421, 200, 6, 26, "Text"],
Cell[80904, 2429, 4019, 69, 192, "Text",
 Evaluatable->False],
Cell[84926, 2500, 137, 3, 29, "Text"],
Cell[85066, 2505, 4391, 161, 307, "Text"],
Cell[89460, 2668, 2051, 71, 262, "Text"],
Cell[CellGroupData[{
Cell[91536, 2743, 224, 5, 37, "Subsection"],
Cell[91763, 2750, 616, 17, 68, "Input"],
Cell[92382, 2769, 1039, 36, 129, "Input"],
Cell[93424, 2807, 6225, 186, 373, "Input"]
}, Closed]],
Cell[99664, 2996, 158, 5, 26, "Text"],
Cell[99825, 3003, 11570, 192, 192, "Text",
 Evaluatable->False],
Cell[111398, 3197, 222, 5, 47, "Text"],
Cell[111623, 3204, 6188, 219, 294, "Text"],
Cell[117814, 3425, 1863, 61, 202, "Text"],
Cell[CellGroupData[{
Cell[119702, 3490, 215, 5, 37, "Subsection"],
Cell[119920, 3497, 913, 25, 68, "Input"],
Cell[120836, 3524, 1798, 58, 202, "Input"],
Cell[122637, 3584, 4746, 138, 331, "Input"],
Cell[127386, 3724, 7182, 211, 431, "Input"],
Cell[134571, 3937, 4793, 139, 331, "Input"],
Cell[139367, 4078, 7206, 211, 431, "Input"]
}, Closed]],
Cell[146588, 4292, 164, 5, 26, "Text"],
Cell[146755, 4299, 4458, 76, 192, "Text",
 Evaluatable->False],
Cell[151216, 4377, 127, 3, 29, "Text"],
Cell[151346, 4382, 3408, 128, 267, "Text"],
Cell[154757, 4512, 1312, 45, 219, "Text"],
Cell[CellGroupData[{
Cell[156094, 4561, 223, 5, 37, "Subsection"],
Cell[156320, 4568, 714, 19, 68, "Input"],
Cell[157037, 4589, 862, 29, 129, "Input"],
Cell[157902, 4620, 4243, 126, 293, "Input"]
}, Closed]],
Cell[162160, 4749, 158, 5, 26, "Text"],
Cell[162321, 4756, 6438, 108, 192, "Text",
 Evaluatable->False],
Cell[168762, 4866, 157, 4, 47, "Text"],
Cell[168922, 4872, 3822, 141, 291, "Text"],
Cell[172747, 5015, 2894, 94, 296, "Text"],
Cell[CellGroupData[{
Cell[175666, 5113, 223, 5, 37, "Subsection"],
Cell[175892, 5120, 1998, 60, 189, "Input"],
Cell[177893, 5182, 867, 24, 112, "Input"],
Cell[178763, 5208, 2810, 83, 249, "Input"],
Cell[181576, 5293, 5385, 160, 332, "Input"],
Cell[186964, 5455, 7936, 237, 432, "Input"],
Cell[194903, 5694, 213, 9, 65, "Text"],
Cell[195119, 5705, 733, 20, 85, "Input"],
Cell[195855, 5727, 1918, 63, 214, "Input"],
Cell[197776, 5792, 2132, 64, 234, "Input"],
Cell[199911, 5858, 50, 0, 29, "Text"],
Cell[199964, 5860, 2811, 83, 249, "Input"]
}, Closed]],
Cell[202790, 5946, 435, 8, 26, "Text"],
Cell[CellGroupData[{
Cell[203250, 5958, 407, 7, 29, "Text"],
Cell[203660, 5967, 130, 3, 31, "Input",
 InitializationCell->True]
}, Closed]]
}
]
*)

(* End of internal cache information *)
