(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    340451,       9283]
NotebookOptionsPosition[    333166,       9086]
NotebookOutlinePosition[    333750,       9109]
CellTagsIndexPosition[    333707,       9106]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[StyleBox["11.11  Sources and Sinks",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tIf the two-dimensional motion of an ideal fluid consists of an outward \
radial flow from a point and is symmetrical in all directions, then the point \
is called a simple source.  A source at the origin can be considered as a \
line perpendicular to the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane along which fluid is being emitted.  If the rate of emission of \
volume of fluid per unit length  ",
 Cell[BoxData[
  RowBox[{"2", "\[Pi]", " ", "m"}]]],
 ",  then the origin is said to be a source of strength  ",
 StyleBox["m",
  FontFamily->"Courier New"],
 ",  the complex potential for the flow is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{"m", " ", "log", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ",  \n\nand the velocity  ",
 StyleBox["V",
  FontWeight->"Bold"],
 "  at the point ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"x", ",", "y"}], ")"}]]],
 " is given by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["V",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    OverscriptBox[
     RowBox[{
      RowBox[{"F", "'"}], 
      RowBox[{"(", "z", ")"}]}], "_"], "  ", "=", "  ", 
    FractionBox["m", 
     OverscriptBox[
      RowBox[{"z", " "}], "_"]]}]}]]],
 ".  \n\nFor fluid flows, a sink is a negative source and is a point of \
inward radial flow at which the fluid is considered to be absorbed or \
annihilated.  Sources and sinks for flows are illustrated in Figure 11.93."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{543, 285},
  ImageMargins->0],
 "  \n\n\t\t",
 "\t\t\tFigure 11.93  ",
 "Sources and sinks for an ideal fluid. "
}], "Text",
 CellChangeTimes->{{3.3995617421875*^9, 3.39956174240625*^9}, {
  3.399567314703125*^9, 3.39956731925*^9}, {3.50680395959375*^9, 
  3.50680396321875*^9}}],

Cell[TextData[StyleBox["11.11.1  Source: A Charged Line",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tIn the case of electrostatics a source will correspond to a uniformly \
charged line perpendicular to the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-plane at the point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  We will show that if the line ",
 StyleBox["L",
  FontFamily->"Courier New"],
 " is located at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 "  and carries a charge density of  ",
 Cell[BoxData[
  FractionBox["q", "2"]]],
 "  coulombs per unit length, then the magnitude of the electric field is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{
     StyleBox["E",
      FontWeight->"Bold"], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "|"}], "=", 
   FractionBox["q", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"]}]]]}]]],
 ".  Hence  ",
 StyleBox["E",
  FontWeight->"Bold"],
 "  is given by  \n\n",
 StyleBox["(11-41)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["E",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox[
     RowBox[{"q", " ", "z"}], 
     RowBox[{"|", 
      SuperscriptBox["z", "2"], "|"}]], "  ", "=", "  ", 
    FractionBox["q", 
     OverscriptBox[
      RowBox[{"z", " "}], "_"]]}]}]]],
 ",  \n\nand the complex potential is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"-", " ", "q"}], " ", "log", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ",  and  \n\t\t\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["E",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{"-", "  ", 
    OverscriptBox[
     RowBox[{
      RowBox[{"F", "'"}], 
      RowBox[{"(", "z", ")"}]}], "_"]}], " "}]]],
 ".  \n\nA sink for electrostatics is a negatively charged line perpendicular \
to the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-plane.  The electrostatic field for electrostatic problems corresponds to \
the velocity field for fluid flow problems, except that their corresponding \
potentials differ by a sign change. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tTo establish Equation ",
 StyleBox["(11-41)",
  FontColor->RGBColor[0, 0, 1]],
 ", we start with Coulomb's law, which states that two particles with charges \
",
 StyleBox["q",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["Q",
  FontFamily->"Courier New"],
 " exert a force on one another with magnitude   ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"C", " ", "q", " ", "Q"}], 
   SuperscriptBox["r", "2"]]]],
 ",  where ",
 StyleBox["r",
  FontFamily->"Courier New"],
 " is the distance between particles and ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a constant that depends on the scientific units.  For simplicity, we \
assume that ",
 Cell[BoxData[
  RowBox[{"C", "=", "1"}]]],
 " and the test particle at the point ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " has charge ",
 Cell[BoxData[
  RowBox[{"Q", "=", "1"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tThe contribution ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox[
    RowBox[{"\[CapitalDelta]", 
     StyleBox["E",
      FontWeight->"Bold"]}]], "1"]]],
 " induced by the element of charge  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"q", " ", "\[CapitalDelta]h"}], "2"]]],
 "  along the segment of length ",
 Cell[BoxData["\[CapitalDelta]h"]],
 " situated at a height ",
 StyleBox["h",
  FontFamily->"Courier New"],
 " above the plane has magnitude  ",
 Cell[BoxData[
  RowBox[{"|", 
   SubscriptBox[
    StyleBox[
     RowBox[{"\[CapitalDelta]", 
      StyleBox["E",
       FontWeight->"Bold"]}]], "1"], "|"}]]],
 "  given by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    SubscriptBox[
     StyleBox[
      RowBox[{"\[CapitalDelta]", 
       StyleBox["E",
        FontWeight->"Bold"]}]], "1"], "|"}], "  ", "=", "  ", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"q", "/", "2"}], ")"}], " ", "\[CapitalDelta]h"}], 
    RowBox[{
     SuperscriptBox["r", "2"], "+", 
     SuperscriptBox["h", "2"]}]]}]]],
 ".  \n\n\tIt has the same magnitude as ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox[
    RowBox[{"\[CapitalDelta]", 
     StyleBox["E",
      FontWeight->"Bold"]}]], "2"]]],
 " induced by the element  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"q", " ", "\[CapitalDelta]h"}], "2"]]],
 "  located a distance ",
 StyleBox["-h",
  FontFamily->"Courier New"],
 "  below the plane.  From the vertical symmetry involved their sum,  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    StyleBox[
     RowBox[{"\[CapitalDelta]", 
      StyleBox["E",
       FontWeight->"Bold"]}]], "1"], "+", 
   SubscriptBox[
    StyleBox[
     RowBox[{"\[CapitalDelta]", 
      StyleBox["E",
       FontWeight->"Bold"]}]], "2"]}]]],
 ",  lies parallel to the plane along the ray from the origin, as shown in \
Figure 11.94. "
}], "Text"],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{506, 343},
  ImageMargins->0],
 "  \n\n",
 "\t\tFigure 11.94  ",
 "Contributions to ",
 Cell[BoxData[
  StyleBox["E",
   FontWeight->"Bold"]]],
 " from the elements of charge ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"q", " ", "\[CapitalDelta]h"}], "2"]]],
 " situated at ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"0", 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "0", 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    RowBox[{"\[PlusMinus]", "h"}]}], ")"}]]],
 ", above and below the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane."
}], "Text",
 CellChangeTimes->{{3.399561746015625*^9, 3.399561746578125*^9}, {
   3.399567333609375*^9, 3.39956733996875*^9}, 3.50680398228125*^9}],

Cell[TextData[{
 "\tBy the principal of superposition, we add all contributions from the \
elements of charge along ",
 StyleBox["L",
  FontFamily->"Courier New"],
 " to obtain  ",
 Cell[BoxData[
  RowBox[{
   StyleBox["E",
    FontWeight->"Bold"], " ", "=", " ", 
   RowBox[{"\[Sum]", " ", 
    SubscriptBox[
     StyleBox[
      RowBox[{"\[CapitalDelta]", 
       StyleBox["E",
        FontWeight->"Bold"]}]], "k"]}]}]]],
 ".  By vertical symmetry,  ",
 Cell[BoxData[
  StyleBox["E",
   FontWeight->"Bold"]]],
 " lies parallel to the complex plane along the ray from the origin through \
the point ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ".  Hence the magnitude of  ",
 Cell[BoxData[
  StyleBox["E",
   FontWeight->"Bold"]]],
 " is the sum of all components  ",
 Cell[BoxData[
  RowBox[{"|", 
   StyleBox[
    RowBox[{"\[CapitalDelta]", 
     StyleBox["E",
      FontWeight->"Bold"]}]], "|", 
   RowBox[{"cos", " ", "t"}]}]]],
 "  that are parallel to the complex plane, where ",
 StyleBox["t",
  FontFamily->"Courier New"],
 " is the angle between  ",
 Cell[BoxData[
  StyleBox["E",
   FontWeight->"Bold"]]],
 " and the plane.  Letting  ",
 Cell[BoxData[
  RowBox[{"\[CapitalDelta]h", "\[Rule]", "0"}]]],
 "  in this summation process produces the definite integral   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{
     StyleBox["E",
      FontWeight->"Bold"], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "|"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
     RowBox[{"|", 
      StyleBox[
       RowBox[{"\[CapitalDelta]", 
        StyleBox["E",
         FontWeight->"Bold"]}]], "|", 
      RowBox[{"cos", " ", "t", 
       RowBox[{"\[DifferentialD]", "h"}]}]}]}], "  ", "=", "  ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"q", "/", "2"}], ")"}], " ", "\[CapitalDelta]h"}], 
       RowBox[{
        SuperscriptBox["r", "2"], "+", 
        SuperscriptBox["h", "2"]}]], 
      RowBox[{"\[DifferentialD]", "h"}]}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tNext, we use the change of variable  ",
 Cell[BoxData[
  RowBox[{"h", " ", "=", " ", 
   RowBox[{
    RowBox[{"r", " ", "tan", " ", "t", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "   ", 
     RowBox[{"\[DifferentialD]", "h"}]}], " ", "=", " ", 
    RowBox[{"r", " ", 
     SuperscriptBox["sec", "2"], " ", "t", " ", 
     RowBox[{"\[DifferentialD]", "t"}]}]}]}]]],
 "  and the trigonometric identity  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["sec", "2"], " ", "t"}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SuperscriptBox["r", "2"], "+", 
     SuperscriptBox["h", "2"]}], 
    SuperscriptBox["r", "2"]]}]]],
 "  to obtain the equivalent integral:  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{
     StyleBox["E",
      FontWeight->"Bold"], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "|"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{
       RowBox[{"-", "\[Pi]"}], "/", "2"}], 
      RowBox[{"\[Pi]", "/", "2"}]], 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"q", "/", "2"}], ")"}], "cos", " ", "t"}], 
       RowBox[{
        SuperscriptBox["r", "2"], "+", 
        SuperscriptBox["h", "2"]}]], 
      FractionBox[
       RowBox[{
        SuperscriptBox["r", "2"], "+", 
        SuperscriptBox["h", "2"]}], "r"], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["q", 
       RowBox[{"2", "r"}]], 
      RowBox[{
       SubsuperscriptBox["\[Integral]", 
        RowBox[{
         RowBox[{"-", "\[Pi]"}], "/", "2"}], 
        RowBox[{"\[Pi]", "/", "2"}]], " ", 
       RowBox[{"cos", " ", "t", 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}], "  ", "=", "  ", 
     FractionBox["q", "r"]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tMultiplying this magnitude  ",
 Cell[BoxData[
  FractionBox["q", "r"]]],
 "  by the unit vector  ",
 Cell[BoxData[
  FractionBox["z", 
   RowBox[{"|", "z", "|"}]]]],
 "  establishes Formula ",
 StyleBox["(11-41)",
  FontColor->RGBColor[0, 0, 1]],
 ".  If ",
 Cell[BoxData[
  RowBox[{"q", ">", "0"}]]],
 ", then the field is directed away from ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 " and, if ",
 Cell[BoxData[
  RowBox[{"q", "<", "0"}]]],
 ", then it is directed toward ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 ".  An electrical field located at ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "\[NotEqual]", "0"}]]],
 " is given by   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["E",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["z", "0"]}], ")"}]}], 
     RowBox[{"|", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", 
         SubscriptBox["z", "0"]}], ")"}], "2"], "|"}]], " ", "=", " ", 
    FractionBox["q", 
     RowBox[{
      OverscriptBox[
       RowBox[{"z", " "}], "_"], " ", "-", " ", 
      OverscriptBox[
       SubscriptBox["z", "0"], "_"]}]]}]}]]],
 ",  \n\nand the corresponding complex potential is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", " ", "q"}], "  ", "log", 
    RowBox[{"(", 
     RowBox[{"z", "-", 
      SubscriptBox["z", "0"]}], ")"}]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 11.30.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  ",
 StyleBox["(Source and sink of equal strength)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let a source and sink of unit strength be located at the points ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{"+", "1"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{"-", "1"}]}]]],
 ", respectively.  The complex potential for a fluid flowing from the source \
at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{"+", "1"}]}]]],
 "  to the sink at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{"-", "1"}]}]]],
 "  is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"log", 
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}]}], " ", "-", " ", 
     RowBox[{"log", 
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}]}]}], "  ", "=", "  ", 
    RowBox[{"log", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"z", "-", "1"}], 
       RowBox[{"z", "+", "1"}]], ")"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{338, 228},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]], "Text"],

Cell["\<\
\t\t\tFigure 11.95 (a)  Source and sink of unit strength.\
\>", "Text",
 CellChangeTimes->{3.50680400571875*^9}],

Cell[TextData[{
 "The velocity potential and stream function are  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{"ln", "|", 
    FractionBox[
     RowBox[{"z", "-", "1"}], 
     RowBox[{"z", "+", "1"}]], "|"}]}]]],
 ",   and  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{"arg", 
    RowBox[{"(", 
     FractionBox[
      RowBox[{"z", "-", "1"}], 
      RowBox[{"z", "+", "1"}]], ")"}]}]}]]],
 ",  \n\nrespectively.  Solving for the streamline  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", "c"}]]],
 ",  we start with   \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"c", "  ", "=", "  ", 
    RowBox[{
     RowBox[{"arg", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", "1"}], 
        RowBox[{"z", "+", "1"}]], ")"}]}], "  ", "=", "  ", 
     RowBox[{"arg", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}], "-", "1"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"x", "-", 
           RowBox[{"\[ImaginaryI]", " ", "y"}], "+", "1"}], ")"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}], "+", "1"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"x", "-", 
           RowBox[{"\[ImaginaryI]", " ", "y"}], "+", "1"}], ")"}]}]], 
       ")"}]}]}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"     ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"arg", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["y", "2"], "-", "1", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "2", "y"}]}], 
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         RowBox[{"2", " ", "x"}], "+", "1", "+", 
         SuperscriptBox["y", "2"], " "}]], ")"}]}], "  ", "=", "  ", 
     RowBox[{"arg", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["y", "2"], "-", "1", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "2", "y"}]}], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"x", "+", "1"}], ")"}], "2"], "+", 
         SuperscriptBox["y", "2"], " "}]], ")"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"     ", 
   RowBox[{"=", "  ", 
    RowBox[{"arctan", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"2", "y"}], 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "-", "1", " "}]], ")"}]}]}]}]}]],
 "  \n\nand obtain the equation\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"tan", " ", "c"}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"], "-", "1"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{"2", "y"}]}]]],
 ". \n\nA straightforward calculation shows that points on the streamline \
must satisfy the equation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "2"], " ", "+", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"y", "-", 
       RowBox[{"cot", " ", "c"}]}], ")"}], "2"]}], "  ", "=", "  ", 
   RowBox[{"1", " ", "+", " ", 
    RowBox[{
     SuperscriptBox["cot", "2"], "c"}]}]}]]],
 ",  \n\nwhich is the equation of a circle with center at  ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"0", ",", 
    RowBox[{"cot", " ", "c"}]}], ")"}]]],
 "  that passes through the points  ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    RowBox[{"\[PlusMinus]", "1"}], ",", "0"}], ")"}]]],
 ".  Several streamlines are indicated in Figure 11.95(a)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"11.30", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670702271875*^9, 3.50670702271875*^9}}],

Cell["Enter the formula for the complex potential F[z].", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "F", ",", "\[Phi]", ",", "\[Psi]", ",", "W", ",", "x", ",", 
      "y", ",", "z", ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "Z_", "]"}], " ", "=", " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"Z", " ", "-", " ", "1"}], 
       RowBox[{"Z", " ", "+", " ", "1"}]], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{"F", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Im", "[", 
         RowBox[{"F", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W = F[Z] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The velocity potential is:\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<\[Phi][x,y] = Re[F[x + \[ImaginaryI]y]]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The stream function is:\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<\[Psi][x,y] = Im[F[x + \[ImaginaryI]y]]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"]}], ",", 
       RowBox[{"2", " ", "y"}]}], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399567429390625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a density plot of the velocity potential."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"DensityPlot", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "100"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The velocity potential for the\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<source at \!\(\*SubscriptBox[\(z\), \(1\)]\)=+1 and sink at \
\!\(\*SubscriptBox[\(z\), \(2\)]\)=-1.\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399567435375*^9, 3.3995674369375*^9}, 
   3.400193624390625*^9}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the stream function."
}], "Text"],

Cell[BoxData[
 RowBox[{" ", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"\[Psi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "0", ",", "1.5"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Contours", "\[Rule]", "11"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"\[Psi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "1.50001"}], ",", 
         RowBox[{"-", "0.00001"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Contours", "\[Rule]", "11"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The stream function for the\>\"", "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<source at \!\(\*SubscriptBox[\(z\), \(1\)]\)=+1 and sink at \
\!\(\*SubscriptBox[\(z\), \(2\)]\)=-1.\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"F", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399567452421875*^9, 3.399567453921875*^9}, 
   3.40019363059375*^9, {3.4001941215625*^9, 3.400194140703125*^9}, {
   3.400406330328125*^9, 3.400406338484375*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the velocity potential."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", "11"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The velocity potential for the\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<source at \!\(\*SubscriptBox[\(z\), \(1\)]\)=+1 and sink at \
\!\(\*SubscriptBox[\(z\), \(2\)]\)=-1.\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399567461046875*^9, 3.39956747040625*^9}, 
   3.40019363559375*^9}],

Cell["Find the inverse of the function F[Z].", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"F", "[", "Z", "]"}], " ", "\[Equal]", " ", "W"}], ",", "Z"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", "  ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], ",", 
       RowBox[{"W", "\[Rule]", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W = F[Z] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The inverse function is:\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x,y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399567477125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph the stream functions using  f[x,y]."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"n", " ", "=", " ", "12"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "k", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", ",", 
             FractionBox[
              RowBox[{" ", 
               RowBox[{"k", " ", "\[Pi]"}]}], "n"]}], "]"}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", ",", 
             FractionBox[
              RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"2", "n"}], ",", "2"}], "}"}]}], "]"}], "]"}]}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", ",", 
             FractionBox[
              RowBox[{" ", 
               RowBox[{"k", " ", "\[Pi]"}]}], "n"]}], "]"}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", ",", 
             FractionBox[
              RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", 
          RowBox[{"2", "n"}], ",", "2"}], "}"}]}], "]"}], "]"}]}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "None"}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The streamlines for the\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<source at \!\(\*SubscriptBox[\(z\), \(1\)]\)=+1 and sink at \
\!\(\*SubscriptBox[\(z\), \(2\)]\)=-1.\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[x,y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399567481109375*^9, 3.399567483703125*^9}, {
  3.400193640984375*^9, 3.400193641234375*^9}, {3.400406344875*^9, 
  3.400406353046875*^9}},
 AspectRatioFixed->True],

Cell["\<\
The stream function for a fluid flowing from the source at  z = +1  to the \
sink at  z = -1.  \
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"n", " ", "=", " ", "12"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "k", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns3", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"f", "[", 
            RowBox[{"k", ",", "y"}], "]"}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"k", ",", "y"}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "}"}]}], "]"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr3", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Green"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns4", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"f", "[", 
            RowBox[{"k", ",", "y"}], "]"}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"k", ",", "y"}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{
           RowBox[{"-", "4"}], "+", 
           FractionBox["1", "2"]}], ",", 
          RowBox[{"4", "-", 
           FractionBox["1", "2"]}], ",", "1"}], "}"}]}], "]"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr4", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns4", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Magenta"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr3", ",", "gr4", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "None"}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The velocity potential for the\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<source at \!\(\*SubscriptBox[\(z\), \(1\)]\)=+1 and sink at \
\!\(\*SubscriptBox[\(z\), \(2\)]\)=-1.\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[x,y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399567487*^9, 3.399567488734375*^9}, {
  3.400193646734375*^9, 3.4001936469375*^9}, {3.4004063588125*^9, 
  3.40040636721875*^9}},
 AspectRatioFixed->True],

Cell["\<\
The velocity potential for a fluid flowing from the source at  z = +1  to the \
sink at  z = -1.  \
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", "gr3", ",", "gr4", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "None"}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The streamlines and velocity potential for the\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<source at \!\(\*SubscriptBox[\(z\), \(1\)]\)=+1 and sink at \
\!\(\*SubscriptBox[\(z\), \(2\)]\)=-1.\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[x,y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399567491796875*^9, 3.399567494625*^9}, {
  3.400406373671875*^9, 3.40040637521875*^9}},
 AspectRatioFixed->True],

Cell["\<\
The streamlines and velocity potential for a fluid flowing from the source at \
 z = +1  to the sink at  z = -1.  \
\>", "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 11.31.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  ",
 StyleBox["(Two sources of equal strength)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let two sources of unit strength be located at the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{"1", "  ", "and", "  ", 
     SubscriptBox["z", "2"]}], "=", 
    RowBox[{"-", "1"}]}]}]]],
 ".  The resulting complex potential for a fluid flow is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"log", 
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}]}], " ", "+", " ", 
     RowBox[{"log", 
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}]}]}], "  ", "=", "  ", 
    RowBox[{"log", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z", "2"], "-", "1"}], ")"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{338, 228},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]], "Text"],

Cell["\<\
\t\t\tFigure 11.95 (b)  Two sources of unit strength\
\>", "Text",
 CellChangeTimes->{3.5068040274375*^9}],

Cell[TextData[{
 "The velocity potential and stream function are \n\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{"ln", "|", 
    RowBox[{
     SuperscriptBox["z", "2"], "-", "1"}], "|"}]}]]],
 ",   and  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{"arg", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z", "2"], "-", "1"}], ")"}]}]}]]],
 ",  \n\nrespectively.  Solving for the streamline  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", "c"}]]],
 ",  we start with  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"c", "  ", "=", "  ", 
    RowBox[{
     RowBox[{"arg", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "-", "1"}], ")"}]}], "  ", "=", "  ", 
     RowBox[{"arg", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["y", "2"], "-", "1", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "2", "x", " ", "y"}]}], ")"}]}]}]}], 
   "  ", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"     ", 
   RowBox[{"=", "  ", 
    RowBox[{"arctan", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"2", "xy"}], 
       RowBox[{
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["y", "2"], "-", "1"}]], ")"}]}]}]}]}]],
 "\n\nand obtain the equation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "2"], "  ", "+", "  ", 
    RowBox[{"2", "x", " ", "y", " ", "cot", " ", "c"}], "  ", "-", "  ", 
    SuperscriptBox["y", "2"]}], "   ", "=", "   ", "1"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\t If we express this equation in the form  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"x", " ", "-", " ", 
      RowBox[{"y", " ", "tan", 
       FractionBox["c", "2"]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"x", " ", "+", " ", 
      RowBox[{"y", " ", "cot", 
       FractionBox["c", "2"]}]}], ")"}]}], "  ", "=", "  ", "1"}]]],
 "  then we can get  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", " ", "cos", 
       FractionBox["c", "2"]}], " ", "-", " ", 
      RowBox[{"y", " ", "sin", 
       FractionBox["c", "2"]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", " ", "sin", 
       FractionBox["c", "2"]}], " ", "+", " ", 
      RowBox[{"y", " ", "cos", 
       FractionBox["c", "2"]}]}], ")"}]}], "  ", "=", "  ", 
   RowBox[{"sin", 
    FractionBox["c", "2"], "  ", "cos", 
    FractionBox["c", "2"]}]}]]],
 ",   or  \n\t\t\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", " ", "cos", 
       FractionBox["c", "2"]}], " ", "-", " ", 
      RowBox[{"y", " ", "sin", 
       FractionBox["c", "2"]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", " ", "sin", 
       FractionBox["c", "2"]}], " ", "+", " ", 
      RowBox[{"y", " ", "cos", 
       FractionBox["c", "2"]}]}], ")"}]}], "  ", "=", "  ", 
   FractionBox[
    RowBox[{"sin", " ", "c"}], "2"]}]]],
 ".\n\nNow use the rotation of axes  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "*"], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"x", " ", "cos", 
      FractionBox[
       RowBox[{"-", "c"}], "2"]}], " ", "+", " ", 
     RowBox[{"y", " ", "sin", 
      FractionBox[
       RowBox[{"-", "c"}], "2"], 
      StyleBox[
       RowBox[{" ", 
        StyleBox["  ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}]], 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}], "\n"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SuperscriptBox["y", "*"], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", " ", "x"}], " ", "sin", 
      FractionBox[
       RowBox[{"-", "c"}], "2"]}], " ", "+", " ", 
     RowBox[{"y", " ", "cos", 
      FractionBox[
       RowBox[{"-", "c"}], "2"]}]}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]}]],
 "  \n\nthen the streamlines must satisfy the equation   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "*"], 
    SuperscriptBox["y", "*"]}], "  ", "=", "  ", 
   FractionBox[
    RowBox[{"sin", " ", "c"}], "2"]}]]],
 "  \n\nand are rectangular hyperbolas with centers at the origin that pass \
through the points  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{"\[PlusMinus]", "1"}]}]]],
 ".  Several streamlines are indicated in Figure 11.95(b)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"11.31", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.5067070275*^9, 3.5067070275*^9}}],

Cell["Enter the formula for the complex potential F[z].", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "f1", ",", "f2", ",", "F", ",", "\[Phi]", ",", "\[Psi]", ",", 
      "W", ",", "x", ",", "y", ",", "z", ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "Z_", "]"}], " ", "=", " ", 
     RowBox[{"Log", "[", 
      RowBox[{
       SuperscriptBox["Z", "2"], " ", "-", " ", "1"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{"F", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Im", "[", 
        RowBox[{"F", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W = F[Z] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The velocity potential is:\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<\[Phi][x,y] = Re[F[x + \[ImaginaryI]y]]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The stream function is:\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<\[Psi][x,y] = Im[F[x + \[ImaginaryI]y]]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399567505953125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a density plot of the velocity potential."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"DensityPlot", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotPoints", "\[Rule]", "100"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The velocity potential for two sources\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<of unit strength at \!\(\*SubscriptBox[\(z\), \(1\)]\)=+1 and \
\!\(\*SubscriptBox[\(z\), \(2\)]\)=-1.\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399567509171875*^9, 3.399567510625*^9}, 
   3.400193651390625*^9}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the stream function."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"\[Psi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0.00001", ",", "1.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "0.00001", ",", "1.5"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Contours", "\[Rule]", "11"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"\[Psi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1.5"}], ",", 
         RowBox[{"-", "0.00001"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "0.00001", ",", "1.5"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Contours", "\[Rule]", "11"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr3", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"\[Psi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0.00001", ",", "1.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "1.5"}], ",", 
         RowBox[{"-", "0.00001"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Contours", "\[Rule]", "11"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr4", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"\[Psi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1.5"}], ",", 
         RowBox[{"-", "0.00001"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "1.5"}], ",", 
         RowBox[{"-", "0.00001"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Contours", "\[Rule]", "11"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", "gr3", ",", "gr4", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The stream function for two sources\>\"", "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<of unit strength at \!\(\*SubscriptBox[\(z\), \(1\)]\)=+1 and \
\!\(\*SubscriptBox[\(z\), \(2\)]\)=-1.\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"F", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399567519203125*^9, 3.399567557734375*^9}, 
   3.400193656296875*^9, {3.40040638090625*^9, 3.400406396328125*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the velocity potential."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Contours", "\[Rule]", "11"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The velocity potential for two sources\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<of unit strength at \!\(\*SubscriptBox[\(z\), \(1\)]\)=+1 and \
\!\(\*SubscriptBox[\(z\), \(2\)]\)=-1.\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39956756446875*^9, 3.399567565921875*^9}, 
   3.400193660796875*^9}],

Cell["Find the inverse of the function F[Z].", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"F", "[", "Z", "]"}], " ", "\[Equal]", " ", "W"}], ",", "Z"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", "  ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], ",", 
       RowBox[{"W", "\[Rule]", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W = F[Z] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The inverse function is:\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x,y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39956757453125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph the stream functions using  f[x,y]."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"n", " ", "=", " ", "12"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "k", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", ",", 
             FractionBox[
              RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", ",", 
             FractionBox[
              RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", 
          RowBox[{"n", "-", "1"}], ",", "2"}], "}"}]}], "]"}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", ",", 
             FractionBox[
              RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", ",", 
             FractionBox[
              RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"12", "+", "2"}], ",", 
          RowBox[{"12", "+", "n", "-", "1"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqns3", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"-", 
            RowBox[{"f", "[", 
             RowBox[{"x", ",", 
              FractionBox[
               RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}]}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{"-", 
            RowBox[{"f", "[", 
             RowBox[{"x", ",", 
              FractionBox[
               RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}]}], "]"}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", 
          RowBox[{"n", "-", "1"}], ",", "2"}], "}"}]}], "]"}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"eqns4", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"-", 
            RowBox[{"f", "[", 
             RowBox[{"x", ",", 
              FractionBox[
               RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}]}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{"-", 
            RowBox[{"f", "[", 
             RowBox[{"x", ",", 
              FractionBox[
               RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}]}], "]"}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"12", "+", "2"}], ",", 
          RowBox[{"12", "+", "n", "-", "1"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqns", "  ", "=", " ", 
     RowBox[{"Union", "[", 
      RowBox[{"eqns1", ",", "eqns2", ",", "eqns3", ",", "eqns4"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", ",", 
             FractionBox[
              RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", ",", 
             FractionBox[
              RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"n", "-", "1"}], ",", "2"}], "}"}]}], "]"}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", ",", 
             FractionBox[
              RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", ",", 
             FractionBox[
              RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"12", "+", "1"}], ",", 
          RowBox[{"12", "+", "n", "-", "1"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqns3", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"-", 
            RowBox[{"f", "[", 
             RowBox[{"x", ",", 
              FractionBox[
               RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}]}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{"-", 
            RowBox[{"f", "[", 
             RowBox[{"x", ",", 
              FractionBox[
               RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}]}], "]"}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"n", "-", "1"}], ",", "2"}], "}"}]}], "]"}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"eqns4", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"-", 
            RowBox[{"f", "[", 
             RowBox[{"x", ",", 
              FractionBox[
               RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}]}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{"-", 
            RowBox[{"f", "[", 
             RowBox[{"x", ",", 
              FractionBox[
               RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}]}], "]"}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"12", "+", "1"}], ",", 
          RowBox[{"12", "+", "n", "-", "1"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqns", "  ", "=", " ", 
     RowBox[{"Union", "[", 
      RowBox[{"eqns1", ",", "eqns2", ",", "eqns3", ",", "eqns4"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"-", "3"}]}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.98"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0.98", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", "boundary", ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.35"}], ",", "2.35"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.35"}], ",", "2.35"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The streamlines for two sources\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<of unit strength at \!\(\*SubscriptBox[\(z\), \(1\)]\)=+1 and \
\!\(\*SubscriptBox[\(z\), \(2\)]\)=-1.\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[x,y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39956757809375*^9, 3.399567581484375*^9}, {
  3.400193666109375*^9, 3.400193666546875*^9}, {3.400406402265625*^9, 
  3.40040641634375*^9}},
 AspectRatioFixed->True],

Cell["\<\
The stream function for a fluid with two sources of unit strength be located \
at the points  z = 1  and  z = -1. \
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"n", " ", "=", " ", "12"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "k", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"f", "[", 
            RowBox[{"k", " ", ",", "y"}], "]"}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"k", " ", ",", "y"}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "}"}]}], "]"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqns3", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"-", 
            RowBox[{"f", "[", 
             RowBox[{"k", " ", ",", "y"}], "]"}]}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{"-", 
            RowBox[{"f", "[", 
             RowBox[{"k", " ", ",", "y"}], "]"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "}"}]}], "]"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqns", "  ", "=", " ", 
     RowBox[{"Union", "[", 
      RowBox[{"eqns1", ",", "eqns3"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"graph3", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "\[Pi]"}], ",", "\[Pi]"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Green"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"f", "[", 
            RowBox[{"k", " ", ",", "y"}], "]"}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"k", " ", ",", "y"}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"-", 
           FractionBox["5", "2"]}], ",", 
          FractionBox["3", "2"], ",", "1"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"eqns4", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"-", 
            RowBox[{"f", "[", 
             RowBox[{"k", " ", ",", "y"}], "]"}]}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{"-", 
            RowBox[{"f", "[", 
             RowBox[{"k", " ", ",", "y"}], "]"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"-", 
           FractionBox["5", "2"]}], ",", 
          FractionBox["3", "2"], ",", "1"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"eqns", "  ", "=", " ", 
     RowBox[{"Union", "[", 
      RowBox[{"eqns2", ",", "eqns4"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"graph4", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "\[Pi]"}], ",", "\[Pi]"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Magenta"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph3", ",", "graph4", ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.35"}], ",", "2.35"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.35"}], ",", "2.35"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The velocity potential for two sources\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<of unit strength at \!\(\*SubscriptBox[\(z\), \(1\)]\)=+1 and \
\!\(\*SubscriptBox[\(z\), \(2\)]\)=-1.\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[x,y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39956758753125*^9, 3.3995675895625*^9}, {
  3.400193670875*^9, 3.40019367109375*^9}, {3.400406422171875*^9, 
  3.400406434390625*^9}},
 AspectRatioFixed->True],

Cell["\<\
The velocity potential for a fluid with two sources of unit strength be \
located at the points  z = 1  and  z = -1. \
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{
    "graph1", ",", "graph2", ",", "graph3", ",", "graph4", ",", "boundary", 
     ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.35"}], ",", "2.35"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.35"}], ",", "2.35"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The streamlines and the velocity potential for two sources\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<of unit strength at \!\(\*SubscriptBox[\(z\), \(1\)]\)=+1 and \
\!\(\*SubscriptBox[\(z\), \(2\)]\)=-1.\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[x,y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39956759490625*^9, 3.39956759934375*^9}, {
  3.40040643984375*^9, 3.40040644146875*^9}}],

Cell["\<\
The streamlines and velocity potential for a fluid with two sources of unit \
strength be located at the points  z = 1  and  z = -1. \
\>", "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Ideal Fluid Flow",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tLet an ideal fluid flow in a domain in the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane be effected by a source located at the point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  Then the flow at points ",
 StyleBox["z",
  FontFamily->"Courier New"],
 ", which lie in a small neighborhood of the point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", is approximated by that of a source with the complex potential  \n\n\t\t\t\
",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"log", 
     RowBox[{"(", 
      RowBox[{"z", "-", 
       SubscriptBox["z", "0"]}], ")"}]}], " ", "+", " ", "constant"}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "If  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  is a conformal mapping and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "0"], " ", "=", " ", 
   RowBox[{"S", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 ",  then ",
 StyleBox["S(z)",
  FontFamily->"Courier New"],
 " has a nonzero derivative at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " and   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", "-", 
    SubscriptBox["w", "0"]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"z", "-", 
      SubscriptBox["z", "0"]}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"S", "'"}], 
       RowBox[{"(", 
        SubscriptBox["z", "0"], ")"}]}], " ", "+", " ", 
      RowBox[{"\[Eta]", 
       RowBox[{"(", "z", ")"}]}]}], ")"}]}]}]]],
 "\n\nwhere  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Eta]", 
    RowBox[{"(", "z", ")"}]}], "\[Rule]", "0"}]]],
 "  as  ",
 Cell[BoxData[
  RowBox[{"z", "\[Rule]", 
   SubscriptBox["z", "0"]}]]],
 ".  Taking logarithms yields \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"log", 
    RowBox[{"(", 
     RowBox[{"w", "-", 
      SubscriptBox["w", "0"]}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"log", 
     RowBox[{"(", 
      RowBox[{"z", "-", 
       SubscriptBox["z", "0"]}], ")"}]}], "  ", "+", "  ", 
    RowBox[{"Log", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"S", "'"}], 
        RowBox[{"(", 
         SubscriptBox["z", "0"], ")"}]}], " ", "+", " ", 
       RowBox[{"\[Eta]", 
        RowBox[{"(", "z", ")"}]}]}], ")"}]}]}]}]]],
 ".\n\nBecause  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"S", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "\[NotEqual]", "0"}]]],
 ",  the term  ",
 Cell[BoxData[
  RowBox[{"Log", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"S", "'"}], 
      RowBox[{"(", 
       SubscriptBox["z", "0"], ")"}]}], " ", "+", " ", 
     RowBox[{"\[Eta]", 
      RowBox[{"(", "z", ")"}]}]}], ")"}]}]]],
 "  approaches the constant value  ",
 Cell[BoxData[
  RowBox[{"Log", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"S", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], ")"}]}]]],
 "  as  ",
 Cell[BoxData[
  RowBox[{"z", "\[Rule]", 
   SubscriptBox["z", "0"]}]]],
 ".  As  ",
 Cell[BoxData[
  RowBox[{"log", 
   RowBox[{"(", 
    RowBox[{"z", "-", 
     SubscriptBox["z", "0"]}], ")"}]}]]],
 "  is the complex potential for a source located at the point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", the image of a source under a conformal mapping is a source."
}], "Text"],

Cell[TextData[{
 "\tWe can use the technique of conformal mapping to determine the fluid flow \
in a domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " in the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane that is produced by sources and sinks.  If we can construct a \
conformal mapping  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  so that the image of sources, sinks, and boundary curves for the flow in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " are mapped onto sources, sinks, and boundary curves in a domain ",
 StyleBox["G",
  FontFamily->"Courier New"],
 " where the complex potential is known to be ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["F", "1"], 
   RowBox[{"(", "w", ")"}]}]]],
 ", then the complex potential in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " is given by ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["F", "2"], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SubscriptBox["F", "1"], 
    RowBox[{"(", 
     RowBox[{"S", 
      RowBox[{"(", "z", ")"}]}], ")"}]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 11.32.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Suppose that the lines  ",
 Cell[BoxData[
  RowBox[{"x", " ", "=", " ", 
   RowBox[{"\[PlusMinus]", 
    FractionBox["\[Pi]", "2"]}]}]]],
 "  are considered as walls of a containing vessel for a fluid flow produced \
by a single source of unit strength located at the origin.  The conformal \
mapping  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{"sin", " ", "z"}]}]}]]],
 "   maps the infinite strip bounded by the lines  ",
 Cell[BoxData[
  RowBox[{"x", " ", "=", " ", 
   RowBox[{"\[PlusMinus]", 
    FractionBox["\[Pi]", "2"]}]}]]],
 "  onto the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " plane slit along the boundary rays  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "\[LessEqual]", 
    RowBox[{"-", "1"}]}], ",", 
   RowBox[{"v", "=", "0"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "\[GreaterEqual]", "1"}], ",", 
   RowBox[{"v", "=", "0"}]}]]],
 ",  and the image of the source at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 "  is a source located at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "0"], "=", "0"}]]],
 ".  The complex potential  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["F", "1"], 
    RowBox[{"(", "w", ")"}]}], " ", "=", " ", 
   RowBox[{"log", " ", "w"}]}]]],
 "  \n\ndetermines a fluid flow in the w plane past the boundary curves  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "\[LessEqual]", 
    RowBox[{"-", "1"}]}], ",", 
   RowBox[{"v", "=", "0"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "\[GreaterEqual]", "1"}], ",", 
   RowBox[{"v", "=", "0"}]}]]],
 ", which lie along streamlines of the flow.  Therefore the complex potential \
for the fluid flow in the infinite strip in the z plane is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["F", "2"], 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["F", "1"], 
     RowBox[{"(", 
      RowBox[{"S", 
       RowBox[{"(", "z", ")"}]}], ")"}]}], "  ", "=", "  ", 
    RowBox[{"log", " ", 
     RowBox[{"(", 
      RowBox[{"sin", " ", "z"}], ")"}]}]}]}]]],
 ".  \n\nSeveral streamlines for the flow are illustrated in Figure 11.96. "
}], "Text"],

Cell[TextData[Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{256, 228},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]], "Text"],

Cell["\<\
\t\t\tFigure 11.96  A source in the center of a strip. \
\>", "Text",
 CellChangeTimes->{3.5068040523125*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"11.32", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.5067070328125*^9, 3.5067070328125*^9}}],

Cell["Enter the formula for the complex potential F[z].", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "F", ",", "\[Phi]", ",", "\[Psi]", ",", "W", ",", "x", ",", 
      "y", ",", "z", ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "Z_", "]"}], " ", "=", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"Sin", "[", "Z", "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{"F", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Im", "[", 
        RowBox[{"F", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W = F[Z] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The velocity potential is:\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<\[Phi][x,y] = Re[F[x + \[ImaginaryI]y]]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The stream function is:\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<\[Psi][x,y] = Im[F[x + \[ImaginaryI]y]]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39956761396875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a density plot of the velocity potential."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"DensityPlot", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       FractionBox[
        RowBox[{"-", "\[Pi]"}], "2"], ",", 
       FractionBox["\[Pi]", "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotPoints", "\[Rule]", "100"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["5", "\[Pi]"]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The velocity potential is:\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3995676178125*^9, 3.399567619171875*^9}, 
   3.400193675359375*^9}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a density plot of the stream function."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"\[Psi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         FractionBox[
          RowBox[{"-", "\[Pi]"}], "2"], ",", 
         FractionBox["\[Pi]", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "0.00001", ",", "2.5"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Contours", "\[Rule]", "11"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"\[Psi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         FractionBox[
          RowBox[{"-", "\[Pi]"}], "2"], ",", 
         FractionBox["\[Pi]", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "2.50001"}], ",", 
         RowBox[{"-", "0.00001"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Contours", "\[Rule]", "11"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "\[Pi]"}], "2"], ",", 
          FractionBox["\[Pi]", "2"]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["5", "\[Pi]"]}]}], "]"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The stream function\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399567633765625*^9, 3.39956767715625*^9}, 
   3.400193679625*^9, {3.40040644825*^9, 3.40040645821875*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the velocity potential."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"\[Phi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         FractionBox[
          RowBox[{"-", "\[Pi]"}], "2"], ",", 
         FractionBox["\[Pi]", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "0", ",", "2.5"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Contours", "\[Rule]", "11"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"\[Phi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         FractionBox[
          RowBox[{"-", "\[Pi]"}], "2"], ",", 
         FractionBox["\[Pi]", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "2.50001"}], ",", 
         RowBox[{"-", "0.00001"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Contours", "\[Rule]", "11"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "\[Pi]"}], "2"], ",", 
          FractionBox["\[Pi]", "2"]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["5", "\[Pi]"]}]}], "]"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The velocity potential is:\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399567683546875*^9, 3.399567699390625*^9}, 
   3.400193684234375*^9, {3.400406464171875*^9, 3.4004064756875*^9}}],

Cell["Find the inverse of the function F[Z].", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"F", "[", "Z", "]"}], " ", "\[Equal]", " ", "W"}], ",", "Z"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", "  ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], ",", 
       RowBox[{"W", "\[Rule]", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W = F[Z] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The inverse function is:\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x,y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3995677079375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph the stream functions using  f[x,y]."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"n", " ", "=", " ", "12"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "k", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", ",", 
            FractionBox[
             RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", ",", 
            FractionBox[
             RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", 
         RowBox[{"n", "-", "2"}], ",", "2"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", ",", 
            FractionBox[
             RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", ",", 
            FractionBox[
             RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{"n", "+", "2"}], ",", 
         RowBox[{
          RowBox[{"2", "n"}], "-", "2"}], ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns3", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", ",", 
            FractionBox[
             RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", ",", 
            FractionBox[
             RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", 
         RowBox[{"2", "n"}], ",", "2"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr3", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             FractionBox[
              RowBox[{"-", "\[Pi]"}], "2"], ",", 
             RowBox[{"-", "3"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             FractionBox[
              RowBox[{"-", "\[Pi]"}], "2"], ",", "3"}], "}"}]}], "}"}], "]"}],
         ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             FractionBox["\[Pi]", "2"], ",", 
             RowBox[{"-", "3"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             FractionBox["\[Pi]", "2"], ",", "3"}], "}"}]}], "}"}], "]"}], 
        ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"-", "0.045"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"-", "3"}]}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0.045"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "3"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             FractionBox[
              RowBox[{"-", "\[Pi]"}], "2"], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.045"}], ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0.045", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             FractionBox["\[Pi]", "2"], ",", "0"}], "}"}]}], "}"}], "]"}]}], 
       "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", "gr3", ",", "boundary", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.58"}], ",", "1.58"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["5", "3.16"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
     RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    w = f[x,y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399567721390625*^9, 3.3995677236875*^9}, {
  3.4001936893125*^9, 3.4001936898125*^9}, {3.400406481265625*^9, 
  3.40040649834375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "The stream function for a fluid flow in the infinite strip  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"-", "\[Pi]"}], "2"], "<", 
   RowBox[{"Re", "[", "z", "]"}], "<", 
   FractionBox["\[Pi]", "2"]}]]],
 "  with a single source at the origin."
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 11.33.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Suppose that the lines  ",
 Cell[BoxData[
  RowBox[{"x", " ", "=", " ", 
   RowBox[{"\[PlusMinus]", 
    FractionBox["\[Pi]", "2"]}]}]]],
 "  are considered as walls of a containing vessel for the fluid flow \
produced by a single source of unit strength located at the point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], " ", "=", " ", 
   FractionBox["\[Pi]", "2"]}]]],
 "  and a sink of unit strength located at the point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], " ", "=", " ", 
   RowBox[{"-", 
    FractionBox["\[Pi]", "2"]}]}]]],
 ".  The conformal mapping  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{"sin", " ", "z"}]}]}]]],
 "  maps the infinite strip bounded by the lines  ",
 Cell[BoxData[
  RowBox[{"x", " ", "=", " ", 
   RowBox[{"\[PlusMinus]", 
    FractionBox["\[Pi]", "2"]}]}]]],
 "  onto the w plane slit along the boundary rays  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["K", "1"], ":", 
    RowBox[{"u", "\[LessEqual]", 
     RowBox[{"-", "1"}]}]}], ",", 
   RowBox[{"v", "=", "0"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["K", "2"], ":", 
    RowBox[{"u", "\[GreaterEqual]", "1"}]}], ",", 
   RowBox[{"v", "=", "0"}]}]]],
 ".  The image of the source at ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   FractionBox["\[Pi]", "2"]}]]],
 " is a source at ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "1"], "=", "1"}]]],
 ", and the image of the sink at ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   FractionBox[
    RowBox[{"-", "\[Pi]"}], "2"]}]]],
 " is a sink at ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "2"], "=", 
   RowBox[{"-", "1"}]}]]],
 ".  The potential  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["F", "1"], 
    RowBox[{"(", "w", ")"}]}], " ", "=", " ", 
   RowBox[{"log", " ", 
    FractionBox[
     RowBox[{"w", "-", "1"}], 
     RowBox[{"w", "+", "1"}]]}]}]]],
 "  \n\ndetermines a fluid flow in the w plane past the boundary curves ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["K", "1"], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SubscriptBox["K", "2"]}]]],
 ", which lie along streamlines of the flow.  Therefore the complex potential \
for the fluid flow in the infinite strip in the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane is \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["F", "2"], 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["F", "1"], 
     RowBox[{"(", 
      RowBox[{"S", 
       RowBox[{"(", "z", ")"}]}], ")"}]}], "  ", "=", 
    RowBox[{"log", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"sin", " ", "z"}], "  ", "-", "  ", "1"}], 
       RowBox[{
        RowBox[{"sin", " ", "z"}], "  ", "+", "  ", "1"}]], ")"}]}]}]}]]],
 ".  \n\nSeveral streamlines for the flow are illustrated in Figure 11.97."
}], "Text"],

Cell[TextData[Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{294, 228},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]], "Text"],

Cell["\<\
\t\t\tFigure 11.97  A source and a sink on the edges of a strip. \
\>", "Text",
 CellChangeTimes->{3.50680407203125*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"11.33", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670703828125*^9, 3.506707038296875*^9}}],

Cell["Enter the formula for the complex potential F[z].", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "F", ",", "\[Phi]", ",", "\[Psi]", ",", "W", ",", "x", ",", 
      "y", ",", "z", ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "Z_", "]"}], " ", "=", " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{
        RowBox[{"Sin", "[", "Z", "]"}], "-", "1"}], 
       RowBox[{
        RowBox[{"Sin", "[", "Z", "]"}], "+", "1"}]], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{"F", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"MapAll", "[", 
      RowBox[{"Together", ",", 
       RowBox[{"ComplexExpand", "[", 
        RowBox[{
         RowBox[{"Im", "[", 
          RowBox[{"F", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
         RowBox[{"TargetFunctions", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}]}], "]"}]}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W = F[Z] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The velocity potential is:\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<\[Phi][x,y] = Re[F[x + \[ImaginaryI]y]]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The stream function is:\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<\[Psi][x,y] = Im[F[x + \[ImaginaryI]y]]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cosh", "[", "y", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "x", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", "x", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sinh", "[", "y", "]"}], "2"]}]}], ",", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "x", "]"}], " ", 
        RowBox[{"Sinh", "[", "y", "]"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3995677383125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a density plot of the velocity potential."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"DensityPlot", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       FractionBox[
        RowBox[{"-", "\[Pi]"}], "2"], ",", 
       FractionBox["\[Pi]", "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "100"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["5", "\[Pi]"]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The velocity potential\>\"", "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399567742984375*^9, 3.399567745359375*^9}, 
   3.4001938449375*^9}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a density plot of the stream function."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"\[Psi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         FractionBox[
          RowBox[{"-", "\[Pi]"}], "2"], ",", 
         FractionBox["\[Pi]", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "0.00001", ",", "2.5"}], "}"}], ",", 
       RowBox[{"Contours", "\[Rule]", "11"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"\[Psi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         FractionBox[
          RowBox[{"-", "\[Pi]"}], "2"], ",", 
         FractionBox["\[Pi]", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "2.50001"}], ",", 
         RowBox[{"-", "0.00001"}]}], "}"}], ",", 
       RowBox[{"Contours", "\[Rule]", "11"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "\[Pi]"}], "2"], ",", 
          FractionBox["\[Pi]", "2"]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["5", "\[Pi]"]}]}], "]"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The stream function\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39956776209375*^9, 3.399567788*^9}, 
   3.400193901265625*^9, {3.400406505234375*^9, 3.400406514390625*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the velocity potential."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"\[Phi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         FractionBox[
          RowBox[{"-", "\[Pi]"}], "2"], ",", 
         FractionBox["\[Pi]", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "0.00001", ",", "2.5"}], "}"}], ",", 
       RowBox[{"Contours", "\[Rule]", "11"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"\[Phi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         FractionBox[
          RowBox[{"-", "\[Pi]"}], "2"], ",", 
         FractionBox["\[Pi]", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "2.50001"}], ",", 
         RowBox[{"-", "0.00001"}]}], "}"}], ",", 
       RowBox[{"Contours", "\[Rule]", "11"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "\[Pi]"}], "2"], ",", 
          FractionBox["\[Pi]", "2"]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["5", "\[Pi]"]}]}], "]"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The velocity potential is:\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39956779725*^9, 3.399567802390625*^9}, 
   3.400193905953125*^9, {3.400406520296875*^9, 3.400406530109375*^9}}],

Cell["Find the inverse of the function F[Z].", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"F", "[", "Z", "]"}], " ", "\[Equal]", " ", "W"}], ",", "Z"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", "  ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], ",", 
       RowBox[{"W", "\[Rule]", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W = F[Z] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The inverse function is:\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x,y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39956781628125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph the stream functions using  f[x,y]."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"n", " ", "=", " ", "8"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "k", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", ",", 
            FractionBox[
             RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", ",", 
            FractionBox[
             RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}]}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", 
         RowBox[{"2", "n"}], ",", "2"}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "7"}], ",", "7"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", ",", 
            FractionBox[
             RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", ",", 
            FractionBox[
             RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}]}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", 
         RowBox[{"2", "n"}], ",", "2"}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "7"}], ",", "7"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             FractionBox[
              RowBox[{"-", "\[Pi]"}], "2"], ",", "2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             FractionBox[
              RowBox[{"-", "\[Pi]"}], "2"], ",", 
             RowBox[{"-", "2"}]}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             FractionBox["\[Pi]", "2"], ",", "2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             FractionBox["\[Pi]", "2"], ",", 
             RowBox[{"-", "2"}]}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", "boundary", ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "1.6"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
     RowBox[{"Axes", "\[Rule]", "None"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "\[Pi]"}], "2"], ",", 
          FractionBox["\[Pi]", "2"]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     f[x,y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3995678199375*^9, 3.399567821890625*^9}, {
  3.40019391071875*^9, 3.400193910984375*^9}, {3.400406545875*^9, 
  3.400406555671875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "The stream function for a fluid flow in the infinite strip  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"-", "\[Pi]"}], "2"], "<", 
   RowBox[{"Re", "[", "z", "]"}], "<", 
   FractionBox["\[Pi]", "2"]}]]],
 "  with a two sources at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"-", "\[Pi]"}], "2"], "  ", "and", "  ", 
     SubscriptBox["z", "2"]}], "=", 
    FractionBox["\[Pi]", "2"]}]}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 "\tWe can use the technique of transformation of a source to determine the \
effluence from a channel extending from infinity.  In this case, we construct \
a conformal mapping  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  from the upper half-plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 " so that the single source located at ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 " is mapped to the point ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "0"], "=", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Infinity]"}]}]]],
 " at infinity that lies along the channel.  The streamlines emanating from ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 " in the upper half-plane are mapped onto streamlines issuing from the \
channel."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 11.34.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Consider the conformal mapping   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", "  ", "=", "  ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], " ", "=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["2", "\[Pi]"], 
      SqrtBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], "-", "1"}], ")"}]]}], " ", "+", " ", 
     RowBox[{
      FractionBox["2", "\[Pi]"], "Arcsin", 
      RowBox[{"(", 
       FractionBox["1", "z"], ")"}]}]}]}]}]]],
 ",  \n\nwhich maps the upper half-plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 " onto the domain consisting of the upper half-plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]]],
 " joined to the channel  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "1"}], "\[LessEqual]", "u", "\[LessEqual]", "1"}], ",", 
   RowBox[{"v", "\[LessEqual]", "0"}]}]]],
 ".  The point ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 " is mapped onto the point ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "0"], "=", " ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "=", 
    RowBox[{
     RowBox[{"S", 
      RowBox[{"(", "0", ")"}]}], "=", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Infinity]"}]}]}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", "1"}]]],
 " is mapped onto ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "1"], "=", " ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}]}], "=", 
    RowBox[{
     RowBox[{"S", 
      RowBox[{"(", "1", ")"}]}], "=", "1"}]}]}]]],
 " along the channel.  Images of the rays  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"r", ">", "0"}], ",", " ", 
   RowBox[{"\[Theta]", "=", "\[Alpha]"}]}]]],
 ", where ",
 Cell[BoxData["\[Alpha]"]],
 " is a constant, are streamlines issuing from the channel as indicated in \
Figure 11.98."
}], "Text"],

Cell[TextData[Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{338, 228},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]], "Text"],

Cell["\<\
\t\t\tFigure 11.98  Effluence from a channel into a half-plane. \
\>", "Text",
 CellChangeTimes->{3.506804093171875*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"11.34", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506707041546875*^9, 3.506707041546875*^9}}],

Cell[TextData[{
 "When ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is used we must use a different branch of the square root."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"S", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", "\[ImaginaryI]"}], "\[Pi]"], 
       SqrtBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["z", "2"]}], ")"}]]}], "+", 
      RowBox[{
       FractionBox["2", "\[Pi]"], 
       RowBox[{"ArcSin", "[", 
        FractionBox["1", "z"], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[-1] = \>\"", ",", 
      RowBox[{"S", "[", 
       RowBox[{"-", "1"}], "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< S[0] = \>\"", ",", 
      RowBox[{"S", "[", "0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< S[1] = \>\"", ",", 
      RowBox[{"S", "[", "1", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399567844296875*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph conformal mapping  w = S(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"S", ",", 
     RowBox[{"{", 
      RowBox[{"0.001", ",", "3.001", ",", "0.25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0001", ",", "3.14149", ",", 
       FractionBox["3.14139", "24"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.05"}], ",", "2.05"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.85"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], "]"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image of the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under w = S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399567848703125*^9, 3.39956786653125*^9}, {
  3.400193915828125*^9, 3.400193916046875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqns1", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "23", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.01", ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "23", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.01", ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", 
             RowBox[{"-", "2"}]}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"2", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", 
             RowBox[{"-", "2"}]}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", "boundary", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.05"}], ",", "2.05"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.85"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "1"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"1", ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the flow in the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<where a source is located at \!\(\*SubscriptBox[\(z\), \(0\)]\) = \
0, under the\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<conformal mapping w = S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399567852015625*^9, 3.399567860203125*^9}, 
   3.400193920734375*^9, {3.400406561765625*^9, 3.400406572578125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use a Schwarz-Christoffel transformation to show that the conformal \
mapping  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", "  ", "=", "  ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "  ", "+", " ", 
     RowBox[{"2", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], 
       FractionBox["1", "2"]]}], " ", "+", " ", 
     RowBox[{"Log", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"1", "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          FractionBox["1", "2"]]}], 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          FractionBox["1", "2"]]}]], ")"}]}]}]}]}]]],
 "  \n\nwill map the flow in the upper half-plane from a source at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 "  onto the flow from a channel with  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "0"], "=", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], " ", "=", " ", 
    RowBox[{"-", "\[Infinity]"}]}]}]]],
 "  into the first quadrant, as shown in Figure 11.105. \nHint: Set  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "0"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", 
    RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "d"}], "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["let",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", "d"}], "\[Rule]", "\[Infinity]"}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{524, 228},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]], "Text"],

Cell["\<\
\t\t\t\tFigure 11.105  Flow from a channel into a quadrant. \
\>", "Text",
 CellChangeTimes->{{3.5068041141875*^9, 3.5068041179375*^9}}],

Cell[TextData[{
 "Solution.  Using the Schwarz-Christoffel transformation method, the \
exterior angles are  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", "\[Pi]"}]}]]],
 ",  and the formula for the derivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " is  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "1"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], ")"}]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "0"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", "\[Pi]", ")"}]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      FractionBox["1", "2"]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{"-", "1"}]]}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], 
       FractionBox["1", "2"]], "z"]}]}]}]}]],
 "   \nintegrate \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", " ", 
   RowBox[{"B", " ", "+", " ", 
    RowBox[{"A", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         FractionBox["1", "2"]], "z"], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}]],
  AspectRatioFixed->True],
 "\n\t\t\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", " ", 
   RowBox[{"B", " ", "+", " ", 
    RowBox[{"A", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         FractionBox["1", "2"]]}], "  ", "-", "  ", 
       RowBox[{"Log", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z", "+", "1"}], ")"}], 
            FractionBox["1", "2"]]}], 
          RowBox[{"1", "-", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z", "+", "1"}], ")"}], 
            FractionBox["1", "2"]]}]], ")"}]}]}], ")"}]}]}]}]],
  AspectRatioFixed->True],
 "\n\t\t\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", " ", 
   RowBox[{"B", " ", "+", " ", 
    RowBox[{"A", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         FractionBox["1", "2"]]}], "  ", "+", "  ", 
       RowBox[{"Log", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{"1", "-", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z", "+", "1"}], ")"}], 
            FractionBox["1", "2"]]}], 
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z", "+", "1"}], ")"}], 
            FractionBox["1", "2"]]}]], ")"}]}]}], ")"}]}]}]}]],
  AspectRatioFixed->True],
 "\n\n\t\nuse the conditions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "0", ")"}]}], " ", "=", " ", "0"}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "1", ")"}]}], "=", 
   RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]}]]],
 "  and solve the resulting system for ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["B",
  FontFamily->"Courier New"],
 ".  The desired result is\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "  ", "+", "  ", 
    RowBox[{"2", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      FractionBox["1", "2"]]}], "  ", "+", "  ", 
    RowBox[{"Log", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"1", "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         FractionBox["1", "2"]]}], 
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         FractionBox["1", "2"]]}]], ")"}]}]}]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "1."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670704671875*^9, 3.50670704671875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "  ", "+", "  ", 
      RowBox[{"2", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        FractionBox["1", "2"]]}], "  ", "+", "  ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"1", "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          FractionBox["1", "2"]]}], 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          FractionBox["1", "2"]]}]], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[-1] = \>\"", ",", 
      RowBox[{"S", "[", 
       RowBox[{"-", "1"}], "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< S[0] = \>\"", ",", 
      RowBox[{"S", "[", "0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39956788678125*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph conformal mapping  w = S(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "5"}], ",", "\[Pi]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "\[Pi]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "6"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "5"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"S", ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "7.00001", ",", "0.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "3.14149", ",", 
         FractionBox["3.14139", "24"]}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5"}], ",", "6"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "6"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "boundary", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["6", "11"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "6", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"4", ",", "6", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the flow in the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<where a source is located at \!\(\*SubscriptBox[\(z\), \(0\)]\) = \
0, under the\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<conformal mapping w = S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399567890734375*^9, 3.39956789375*^9}, {
  3.40019392603125*^9, 3.400193926203125*^9}, {3.400406579234375*^9, 
  3.400406584109375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqns1", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "23", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.001", ",", "20"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "23", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.001", ",", "20"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "5"}], ",", "\[Pi]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "\[Pi]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "6"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "5"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", "boundary", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["6", "11"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "6", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"4", ",", "6", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the flow in the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<where a source is located at \!\(\*SubscriptBox[\(z\), \(0\)]\) = \
0, under the\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<conformal mapping w = S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39956790628125*^9, 3.399567908578125*^9}, 
   3.400193930703125*^9, {3.40040659259375*^9, 3.400406601671875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can extend the flow into the fourth quadrant using symmetry."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "5"}], ",", "\[Pi]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "\[Pi]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "6"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "5"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"S", ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "7.00001", ",", "0.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "3.14149", ",", 
         FractionBox["3.14139", "24"]}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5"}], ",", "6"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "6"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], "=", 
     RowBox[{"Conjugate", "[", 
      RowBox[{"S", "[", "z", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"g", ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "7.00001", ",", "0.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "3.14149", ",", 
         FractionBox["3.14139", "24"]}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5"}], ",", "6"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "6"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", "boundary", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["12", "11"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"6", ",", "6", ",", "2"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", 
          RowBox[{"-", "5"}], ",", 
          RowBox[{"-", "4"}], ",", "4", ",", "5", ",", "6"}], "}"}]}], 
       "}"}]}]}], "]"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39956792*^9, 3.39956792746875*^9}, {3.400193935875*^9, 
  3.400193936046875*^9}, {3.4004066091875*^9, 3.40040661675*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqns1", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "23", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.001", ",", "20"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "23", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.001", ",", "20"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "5"}], ",", "\[Pi]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "\[Pi]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "6"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "5"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns3", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"g", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"g", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "23", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph3", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.001", ",", "20"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns4", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"g", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"g", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "23", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph4", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns4", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.001", ",", "20"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "5"}], ",", "\[Pi]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "\[Pi]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "6"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "5"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{
    "graph1", ",", "graph2", ",", "graph3", ",", "graph4", ",", "boundary", 
     ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["12", "11"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", 
          RowBox[{"-", "5"}], ",", 
          RowBox[{"-", "4"}], ",", "4", ",", "5", ",", "6"}], "}"}]}], 
       "}"}]}]}], "]"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image of the flow in the z-plane,\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<where a source is located at \!\(\*SubscriptBox[\(z\), \(0\)]\) = \
0, under the\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<conformal mapping w = S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399567962265625*^9, 3.3995679665*^9}, 
   3.400193940640625*^9, {3.400406622640625*^9, 3.400406638703125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use a Schwarz-Christoffel transformation to show that the conformal \
mapping  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", "  ", "=", "  ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"4", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", "z"}], ")"}], 
       RowBox[{"1", "/", "4"}]]}], " ", "+", " ", 
     RowBox[{"Log", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         RowBox[{"1", "/", "4"}]], "-", "1"}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         RowBox[{"1", "/", "4"}]], "+", "1"}]]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "Log", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         RowBox[{"1", "/", "4"}]]}], 
       RowBox[{"\[ImaginaryI]", "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         RowBox[{"1", "/", "4"}]]}]]}]}]}]}]]],
 " \n\t\t\t\n\nwill map the flow in the upper half-plane from a source at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 "  onto the flow from a channel with  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "0"], "=", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], " ", "=", " ", 
    RowBox[{"-", "\[Infinity]"}]}]}]]],
 "  into a sector, as shown in Figure 11.106.\nHint: Set  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "0"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "\[ImaginaryI]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "d"}], "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["let",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", "d"}], "\[Rule]", "\[Infinity]"}]}]}]]],
 ".  Use the change of variable  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "+", "1"}], "=", 
   SuperscriptBox["s", "4"]}]]],
 "  in the resulting integral."
}], "Text"],

Cell[TextData[Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{487, 228},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]], "Text"],

Cell["\<\
\t\t\tFigure 11.106  Flow from a channel into a sector in the first quadrant. \
\>", "Text",
 CellChangeTimes->{3.506804141109375*^9}],

Cell[TextData[{
 "Solution.  Using the Schwarz-Christoffel transformation method, the \
exterior angles are  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "4"]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", "\[Pi]"}]}]]],
 ",  and the formula for the derivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " is  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "1"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "4"]}], ")"}]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "0"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", "\[Pi]", ")"}]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      FractionBox["1", "4"]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{"-", "1"}]]}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], 
       FractionBox["1", "4"]], "z"]}]}]}]}]],
 "   \nintegrate \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", " ", 
   RowBox[{"B", " ", "+", " ", 
    RowBox[{"A", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         FractionBox["1", "4"]], "z"], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}]],
  AspectRatioFixed->True],
 "\n\t\t\t\nuse the substitutions \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"z", "+", "1"}], "  ", "=", "  ", 
   SuperscriptBox["s", "4"]}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"z", "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["s", "4"], "-", "1"}]}]}], "\[IndentingNewLine]", 
  RowBox[{"   ", 
   RowBox[{
    RowBox[{"\[DifferentialD]", "z"}], "  ", "=", "  ", 
    RowBox[{"4", " ", 
     SuperscriptBox["s", "3"], 
     RowBox[{"\[DifferentialD]", "s"}]}]}]}]}]],
 "  \nand get\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Integral]", 
     RowBox[{
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        FractionBox["1", "4"]], "z"], 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{"\[Integral]", 
     RowBox[{
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         SuperscriptBox["s", "4"], ")"}], 
        RowBox[{"1", "/", "4"}]], 
       RowBox[{
        SuperscriptBox["s", "4"], "-", "1"}]], "4", " ", 
      SuperscriptBox["s", "3"], 
      RowBox[{"\[DifferentialD]", "s"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                            ", 
   RowBox[{"=", "   ", 
    RowBox[{"\[Integral]", 
     RowBox[{
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox["s", "4"]}], 
       RowBox[{
        SuperscriptBox["s", "4"], "-", "1"}]], 
      RowBox[{"\[DifferentialD]", "s"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"4", " ", "s"}], " ", "-", " ", 
     RowBox[{"2", " ", "Arctan", " ", "s"}], " ", "+", " ", 
     RowBox[{"Log", 
      RowBox[{"(", 
       RowBox[{"s", "-", "1"}], ")"}]}], " ", "-", " ", 
     RowBox[{"Log", 
      RowBox[{"(", 
       RowBox[{"s", "+", "1"}], ")"}]}]}]}]}]}],
  AspectRatioFixed->True],
 "  \n\nUse the identity  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", " ", "2"}], "ArcTan", " ", "s"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], 
     FractionBox["\[ImaginaryI]", "2"], "Log", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", "+", "s"}], 
       RowBox[{"\[ImaginaryI]", "-", "s"}]], ")"}]}], " ", "=", " ", 
    RowBox[{"\[ImaginaryI]", " ", "Log", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", "-", "s"}], 
       RowBox[{"\[ImaginaryI]", "+", "s"}]], ")"}]}]}]}]]],
 "  and write the integral as\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Integral]", 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], 
       FractionBox["1", "4"]], "z"], 
     RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"4", " ", "s"}], "  ", "+", "  ", 
    RowBox[{"Log", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"s", "-", "1"}], 
       RowBox[{"s", "+", "1"}]], ")"}]}], "  ", "+", "  ", 
    RowBox[{"\[ImaginaryI]", " ", "Log", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", "-", "s"}], 
       RowBox[{"\[ImaginaryI]", "+", "s"}]], ")"}]}]}]}]],
  AspectRatioFixed->True],
 " \n\nNow use the substitution ",
 Cell[BoxData[
  RowBox[{"s", "\[Rule]", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"z", "+", "1"}], ")"}], 
    FractionBox["1", "4"]]}]]],
 " and get \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"B", " ", "+", " ", 
     RowBox[{"A", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          FractionBox["1", "4"]], "z"], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], 
   "  "}], "\[IndentingNewLine]", 
  RowBox[{"=", "  ", 
   RowBox[{"B", " ", "+", " ", 
    RowBox[{"A", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], 
         RowBox[{"1", "/", "4"}]]}], " ", "+", " ", 
       RowBox[{"Log", 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "+", "1"}], ")"}], 
           RowBox[{"1", "/", "4"}]], "-", "1"}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "+", "1"}], ")"}], 
           RowBox[{"1", "/", "4"}]], "+", "1"}]]}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "Log", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", "-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "+", "1"}], ")"}], 
           RowBox[{"1", "/", "4"}]]}], 
         RowBox[{"\[ImaginaryI]", "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "+", "1"}], ")"}], 
           RowBox[{"1", "/", "4"}]]}]]}]}], ")"}]}]}]}]}],
  AspectRatioFixed->True],
 "\n\t\t\t\nuse the conditions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "0", ")"}]}], " ", "=", " ", "0"}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "1", ")"}]}], "=", 
   RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]}]]],
 "  and solve the resulting system for ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["B",
  FontFamily->"Courier New"],
 ".  The desired result is\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"4", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", "z"}], ")"}], 
      RowBox[{"1", "/", "4"}]]}], "+", 
    RowBox[{"Log", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        RowBox[{"1", "/", "4"}]], "-", "1"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        RowBox[{"1", "/", "4"}]], "+", "1"}]]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "Log", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        RowBox[{"1", "/", "4"}]]}], 
      RowBox[{"\[ImaginaryI]", "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        RowBox[{"1", "/", "4"}]]}]]}]}]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "2."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506707051359375*^9, 3.506707051375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"4", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        RowBox[{"1", "/", "4"}]]}], " ", "+", " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          RowBox[{"1", "/", "4"}]], "-", "1"}], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          RowBox[{"1", "/", "4"}]], "+", "1"}]], "]"}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", "-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "+", "1"}], ")"}], 
           RowBox[{"1", "/", "4"}]]}], 
         RowBox[{"\[ImaginaryI]", "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "+", "1"}], ")"}], 
           RowBox[{"1", "/", "4"}]]}]], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[-1] = \>\"", ",", 
      RowBox[{"S", "[", 
       RowBox[{"-", "1"}], "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< S[0] = \>\"", ",", 
      RowBox[{"S", "[", "0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3995679881875*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph conformal mapping  w = S(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"S", ",", 
       RowBox[{"{", 
        RowBox[{"0.000001", ",", "16.000001", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "3.14149", ",", 
         FractionBox["3.14139", "24"]}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "boundary", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["6", "10"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "6", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"4", ",", "6", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the flow in the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<where a source is located at \!\(\*SubscriptBox[\(z\), \(0\)]\) = \
0, under the\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<conformal mapping w = S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399567991796875*^9, 3.39956799596875*^9}, {
  3.400193860203125*^9, 3.400193860390625*^9}, {3.400406646171875*^9, 
  3.400406650828125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqns1", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "23", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.01", ",", "55"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "23", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.01", ",", "55"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4"}], ",", "\[Pi]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "\[Pi]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Pi]", ",", 
             RowBox[{"2", "\[Pi]"}]}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", "boundary", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["6", "10"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "6", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"4", ",", "6", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the flow in the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<where a source is located at \!\(\*SubscriptBox[\(z\), \(0\)]\) = \
0, under the\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<conformal mapping w = S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39956800115625*^9, 3.399568005*^9}, 
   3.40019386534375*^9, {3.40040665596875*^9, 3.400406663890625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can extend the flow into the fourth quadrant using symmetry."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"6", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"S", ",", 
       RowBox[{"{", 
        RowBox[{"0.000001", ",", "16.000001", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "3.14149", ",", 
         FractionBox["3.14139", "24"]}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], "=", 
     RowBox[{"Conjugate", "[", 
      RowBox[{"S", "[", "z", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"g", ",", 
       RowBox[{"{", 
        RowBox[{"0.000001", ",", "16.000001", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "3.14149", ",", 
         FractionBox["3.14139", "24"]}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", "boundary", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["12", "10"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"6", ",", "6", ",", "2"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", 
          RowBox[{"-", "5"}], ",", 
          RowBox[{"-", "4"}], ",", "4", ",", "5", ",", "6"}], "}"}]}], 
       "}"}]}]}], "]"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399568016625*^9, 3.39956802115625*^9}, {
  3.40019386975*^9, 3.400193870359375*^9}, {3.4004066685*^9, 
  3.400406677546875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqns1", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "23", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.01", ",", "55"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "23", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.01", ",", "55"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns3", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"g", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"g", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "23", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph3", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.01", ",", "55"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns4", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"g", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"g", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "23", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph4", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns4", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.01", ",", "55"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4.3"}], ",", "\[Pi]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "\[Pi]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Pi]", ",", 
             RowBox[{"2", "\[Pi]"}]}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4.3"}], ",", 
             RowBox[{"-", "\[Pi]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"-", "\[Pi]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Pi]", ",", 
             RowBox[{
              RowBox[{"-", "2"}], "\[Pi]"}]}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{
    "graph1", ",", "graph2", ",", "graph3", ",", "graph4", ",", "boundary", 
     ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "6"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", "6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["12", "10"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "6"}], ",", 
          RowBox[{"-", "5"}], ",", 
          RowBox[{"-", "4"}], ",", "4", ",", "5", ",", "6"}], "}"}]}], 
       "}"}]}]}], "]"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image of the flow in the z-plane,\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<where a source is located at \!\(\*SubscriptBox[\(z\), \(0\)]\) = \
0, under the\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<conformal mapping w = S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39956802734375*^9, 3.399568031875*^9}, {
   3.399568079953125*^9, 3.3995680865625*^9}, 3.400193875453125*^9, {
   3.40040668515625*^9, 3.400406701015625*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use a Schwarz-Christoffel transformation to show that the conformal \
mapping  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", "  ", "=", "  ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "\[Pi]"], "Arcsin", " ", "z"}], " ", "+", " ", 
     RowBox[{
      FractionBox["\[ImaginaryI]", "\[Pi]"], "Arcsin", 
      FractionBox["1", "z"]}], " ", "+", " ", 
     FractionBox[
      RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], "2"]}]}]}]]],
 "  \n\nwill map the flow in the upper half-plane from a source at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 "  onto the flow in a right-angled channel with  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "0"], "=", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], " ", "=", " ", 
    RowBox[{"-", "\[Infinity]"}]}]}]]],
 ", as shown in Figure 11.107."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{338, 228},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]], "Text"],

Cell["\<\
\t\t\tFigure 11.107  Flow in a right-angled channel. \
\>", "Text",
 CellChangeTimes->{3.506804160625*^9}],

Cell[TextData[{
 "Solution.  Using the Schwarz-Christoffel transformation method, if we \
choose  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "3"], "=", "1"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", "d"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "3"], "=", 
    RowBox[{"1", "+", "\[ImaginaryI]"}]}]}]]],
 ",  then the formula  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     SubscriptBox["A", "1"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "1"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "3"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SubscriptBox["A", "1"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "0"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SubscriptBox["A", "1"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}]}]}]],
 "\n\nwill determine a mapping ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " of the upper half-plane onto the domain indicated in Figure 11.74(a).  \
With  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    StyleBox["\[Alpha]",
     FontSize->14], "1"], "=", 
   FractionBox["\[Pi]", "2"]}]]],
 ",  we let ",
 Cell[BoxData[
  RowBox[{"d", "\[Rule]", "\[Infinity]"}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    StyleBox["\[Alpha]",
     FontSize->14], "2"], "\[Rule]", "\[Pi]"}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    StyleBox["\[Alpha]",
     FontSize->14], "3"], "\[Rule]", 
   RowBox[{"-", 
    FractionBox["\[Pi]", "2"]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tThe limiting formula for the derivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " becomes   \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     SubscriptBox["A", "1"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SubscriptBox["A", "1"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{
       RowBox[{"-", "\[Pi]"}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], ")"}]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SubscriptBox["A", "1"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{"-", 
       FractionBox["1", "2"]}]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{"-", "1"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      FractionBox["1", "2"]]}]}], "\[IndentingNewLine]"}], "\n", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SubscriptBox["A", "1"], " ", 
     FractionBox["1", "z"], 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       FractionBox["1", "2"]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], 
       FractionBox["1", "2"]]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SubscriptBox["A", "1"], " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", "1"}], ")"}], 
        FractionBox["1", "2"]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", "1"}], ")"}], 
        FractionBox["1", "2"]]}], 
      RowBox[{"z", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        FractionBox["1", "2"]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", "1"}], ")"}], 
        FractionBox["1", "2"]]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SubscriptBox["A", "1"], " ", 
     FractionBox[
      RowBox[{"z", "-", "1"}], 
      RowBox[{"z", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
        FractionBox["1", "2"]]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", " ", 
     FractionBox[
      RowBox[{"z", "-", "1"}], 
      RowBox[{"z", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["z", "2"]}], ")"}], 
        FractionBox["1", "2"]]}]]}]}]}]}]],
 "\n\nwhere  ",
 Cell[BoxData[
  RowBox[{"A", " ", "=", " ", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", 
    SubscriptBox["A", "1"]}]}]]],
 ", which will determine a mapping ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " from the upper half plane onto the channel as indicated in Figure 11.74(b) \
and Figure 11.107."
}], "Text"],

Cell[TextData[{
 "\tUsing integrals in Table 11.2, we obtain \n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         RowBox[{"z", "-", "1"}], 
         RowBox[{"z", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SuperscriptBox["z", "2"]}], ")"}], 
           FractionBox["1", "2"]]}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "+", "  ", "B"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox["z", 
         RowBox[{"z", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SuperscriptBox["z", "2"]}], ")"}], 
           FractionBox["1", "2"]]}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "-", "   ", 
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"z", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SuperscriptBox["z", "2"]}], ")"}], 
           FractionBox["1", "2"]]}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "+", " ", "B"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox["z", "2"]}], ")"}], 
          FractionBox["1", "2"]]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "-", "   ", 
     RowBox[{"A", " ", "\[ImaginaryI]", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"z", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
           FractionBox["1", "2"]]}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "+", " ", "B"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"A", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Arcsin", " ", "z"}], " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "Arcsin", 
         RowBox[{"(", 
          FractionBox["1", "z"], ")"}]}]}], ")"}]}], "  ", "+", "  ", 
     "B"}]}]}]}],
  AspectRatioFixed->True],
 "   "
}], "Text"],

Cell[TextData[{
 "\tIf we use the principal branch of the inverse sine function, then the \
boundary values  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"0", "  ", "and", "  ", "S", 
     RowBox[{"(", "1", ")"}]}], "=", 
    RowBox[{"1", "+", "\[ImaginaryI]"}]}]}]]],
 "  lead to the system  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"A", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "2"]}], ")"}]}], "+", "B"}], 
   "=", "0"}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"A", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "2"], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "2"]}], ")"}]}], "+", "B"}], 
   "=", 
   RowBox[{"1", "+", "\[ImaginaryI]"}]}]]],
 ",  \n\nwhich we can solve to obtain ",
 Cell[BoxData[
  RowBox[{"A", "=", 
   RowBox[{
    RowBox[{
     FractionBox["1", "\[Pi]"], "  ", "and", "  ", "B"}], "=", 
    FractionBox[
     RowBox[{"1", "+", "\[ImaginaryI]"}], "2"]}]}]]],
 ".  Hence the required solution is \n \n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "\[Pi]"], "Arcsin", " ", "z"}], " ", "+", " ", 
     RowBox[{
      FractionBox["\[ImaginaryI]", "\[Pi]"], "Arcsin", 
      FractionBox["1", "z"]}], " ", "+", " ", 
     FractionBox[
      RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], "2"], " "}]}]}]]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Extra", " ", "Solution", " ", "3."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506707055859375*^9, 3.506707055859375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       FractionBox["1", "\[Pi]"], " ", 
       RowBox[{"ArcSin", "[", "z", "]"}]}], " ", "+", " ", 
      RowBox[{
       FractionBox["\[ImaginaryI]", "\[Pi]"], " ", 
       RowBox[{"ArcSin", "[", 
        FractionBox["1", "z"], "]"}]}], " ", "+", " ", 
      FractionBox[
       RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], "2"]}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[0] = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{"S", "[", "z", "]"}], ",", 
        RowBox[{"z", "\[Rule]", "0"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[1] = \>\"", ",", 
      RowBox[{"S", "[", "1", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39956811184375*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph conformal mapping  w = S(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"S", ",", 
     RowBox[{"{", 
      RowBox[{"0.00001", ",", "15.00001", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0001", ",", "3.14149", ",", 
       FractionBox["3.14139", "24"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], "]"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the flow in the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<where a source is located at \!\(\*SubscriptBox[\(z\), \(0\)]\) = \
0, under the\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<conformal mapping w = S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399568121734375*^9, 3.399568128*^9}, {
  3.400193879828125*^9, 3.40019388003125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqns1", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "23", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.01", ",", "55"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "23", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.001", ",", "55"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1", ",", "2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", "boundary", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "1"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"1", ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the flow in the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<where a source is located at \!\(\*SubscriptBox[\(z\), \(0\)]\) = \
0, under the\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<conformal mapping w = S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3995681310625*^9, 3.399568136640625*^9}, 
   3.4001938853125*^9, {3.400406707171875*^9, 3.400406714734375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use a Schwarz-Christoffel transformation to show that the conformal \
mapping  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", "  ", "=", "  ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"2", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], 
       RowBox[{"1", "/", "2"}]]}], "   ", "-", "  ", 
     RowBox[{"Log", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"1", "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          RowBox[{"1", "/", "2"}]]}], 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          RowBox[{"1", "/", "2"}]]}]], ")"}]}]}]}]}]]],
 "  \n\nwill map the flow in the upper half-plane onto the flow from a \
channel back into a quadrant, as shown in Figure 11.108, \nwhere  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], " ", "=", " ", "0"}], ",", 
   RowBox[{
    SubscriptBox["z", "2"], " ", "=", " ", "1"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], " ", "=", " ", "\[Infinity]"}], ",", 
   RowBox[{
    SubscriptBox["w", "1"], " ", "=", " ", 
    RowBox[{
     RowBox[{"S", 
      RowBox[{"(", "1", ")"}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"2", " ", 
       SqrtBox["2"]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "-", 
      RowBox[{"2", "Log", 
       RowBox[{"(", 
        RowBox[{
         SqrtBox["2"], "-", "1"}], ")"}]}]}]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{378, 228},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]], "Text"],

Cell["\<\
\t\t\tFigure 11.108  Flow from a channel  back into the first quadrant. \
\>", "Text",
 CellChangeTimes->{3.50680418465625*^9}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 4.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"2", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        RowBox[{"1", "/", "2"}]]}], "  ", "-", " ", 
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"1", "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          RowBox[{"1", "/", "2"}]]}], 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          RowBox[{"1", "/", "2"}]]}]], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  S[0] = \>\"", ",", 
      RowBox[{"S", "[", "0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  S[1] = \>\"", ",", 
      RowBox[{"S", "[", "1", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[1.0] = \>\"", ",", 
      RowBox[{"S", "[", "1.0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<  S[1] = 2\!\(\*SqrtBox[\(2\)]\) - \[ImaginaryI] \[Pi] - 2 Log[\!\(\
\*SqrtBox[\(2\)]\)-1]\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[1.0] = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{
        RowBox[{"2", " ", 
         SqrtBox["2"]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "-", 
        RowBox[{"2", 
         RowBox[{"Log", "[", 
          RowBox[{
           SqrtBox["2"], "-", "1"}], "]"}]}]}], "]"}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39956815459375*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph conformal mapping  w = S(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"PolarMap", "[", 
    RowBox[{"S", ",", 
     RowBox[{"{", 
      RowBox[{"0.00001", ",", "10.00001", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0001", ",", "3.14149", ",", 
       FractionBox["3.14139", "24"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.001"}], ",", "10"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "8.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["8.5", "10"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "10", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the flow in the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<where a source is located at \!\(\*SubscriptBox[\(z\), \(0\)]\) = \
0, under the\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<conformal mapping w = S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399568160375*^9, 3.399568181125*^9}, {3.400193890125*^9,
   3.4001938903125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqns1", " ", "=", "  ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "23", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.001", ",", "10"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"S", "[", 
           RowBox[{"r", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k", " ", 
              RowBox[{"\[Pi]", "/", "24"}]}]]}], " ", "]"}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "23", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.001", ",", "10"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "10"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"4.6", ",", "\[Pi]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", "\[Pi]"}], "}"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", "boundary", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.001"}], ",", "10"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "8.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["8.5", "10"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "10", ",", "2"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The image of the flow in the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<where a source is located at \!\(\*SubscriptBox[\(z\), \(0\)]\) = \
0, under the\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<conformal mapping w = S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399568163890625*^9, 3.399568164296875*^9}, 
   3.400193895703125*^9, {3.40040672115625*^9, 3.400406730078125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",
 InitializationCell->True]
}, Closed]]
},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{971, 634},
WindowMargins->{{2, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->False,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 112, 2, 29, "Text"],
Cell[1663, 50, 1637, 49, 234, "Text",
 Evaluatable->False],
Cell[3303, 101, 37620, 623, 338, "Text"],
Cell[40926, 726, 119, 2, 29, "Text"],
Cell[41048, 730, 2330, 84, 271, "Text",
 Evaluatable->False],
Cell[43381, 816, 884, 33, 72, "Text"],
Cell[44268, 851, 1872, 70, 139, "Text"],
Cell[46143, 923, 19660, 347, 402, "Text"],
Cell[65806, 1272, 2234, 79, 112, "Text"],
Cell[68043, 1353, 2063, 69, 92, "Text"],
Cell[70109, 1424, 1685, 65, 176, "Text"],
Cell[71797, 1491, 1285, 50, 92, "Text",
 Evaluatable->False],
Cell[73085, 1543, 4718, 80, 242, "Text"],
Cell[77806, 1625, 122, 3, 29, "Text"],
Cell[77931, 1630, 3972, 127, 494, "Text"],
Cell[CellGroupData[{
Cell[81928, 1761, 231, 6, 37, "Subsection"],
Cell[82162, 1769, 65, 0, 29, "Text"],
Cell[82230, 1771, 4022, 118, 452, "Input"],
Cell[86255, 1891, 139, 5, 29, "Text"],
Cell[86397, 1898, 1661, 46, 172, "Input"],
Cell[88061, 1946, 136, 5, 29, "Text"],
Cell[88200, 1953, 2914, 79, 252, "Input"],
Cell[91117, 2034, 139, 5, 29, "Text"],
Cell[91259, 2041, 1716, 47, 172, "Input"],
Cell[92978, 2090, 54, 0, 29, "Text"],
Cell[93035, 2092, 1348, 39, 172, "Input"],
Cell[94386, 2133, 134, 5, 29, "Text"],
Cell[94523, 2140, 3636, 103, 284, "Input"],
Cell[98162, 2245, 119, 3, 29, "Text"],
Cell[98284, 2250, 3420, 97, 268, "Input"],
Cell[101707, 2349, 122, 3, 29, "Text"],
Cell[101832, 2354, 1293, 35, 132, "Input"],
Cell[103128, 2391, 138, 3, 29, "Text"]
}, Closed]],
Cell[103281, 2397, 1013, 36, 83, "Text",
 Evaluatable->False],
Cell[104297, 2435, 6210, 104, 242, "Text"],
Cell[110510, 2541, 116, 3, 29, "Text"],
Cell[110629, 2546, 1794, 59, 325, "Text"],
Cell[112426, 2607, 3620, 121, 362, "Text"],
Cell[CellGroupData[{
Cell[116071, 2732, 223, 6, 37, "Subsection"],
Cell[116297, 2740, 65, 0, 29, "Text"],
Cell[116365, 2742, 3401, 98, 395, "Input"],
Cell[119769, 2842, 139, 5, 29, "Text"],
Cell[119911, 2849, 1701, 47, 192, "Input"],
Cell[121615, 2898, 136, 5, 29, "Text"],
Cell[121754, 2905, 4148, 112, 332, "Input"],
Cell[125905, 3019, 139, 5, 29, "Text"],
Cell[126047, 3026, 1702, 46, 212, "Input"],
Cell[127752, 3074, 54, 0, 29, "Text"],
Cell[127809, 3076, 1350, 39, 172, "Input"],
Cell[129162, 3117, 134, 5, 29, "Text"],
Cell[129299, 3124, 9346, 275, 580, "Input"],
Cell[138648, 3401, 138, 3, 29, "Text"],
Cell[138789, 3406, 5007, 144, 364, "Input"],
Cell[143799, 3552, 141, 3, 29, "Text"],
Cell[143943, 3557, 1380, 37, 152, "Input"],
Cell[145326, 3596, 157, 3, 29, "Text"]
}, Closed]],
Cell[145498, 3602, 818, 28, 116, "Text"],
Cell[146319, 3632, 2685, 106, 191, "Text"],
Cell[149007, 3740, 1126, 40, 65, "Text"],
Cell[150136, 3782, 2393, 80, 239, "Text"],
Cell[152532, 3864, 2416, 42, 242, "Text"],
Cell[154951, 3908, 119, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[155095, 3915, 229, 6, 37, "Subsection"],
Cell[155327, 3923, 65, 0, 29, "Text"],
Cell[155395, 3925, 3346, 97, 392, "Input"],
Cell[158744, 4024, 139, 5, 29, "Text"],
Cell[158886, 4031, 1432, 38, 202, "Input"],
Cell[160321, 4071, 136, 5, 29, "Text"],
Cell[160460, 4078, 2650, 72, 267, "Input"],
Cell[163113, 4152, 139, 5, 29, "Text"],
Cell[163255, 4159, 2658, 72, 267, "Input"],
Cell[165916, 4233, 54, 0, 29, "Text"],
Cell[165973, 4235, 1349, 39, 172, "Input"],
Cell[167325, 4276, 134, 5, 29, "Text"],
Cell[167462, 4283, 6348, 186, 382, "Input"],
Cell[173813, 4471, 289, 9, 35, "Text"]
}, Closed]],
Cell[174117, 4483, 3312, 115, 282, "Text"],
Cell[177432, 4600, 3860, 66, 242, "Text"],
Cell[181295, 4668, 130, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[181450, 4675, 232, 6, 37, "Subsection"],
Cell[181685, 4683, 65, 0, 29, "Text"],
Cell[181753, 4685, 4476, 132, 453, "Input"],
Cell[186232, 4819, 139, 5, 29, "Text"],
Cell[186374, 4826, 1382, 38, 148, "Input"],
Cell[187759, 4866, 136, 5, 29, "Text"],
Cell[187898, 4873, 2598, 71, 214, "Input"],
Cell[190499, 4946, 139, 5, 29, "Text"],
Cell[190641, 4953, 2608, 71, 214, "Input"],
Cell[193252, 5026, 54, 0, 29, "Text"],
Cell[193309, 5028, 1367, 39, 172, "Input"],
Cell[194679, 5069, 134, 5, 29, "Text"],
Cell[194816, 5076, 4150, 122, 293, "Input"],
Cell[198969, 5200, 517, 19, 35, "Text"]
}, Closed]],
Cell[199501, 5222, 931, 29, 62, "Text"],
Cell[200435, 5253, 2118, 78, 149, "Text"],
Cell[202556, 5333, 4636, 78, 242, "Text"],
Cell[207195, 5413, 130, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[207350, 5420, 233, 6, 37, "Subsection"],
Cell[207586, 5428, 149, 5, 29, "Text"],
Cell[207738, 5435, 1345, 42, 198, "Input"],
Cell[209086, 5479, 127, 5, 29, "Text"],
Cell[209216, 5486, 1593, 45, 175, "Input"],
Cell[210812, 5533, 4690, 133, 289, "Input"]
}, Closed]],
Cell[215517, 5669, 3031, 104, 148, "Text"],
Cell[218551, 5775, 5881, 99, 242, "Text"],
Cell[224435, 5876, 146, 3, 29, "Text"],
Cell[224584, 5881, 5731, 204, 565, "Text"],
Cell[CellGroupData[{
Cell[230340, 6089, 223, 5, 37, "Subsection"],
Cell[230566, 6096, 1446, 44, 196, "Input"],
Cell[232015, 6142, 127, 5, 29, "Text"],
Cell[232145, 6149, 3098, 89, 251, "Input"],
Cell[235246, 6240, 4502, 127, 262, "Input"],
Cell[239751, 6369, 192, 6, 65, "Text"],
Cell[239946, 6377, 3592, 102, 274, "Input"],
Cell[243541, 6481, 7566, 215, 403, "Input"]
}, Closed]],
Cell[251122, 6699, 3469, 118, 148, "Text"],
Cell[254594, 6819, 5551, 93, 242, "Text"],
Cell[260148, 6914, 144, 3, 29, "Text"],
Cell[260295, 6919, 9441, 321, 938, "Text"],
Cell[CellGroupData[{
Cell[269761, 7244, 222, 5, 37, "Subsection"],
Cell[269986, 7251, 1847, 56, 176, "Input"],
Cell[271836, 7309, 127, 5, 29, "Text"],
Cell[271966, 7316, 2488, 71, 224, "Input"],
Cell[274457, 7389, 4530, 128, 262, "Input"],
Cell[278990, 7519, 192, 6, 65, "Text"],
Cell[279185, 7527, 2721, 77, 220, "Input"],
Cell[281909, 7606, 7339, 207, 403, "Input"]
}, Closed]],
Cell[289263, 7816, 1108, 35, 107, "Text",
 Evaluatable->False],
Cell[290374, 7853, 4628, 78, 242, "Text"],
Cell[295005, 7933, 116, 3, 29, "Text"],
Cell[295124, 7938, 4368, 162, 184, "Text"],
Cell[299495, 8102, 4227, 148, 472, "Text"],
Cell[303725, 8252, 2679, 85, 301, "Text"],
Cell[306407, 8339, 1688, 59, 163, "Text"],
Cell[CellGroupData[{
Cell[308120, 8402, 225, 5, 37, "Subsection"],
Cell[308348, 8409, 1285, 39, 169, "Input"],
Cell[309636, 8450, 127, 5, 29, "Text"],
Cell[309766, 8457, 1740, 49, 195, "Input"],
Cell[311509, 8508, 4481, 126, 262, "Input"]
}, Closed]],
Cell[316005, 8637, 1703, 57, 137, "Text"],
Cell[317711, 8696, 5450, 92, 242, "Text"],
Cell[323164, 8790, 137, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[323326, 8797, 113, 2, 29, "Text"],
Cell[323442, 8801, 2319, 70, 292, "Input"],
Cell[325764, 8873, 127, 5, 29, "Text"],
Cell[325894, 8880, 1801, 50, 204, "Input"],
Cell[327698, 8932, 4437, 124, 289, "Input"]
}, Closed]],
Cell[332150, 9059, 435, 8, 26, "Text"],
Cell[CellGroupData[{
Cell[332610, 9071, 407, 7, 29, "Text"],
Cell[333020, 9080, 130, 3, 31, "Input",
 InitializationCell->True]
}, Closed]]
}
]
*)

(* End of internal cache information *)
