(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     59940,       2060]
NotebookOptionsPosition[     56783,       1957]
NotebookOutlinePosition[     57338,       1979]
CellTagsIndexPosition[     57295,       1976]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[StyleBox["12.4  The Fourier Transform",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tIn this section we develop the complex ",
 ButtonBox["Fourier",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Fourier.\
html"], None}],
 " transform of the function  ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 ",  we will use ideas that were introduced in Section 12.1. \n\nIf we let ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 " be a real-valued function with period ",
 Cell[BoxData[
  RowBox[{"2", "\[Pi]"}]]],
 ", which is piecewise continuous such that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", "'"}], 
   RowBox[{"(", "t", ")"}]}]]],
 " also exists and is piecewise continuous, \n\nthen ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 " has the complex Fourier series representation \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", 
      RowBox[{"-", "\[Infinity]"}]}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "n", " ", "t"}]]}]}]}]]],
 ", \nwhere \n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "n"], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "\[Pi]"], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Pi]"}], "\[Pi]"], " ", 
     RowBox[{"U", 
      RowBox[{"(", "t", ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "n", " ", "t"}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 ",    for all  ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ". \n\t\t\t\nThe coefficients ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["c", "n"], "}"}]]],
 " are complex numbers.  Previously, we expressed ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 "as the real trigonometric series  \n\n",
 StyleBox["(12.19)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    FractionBox[
     SubscriptBox["a", "0"], "2"], "+", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["a", "n"], "cos", 
        RowBox[{"(", 
         RowBox[{"n", " ", "t"}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["b", "n"], "sin", 
        RowBox[{"(", 
         RowBox[{"n", " ", "t"}], ")"}]}]}], ")"}]}]}]}]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.50685946434375*^9, 3.506859475828125*^9}}],

Cell[TextData[{
 "Hence a relationship between the coefficients is \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["a", "n"], " ", "=", " ", 
    RowBox[{
     SubscriptBox["c", "n"], "+", 
     SubscriptBox["c", 
      RowBox[{"-", "n"}]]}]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "        ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "n"}], "=", "0"}], ",", "1", ",", "2", 
   ",", "...", " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["b", "n"], " ", "=", " ", 
    RowBox[{"\[ImaginaryI]", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "n"], "-", 
       SubscriptBox["c", 
        RowBox[{"-", "n"}]]}], ")"}]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "n"}], "=", "1"}], ",", "2", ",", "3", 
   ",", 
   RowBox[{"...", " ", 
    StyleBox[".",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}]}]}]],
 " "
}], "Text"],

Cell[TextData[{
 "We can easily establish these relations.  We start by writing  \n\n",
 StyleBox["(12.20)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"U", 
     RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
    RowBox[{
     SubscriptBox["c", "0"], " ", "+", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      RowBox[{
       SubscriptBox["c", "n"], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "n", " ", "t"}]]}]}], "+", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      RowBox[{
       SubscriptBox["c", 
        RowBox[{"-", "n"}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "n", " ", "t"}]]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{
    RowBox[{"=", " ", 
     RowBox[{
      SubscriptBox["c", "0"], " ", "+", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "1"}], "\[Infinity]"], 
       RowBox[{
        SubscriptBox["c", "n"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"cos", 
           RowBox[{"(", 
            RowBox[{"n", " ", "t"}], ")"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "sin", 
           RowBox[{"(", 
            RowBox[{"n", " ", "t"}], ")"}]}]}], ")"}]}]}], "+", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "1"}], "\[Infinity]"], 
       RowBox[{
        SubscriptBox["c", 
         RowBox[{"-", "n"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"cos", 
           RowBox[{"(", 
            RowBox[{"n", " ", "t"}], ")"}]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "sin", 
           RowBox[{"(", 
            RowBox[{"n", " ", "t"}], ")"}]}]}], ")"}]}]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", " ", 
    RowBox[{
     SubscriptBox["c", "0"], " ", "+", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      RowBox[{"[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["c", "n"], "+", 
           SubscriptBox["c", 
            RowBox[{"-", "n"}]]}], ")"}], "cos", 
         RowBox[{"(", 
          RowBox[{"n", " ", "t"}], ")"}]}], "+", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["c", "n"], "-", 
           SubscriptBox["c", 
            RowBox[{"-", "n"}]]}], ")"}], "sin", 
         RowBox[{"(", 
          RowBox[{"n", " ", "t"}], ")"}]}]}], "]"}]}]}]}]}]}]],
 " "
}], "Text"],

Cell[TextData[{
 "Comparing Equations (12.20) and (12.19), we see that  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "0"], " ", "=", " ", 
   RowBox[{"2", 
    SubscriptBox["c", "0"]}]}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "n"], " ", "=", " ", 
   RowBox[{
    SubscriptBox["c", "n"], "+", 
    SubscriptBox["c", 
     RowBox[{"-", "n"}]]}]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["b", "n"], " ", "=", " ", 
   RowBox[{"\[ImaginaryI]", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["c", "n"], "-", 
      SubscriptBox["c", 
       RowBox[{"-", "n"}]]}], ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "If ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", "'"}], 
   RowBox[{"(", "t", ")"}]}]]],
 " are piecewise continuous and have period ",
 Cell[BoxData[
  RowBox[{"2", "L"}]]],
 ", then ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 " has the complex Fourier series representation \n\n",
 StyleBox["(12.21)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", 
      RowBox[{"-", "\[Infinity]"}]}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", "n", " ", 
       RowBox[{"t", "/", "L"}]}]]}]}]}]]],
 ", \n\t\twhere \n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "n"], " ", "=", " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "L"}]], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "L"}], "L"], " ", 
     RowBox[{"U", 
      RowBox[{"(", "t", ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Pi]", " ", "n", " ", 
        RowBox[{"t", "/", "L"}]}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 ",    for all  ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ". "
}], "Text"],

Cell[TextData[{
 "\tWe've shown how periodic functions are represented by trigonometric \
series, but many practical problems involve nonperiodic functions.  \n\nA \
representation analogous to a Fourier series for a nonperiodic function ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 " is obtained by considering the Fourier series of ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 " for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "L"}], "<", "t", "<", "L"}]]],
 "  \n\nand then taking the limit as  ",
 Cell[BoxData[
  RowBox[{"L", "\[Rule]", "\[Infinity]"}]]],
 ".  The result is known as the ",
 StyleBox["Fourier transform",
  FontColor->RGBColor[0, 0, 1]],
 " of ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tWe start with the nonperiodic function ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 " and consider the periodic function ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["U", "L"], 
   RowBox[{"(", "t", ")"}]}]]],
 " with period ",
 Cell[BoxData[
  RowBox[{"2", "L"}]]],
 ", where \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["U", "L"], 
     RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
    RowBox[{"U", 
     RowBox[{"(", "t", ")"}]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "            ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "-", "L"}], "<", "t", "<", "L"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["U", "L"], 
     RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
    RowBox[{
     SubscriptBox["U", "L"], 
     RowBox[{"(", 
      RowBox[{"t", "+", 
       RowBox[{"2", "L"}]}], ")"}]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   RowBox[{
    StyleBox["for",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox["all",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", 
    RowBox[{"t", 
     StyleBox[".",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}]}]}]],
 " "
}], "Text"],

Cell[TextData[{
 "Then ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["U", "L"], 
   RowBox[{"(", "t", ")"}]}]]],
 " has the complex Fourier series representation \n\n",
 StyleBox["(12.23)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["U", "L"], 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", 
      RowBox[{"-", "\[Infinity]"}]}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", "n", " ", 
       RowBox[{"t", "/", "L"}]}]]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "\tWe need to introduce some terminology in order to discuss the terms in \
Equation (12.23).  First\n\n",
 StyleBox["(12.24)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Omega]", "n"], " ", "=", " ", 
   FractionBox[
    RowBox[{"\[Pi]", " ", "n"}], "L"]}]]],
 "\n\nis called the ",
 StyleBox["frequency",
  FontColor->RGBColor[0, 0, 1]],
 ".  If ",
 StyleBox["t",
  FontFamily->"Courier New"],
 " denotes time, then the units for ",
 Cell[BoxData[
  SubscriptBox["\[Omega]", "n"]]],
 " are radians per unit time.  The set of all possible frequencies is called \
the ",
 StyleBox["frequency spectrum",
  FontColor->RGBColor[0, 0, 1]],
 ", that is, \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"...", ",", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"3", " ", "\[Pi]"}], "L"]}], ",", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", "\[Pi]"}], "L"]}], ",", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "L"]}], ",", "0", ",", 
    FractionBox["\[Pi]", "L"], ",", 
    FractionBox[
     RowBox[{"2", " ", "\[Pi]"}], "L"], ",", 
    FractionBox[
     RowBox[{"3", " ", "\[Pi]"}], "L"], ",", "..."}], "}"}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "Note that, as ",
 StyleBox["L",
  FontFamily->"Courier New"],
 " increases, the spectrum becomes finer and approaches a continuous spectrum \
of frequencies.  It is reasonable to expect that the summation in the \n\n\
Fourier series for  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["U", "L"], 
   RowBox[{"(", "t", ")"}]}]]],
 "  will give rise to an integral over ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{
    RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "]"}]]],
 ".  This result is stated in Theorem 12.9. "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 12.9 (Fourier Transform) .",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}], 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   RowBox[{"U", "'"}], 
   RowBox[{"(", "t", ")"}]}]]],
 " be piecewise continuous, and  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", 
    RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
   RowBox[{"|", 
    RowBox[{"U", 
     RowBox[{"(", "t", ")"}]}], "|", 
    RowBox[{
     RowBox[{"\[DifferentialD]", "t"}], " ", "<", " ", "M"}]}]}]]],
 ",  \n\nfor some positive constant  M.  ",
 "The angular frequency Fourier transform ",
 " ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "\[Omega]", ")"}]}]]],
 "  of  ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 "  is defined as  \n\n",
 StyleBox["(12.25)\t",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "\[Omega]", ")"}]}], " ", "=", " ", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
    RowBox[{"U", 
     RowBox[{"(", "t", ")"}], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "i"}], " ", "\[Omega]", " ", "t"}]], 
     RowBox[{"\[DifferentialD]", "t"}]}]}]}]]],
 ".  \n\nAt points of continuity,  ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 "  has the integral representation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "\[Pi]"}]], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
     RowBox[{"F", 
      RowBox[{"(", "\[Omega]", ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]], 
      RowBox[{"\[DifferentialD]", "\[Omega]"}]}]}]}]}]]],
 ".  \n\nAt a point  ",
 Cell[BoxData[
  RowBox[{"t", "=", "a"}]]],
 "  of discontinuity of  ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 ",  this integral converges to  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{
    RowBox[{"U", 
     RowBox[{"(", 
      SuperscriptBox["a", "-"], ")"}]}], " ", "+", " ", 
    RowBox[{"U", 
     RowBox[{"(", 
      SuperscriptBox["a", "+"], ")"}]}]}], "2"]]],
 ".  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.5068595081875*^9, 3.5068595236875*^9}, 
   3.50685955484375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "The fact that  ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 "   is transformed into  ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "\[Omega]", ")"}]}]]],
 "  is commonly expressed by the operator notation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[ScriptCapitalF]", 
    RowBox[{"(", 
     RowBox[{"U", 
      RowBox[{"(", "t", ")"}]}], ")"}]}], "=", 
   RowBox[{"F", 
    RowBox[{"(", "\[Omega]", ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.9 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Computer Software Remarks.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Alternative definitions for the Fourier transform can be made in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " by using subroutine call  \n\n                    ",
 Cell[BoxData[
  StyleBox[
   RowBox[{"FourierTransform", "[", " ", 
    RowBox[{
     RowBox[{"f", "[", "t", "]"}], ",", "t", ",", "\[Omega]", ",", " ", 
     RowBox[{"FourierParameters", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b"}], "}"}]}]}], " ", "]"}],
   FontWeight->"Bold"]]],
 ",  \n\nwhere the Fourier transform with parameters ",
 Cell[BoxData[
  RowBox[{
   StyleBox["a",
    FontWeight->"Bold"], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   StyleBox["b",
    FontWeight->"Bold"]}]]],
 " is computed using the formula  ",
 Cell[BoxData[
  RowBox[{
   SqrtBox[
    FractionBox[
     RowBox[{"|", "b", "|"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "\[Pi]"}], ")"}], 
      RowBox[{"1", "-", "a"}]]]], 
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "b", " ", "\[Omega]", " ", "t"}]], 
     RowBox[{"\[DifferentialD]", "t"}]}]}]}]]],
 ". \n\nFormula ",
 StyleBox["(12.25)",
  FontColor->RGBColor[0, 0, 1]],
 " in Theorem 12.9 is computed in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " by setting ",
 Cell[BoxData[
  RowBox[{
   StyleBox["a",
    FontWeight->"Bold"], 
   StyleBox["=",
    FontWeight->"Bold"], 
   RowBox[{
    RowBox[{
     StyleBox["1",
      FontWeight->"Bold"], "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     StyleBox["b",
      FontWeight->"Bold"]}], 
    StyleBox["=",
     FontWeight->"Bold"], 
    StyleBox[
     RowBox[{"-", "1"}],
     FontWeight->"Bold"]}]}]]],
 " and using the option  ",
 Cell[BoxData[
  StyleBox[
   RowBox[{"FourierParameters", " ", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}]}], "}"}]}],
   FontWeight->"Bold"]]],
 ". "
}], "Text",
 CellChangeTimes->{{3.506859760234375*^9, 3.506859761265625*^9}}],

Cell["\<\
\tTable 12.1 gives some important properties of the Fourier transform.\
\>", "Text"],

Cell[BoxData[
 StyleBox[GridBox[{
    {
     StyleBox["Linearity",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     RowBox[{
      RowBox[{
       RowBox[{"\[ScriptCapitalF]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", " ", 
           SubscriptBox["U", "1"], 
           RowBox[{"(", "t", ")"}]}], "+", 
          RowBox[{"b", " ", 
           SubscriptBox["U", "2"], 
           RowBox[{"(", "t", ")"}]}]}], ")"}]}], " ", "=", " ", 
       RowBox[{
        RowBox[{"a", " ", "\[ScriptCapitalF]", 
         RowBox[{"(", " ", 
          RowBox[{
           SubscriptBox["U", "1"], 
           RowBox[{"(", "t", ")"}]}], ")"}]}], "+", 
        RowBox[{"b", " ", "\[ScriptCapitalF]", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["U", "2"], 
           RowBox[{"(", "t", ")"}]}], ")"}]}]}]}], "\[IndentingNewLine]"}]},
    {
     StyleBox["Symmetry",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     RowBox[{
      RowBox[{
       RowBox[{
        StyleBox["If",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "  ", "\[ScriptCapitalF]", 
        RowBox[{"(", 
         RowBox[{"U", 
          RowBox[{"(", "t", ")"}]}], ")"}]}], "=", 
       RowBox[{"F", 
        RowBox[{"(", "\[Omega]", ")"}]}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], " ", 
      RowBox[{
       RowBox[{
        StyleBox["then",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "   ", "\[ScriptCapitalF]", 
        RowBox[{"(", 
         RowBox[{"F", 
          RowBox[{"(", "t", ")"}]}], ")"}]}], "=", 
       RowBox[{"2", "\[Pi]", " ", "U", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"-", "\[Omega]"}], ")"}], 
         StyleBox[".",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "\[IndentingNewLine]"}]}]}]}]},
    {
     StyleBox[
      RowBox[{"Time", " ", "Scaling"}],
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     RowBox[{
      RowBox[{
       RowBox[{"\[ScriptCapitalF]", 
        RowBox[{"(", 
         RowBox[{"U", 
          RowBox[{"(", 
           RowBox[{"a", " ", "t"}], ")"}]}], ")"}]}], " ", "=", " ", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"|", "a", "|"}]], "F", 
        RowBox[{"(", 
         FractionBox["\[Omega]", "a"], ")"}]}]}], "\[IndentingNewLine]"}]},
    {
     StyleBox[
      RowBox[{"Time", " ", "Shifting"}],
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     RowBox[{" ", 
      RowBox[{
       RowBox[{
        RowBox[{"\[ScriptCapitalF]", 
         RowBox[{"(", 
          RowBox[{"U", 
           RowBox[{"(", 
            RowBox[{"t", "-", 
             SubscriptBox["t", "0"]}], ")"}]}], ")"}]}], " ", "=", " ", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           SubscriptBox["t", "0"], "\[Omega]"}]], " ", "F", 
         RowBox[{"(", "\[Omega]", ")"}]}]}], "\[IndentingNewLine]"}]}]},
    {
     StyleBox[
      RowBox[{"Frequency", " ", "Shifting"}],
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     RowBox[{
      RowBox[{
       RowBox[{"\[ScriptCapitalF]", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[Omega]", "0"], "t"}]], "U", 
          RowBox[{"(", "t", ")"}]}], ")"}]}], " ", "=", " ", 
       RowBox[{"F", 
        RowBox[{"(", 
         RowBox[{"\[Omega]", "-", 
          SubscriptBox["\[Omega]", "0"]}], ")"}]}]}], "\[IndentingNewLine]"}]},
    {
     StyleBox[
      RowBox[{"Time", " ", "Differentiation"}],
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     RowBox[{
      RowBox[{
       RowBox[{"\[ScriptCapitalF]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"U", "'"}], 
          RowBox[{"(", "t", ")"}]}], ")"}]}], " ", "=", " ", 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "F", 
        RowBox[{"(", "\[Omega]", ")"}]}]}], "\[IndentingNewLine]"}]},
    {
     StyleBox[
      RowBox[{"Frequency", " ", "Differentiation"}],
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox[
         SuperscriptBox["d", "n"], 
         SuperscriptBox["d\[Omega]", "n"]], "F", 
        RowBox[{"(", "\[Omega]", ")"}]}], " ", "=", "  ", 
       RowBox[{"\[ScriptCapitalF]", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", "t"}], ")"}], "n"], "U", 
          RowBox[{"(", "t", ")"}]}], ")"}]}]}], "\[IndentingNewLine]"}]},
    {
     StyleBox[
      RowBox[{"Moment", " ", "Theorem"}],
      FontFamily->"Times New Roman",
      FontColor->RGBColor[0, 0, 1]], 
     RowBox[{
      RowBox[{
       RowBox[{
        StyleBox["If",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "  ", 
        SubscriptBox["M", "n"]}], " ", "=", " ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", 
         RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], " ", 
        RowBox[{
         SuperscriptBox["t", "n"], "U", 
         RowBox[{"(", "t", ")"}], 
         RowBox[{"\[DifferentialD]", "t"}]}]}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], " ", 
      RowBox[{
       RowBox[{
        StyleBox["then",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "  ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "\[ImaginaryI]"}], ")"}], "n"], 
        SubscriptBox["M", "n"]}], " ", "=", " ", 
       RowBox[{
        SuperscriptBox["F", 
         RowBox[{"(", "n", ")"}]], 
        RowBox[{
         RowBox[{"(", "0", ")"}], 
         StyleBox[".",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]]}]}]}]}]}
   }],
  FontWeight->"Plain"]], "Input"],

Cell["\<\
\t\t\t\tTable 12.1  Properties of the Fourier transform.\
\>", "Text",
 CellChangeTimes->{{3.510078720453125*^9, 3.510078728203125*^9}}],

Cell[TextData[{
 StyleBox["Example 12.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[ScriptCapitalF]", 
    RowBox[{"(", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       RowBox[{"|", "t", "|"}]}]], ")"}]}], " ", "=", " ", 
   FractionBox["2", 
    RowBox[{"1", " ", "+", " ", 
     SuperscriptBox["\[Omega]", "2"]}]]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Solution.", "Text"],

Cell[TextData[{
 "\tUsing formula ",
 StyleBox["(12.25),",
  FontColor->RGBColor[0, 0, 1]],
 " we obtain  \n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"F", 
     RowBox[{"(", "\[Omega]", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        RowBox[{"|", "t", "|"}]}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]], 
      RowBox[{"\[DifferentialD]", "t"}], "                                             ", 
      StyleBox[
       FractionBox["\[Placeholder]", "\[Placeholder]"],
       FontColor->GrayLevel[1]]}]}]}], 
   StyleBox[" ",
    FontColor->GrayLevel[1]], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], "0"], "  ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         RowBox[{"|", "t", "|"}]}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "+", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], "  ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         RowBox[{"|", "t", "|"}]}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}], "   ", 
       StyleBox[
        FractionBox["\[Placeholder]", "\[Placeholder]"],
        FontColor->GrayLevel[1]]}]}]}]}], 
   StyleBox[" ",
    FontColor->GrayLevel[1]], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], "0"], "  ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}], ")"}], " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "+", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], "  ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}], ")"}], " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}], "            ", 
       StyleBox[
        FractionBox["\[Placeholder]", "\[Placeholder]"],
        FontColor->GrayLevel[1]]}]}]}]}], 
   StyleBox[" ",
    FontColor->GrayLevel[1]], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"1", "-", 
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}], ")"}], " ", "t"}]]}], 
     UnderoverscriptBox["\[VerticalSeparator]", 
      RowBox[{"t", "=", 
       RowBox[{"-", "\[Infinity]"}]}], 
      RowBox[{"t", "=", "0"}]], "  ", 
     RowBox[{
      RowBox[{"+", "  ", 
       FractionBox[
        RowBox[{"-", "1"}], 
        RowBox[{"1", "+", 
         RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}]]}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}], ")"}], " ", "t"}]]}], 
     UnderoverscriptBox["\[VerticalSeparator]", 
      RowBox[{"t", "=", "0"}], 
      RowBox[{"t", "=", "\[Infinity]"}]], "  ", 
     StyleBox[
      FractionBox["\[Placeholder]", "\[Placeholder]"],
      FontColor->GrayLevel[1]]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"1", "-", 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}]], " ", "+", " ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"1", "+", 
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}]], "                                                      ", 
      StyleBox[
       FractionBox["\[Placeholder]", "\[Placeholder]"],
       FontColor->GrayLevel[1]]}]}]}], 
   StyleBox[" ",
    FontColor->GrayLevel[1]], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["2", 
      RowBox[{"1", " ", "+", " ", 
       SuperscriptBox["\[Omega]", "2"]}]], "                                                                    ", 
     StyleBox[
      FractionBox["\[Placeholder]", "\[Placeholder]"],
      FontColor->GrayLevel[1]], 
     StyleBox["  ",
      FontColor->GrayLevel[1]]}]}]}]}]],
 "  \n\t\t\nestablishing the result. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"12.5", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.50686023975*^9, 3.50686023975*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Solution.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Using the integral formula ",
 StyleBox["(12.25),",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "\[Omega]", ")"}]}], " ", "=", " ", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
    RowBox[{"U", 
     RowBox[{"(", "t", ")"}], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "i"}], " ", "\[Omega]", " ", "t"}]], 
     RowBox[{"\[DifferentialD]", "t"}]}]}]}]]],
 ",  ",
 "for the angular frequency Fourier transform we obtain",
 "  \n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"F", 
     RowBox[{"(", "\[Omega]", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        RowBox[{"|", "t", "|"}]}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]], 
      RowBox[{"\[DifferentialD]", "t"}], "                                             ", 
      StyleBox[
       FractionBox["\[Placeholder]", "\[Placeholder]"],
       FontColor->GrayLevel[1]]}]}]}], 
   StyleBox[" ",
    FontColor->GrayLevel[1]], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], "0"], "  ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         RowBox[{"|", "t", "|"}]}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "+", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], "  ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         RowBox[{"|", "t", "|"}]}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}], "   ", 
       StyleBox[
        FractionBox["\[Placeholder]", "\[Placeholder]"],
        FontColor->GrayLevel[1]]}]}]}]}], 
   StyleBox[" ",
    FontColor->GrayLevel[1]], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], "0"], "  ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}], ")"}], " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "+", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], "  ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}], ")"}], " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}], "            ", 
       StyleBox[
        FractionBox["\[Placeholder]", "\[Placeholder]"],
        FontColor->GrayLevel[1]]}]}]}]}], 
   StyleBox[" ",
    FontColor->GrayLevel[1]], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"1", "-", 
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}], ")"}], " ", "t"}]]}], 
     UnderoverscriptBox["\[VerticalSeparator]", 
      RowBox[{"t", "=", 
       RowBox[{"-", "\[Infinity]"}]}], 
      RowBox[{"t", "=", "0"}]], "  ", 
     RowBox[{
      RowBox[{"+", "  ", 
       FractionBox[
        RowBox[{"-", "1"}], 
        RowBox[{"1", "+", 
         RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}]]}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}], ")"}], " ", "t"}]]}], 
     UnderoverscriptBox["\[VerticalSeparator]", 
      RowBox[{"t", "=", "0"}], 
      RowBox[{"t", "=", "\[Infinity]"}]], "  ", 
     StyleBox[
      FractionBox["\[Placeholder]", "\[Placeholder]"],
      FontColor->GrayLevel[1]]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"1", "-", 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}]], " ", "+", " ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"1", "+", 
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}]], "                                                      ", 
      StyleBox[
       FractionBox["\[Placeholder]", "\[Placeholder]"],
       FontColor->GrayLevel[1]]}]}]}], 
   StyleBox[" ",
    FontColor->GrayLevel[1]], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["2", 
      RowBox[{"1", " ", "+", " ", 
       SuperscriptBox["\[Omega]", "2"]}]], "                                                                    ", 
     StyleBox[
      FractionBox["\[Placeholder]", "\[Placeholder]"],
      FontColor->GrayLevel[1]], 
     StyleBox["  ",
      FontColor->GrayLevel[1]]}]}]}]}]],
 "  "
}], "Text",
 CellChangeTimes->{3.5068596205*^9}],

Cell[TextData[{
 StyleBox["We are done.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "   "
}], "Text"],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  We can let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " calculate the angular frequency Fourier transform integral. "
}], "Text",
 CellChangeTimes->{
  3.506859641453125*^9, {3.506859770984375*^9, 3.506859772984375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "  ", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       RowBox[{"Abs", "[", "t", "]"}]}]], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], " ", ",", " ", 
   RowBox[{"\[Omega]", ">", "0"}]}], "  ", "]"}]], "Input"],

Cell[BoxData[
 FractionBox["2", 
  RowBox[{"1", "+", 
   SuperscriptBox["\[Omega]", "2"]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["We are really done.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "   "
}], "Text"],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", the command for finding ",
 "the angular frequency Fourier transform is",
 " "
}], "Text",
 CellChangeTimes->{3.50685982346875*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\"\<F(\[Omega])\>\"", "  ", "\[Equal]", "  ", 
  RowBox[{"FourierTransform", "[", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      RowBox[{"Abs", "[", "t", "]"}]}]], ",", " ", "t", ",", " ", "\[Omega]", 
    ",", " ", 
    RowBox[{"FourierParameters", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}], "}"}]}]}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"\<\"F(\[Omega])\"\>", "==", 
  FractionBox["2", 
   RowBox[{"1", "+", 
    SuperscriptBox["\[Omega]", "2"]}]]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Caveat.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  The default setting for the Fourier transform in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " uses the formula  ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    SqrtBox[
     RowBox[{"2", " ", "\[Pi]"}]]], 
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]], 
     RowBox[{"\[DifferentialD]", "t"}]}]}]}]]],
 ".   \n\nIf you multiply the conjugate of ",
 StyleBox["Mathematica'",
  FontSlant->"Italic"],
 "s default answer by  ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"2", "\[Pi]"}]]]],
 "  you will obtain the answer of formula ",
 StyleBox["(12.25).",
  FontColor->RGBColor[0, 0, 1]],
 " "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\"\<F(\[Omega])\>\"", "  ", "\[Equal]", "  ", 
  RowBox[{"FourierTransform", "[", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      RowBox[{"Abs", "[", "t", "]"}]}]], ",", " ", "t", ",", " ", 
    "\[Omega]"}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"\<\"F(\[Omega])\"\>", "==", 
  FractionBox[
   SqrtBox[
    FractionBox["2", "\[Pi]"]], 
   RowBox[{"1", "+", 
    SuperscriptBox["\[Omega]", "2"]}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SqrtBox[
    RowBox[{"2", "\[Pi]"}]], 
   FractionBox[
    SqrtBox[
     FractionBox["2", "\[Pi]"]], 
    RowBox[{"1", "+", 
     SuperscriptBox["\[Omega]", "2"]}]]}], "  ", "\[Equal]", "  ", 
  FractionBox["2", 
   RowBox[{"1", "+", 
    SuperscriptBox["\[Omega]", "2"]}]]}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 12.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[ScriptCapitalF]", 
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{"1", " ", "+", " ", 
       SuperscriptBox["t", "2"]}]], ")"}]}], " ", "=", " ", 
   RowBox[{"\[Pi]", "  ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      RowBox[{"|", "\[Omega]", "|"}]}]]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Solution.", "Text"],

Cell[TextData[{
 "\tUsing the result of Example 12.5 and the symmetry property, we obtain \n\n\
\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[ScriptCapitalF]", 
    RowBox[{"(", 
     FractionBox["2", 
      RowBox[{"1", " ", "+", " ", 
       SuperscriptBox["t", "2"]}]], ")"}]}], " ", "=", " ", 
   RowBox[{"2", "\[Pi]", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      RowBox[{"|", 
       RowBox[{"-", "\[Omega]"}], "|"}]}]]}]}]]],
 "\n\nWe use the linearity property and multiply each term by  ",
 Cell[BoxData[
  FractionBox["1", "2"]]],
 "  and get  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[ScriptCapitalF]", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["1", "2"], 
      FractionBox["2", 
       RowBox[{"1", " ", "+", " ", 
        SuperscriptBox["t", "2"]}]]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", "2"], ")"}], "2", "\[Pi]", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      RowBox[{"|", 
       RowBox[{"-", "\[Omega]"}], "|"}]}]]}]}]]],
 ".\n\nThen rewrite this in the form \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[ScriptCapitalF]", 
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{"1", " ", "+", " ", 
       SuperscriptBox["t", "2"]}]], ")"}]}], " ", "=", " ", 
   RowBox[{"\[Pi]", "  ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      RowBox[{"|", "\[Omega]", "|"}]}]]}]}]]],
 " \n\nestablishing the result. "
}], "Text",
 CellChangeTimes->{3.510078609890625*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"12.6", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506860246671875*^9, 3.506860246671875*^9}}],

Cell[TextData[{
 StyleBox["Solution.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Using the result of Example 12.5 and the Symmetry Property ",
 "for Fourier transforms, we",
 " obtain \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[ScriptCapitalF]", 
    RowBox[{"(", 
     FractionBox["2", 
      RowBox[{"1", " ", "+", " ", 
       SuperscriptBox["t", "2"]}]], ")"}]}], " ", "=", " ", 
   RowBox[{"2", "\[Pi]", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      RowBox[{"|", 
       RowBox[{"-", "\[Omega]"}], "|"}]}]]}]}]]],
 "\n\nThen use the Linearity Property for ",
 ButtonBox["Fourier transforms",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/FourierTransformMod.html"], 
    None}],
 " and multiply each term by  ",
 Cell[BoxData[
  FractionBox["1", "2"]]],
 "  and get \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[ScriptCapitalF]", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["1", "2"], 
      FractionBox["2", 
       RowBox[{"1", " ", "+", " ", 
        SuperscriptBox["t", "2"]}]]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", "2"], ")"}], "2", "\[Pi]", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      RowBox[{"|", 
       RowBox[{"-", "\[Omega]"}], "|"}]}]]}]}]]],
 ".\n\nTherefore,\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[ScriptCapitalF]", 
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{"1", " ", "+", " ", 
       SuperscriptBox["t", "2"]}]], ")"}]}], " ", "=", " ", 
   RowBox[{"\[Pi]", "  ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      RowBox[{"|", "\[Omega]", "|"}]}]]}]}]]],
 ".  "
}], "Text",
 CellChangeTimes->{3.506859881390625*^9}],

Cell[TextData[{
 StyleBox["We are done.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "   "
}], "Text"],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  We can let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " calculate ",
 "the angular frequency Fourier transform integral",
 ". "
}], "Text",
 CellChangeTimes->{{3.50685971375*^9, 3.506859715828125*^9}, 
   3.506859903234375*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "  ", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"1", "+", 
       SuperscriptBox["t", "2"]}]], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], " ", ",", " ", 
   RowBox[{
    RowBox[{"Im", "[", "\[Omega]", "]"}], "\[Equal]", "0"}]}], "  ", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "\[Omega]"}], " ", 
    RowBox[{"Sign", "[", "\[Omega]", "]"}]}]], " ", "\[Pi]"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["We are really done.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "   "
}], "Text"],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", the command for finding ",
 "the angular frequency Fourier transform is",
 " "
}], "Text",
 CellChangeTimes->{3.5068599311875*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\"\<F(\[Omega])\>\"", "  ", "\[Equal]", "  ", 
  RowBox[{"FourierTransform", "[", " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"1", "+", 
      SuperscriptBox["t", "2"]}]], ",", " ", "t", ",", " ", "\[Omega]", ",", 
    " ", 
    RowBox[{"FourierParameters", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}], "}"}]}]}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"\<\"F(\[Omega])\"\>", "==", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     RowBox[{"Abs", "[", "\[Omega]", "]"}]}]], " ", "\[Pi]"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Caveat.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  The default setting for the Fourier transform in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " uses the formula  ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    SqrtBox[
     RowBox[{"2", " ", "\[Pi]"}]]], 
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]], 
     RowBox[{"\[DifferentialD]", "t"}]}]}]}]]],
 ".   \n\nIf you multiply the conjugate of ",
 StyleBox["Mathematica'",
  FontSlant->"Italic"],
 "s default answer by  ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"2", "\[Pi]"}]]]],
 "  you will obtain the answer of formula ",
 StyleBox["(12.25).",
  FontColor->RGBColor[0, 0, 1]],
 " "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\"\<F(\[Omega])\>\"", "  ", "\[Equal]", "  ", 
  RowBox[{"FourierTransform", "[", " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"1", "+", 
      SuperscriptBox["t", "2"]}]], ",", " ", "t", ",", " ", "\[Omega]"}], " ",
    "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"\<\"F(\[Omega])\"\>", "==", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     RowBox[{"Abs", "[", "\[Omega]", "]"}]}]], " ", 
   SqrtBox[
    FractionBox["\[Pi]", "2"]]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SqrtBox[
    RowBox[{"2", "\[Pi]"}]], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     RowBox[{"Abs", "[", "\[Omega]", "]"}]}]], " ", 
   SqrtBox[
    FractionBox["\[Pi]", "2"]]}], "  ", "\[Equal]", "   ", 
  RowBox[{"\[Pi]", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     RowBox[{"Abs", "[", "\[Omega]", "]"}]}]]}]}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]]
}, Closed]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{922, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 1000, 24, 341, "Text"],
Cell[1560, 46, 115, 2, 29, "Text"],
Cell[1678, 50, 2688, 92, 257, "Text"],
Cell[4369, 144, 2376, 83, 104, "Text"],
Cell[6748, 229, 2792, 88, 142, "Text"],
Cell[9543, 319, 638, 26, 29, "Text"],
Cell[10184, 347, 1457, 55, 108, "Text"],
Cell[11644, 404, 796, 26, 101, "Text"],
Cell[12443, 432, 2995, 109, 104, "Text"],
Cell[15441, 543, 676, 25, 65, "Text"],
Cell[16120, 570, 1215, 42, 151, "Text"],
Cell[17338, 614, 552, 17, 65, "Text"],
Cell[17893, 633, 2740, 97, 268, "Text",
 Evaluatable->False],
Cell[20636, 732, 484, 19, 65, "Text"],
Cell[CellGroupData[{
Cell[21145, 755, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[21289, 761, 171, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[21475, 768, 2617, 92, 160, "Text"],
Cell[24095, 862, 94, 2, 29, "Text"],
Cell[24192, 866, 8392, 264, 324, "Input"],
Cell[32587, 1132, 146, 3, 29, "Text"],
Cell[32736, 1137, 476, 18, 37, "Text",
 Evaluatable->False],
Cell[33215, 1157, 25, 0, 29, "Text"],
Cell[33243, 1159, 5193, 145, 347, "Text"],
Cell[CellGroupData[{
Cell[38461, 1308, 270, 8, 37, "Subsection",
 Evaluatable->False],
Cell[38734, 1318, 5766, 165, 314, "Text"],
Cell[44503, 1485, 115, 5, 29, "Text"],
Cell[44621, 1492, 325, 10, 29, "Text"],
Cell[CellGroupData[{
Cell[44971, 1506, 526, 14, 44, "Input"],
Cell[45500, 1522, 103, 3, 47, "Output"]
}, Open  ]],
Cell[45618, 1528, 122, 5, 29, "Text"],
Cell[45743, 1535, 285, 11, 29, "Text"],
Cell[CellGroupData[{
Cell[46053, 1550, 428, 11, 33, "Input"],
Cell[46484, 1563, 147, 4, 47, "Output"]
}, Open  ]],
Cell[46646, 1570, 919, 32, 81, "Text"],
Cell[CellGroupData[{
Cell[47590, 1606, 290, 7, 33, "Input"],
Cell[47883, 1615, 187, 6, 71, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48107, 1626, 324, 12, 71, "Input"],
Cell[48434, 1640, 31, 0, 30, "Output"]
}, Open  ]]
}, Closed]],
Cell[48492, 1644, 508, 19, 39, "Text",
 Evaluatable->False],
Cell[49003, 1665, 25, 0, 29, "Text"],
Cell[49031, 1667, 1511, 49, 290, "Text"],
Cell[CellGroupData[{
Cell[50567, 1720, 232, 6, 37, "Subsection"],
Cell[50802, 1728, 1749, 59, 254, "Text"],
Cell[52554, 1789, 115, 5, 29, "Text"],
Cell[52672, 1796, 332, 12, 29, "Text"],
Cell[CellGroupData[{
Cell[53029, 1812, 549, 16, 47, "Input"],
Cell[53581, 1830, 183, 5, 30, "Output"]
}, Open  ]],
Cell[53779, 1838, 122, 5, 29, "Text"],
Cell[53904, 1845, 284, 11, 29, "Text"],
Cell[CellGroupData[{
Cell[54213, 1860, 410, 11, 47, "Input"],
Cell[54626, 1873, 195, 5, 30, "Output"]
}, Open  ]],
Cell[54836, 1881, 919, 32, 81, "Text"],
Cell[CellGroupData[{
Cell[55780, 1917, 271, 7, 47, "Input"],
Cell[56054, 1926, 231, 7, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56322, 1938, 399, 13, 54, "Input"],
Cell[56724, 1953, 31, 0, 30, "Output"]
}, Open  ]]
}, Closed]]
}
]
*)

(* End of internal cache information *)
