(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    132089,       4083]
NotebookOptionsPosition[    126555,       3909]
NotebookOutlinePosition[    127111,       3931]
CellTagsIndexPosition[    127068,       3928]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[StyleBox["12.5  The Laplace Transform",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tIn this section we investigate the Laplace transform, which is a very \
powerful tool for engineering applications.  It's discovery is attributed to \
the French mathematician ",
 StyleBox[ButtonBox["Pierre-Simon Laplace",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Biographies/Laplace.\
html"], None}],
  FontFamily->"Times New Roman",
  FontVariations->{"Underline"->True}],
 " (1749-1827).  The background we introduced in Section 12.4 regarding the ",
 StyleBox[ButtonBox["Fourier transform",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/FourierTransform.html"], None}],
  FontFamily->"Times New Roman",
  FontVariations->{"Underline"->True}],
 " in important for our approach to the theory of the Laplace transform. "
}], "Text",
 CellChangeTimes->{{3.50680496190625*^9, 3.5068049774375*^9}}],

Cell[TextData[StyleBox["12.5.1.  From the Fourier Transform to the Laplace \
Transform",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "We have shown that certain real-valued functions ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}]}]]],
 " have a Fourier transform and that the integral  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "\[Omega]", ")"}]}], " ", "=", " ", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]], 
     RowBox[{"\[DifferentialD]", "t"}]}]}]}]]],
 ".  \n\ndefines the complex function ",
 Cell[BoxData[
  RowBox[{"g", 
   RowBox[{"(", "\[Omega]", ")"}]}]]],
 " of the real variable ",
 Cell[BoxData["\[Omega]"]],
 ".  If we multiply the integrand  ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]]}]]],
 "  by  ",
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "\[Sigma]"}], " ", "t"}]]]],
 ",  then we create a complex function  ",
 Cell[BoxData[
  RowBox[{"G", 
   RowBox[{"(", 
    RowBox[{"\[Sigma]", "+", 
     RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}], " ", ")"}]}]]],
 "  of the complex variable ",
 Cell[BoxData[
  RowBox[{"\[Sigma]", "+", 
   RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " "}]}]]],
 ":  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", 
     RowBox[{"\[Sigma]", "+", 
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[Sigma]"}], " ", "t"}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "t"}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], " ", "=", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]", " ", "+", 
           RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}], ")"}]}], " ", "t"}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 ".  "
}], "Text",
 CellChangeTimes->{3.5100787365*^9}],

Cell[TextData[{
 "The function  ",
 Cell[BoxData[
  RowBox[{"G", 
   RowBox[{"(", 
    RowBox[{"\[Sigma]", "+", 
     RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}], " ", ")"}]}]]],
 "  is called the ",
 StyleBox["two-sided Laplace transform",
  FontColor->RGBColor[0, 0, 1]],
 " of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}]}]]],
 ", (or ",
 StyleBox[ButtonBox["bilateral Laplace transform",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/BilateralLaplaceTransform.html"], None}],
  FontFamily->"Times New Roman",
  FontVariations->{"Underline"->True}],
 " of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}]}]]],
 "), and it exists when the Fourier transform of the function  ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[Sigma]"}], " ", "t"}]]}]]],
 "  exists.  From Fourier transform theory, a sufficient condition for  ",
 Cell[BoxData[
  RowBox[{"G", 
   RowBox[{"(", 
    RowBox[{"\[Sigma]", "+", 
     RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}], " ", ")"}]}]]],
 "  to exist is that \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
    RowBox[{"|", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}]}], "|", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[Sigma]"}], " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}], " ", "<", " ", 
      "\[Infinity]"}]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "\tFor a function ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}]}]]],
 ", this integral is finite for values of ",
 Cell[BoxData["\[Sigma]"]],
 " that lie in some interval  ",
 Cell[BoxData[
  RowBox[{"a", "<", "\[Sigma]", "<", "b"}]]],
 "."
}], "Text"],

Cell[TextData[{
 "\tThe two-sided Laplace transform has the lower limit of integration ",
 Cell[BoxData[
  RowBox[{"t", "=", 
   RowBox[{"-", "\[Infinity]"}]}]]],
 " and hence requires a knowledge of the past history of the function ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}]}]]],
 " (i.e., when  ",
 Cell[BoxData[
  RowBox[{"t", "<", "0"}]]],
 ").  For most physical applications, we are interested in the behavior of a \
system only for ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "t"}]]],
 ".  The initial conditions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "0", ")"}]}], ",", 
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "0", ")"}]}], ",", 
   RowBox[{
    RowBox[{"f", "''"}], 
    RowBox[{"(", "0", ")"}]}], ",", "..."}]]],
 "  are a consequence of the past history of the system and are often all \
that we know.  For this reason, it is useful to define the ",
 StyleBox["one-sided Laplace transform",
  FontColor->RGBColor[0, 0, 1]],
 " of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}]}]]],
 ", which is commonly referred to simply as the ",
 StyleBox[ButtonBox["Laplace transform",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/LaplaceTransform.html"], None}],
  FontFamily->"Times New Roman",
  FontVariations->{"Underline"->True}],
 " of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}]}]]],
 ", which is also defined as an integral: \n\n",
 StyleBox["(12-28)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[ScriptCapitalL]",
     FontSize->16], 
    RowBox[{"(", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"F", 
     RowBox[{"(", "s", ")"}]}], " ", "=", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], "  ", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "s"}], " ", "t"}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 ", \n\t\t\nwhere  ",
 Cell[BoxData[
  RowBox[{"s", "=", 
   RowBox[{"\[Sigma]", "+", 
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}]}]]],
 ".  If the integral in Equation ",
 StyleBox["(12-28)",
  FontColor->RGBColor[0, 0, 1]],
 " for the Laplace transform exists for  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["s", "0"], "=", 
   RowBox[{
    SubscriptBox["\[Sigma]", "0"], "+", 
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}]}]]],
 ",  then values of ",
 Cell[BoxData["\[Sigma]"]],
 " with ",
 Cell[BoxData[
  RowBox[{"\[Sigma]", ">", 
   SubscriptBox["\[Sigma]", "0"]}]]],
 " imply that ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[Sigma]"}], " ", "t"}]], "<", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["\[Sigma]", "0"]}], " ", "t"}]]}]]],
 " and so that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
    RowBox[{"|", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}]}], "|", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[Sigma]"}], " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}], " ", "<", " ", 
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], "\[Infinity]"]}], "  ", "|", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}]}], "|", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["\[Sigma]", "0"]}], " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}], " ", "<", " ", 
      "\[Infinity]"}]}]}]}]]],
 ",  \n\nfrom which it follows that ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "s", ")"}]}]]],
 " exists for ",
 Cell[BoxData[
  RowBox[{"s", "=", 
   RowBox[{"\[Sigma]", "+", 
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}]}]]],
 ".  Therefore the Laplace transform ",
 Cell[BoxData[
  RowBox[{
   StyleBox["\[ScriptCapitalL]",
    FontSize->16], 
   RowBox[{"(", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}]}], ")"}]}]]],
 " is defined for all points ",
 StyleBox["s",
  FontFamily->"Courier New"],
 " in the right half-plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", 
    RowBox[{"(", "s", ")"}]}], ">", 
   SubscriptBox["\[Sigma]", "0"]}]]],
 ". "
}], "Text",
 CellChangeTimes->{{3.399623985234375*^9, 3.399623992609375*^9}}],

Cell[TextData[{
 "\tAnother way to view the relationship between the Fourier transform and \
the Laplace transform is to consider the function ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 " given by \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{"{", GridBox[{
      {
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", "t", ")"}]}], 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}], 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           StyleBox["for",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontVariations->{"StrikeThrough"->False,
            "Underline"->False},
            FontColor->GrayLevel[0]], "   ", "0"}], "\[LessEqual]", "t"}], 
         StyleBox[";",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]]}], " "}]},
      {
       RowBox[{"       ", 
        RowBox[{"0", 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]]}]}], 
       RowBox[{
        RowBox[{
         StyleBox["for",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "   ", "t"}], "<", " ", 
        StyleBox[
         RowBox[{"0", 
          StyleBox[".",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]]}]]}]}
     }], 
    StyleBox["}",
     FontColor->GrayLevel[1]]}]}]]],
 " "
}], "Text"],

Cell[TextData[{
 "Then the Fourier transform theory, in Section 12.4, shows that \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "\[Pi]"}]], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
     RowBox[{
      RowBox[{"[", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", 
         RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
        RowBox[{"U", 
         RowBox[{"(", "t", ")"}], 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "i"}], " ", "\[Omega]", " ", "t"}]], 
         RowBox[{"\[DifferentialD]", "t"}]}]}], "]"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]], 
      RowBox[{"\[DifferentialD]", "\[Omega]"}]}]}]}]}]]],
 ",  \n\nand, because the integrand ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 " is zero for ",
 Cell[BoxData[
  RowBox[{"t", "<", "0"}]]],
 ", we can write this equation as \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "\[Pi]"}]], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
     RowBox[{
      RowBox[{"[", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], "  ", 
        RowBox[{"f", 
         RowBox[{"(", "t", ")"}], 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "i"}], " ", "\[Omega]", " ", "t"}]], 
         RowBox[{"\[DifferentialD]", "t"}]}]}], "]"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]], 
      RowBox[{"\[DifferentialD]", "\[Omega]"}]}]}]}]}]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.50680500484375*^9, 3.5068050184375*^9}}],

Cell[TextData[{
 "Now use the change of variable ",
 Cell[BoxData[
  RowBox[{"s", "=", 
   RowBox[{"\[Sigma]", "+", 
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}]}]]],
 "  and hold  ",
 Cell[BoxData[
  RowBox[{"\[Sigma]", " ", ">", 
   SubscriptBox["\[Sigma]", "0"]}]]],
 "  fixed.  We have  ",
 Cell[BoxData[
  RowBox[{"ds", "=", 
   RowBox[{"0", "+", 
    RowBox[{"\[ImaginaryI]", " ", "d\[Omega]"}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"d\[Omega]", "=", 
   FractionBox["ds", "\[ImaginaryI]"]}]]],
 ".  Then the new limits of integration are from  ",
 Cell[BoxData[
  RowBox[{"s", "=", 
   RowBox[{"\[Sigma]", "-", 
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}]}]]],
 "  to  ",
 Cell[BoxData[
  RowBox[{"s", "=", 
   RowBox[{"\[Sigma]", "+", 
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}]}]]],
 ". The resulting equation is \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "\[Pi]"}]], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"\[Sigma]", "-", 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}], 
      RowBox[{"\[Sigma]", "+", 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}]], "  ", 
     RowBox[{
      RowBox[{"[", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], "  ", 
        RowBox[{"f", 
         RowBox[{"(", "t", ")"}], 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "s"}], " ", "t"}]], 
         RowBox[{"\[DifferentialD]", "t"}]}]}], "]"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"s", " ", "t"}]], 
      RowBox[{"\[DifferentialD]", "s"}]}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Definition (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Laplace Transform",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/LaplaceTransform.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Therefore the ",
 StyleBox["Laplace transform",
  FontColor->RGBColor[0, 0, 1]],
 " is as the integral:  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[ScriptCapitalL]",
     FontSize->16], 
    RowBox[{"(", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"F", 
     RowBox[{"(", "s", ")"}]}], " ", "=", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], "  ", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "s"}], " ", "t"}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 ",   \n\nwhere  ",
 Cell[BoxData[
  RowBox[{"s", "=", 
   RowBox[{"\[Sigma]", "+", 
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}]}]]],
 ",  and the ",
 StyleBox["inverse Laplace transform",
  FontColor->RGBColor[0, 0, 1]],
 " is given by: \n\n",
 StyleBox["(12.29)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox[
     SuperscriptBox["\[ScriptCapitalL]", 
      RowBox[{"-", "1"}]],
     FontSize->16], 
    RowBox[{"(", 
     RowBox[{"F", 
      RowBox[{"(", "s", ")"}]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "\[Pi]"}]], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"\[Sigma]", "-", 
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}], 
       RowBox[{"\[Sigma]", "+", 
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}]], "  ", 
      RowBox[{"F", 
       RowBox[{"(", "s", ")"}], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"s", " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "s"}]}]}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[StyleBox["12.5.2  Properties of the Laplace Transform",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tAlthough a function ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}]}]]],
 " may be defined for all values of ",
 StyleBox["t",
  FontFamily->"Courier New"],
 ", it's Laplace transform is not influenced by values of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}]}]]],
 ", when ",
 Cell[BoxData[
  RowBox[{"t", "<", "0"}]]],
 ".  The Laplace transform of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}]}]]],
 " is actually defined for the function ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 " given in the last section by\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{"{", GridBox[{
      {
       RowBox[{
        RowBox[{
         RowBox[{"f", 
          RowBox[{"(", "t", ")"}], "  ", "for", "  ", "t"}], 
         "\[GreaterEqual]", "0"}], ","}]},
      {
       RowBox[{
        RowBox[{"0", "          ", "for", "  ", "t"}], "<", "0."}]}
     }], 
    StyleBox["}",
     FontColor->GrayLevel[1]]}]}]]],
 " \n\nA sufficient condition for the existence of the Laplace transform is \
that  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}]}], "|"}]]],
 "  does not grow too rapidly as  ",
 Cell[BoxData[
  RowBox[{"t", " ", "\[Rule]", " ", 
   RowBox[{"+", "\[Infinity]"}]}]]],
 ".  We say that the function   ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}]}]]],
 "  is of ",
 StyleBox["exponential order",
  FontColor->RGBColor[0, 0, 1]],
 " if there exists real constants  ",
 Cell[BoxData[
  RowBox[{"M", ">", 
   RowBox[{"0", "  ", "and", "  ", "K"}]}]]],
 "  such that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}]}], "|", 
   RowBox[{"\[LessEqual]", 
    RowBox[{"M", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"K", " ", "t"}]]}]}]}]]],
 "  holds for all  ",
 Cell[BoxData[
  RowBox[{"t", "\[GreaterEqual]", "0"}]]],
 ".  \n\nAll functions in this chapter are assumed to be of exponential \
order.  Theorem 12.10 shows that the Laplace transform  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "s", ")"}]}], "=", 
   RowBox[{"F", 
    RowBox[{"(", 
     RowBox[{"\[Sigma]", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "\[Tau]"}]}], ")"}]}]}]]],
 "  exists for values of  ",
 Cell[BoxData[
  RowBox[{"s", "=", 
   RowBox[{"\[Sigma]", " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "\[Tau]"}]}]}]]],
 "  in a domain that includes the right half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", 
    RowBox[{"(", "s", ")"}]}], ">", "K"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 12.10  (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Laplace Transform",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/LaplaceTransform.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If  ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}]}]]],
 "  is of exponential order, then its ",
 StyleBox["Laplace Transform",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[ScriptCapitalL]",
     FontSize->16], 
    RowBox[{"(", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}]}], ")"}]}], "=", 
   RowBox[{"F", 
    RowBox[{"(", "s", ")"}]}]}]]],
 " exists and is given by \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "s", ")"}]}], " ", "=", " ", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "s"}], " ", "t"}]], 
     RowBox[{"\[DifferentialD]", "t"}]}]}]}]]],
 ",   \n\nwhere  ",
 Cell[BoxData[
  RowBox[{"s", " ", "=", " ", 
   RowBox[{"\[Sigma]", "+", 
    RowBox[{"\[ImaginaryI]", " ", "\[Tau]"}]}]}]]],
 ".  The defining integral for  ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "s", ")"}]}]]],
 "  exists at points  ",
 Cell[BoxData[
  RowBox[{"s", "=", 
   RowBox[{"\[Sigma]", "+", 
    RowBox[{"\[ImaginaryI]", " ", "\[Tau]"}]}]}]]],
 "  in the right half plane  ",
 Cell[BoxData[
  RowBox[{"\[Sigma]", ">", "K"}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.10 is left for the reader in the \
book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Remark 12.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The domain of definition of the defining integral for the Laplace \
transform ",
 Cell[BoxData[
  RowBox[{
   StyleBox["\[ScriptCapitalL]",
    FontSize->16], 
   RowBox[{"(", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}]}], ")"}]}]]],
 " seems to be restricted to a half plane.  However, the resulting formula ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "s", ")"}]}]]],
 " might have a domain much larger than this half plane.  Later we will show \
that ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "s", ")"}]}]]],
 " is an analytic function of the complex variable s.  For most applications \
involving Laplace transforms that we present, the Laplace transforms are \
rational functions that take the form  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"P", 
    RowBox[{"(", "s", ")"}]}], 
   RowBox[{"Q", 
    RowBox[{"(", "s", ")"}]}]]]],
 ",  where ",
 Cell[BoxData[
  RowBox[{"P", 
   RowBox[{"(", "s", ")"}]}]]],
 " and  ",
 Cell[BoxData[
  RowBox[{"Q", 
   RowBox[{"(", "s", ")"}]}]]],
 " are polynomials; in other important applications, the functions take the \
form  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"a", " ", "s"}]], " ", "P", 
    RowBox[{"(", "s", ")"}]}], 
   RowBox[{"Q", 
    RowBox[{"(", "s", ")"}]}]]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 12.11  (Linearity of the Laplace Transform).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}], "  ", "and", "  ", "g", 
   RowBox[{"(", "t", ")"}]}]]],
 "  have Laplace transforms  ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "s", ")"}], "  ", "and", " ", "G", 
   RowBox[{"(", "s", ")"}]}]]],
 ",  respectively.  If  ",
 StyleBox["a",
  FontFamily->"Courier New"],
 "  and  ",
 StyleBox["b",
  FontFamily->"Courier New"],
 "  are constants, then   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[ScriptCapitalL]",
     FontSize->16], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "f", 
       RowBox[{"(", "t", ")"}]}], "+", 
      RowBox[{"b", " ", "g", 
       RowBox[{"(", "t", ")"}]}]}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"a", " ", "F", 
     RowBox[{"(", "s", ")"}]}], " ", "+", "  ", 
    RowBox[{"b", " ", "G", 
     RowBox[{"(", "s", ")"}]}]}]}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.11 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Theorem 12.12  (Uniqueness of the Laplace Transform).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}], "  ", "and", "  ", "g", 
   RowBox[{"(", "t", ")"}]}]]],
 "  have Laplace transforms  ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "s", ")"}], "  ", "and", " ", "G", 
   RowBox[{"(", "s", ")"}]}]]],
 ",  respectively.   \n\n\t\t\tIf  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "s", ")"}]}], "\[Congruent]", 
   RowBox[{"G", 
    RowBox[{"(", "s", ")"}]}]}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}]}], "\[Congruent]", 
   RowBox[{"g", 
    RowBox[{"(", "t", ")"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.12 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tTable 12.2 gives the Laplace transforms of some well-known functions, and \
Table 12.3 highlights some important properties of Laplace transforms. (see \
below) \
\>", "Text",
 CellChangeTimes->{{3.399646566328125*^9, 3.3996465745625*^9}, {
  3.506805074375*^9, 3.506805109546875*^9}}],

Cell[TextData[{
 StyleBox["Example 12.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the Laplace transform of the step function given by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{"{", GridBox[{
      {
       RowBox[{"1", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}], 
       RowBox[{
        RowBox[{
         RowBox[{
          StyleBox["for",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], "   ", "0"}], "\[LessEqual]", "t", "<", 
         "c"}], 
        StyleBox[";",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}]},
      {
       RowBox[{"0", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}], 
       RowBox[{
        RowBox[{
         StyleBox["for",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "   ", "c"}], "<", 
        RowBox[{"t", 
         StyleBox[".",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], 
         StyleBox["           ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]]}]}]}
     }], 
    StyleBox["}",
     FontColor->GrayLevel[1]]}]}]]],
 " \n\n\t\t\tis  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[ScriptCapitalL]",
     FontSize->16], 
    RowBox[{"(", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"F", 
     RowBox[{"(", "s", ")"}]}], " ", "=", " ", 
    FractionBox[
     RowBox[{"1", " ", "-", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "c"}], " ", "s"}]]}], "s"]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Solution.", "Text"],

Cell[TextData[{
 "\tUsing the integral definition for ",
 Cell[BoxData[
  RowBox[{
   StyleBox["\[ScriptCapitalL]",
    FontSize->16], 
   RowBox[{"(", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}]}], ")"}]}]]],
 ", we obtain  \n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     StyleBox["\[ScriptCapitalL]",
      FontSize->16], 
     RowBox[{"(", 
      RowBox[{"f", 
       RowBox[{"(", "t", ")"}]}], ")"}]}], " ", "=", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "t", ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "s"}], " ", "t"}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "c"], " ", 
      RowBox[{"1", "*", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "s"}], " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "+", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "c", "\[Infinity]"], " ", 
      RowBox[{"0", "*", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "s"}], " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"-", 
        FractionBox[
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "s"}], " ", "t"}]], "s"]}], ")"}], 
      UnderoverscriptBox["\[VerticalSeparator]", 
       RowBox[{"t", "=", "0"}], 
       RowBox[{"t", "=", "c"}]]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "c"}], " ", "s"}]], "s"]}], "-", 
      RowBox[{"(", 
       RowBox[{"-", 
        FractionBox["1", "s"]}], ")"}]}]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{"1", " ", "-", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "c"}], " ", "s"}]]}], "s"]}]}]}]],
 " "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"12.7", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.5067072763125*^9, 3.5067072763125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}]}]]],
 "  and compute the integral defining   ",
 Cell[BoxData[
  RowBox[{
   StyleBox["\[ScriptCapitalL]",
    FontSize->16], 
   RowBox[{"(", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}]}], ")"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "=", 
     RowBox[{"s", "=", 
      RowBox[{"t", "=", "0"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"c", ",", "s", ",", "t"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g", ",", "F"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", "1"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "t_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "s"}], " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "s_", "]"}], " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "c"], 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "s"}], " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[t] = \[Integral] \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(-st\)]\)\
\[DifferentialD]t = \>\"", ",", 
      RowBox[{"g", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[s] = g[c] - g[0] = \>\"", ",", 
      RowBox[{
       RowBox[{"g", "[", "c", "]"}], "-", 
       RowBox[{"g", "[", "0", "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<F[s] = \!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(c\)]\)\>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(-st\)]\)\
\[DifferentialD]t = \>\"", ",", 
      RowBox[{"F", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[s] = \>\"", ",", 
      RowBox[{"F", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39964659015625*^9, 3.399646591546875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can check this with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s  result using the LaplaceTransform package."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{"LaplaceTransform", "[", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], ",", " ", "t", ",", " ", "s"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[s] = \>\"", ",", 
      RowBox[{"F", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39964659553125*^9, 3.39964659659375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 12.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[ScriptCapitalL]",
     FontSize->16], 
    RowBox[{"(", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"a", " ", "t"}]], " ", ")"}]}], " ", "=", " ", 
   FractionBox["1", 
    RowBox[{"s", "-", "a"}]]}]]],
 ",  where ",
 StyleBox["a",
  FontFamily->"Courier New"],
 " is a real constant."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Solution.", "Text"],

Cell[TextData[{
 "\tWe actually show that the integral defining ",
 Cell[BoxData[
  RowBox[{
   StyleBox["\[ScriptCapitalL]",
    FontSize->16], 
   RowBox[{"(", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"a", " ", "t"}]], ")"}]}]]],
 " equals the formula ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "s", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"s", "-", "a"}]]}]]],
 " for values of ",
 StyleBox["s",
  FontFamily->"Courier New"],
 " with ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", 
    RowBox[{"(", "s", ")"}]}], ">", "a"}]]],
 " and that the extension to other values of ",
 StyleBox["s",
  FontFamily->"Courier New"],
 " is inferred by our knowledge about the domain of a rational function.  \
Using straightforward integration techniques gives \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     StyleBox["\[ScriptCapitalL]",
      FontSize->16], 
     RowBox[{"(", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"a", " ", "t"}]], ")"}]}], " ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"a", " ", "t"}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "s"}], " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "-", "s"}], ")"}], " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{"=", 
    RowBox[{
     UnderscriptBox[
      RowBox[{" ", "lim", " "}], 
      RowBox[{"R", "\[Rule]", "\[Infinity]"}]], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "R"], " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "-", "s"}], ")"}], " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{
      UnderscriptBox[
       RowBox[{" ", "lim", " "}], 
       RowBox[{"R", "\[Rule]", "\[Infinity]"}]], 
      FractionBox[
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "-", "s"}], ")"}], " ", "R"}]], 
       RowBox[{"a", "-", "s"}]]}], " ", "-", " ", 
     FractionBox[
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "-", "s"}], ")"}], " ", "0"}]], 
      RowBox[{"a", "-", "s"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"-", " ", 
      FractionBox["1", 
       RowBox[{"a", "-", "s"}]]}], " ", "+", " ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"a", "-", "s"}]], 
      UnderscriptBox[
       RowBox[{" ", "lim", " "}], 
       RowBox[{"R", "\[Rule]", "\[Infinity]"}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "-", "s"}], ")"}], " ", "R"}]]}]}]}]}]}]],
 "  \n\n Let ",
 Cell[BoxData[
  RowBox[{"s", "=", 
   RowBox[{"\[Sigma]", "+", 
    RowBox[{"\[ImaginaryI]", " ", "\[Tau]"}]}]}]]],
 "  be fixed, or where ",
 Cell[BoxData[
  RowBox[{"\[Sigma]", ">", "a"}]]],
 ".  Then, as ",
 Cell[BoxData[
  RowBox[{"a", "-", "\[Sigma]"}]]],
 " is a negative real number, we have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox[
     RowBox[{" ", "lim", " "}], 
     RowBox[{"R", "\[Rule]", "\[Infinity]"}]], "|", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "-", "s"}], ")"}], "R"}]], "|"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox[
      RowBox[{" ", "lim", " "}], 
      RowBox[{"R", "\[Rule]", "\[Infinity]"}]], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "-", "\[Sigma]"}], ")"}], "R"}]]}], " ", "=", " ", 
    "0"}]}]]],
 ",  which implies that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox[
     RowBox[{" ", "lim", " "}], 
     RowBox[{"R", "\[Rule]", "\[Infinity]"}]], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "-", "s"}], ")"}], "R"}]]}], " ", "=", " ", "0"}]]],
 ",  and use this expression in the preceding equation to obtain  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[ScriptCapitalL]",
     FontSize->16], 
    RowBox[{"(", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"a", " ", "t"}]], ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"s", "-", "a"}]]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"12.8", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.5067072800625*^9, 3.5067072800625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}]}]]],
 "  and compute the integral defining   ",
 Cell[BoxData[
  RowBox[{
   StyleBox["\[ScriptCapitalL]",
    FontSize->16], 
   RowBox[{"(", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}]}], ")"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"s", "=", 
      RowBox[{"t", "=", "0"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"a", ",", "s", ",", "t"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g", ",", "F"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"a", " ", "t"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "s"}], " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "t", "]"}], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "s"}], " ", "t"}]]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "\[Infinity]"}], "}"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"s", ">", 
           RowBox[{"Re", "[", "a", "]"}]}], "&&", 
          RowBox[{"a", "<", 
           RowBox[{"Re", "[", "s", "]"}]}]}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[t] = \[Integral] \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(-st\)]\)\
\[DifferentialD]t = \>\"", ",", 
      RowBox[{"g", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<F[s] = \!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(-st\)]\)\
\[DifferentialD]t = g[\[Infinity]] - g[0]\>\""}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[s] = \>\"", ",", 
      RowBox[{
       RowBox[{"g", "[", "\[Infinity]", "]"}], "-", 
       RowBox[{"g", "[", "0", "]"}]}], ",", "\"\< = \>\"", ",", 
      RowBox[{"F", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39964660334375*^9, 3.3996466045625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Assuming that f(t) is of exponential order, we have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", "[", "t", "]"}], " ", "\[Rule]", " ", 
   RowBox[{
    RowBox[{"0", "  ", "as", "  ", "t"}], " ", "\[Rule]", " ", 
    "\[Infinity]"}]}]]],
 ". Then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"g", "[", "\[Infinity]", "]"}], " ", "=", "0"}], " "}]]],
 ",  and the Laplace transform can be computed by the calculation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"g", "[", "\[Infinity]", "]"}], " ", "-", " ", 
    RowBox[{"g", "[", "0", "]"}]}], "=", 
   RowBox[{"-", " ", 
    RowBox[{"g", "[", "0", "]"}]}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[t] = \[Integral] \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(-st\)]\)\
\[DifferentialD]t = \>\"", ",", 
      RowBox[{"g", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[s] = - g[0] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{"-", 
        RowBox[{"g", "[", "0", "]"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39964660853125*^9, 3.399646609484375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can check this with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s  result using the LaplaceTransform package."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{"LaplaceTransform", "[", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], ",", " ", "t", ",", " ", "s"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[s] = \>\"", ",", 
      RowBox[{"F", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39964661215625*^9, 3.399646613015625*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tWe can use the property of linearity to find new Laplace transforms from \
known transforms.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Example 12.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[ScriptCapitalL]",
     FontSize->16], 
    RowBox[{"(", " ", 
     RowBox[{"sinh", 
      RowBox[{"(", 
       RowBox[{"a", " ", "t"}], ")"}]}], " ", ")"}]}], " ", "=", " ", 
   FractionBox["a", 
    RowBox[{
     SuperscriptBox["s", "2"], " ", "-", " ", 
     SuperscriptBox["a", "2"]}]]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Solution.", "Text"],

Cell[TextData[{
 "\tBecause ",
 Cell[BoxData[
  RowBox[{"sinh", 
   RowBox[{"(", 
    RowBox[{"a", " ", "t"}], ")"}]}]]],
 " can be written as the linear combination  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"sinh", 
    RowBox[{"(", 
     RowBox[{"a", " ", "t"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"a", " ", "t"}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "a"}], " ", "t"}]]}]}]}]]],
 ",  we obtain  \n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     StyleBox["\[ScriptCapitalL]",
      FontSize->16], 
     RowBox[{"(", 
      RowBox[{"sinh", 
       RowBox[{"(", 
        RowBox[{"a", " ", "t"}], ")"}]}], ")"}]}], " ", "=", " ", 
    RowBox[{
     StyleBox["\[ScriptCapitalL]",
      FontSize->16], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"a", " ", "t"}]]}], " ", "-", " ", 
       RowBox[{
        FractionBox["1", "2"], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "a"}], " ", "t"}]]}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                               ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], 
      StyleBox["\[ScriptCapitalL]",
       FontSize->16], 
      RowBox[{"(", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"a", " ", "t"}]], ")"}]}], " ", "-", " ", 
     RowBox[{
      FractionBox["1", "2"], 
      StyleBox["\[ScriptCapitalL]",
       FontSize->16], 
      RowBox[{"(", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "a"}], " ", "t"}]], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                               ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], 
      FractionBox["1", 
       RowBox[{"s", "-", "a"}]]}], " ", "-", " ", 
     RowBox[{
      FractionBox["1", "2"], 
      FractionBox["1", 
       RowBox[{"s", "+", "a"}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                               ", 
   RowBox[{"=", " ", 
    FractionBox["a", 
     RowBox[{
      SuperscriptBox["s", "2"], " ", "-", " ", 
      SuperscriptBox["a", "2"]}]]}]}]}]],
 " "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"12.9", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506707283765625*^9, 3.506707283765625*^9}}],

Cell[TextData[{
 "Since  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "t", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Sinh", "[", 
     RowBox[{"a", " ", "t"}], "]"}], "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"a", " ", "t"}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "a"}], " ", "t"}]]}], "2"], "=", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"a", " ", "t"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "a"}], " ", "t"}]]}]}]}]}]}]]],
 ",  we can apply the results of Example ",
 "12.",
 "8;   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[ScriptCapitalL]",
     FontSize->16], 
    RowBox[{"(", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"a", " ", "t"}]], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"s", " ", "-", " ", "a"}]], "  ", "and", "   ", 
     StyleBox["\[ScriptCapitalL]",
      FontSize->16], 
     RowBox[{"(", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "a"}], " ", "t"}]], ")"}]}], "=", 
    FractionBox["1", 
     RowBox[{"s", " ", "+", " ", "a"}]]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"s", "=", 
      RowBox[{"t", "=", "0"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"a", ",", "s", ",", "t"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "f1", ",", "f2", ",", "f12", ",", "F", ",", "F1", ",", "F2", 
      ",", "F12"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "t_", "]"}], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"a", " ", "t"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f2", "[", "t_", "]"}], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "a"}], " ", "t"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f12", "[", "t_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"a", " ", "t"}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "a"}], " ", "t"}]]}], "2"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"Sinh", "[", 
      RowBox[{"a", " ", "t"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F1", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{"LaplaceTransform", "[", 
      RowBox[{
       RowBox[{"f1", "[", "t", "]"}], ",", " ", "t", ",", " ", "s"}], "]"}]}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F2", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{"LaplaceTransform", "[", 
      RowBox[{
       RowBox[{"f2", "[", "t", "]"}], ",", " ", "t", ",", " ", "s"}], "]"}]}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F12", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{"LaplaceTransform", "[", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], ",", " ", "t", ",", " ", "s"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{"LaplaceTransform", "[", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], ",", " ", "t", ",", " ", "s"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(f\), \(1\)]\)[t] = \>\"", ",", 
      RowBox[{"f1", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(f\), \(2\)]\)[t] = \>\"", ",", 
      RowBox[{"f2", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(f\), \(12\)]\)[t] = \>\"", ",", 
      RowBox[{"f12", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(f\), \(12\)]\)[t] = \>\"", ",", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{"f12", "[", "t", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  f[t] = \>\"", ",", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{"f", "[", "t", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(F\), \(1\)]\)[s] = \>\"", ",", 
      RowBox[{"F1", "[", "s", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(F\), \(2\)]\)[s] = \>\"", ",", 
      RowBox[{"F2", "[", "s", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(F\), \(12\)]\)[s] = \
\!\(\*FractionBox[\(\(\*SubscriptBox[\(F\), \(1\)]\)[s] - \
\(\*SubscriptBox[\(F\), \(2\)]\)[s]\), \(2\)]\) = \>\"", ",", 
      FractionBox[
       RowBox[{
        RowBox[{"F1", "[", "s", "]"}], "-", 
        RowBox[{"F2", "[", "s", "]"}]}], "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(F\), \(12\)]\)[s] = \
\!\(\*FractionBox[\(\(\*SubscriptBox[\(F\), \(1\)]\)[s] - \
\(\*SubscriptBox[\(F\), \(2\)]\)[s]\), \(2\)]\) = \>\"", ",", 
      RowBox[{"Together", "[", 
       FractionBox[
        RowBox[{
         RowBox[{"F1", "[", "s", "]"}], "-", 
         RowBox[{"F2", "[", "s", "]"}]}], "2"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F[s] = \[ScriptCapitalL](Sinh[a t]) = \>\"", ",", 
      RowBox[{"F", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399646619515625*^9, 3.399646621046875*^9}}],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can check this with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s  result using the LaplaceTransform package."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{"LaplaceTransform", "[", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], ",", " ", "t", ",", " ", "s"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[s] = \>\"", ",", 
      RowBox[{"F", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399646622421875*^9, 3.399646623328125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tIntegration by parts is also helpful in finding new Laplace transforms. \
\>", "Text"],

Cell[TextData[{
 StyleBox["Example 12.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[ScriptCapitalL]",
     FontSize->16], 
    RowBox[{"(", " ", "t", " ", ")"}]}], " ", "=", " ", 
   FractionBox["1", 
    SuperscriptBox["s", "2"]]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Solution.", "Text"],

Cell[TextData[{
 "\tIntegration by parts yields  \n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     StyleBox["\[ScriptCapitalL]",
      FontSize->16], 
     RowBox[{"(", " ", "t", " ", ")"}]}], " ", "=", "  ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], "  ", 
     RowBox[{"t", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "s"}], " ", "t"}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"               ", 
   RowBox[{"=", 
    RowBox[{
     UnderscriptBox[
      RowBox[{" ", "lim", " "}], 
      RowBox[{"R", "\[Rule]", "\[Infinity]"}]], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "R"], "  ", 
      RowBox[{"t", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "s"}], " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", 
    RowBox[{
     RowBox[{
      RowBox[{
       UnderscriptBox[
        RowBox[{" ", "lim", " "}], 
        RowBox[{"R", "\[Rule]", "\[Infinity]"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"-", "t"}], "s"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "s"}], " ", "t"}]]}], "-", 
         RowBox[{
          FractionBox["1", 
           SuperscriptBox["s", "2"]], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "s"}], " ", "t"}]]}]}], " ", ")"}]}], 
      UnderoverscriptBox["\[VerticalSeparator]", 
       RowBox[{"t", "=", "0"}], 
       RowBox[{"t", "=", "R"}]]}], "  ", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "           ", "=", 
     RowBox[{
      RowBox[{
       UnderscriptBox[
        RowBox[{" ", "lim", " "}], 
        RowBox[{"R", "\[Rule]", "\[Infinity]"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"-", "R"}], "s"], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "s"}], " ", "R"}]]}], "-", 
         RowBox[{
          FractionBox["1", 
           SuperscriptBox["s", "2"]], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "s"}], " ", "R"}]]}]}], " ", ")"}]}], " ", "+", " ", 
      "0", " ", "+", " ", 
      FractionBox["1", 
       SuperscriptBox["s", "2"]]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", " ", "0"}], " ", "-", " ", "0"}], ")"}], " ", "+", " ", 
      "0", " ", "+", " ", 
      FractionBox["1", 
       SuperscriptBox["s", "2"]]}]}], "  ", "=", "  ", 
    FractionBox["1", 
     SuperscriptBox["s", "2"]], " "}]}]}]],
 " \n\nFor values of ",
 StyleBox["s",
  FontFamily->"Courier New"],
 " in the right half-plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", 
    RowBox[{"(", "s", ")"}]}], ">", "0"}]]],
 ", an argument similar to that in Example 12.8 shows that the limit \
approaches zero, establishing the result."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"12.10", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506707287484375*^9, 3.506707287484375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}]}]]],
 "  and compute the integral defining   ",
 Cell[BoxData[
  RowBox[{
   StyleBox["\[ScriptCapitalL]",
    FontSize->16], 
   RowBox[{"(", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}]}], ")"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"s", "=", 
      RowBox[{"t", "=", "0"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"a", ",", "s", ",", "t"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g", ",", "F"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", "t"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "s"}], " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "t", "]"}], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "s"}], " ", "t"}]]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "\[Infinity]"}], "}"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Im", "[", "s", "]"}], "\[Equal]", "0"}], ",", 
          RowBox[{"s", ">", "0"}]}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[t] = \[Integral] \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(-st\)]\)\
\[DifferentialD]t = \>\"", ",", 
      RowBox[{"g", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<F[s] = \!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(-st\)]\)\
\[DifferentialD]t = g[\[Infinity]] - g[0]\>\""}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[s] = \>\"", ",", 
      RowBox[{
       RowBox[{"g", "[", "\[Infinity]", "]"}], "-", 
       RowBox[{"g", "[", "0", "]"}]}], ",", "\"\< = \>\"", ",", 
      RowBox[{"F", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39964665471875*^9, 3.39964665609375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Assuming that f(t) is of exponential order, we have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", "[", "t", "]"}], " ", "\[Rule]", " ", 
   RowBox[{
    RowBox[{"0", "  ", "as", "  ", "t"}], " ", "\[Rule]", " ", 
    "\[Infinity]"}]}]]],
 ". Then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"g", "[", "\[Infinity]", "]"}], " ", "=", "0"}], " "}]]],
 ",  and the Laplace transform can be computed by the calculation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"g", "[", "\[Infinity]", "]"}], " ", "-", " ", 
    RowBox[{"g", "[", "0", "]"}]}], "=", 
   RowBox[{"-", " ", 
    RowBox[{"g", "[", "0", "]"}]}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[t] = \[Integral] \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(-st\)]\)\
\[DifferentialD]t = \>\"", ",", 
      RowBox[{"g", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[s] = - g[0] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{"-", 
        RowBox[{"g", "[", "0", "]"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3996466584375*^9, 3.39964665996875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can check this with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s  result using the LaplaceTransform package."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{"LaplaceTransform", "[", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], ",", " ", "t", ",", " ", "s"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[s] = \>\"", ",", 
      RowBox[{"F", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399646663328125*^9, 3.39964666415625*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[ScriptCapitalL]",
     FontSize->16], 
    RowBox[{"(", " ", 
     SuperscriptBox["t", "3"], " ", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{"3", "!"}], 
    SuperscriptBox["s", "4"]]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{
  "Explore", " ", "Solution", " ", "for", " ", "Extra", " ", "Example", " ", 
   "1."}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.5067072905625*^9, 3.5067072905625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}]}]]],
 "  and compute the integral defining   ",
 Cell[BoxData[
  RowBox[{
   StyleBox["\[ScriptCapitalL]",
    FontSize->16], 
   RowBox[{"(", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}]}], ")"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"s", "=", 
      RowBox[{"t", "=", "0"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"a", ",", "s", ",", "t"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g", ",", "F"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", 
     SuperscriptBox["t", "3"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "s"}], " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "t", "]"}], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "s"}], " ", "t"}]]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "\[Infinity]"}], "}"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Im", "[", "s", "]"}], "\[Equal]", "0"}], ",", 
          RowBox[{"s", ">", "0"}]}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[t] = \[Integral] \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(-st\)]\)\
\[DifferentialD]t = \>\"", ",", 
      RowBox[{"g", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<F[s] = \!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(-st\)]\)\
\[DifferentialD]t = g[\[Infinity]] - g[0]\>\""}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[s] = \>\"", ",", 
      RowBox[{
       RowBox[{"g", "[", "\[Infinity]", "]"}], "-", 
       RowBox[{"g", "[", "0", "]"}]}], ",", "\"\< = \>\"", ",", 
      RowBox[{"F", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399646670125*^9, 3.39964667128125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Assuming that f(t) is of exponential order, we have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", "[", "t", "]"}], " ", "\[Rule]", " ", 
   RowBox[{
    RowBox[{"0", "  ", "as", "  ", "t"}], " ", "\[Rule]", " ", 
    "\[Infinity]"}]}]]],
 ". Then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"g", "[", "\[Infinity]", "]"}], " ", "=", "0"}], " "}]]],
 ",  and the Laplace transform can be computed by the calculation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"g", "[", "\[Infinity]", "]"}], " ", "-", " ", 
    RowBox[{"g", "[", "0", "]"}]}], "=", 
   RowBox[{"-", " ", 
    RowBox[{"g", "[", "0", "]"}]}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[t] = \[Integral] \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(-st\)]\)\
\[DifferentialD]t = \>\"", ",", 
      RowBox[{"g", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[s] = - g[0] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{"-", 
        RowBox[{"g", "[", "0", "]"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3996466890625*^9, 3.3996466903125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can check this with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s  result using the LaplaceTransform package."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{"LaplaceTransform", "[", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], ",", " ", "t", ",", " ", "s"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[s] = \>\"", ",", 
      RowBox[{"F", "[", "s", "]"}]}], "]"}], ";"}], " "}]}]], "Input",
 CellChangeTimes->{3.399646694203125*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 12.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "   Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[ScriptCapitalL]",
     FontSize->16], 
    RowBox[{"(", " ", 
     RowBox[{"cos", 
      RowBox[{"(", 
       RowBox[{"b", " ", "t"}], ")"}]}], " ", ")"}]}], " ", "=", " ", 
   FractionBox["s", 
    RowBox[{
     SuperscriptBox["s", "2"], "+", " ", 
     SuperscriptBox["b", "2"]}]]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Solution.", "Text"],

Cell[TextData[{
 "\tA direct approach using the definition is tedious.  Instead, let's assume \
that the complex constants ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}], " ", "b"}]]],
 " are permitted and hence that the following Laplace transforms exist: \n\n\t\
\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[ScriptCapitalL]",
     FontSize->16], 
    RowBox[{"(", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "b", " ", "t"}]], ")"}]}], " ", "=", " ", 
   FractionBox["1", 
    RowBox[{"s", " ", "-", " ", 
     RowBox[{"\[ImaginaryI]", " ", "b"}]}]]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[ScriptCapitalL]",
     FontSize->16], 
    RowBox[{"(", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "b", " ", "t"}]], ")"}]}], " ", 
   "=", " ", 
   FractionBox["1", 
    RowBox[{"s", " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "b"}]}]]}]]],
 ".\n\nRecall that ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{"b", " ", "t"}], ")"}]}]]],
 " can be written as the linear combination ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"b", " ", "t"}], ")"}]}], "=", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "b", " ", "t"}]]}], "+", 
     RowBox[{
      FractionBox["1", "2"], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "b", " ", "t"}]]}]}]}]}]]],
 ".  Using the linearity of the Laplace transform, we have  \n\n\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     StyleBox["\[ScriptCapitalL]",
      FontSize->16], 
     RowBox[{"(", " ", 
      RowBox[{"cos", 
       RowBox[{"(", 
        RowBox[{"b", " ", "t"}], ")"}]}], ")"}]}], " ", "=", " ", 
    RowBox[{
     StyleBox["\[ScriptCapitalL]",
      FontSize->16], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "b", " ", "t"}]]}], "+", 
       RowBox[{
        FractionBox["1", "2"], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "b", " ", "t"}]]}]}], 
      ")"}]}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                              ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], 
      StyleBox["\[ScriptCapitalL]",
       FontSize->16], 
      RowBox[{"(", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "b", " ", "t"}]], ")"}]}], " ", "+", 
     " ", 
     RowBox[{
      FractionBox["1", "2"], 
      StyleBox["\[ScriptCapitalL]",
       FontSize->16], 
      RowBox[{"(", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "b", " ", "t"}]], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                              ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], 
      FractionBox["1", 
       RowBox[{"s", " ", "-", " ", 
        RowBox[{"\[ImaginaryI]", " ", "b"}]}]]}], " ", "+", " ", 
     RowBox[{
      FractionBox["1", "2"], 
      FractionBox["1", 
       RowBox[{"s", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "b"}]}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                              ", 
   RowBox[{"=", " ", 
    FractionBox["s", 
     RowBox[{
      SuperscriptBox["s", "2"], " ", "+", " ", 
      SuperscriptBox["b", "2"]}]]}]}]}]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"12.11", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.50670729696875*^9, 3.50670729696875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  ",
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}]}]]],
 "  and compute the integral defining   ",
 Cell[BoxData[
  RowBox[{
   StyleBox["\[ScriptCapitalL]",
    FontSize->16], 
   RowBox[{"(", 
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}]}], ")"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"s", "=", 
      RowBox[{"t", "=", "0"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"a", ",", "s", ",", "t"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g", ",", "F"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"b", " ", "t"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "s"}], " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "t", "]"}], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "s"}], " ", "t"}]]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "\[Infinity]"}], "}"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Re", "[", "s", "]"}], ">", "0"}], ",", 
          RowBox[{
           RowBox[{"Im", "[", "b", "]"}], "\[Equal]", "0"}]}], "}"}]}]}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[t] = \[Integral] \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(-st\)]\)\
\[DifferentialD]t = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{"g", "[", "t", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<F[s] = \!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(-st\)]\)\
\[DifferentialD]t = g[\[Infinity]] - g[0]\>\""}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[s] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"g", "[", "\[Infinity]", "]"}], "-", 
        RowBox[{"g", "[", "0", "]"}]}], "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"F", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399647353625*^9, 3.39964735721875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Assuming that f(t) is of exponential order, we have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", "[", "t", "]"}], " ", "\[Rule]", " ", 
   RowBox[{
    RowBox[{"0", "  ", "as", "  ", "t"}], " ", "\[Rule]", " ", 
    "\[Infinity]"}]}]]],
 ". Then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"g", "[", "\[Infinity]", "]"}], " ", "=", "0"}], " "}]]],
 ",  and the Laplace transform can be computed by the calculation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"g", "[", "\[Infinity]", "]"}], " ", "-", " ", 
    RowBox[{"g", "[", "0", "]"}]}], "=", 
   RowBox[{"-", " ", 
    RowBox[{"g", "[", "0", "]"}]}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[t] = \[Integral] \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(-st\)]\)\
\[DifferentialD]t = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{"g", "[", "t", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[s] = - g[0] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{"-", 
        RowBox[{"g", "[", "0", "]"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399647360359375*^9, 3.3996473615625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Method 2",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox[".",
  FontColor->RGBColor[1, 0, 1]],
 "  Since  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "t", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"b", " ", "t"}], "]"}], "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "b", " ", "t"}]], " ", "+", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "b", " ", "t"}]]}], "2"], "=", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "b", " ", "t"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "b", " ", "t"}]]}]}]}]}]}]]],
 ",  we can use  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[ScriptCapitalL]",
     FontSize->16], 
    RowBox[{"(", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "b", " ", "t"}]], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"s", " ", "-", " ", 
       RowBox[{"\[ImaginaryI]", " ", "b"}]}]], "  ", "and", "   ", 
     StyleBox["\[ScriptCapitalL]",
      FontSize->16], 
     RowBox[{"(", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "b", " ", "t"}]], ")"}]}], "=", 
    FractionBox["1", 
     RowBox[{"s", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "b"}]}]]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"b", "=", 
     RowBox[{"s", "=", 
      RowBox[{"t", "=", "0"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"b", ",", "s", ",", "t"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "f1", ",", "f2", ",", "f12", ",", "F", ",", "F1", ",", "F2", 
      ",", "F12"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "t_", "]"}], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "b", " ", "t"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f2", "[", "t_", "]"}], " ", "=", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "b", " ", "t"}]]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f12", "[", "t_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "b", " ", "t"}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "b", " ", "t"}]]}], "2"]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"b", " ", "t"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F1", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{"LaplaceTransform", "[", 
      RowBox[{
       RowBox[{"f1", "[", "t", "]"}], ",", " ", "t", ",", " ", "s"}], "]"}]}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F2", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{"LaplaceTransform", "[", 
      RowBox[{
       RowBox[{"f2", "[", "t", "]"}], ",", " ", "t", ",", " ", "s"}], "]"}]}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F12", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{"LaplaceTransform", "[", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], ",", " ", "t", ",", " ", "s"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{"LaplaceTransform", "[", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], ",", " ", "t", ",", " ", "s"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(f\), \(1\)]\)[t] = \>\"", ",", 
      RowBox[{"f1", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(f\), \(2\)]\)[t] = \>\"", ",", 
      RowBox[{"f2", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(f\), \(12\)]\)[t] = \>\"", ",", 
      RowBox[{"f12", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(f\), \(12\)]\)[t] = \>\"", ",", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{"f12", "[", "t", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  f[t] = \>\"", ",", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{"f", "[", "t", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(F\), \(1\)]\)[s] = \>\"", ",", 
      RowBox[{"F1", "[", "s", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(F\), \(2\)]\)[s] = \>\"", ",", 
      RowBox[{"F2", "[", "s", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(F\), \(12\)]\)[s] = \
\!\(\*FractionBox[\(\(\*SubscriptBox[\(F\), \(1\)]\)[s] + \
\(\*SubscriptBox[\(F\), \(2\)]\)[s]\), \(2\)]\) = \>\"", ",", 
      FractionBox[
       RowBox[{
        RowBox[{"F1", "[", "s", "]"}], "+", 
        RowBox[{"F2", "[", "s", "]"}]}], "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(F\), \(12\)]\)[s] = \
\!\(\*FractionBox[\(\(\*SubscriptBox[\(F\), \(1\)]\)[s] + \
\(\*SubscriptBox[\(F\), \(2\)]\)[s]\), \(2\)]\) = \>\"", ",", 
      RowBox[{"Together", "[", 
       FractionBox[
        RowBox[{
         RowBox[{"F1", "[", "s", "]"}], "+", 
         RowBox[{"F2", "[", "s", "]"}]}], "2"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F[s] = \[ScriptCapitalL](Cos[b t]) = \>\"", ",", 
      RowBox[{"F", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399647364046875*^9, 3.399647365765625*^9}}],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can check this with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s  result using the LaplaceTransform package."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{"LaplaceTransform", "[", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], ",", " ", "t", ",", " ", "s"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[s] = \>\"", ",", 
      RowBox[{"F", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39964736896875*^9, 3.39964737028125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 12.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the inverse Laplace transform  ",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    SuperscriptBox["\[ScriptCapitalL]", 
     RowBox[{"-", "1"}]],
    FontSize->16], 
   RowBox[{"(", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"3", "s"}], " ", "+", "  ", "6"}], 
     RowBox[{
      SuperscriptBox["s", "2"], "  ", "+", "  ", "9"}]], " ", ")"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Solution.", "Text"],

Cell[TextData[{
 "\tUsing linearity and lines 6 and 7 of Table 11.2, we obtain  \n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     StyleBox[
      SuperscriptBox["\[ScriptCapitalL]", 
       RowBox[{"-", "1"}]],
      FontSize->16], 
     RowBox[{"(", " ", 
      FractionBox[
       RowBox[{
        RowBox[{"3", "s"}], " ", "+", "  ", "6"}], 
       RowBox[{
        SuperscriptBox["s", "2"], "  ", "+", "  ", "9"}]], " ", ")"}]}], " ", 
    "=", " ", 
    RowBox[{
     StyleBox[
      SuperscriptBox["\[ScriptCapitalL]", 
       RowBox[{"-", "1"}]],
      FontSize->16], 
     RowBox[{"(", " ", 
      RowBox[{
       FractionBox[
        RowBox[{"3", " ", "s"}], 
        RowBox[{
         SuperscriptBox["s", "2"], "+", "9"}]], " ", "+", " ", 
       FractionBox["6", 
        RowBox[{
         SuperscriptBox["s", "2"], "+", "9"}]]}], " ", ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                             ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      StyleBox[
       SuperscriptBox["\[ScriptCapitalL]", 
        RowBox[{"-", "1"}]],
       FontSize->16], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"3", " ", "s"}], 
        RowBox[{
         SuperscriptBox["s", "2"], "+", "9"}]], ")"}]}], "+", " ", 
     RowBox[{
      StyleBox[
       SuperscriptBox["\[ScriptCapitalL]", 
        RowBox[{"-", "1"}]],
       FontSize->16], 
      RowBox[{"(", 
       FractionBox["6", 
        RowBox[{
         SuperscriptBox["s", "2"], "+", "9"}]], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                             ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      StyleBox[
       SuperscriptBox["\[ScriptCapitalL]", 
        RowBox[{"-", "1"}]],
       FontSize->16], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"3", " ", "s"}], 
        RowBox[{
         SuperscriptBox["s", "2"], "+", "9"}]], ")"}]}], "+", " ", 
     RowBox[{
      StyleBox[
       SuperscriptBox["\[ScriptCapitalL]", 
        RowBox[{"-", "1"}]],
       FontSize->16], 
      RowBox[{"(", 
       FractionBox["6", 
        RowBox[{
         SuperscriptBox["s", "2"], "+", "9"}]], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                             ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"3", 
      StyleBox[
       SuperscriptBox["\[ScriptCapitalL]", 
        RowBox[{"-", "1"}]],
       FontSize->16], 
      RowBox[{"(", 
       FractionBox["s", 
        RowBox[{
         SuperscriptBox["s", "2"], "+", "9"}]], ")"}]}], "+", " ", 
     RowBox[{"2", 
      StyleBox[
       SuperscriptBox["\[ScriptCapitalL]", 
        RowBox[{"-", "1"}]],
       FontSize->16], 
      RowBox[{"(", 
       FractionBox["3", 
        RowBox[{
         SuperscriptBox["s", "2"], "+", "9"}]], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                             ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"3", 
      StyleBox[
       SuperscriptBox["\[ScriptCapitalL]", 
        RowBox[{"-", "1"}]],
       FontSize->16], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{" ", "s"}], 
        RowBox[{
         SuperscriptBox["s", "2"], "+", 
         SuperscriptBox["3", "2"]}]], ")"}]}], "+", " ", 
     RowBox[{"2", 
      StyleBox[
       SuperscriptBox["\[ScriptCapitalL]", 
        RowBox[{"-", "1"}]],
       FontSize->16], 
      RowBox[{"(", 
       FractionBox["3", 
        RowBox[{
         SuperscriptBox["s", "2"], "+", 
         SuperscriptBox["3", "2"]}]], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                             ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"3", " ", "cos", 
      RowBox[{"(", 
       RowBox[{"3", "t"}], ")"}]}], " ", "+", " ", 
     RowBox[{"2", " ", "sin", 
      RowBox[{"(", 
       RowBox[{"3", "t"}], ")"}]}]}]}]}]}]],
 "  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"12.12", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.506707300921875*^9, 3.506707300921875*^9}},
 AspectRatioFixed->True],

Cell["\<\
Enter the function F[s] and find its partial fraction expansion.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "=", 
     RowBox[{"s", "=", 
      RowBox[{"t", "=", "0"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"A", ",", "s", ",", "t"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "f1", ",", "f2", ",", "F", ",", "L1", ",", "L2"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "s_", "]"}], "  ", "=", "  ", 
     FractionBox[
      RowBox[{
       RowBox[{"3", "s"}], " ", "+", " ", "6"}], 
      RowBox[{
       SuperscriptBox["s", "2"], " ", "+", " ", "9"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"A", " ", "=", " ", 
     RowBox[{"Expand", "[", 
      RowBox[{"F", "[", "s", "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[s] = \>\"", ",", 
      RowBox[{"F", "[", "s", "]"}], ",", "\"\< = \>\"", ",", "A"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39964737840625*^9, 3.399647380203125*^9}},
 AspectRatioFixed->True],

Cell["The transform F[s] is a linear combination.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "t_", "]"}], " ", "=", 
     RowBox[{"Cos", "[", 
      RowBox[{"3", "t"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f2", "[", "t_", "]"}], " ", "=", 
     RowBox[{"Sin", "[", 
      RowBox[{"3", "t"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"L1", "[", "s_", "]"}], " ", "=", " ", 
     FractionBox["s", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", "+", " ", "9"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"L2", "[", "s_", "]"}], " ", "=", " ", 
     FractionBox["3", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", "+", " ", "9"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(f\), \(1\)]\)[t] = \>\"", ",", 
      RowBox[{"f1", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(f\), \(2\)]\)[t] = \>\"", ",", 
      RowBox[{"f2", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(L\), \(1\)]\)[s] = \>\"", ",", 
      RowBox[{"L1", "[", "s", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(L\), \(2\)]\)[s] = \>\"", ",", 
      RowBox[{"L2", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F[s] = \>\"", ",", 
      RowBox[{"F", "[", "s", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Is F[s] \[Equal] 3 \!\(\*SubscriptBox[\(L\), \(1\)]\)[s] + 2 \
\!\(\*SubscriptBox[\(L\), \(2\)]\)[s] ?\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"F", "[", "s", "]"}], " ", "\[Equal]", 
       RowBox[{
        RowBox[{"3", " ", 
         RowBox[{"L1", "[", "s", "]"}]}], " ", "+", " ", 
        RowBox[{"2", " ", 
         RowBox[{"L2", "[", "s", "]"}]}]}]}], ",", "\"\<,   \>\"", ",", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{"F", "[", "s", "]"}], "]"}], " ", "\[Equal]", " ", 
       RowBox[{
        RowBox[{"3", " ", 
         RowBox[{"L1", "[", "s", "]"}]}], " ", "+", " ", 
        RowBox[{"2", " ", 
         RowBox[{"L2", "[", "s", "]"}]}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399647382625*^9, 3.399647384296875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "The inverse of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["L", "1"], "[", "s", "]"}], "  ", "is", "  ", 
    RowBox[{
     SubscriptBox["f", "1"], "[", "t", "]"}]}], "=", 
   RowBox[{"Cos", "[", 
    RowBox[{"3", " ", "t"}], "]"}]}]]],
 "  and  the inverse of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["L", "2"], "[", "s", "]"}], "  ", "is", "  ", 
    RowBox[{
     SubscriptBox["f", "2"], "[", "t", "]"}]}], "=", 
   RowBox[{"Sin", "[", 
    RowBox[{"3", " ", "t"}], "]"}]}]]],
 ".  \nHence  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "t", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"3", " ", 
     RowBox[{
      SubscriptBox["f", "1"], "[", "t", "]"}]}], " ", "+", " ", 
    RowBox[{"2", " ", 
     RowBox[{
      SubscriptBox["f", "2"], "[", "t", "]"}]}]}]}]],
  AspectRatioFixed->True],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"3", " ", 
       RowBox[{"f1", "[", "t", "]"}]}], " ", "+", " ", 
      RowBox[{"2", " ", 
       RowBox[{"f2", "[", "t", "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f[t] = 3 \!\(\*SubscriptBox[\(f\), \(1\)]\)[t] + 2 \
\!\(\*SubscriptBox[\(f\), \(2\)]\)[t]\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39964738771875*^9, 3.3996473890625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can check this with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s  result using the LaplaceTransform package."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"InverseLaplaceTransform", "[", 
      RowBox[{
       RowBox[{"F", "[", "s", "]"}], ",", " ", "s", ",", " ", "t"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[s] = \>\"", ",", 
      RowBox[{"F", "[", "s", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399647391390625*^9, 3.399647392359375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tInverting the Laplace transform is usually accomplished with the aid of a \
table of known Laplace transforms and the technique of partial fraction \
expansion.  ",
 StyleBox[ButtonBox["Table12.2",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://math.fullerton.edu/mathews/c2003/laplacetransform/\
LaplaceTransformMod/Images/Table.12.2.gif"], None}],
  FontFamily->"Times New Roman",
  FontVariations->{"Underline"->True}],
 " gives the Laplace transforms of some well-known functions, and ",
 StyleBox[ButtonBox["Table 12.3",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://math.fullerton.edu/mathews/c2003/laplacetransform/\
LaplaceTransformMod/Images/Table.12.3.gif"], None}],
  FontFamily->"Times New Roman",
  FontVariations->{"Underline"->True}],
 " highlights some important properties of Laplace transforms."
}], "Text",
 CellChangeTimes->{{3.39962695990625*^9, 3.399627090234375*^9}}],

Cell[TextData[{
 "\t\n\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{489, 716},
  ImageMargins->0],
 "  \n\t\t\t\tTable 12.2  Table of Laplace Transforms. \n\t\t\t\t\n\t\t\t\t"
}], "Text",
 CellChangeTimes->{{3.39962695990625*^9, 3.399627090234375*^9}, {
  3.399627125359375*^9, 3.399627262421875*^9}, {3.39962733165625*^9, 
  3.399627357578125*^9}, {3.510078680828125*^9, 3.51007869196875*^9}}],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{565, 231},
  ImageMargins->0],
 "  \n\n\t\t\tTable 12.3  Properties of Laplace Transforms. \n\t\t\t"
}], "Text",
 CellChangeTimes->{{3.39962695990625*^9, 3.399627090234375*^9}, {
   3.399627129671875*^9, 3.39962714234375*^9}, {3.399627173984375*^9, 
   3.3996271965625*^9}, {3.39962725721875*^9, 3.39962727084375*^9}, {
   3.399627342203125*^9, 3.399627349375*^9}, 3.39963666540625*^9, {
   3.510078659796875*^9, 3.51007867203125*^9}}]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{972, 644},
WindowMargins->{{15, Automatic}, {Automatic, 3}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 115, 2, 29, "Text"],
Cell[1666, 50, 904, 20, 65, "Text"],
Cell[2573, 72, 150, 3, 29, "Text"],
Cell[2726, 77, 2596, 81, 163, "Text"],
Cell[5325, 160, 1617, 55, 87, "Text"],
Cell[6945, 217, 284, 11, 29, "Text"],
Cell[7232, 230, 4545, 155, 235, "Text"],
Cell[11780, 387, 2423, 79, 79, "Text"],
Cell[14206, 468, 1991, 59, 151, "Text"],
Cell[16200, 529, 1726, 57, 96, "Text"],
Cell[17929, 588, 2189, 76, 150, "Text"],
Cell[20121, 666, 131, 2, 29, "Text"],
Cell[20255, 670, 2638, 95, 243, "Text"],
Cell[22896, 767, 1734, 64, 105, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[24655, 835, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[24799, 841, 194, 5, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[25008, 849, 1417, 50, 99, "Text"],
Cell[26428, 901, 1085, 40, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[27538, 945, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[27682, 951, 172, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[27869, 958, 815, 31, 62, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[28709, 993, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[28853, 999, 172, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[29040, 1006, 297, 6, 26, "Text"],
Cell[29340, 1014, 2995, 100, 125, "Text",
 Evaluatable->False],
Cell[32338, 1116, 25, 0, 29, "Text"],
Cell[32366, 1118, 2347, 76, 194, "Text"],
Cell[CellGroupData[{
Cell[34738, 1198, 274, 8, 37, "Subsection",
 Evaluatable->False],
Cell[35015, 1208, 322, 14, 29, "Text"],
Cell[35340, 1224, 2754, 79, 378, "Input"],
Cell[38097, 1305, 276, 10, 29, "Text",
 Evaluatable->False],
Cell[38376, 1317, 695, 20, 112, "Input"]
}, Closed]],
Cell[39086, 1340, 529, 21, 32, "Text",
 Evaluatable->False],
Cell[39618, 1363, 25, 0, 29, "Text"],
Cell[39646, 1365, 4886, 163, 315, "Text"],
Cell[CellGroupData[{
Cell[44557, 1532, 274, 8, 37, "Subsection",
 Evaluatable->False],
Cell[44834, 1542, 322, 14, 29, "Text"],
Cell[45159, 1558, 2915, 82, 325, "Input"],
Cell[48077, 1642, 712, 24, 47, "Text",
 Evaluatable->False],
Cell[48792, 1668, 927, 25, 135, "Input"],
Cell[49722, 1695, 276, 10, 29, "Text",
 Evaluatable->False],
Cell[50001, 1707, 696, 20, 112, "Input"]
}, Closed]],
Cell[50712, 1730, 118, 3, 26, "Text"],
Cell[50833, 1735, 528, 21, 37, "Text",
 Evaluatable->False],
Cell[51364, 1758, 25, 0, 29, "Text"],
Cell[51392, 1760, 2467, 86, 217, "Text"],
Cell[CellGroupData[{
Cell[53884, 1850, 232, 6, 37, "Subsection"],
Cell[54119, 1858, 1428, 52, 40, "Text",
 Evaluatable->False],
Cell[55550, 1912, 4921, 134, 582, "Input"],
Cell[60474, 2048, 276, 10, 29, "Text",
 Evaluatable->False],
Cell[60753, 2060, 697, 20, 112, "Input"]
}, Closed]],
Cell[61465, 2083, 98, 2, 26, "Text"],
Cell[61566, 2087, 388, 16, 36, "Text",
 Evaluatable->False],
Cell[61957, 2105, 25, 0, 29, "Text"],
Cell[61985, 2107, 3269, 102, 307, "Text"],
Cell[CellGroupData[{
Cell[65279, 2213, 279, 8, 37, "Subsection",
 Evaluatable->False],
Cell[65561, 2223, 322, 14, 29, "Text"],
Cell[65886, 2239, 2812, 78, 325, "Input"],
Cell[68701, 2319, 712, 24, 47, "Text",
 Evaluatable->False],
Cell[69416, 2345, 925, 25, 135, "Input"],
Cell[70344, 2372, 276, 10, 29, "Text",
 Evaluatable->False],
Cell[70623, 2384, 696, 20, 112, "Input"]
}, Closed]],
Cell[71334, 2407, 437, 18, 33, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[71796, 2429, 302, 9, 37, "Subsection",
 Evaluatable->False],
Cell[72101, 2440, 322, 14, 29, "Text"],
Cell[72426, 2456, 2837, 79, 325, "Input"],
Cell[75266, 2537, 712, 24, 47, "Text",
 Evaluatable->False],
Cell[75981, 2563, 924, 25, 135, "Input"],
Cell[76908, 2590, 276, 10, 29, "Text",
 Evaluatable->False],
Cell[77187, 2602, 646, 19, 92, "Input"]
}, Closed]],
Cell[77848, 2624, 524, 21, 34, "Text",
 Evaluatable->False],
Cell[78375, 2647, 25, 0, 29, "Text"],
Cell[78403, 2649, 3758, 122, 296, "Text"],
Cell[CellGroupData[{
Cell[82186, 2775, 277, 8, 37, "Subsection",
 Evaluatable->False],
Cell[82466, 2785, 407, 18, 29, "Text"],
Cell[82876, 2805, 2997, 84, 325, "Input"],
Cell[85876, 2891, 712, 24, 47, "Text",
 Evaluatable->False],
Cell[86591, 2917, 966, 26, 135, "Input"],
Cell[87560, 2945, 1733, 57, 42, "Text",
 Evaluatable->False],
Cell[89296, 3004, 5016, 136, 590, "Input"],
Cell[94315, 3142, 276, 10, 29, "Text",
 Evaluatable->False],
Cell[94594, 3154, 695, 20, 112, "Input"]
}, Closed]],
Cell[95304, 3177, 522, 20, 39, "Text",
 Evaluatable->False],
Cell[95829, 3199, 25, 0, 29, "Text"],
Cell[95857, 3201, 3936, 135, 330, "Text"],
Cell[CellGroupData[{
Cell[99818, 3340, 279, 8, 37, "Subsection",
 Evaluatable->False],
Cell[100100, 3350, 88, 2, 29, "Text"],
Cell[100191, 3354, 1142, 33, 190, "Input"],
Cell[101336, 3389, 105, 2, 29, "Text",
 Evaluatable->False],
Cell[101444, 3393, 2736, 76, 346, "Input"],
Cell[104183, 3471, 945, 36, 47, "Text",
 Evaluatable->False],
Cell[105131, 3509, 757, 22, 112, "Input"],
Cell[105891, 3533, 276, 10, 29, "Text",
 Evaluatable->False],
Cell[106170, 3545, 704, 20, 112, "Input"]
}, Closed]],
Cell[106889, 3568, 933, 21, 44, "Text"],
Cell[107825, 3591, 8899, 149, 805, "Text"],
Cell[116727, 3742, 9824, 165, 302, "Text"]
}
]
*)

(* End of internal cache information *)
