(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    180392,       6199]
NotebookOptionsPosition[    173649,       5998]
NotebookOutlinePosition[    174014,       6014]
CellTagsIndexPosition[    173971,       6011]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Complex Analysis for Mathematics and Engineering\nby \nJohn H. \
Mathews  and Russell W. Howell\n \nJones and Bartlett Learning\n\n",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Prof. John  H.  Mathews\nDepartment of Mathematics\nCalifornia \
State University Fullerton\nFullerton, CA  92634\nmathews@fullerton.edu\n\n\
Prof. Russell W. Howell\nMathematics & Computer Science Department\nWestmont  \
College\nSanta Barbara,  CA  93108\nhowell@westmont.edu  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.506707968921875*^9, 3.50670798*^9}, {
  3.506845294953125*^9, 3.50684536225*^9}, {3.53271083721875*^9, 
  3.532710860234375*^9}, {3.532710890796875*^9, 3.5327109494375*^9}},
 TextAlignment->Center,
 AspectRatioFixed->True,
 FontFamily->"Times",
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False}],

Cell[TextData[StyleBox["12.9  Inverting the Laplace Transform",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell["\<\
\tThis section is a continuation of our development of the Laplace Transforms \
in Sections 12.5-8. \
\>", "Text",
 CellChangeTimes->{{3.506805404171875*^9, 3.506805416453125*^9}}],

Cell[TextData[{
 "\tSo far, most of the applications involving the Laplace transform involves \
a transform (or part of a transform) that is expressed by \n\n",
 StyleBox["(12.36)\t",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "s", ")"}]}], "=", 
   FractionBox[
    RowBox[{"P", 
     RowBox[{"(", "s", ")"}]}], 
    RowBox[{"Q", 
     RowBox[{"(", "s", ")"}]}]]}]]],
 "  \n\n where ",
 Cell[BoxData[
  RowBox[{"P", 
   RowBox[{"(", "s", ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"Q", 
   RowBox[{"(", "s", ")"}]}]]],
 " are polynomials that have no common factors.  The inverse of ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "s", ")"}]}]]],
 " is found by using its partial fraction representation and referring to \
Table 11.2.  We now show how the theory of complex variables can be used \
systematically to find the partial fraction representation.  Theorem 11.19 is \
an extension of Example 8.7 to ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " linear factors.  We leave the proof to you. "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 12.19 (Nonrepeated Linear Factors).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 Cell[BoxData[
  RowBox[{"P", 
   RowBox[{"(", "s", ")"}]}]]],
 " be a polynomial of degree at most ",
 Cell[BoxData[
  RowBox[{"n", "-", "1"}]]],
 ".  If ",
 Cell[BoxData[
  RowBox[{"Q", 
   RowBox[{"(", "s", ")"}]}]]],
 " has degree ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ", and has distinct complex roots  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14], 
   SubscriptBox["a", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14], 
   StyleBox["...",
    FontFamily->"Times New Roman",
    FontSize->14], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->14], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14], 
   SubscriptBox["a", "n"]}]]],
 ",  then equation (12.36) becomes   \n\n",
 StyleBox["(12.37)\t",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "s", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"P", 
      RowBox[{"(", "s", ")"}]}], 
     RowBox[{"Q", 
      RowBox[{"(", "s", ")"}]}]], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"P", 
       RowBox[{"(", "s", ")"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"s", "-", 
           SubscriptBox["a", "1"]}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", 
           SubscriptBox["a", "2"]}], ")"}]}], "..."}], 
       RowBox[{"(", 
        RowBox[{"s", "-", 
         SubscriptBox["a", "n"]}], ")"}]}]], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "1"}], "n"], 
      FractionBox[
       RowBox[{"Res", "[", 
        RowBox[{"Y", ",", 
         SubscriptBox["a", "k"]}], "]"}], 
       RowBox[{"(", 
        RowBox[{"s", "-", 
         SubscriptBox["a", "k"]}], ")"}]]}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.19 is left for the reader in the \
book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Theorem 12.20 (A Repeated Linear Factors).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  If ",
 Cell[BoxData[
  RowBox[{"P", 
   RowBox[{"(", "s", ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "Q", 
   RowBox[{"(", "s", ")"}]}]]],
 " are polynomials of degree ",
 Cell[BoxData[
  RowBox[{"\[Mu]", " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "\[Nu]"}]]],
 ", respectively and ",
 Cell[BoxData[
  RowBox[{"\[Mu]", "<", 
   RowBox[{"\[Nu]", "+", "n"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Q", 
    RowBox[{"(", "a", ")"}]}], "\[NotEqual]", "0"}]]],
 ",  then equation (12.36) becomes   \n\n",
 StyleBox["(12.38)\t",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "s", ")"}]}], "=", 
   FractionBox[
    RowBox[{"P", 
     RowBox[{"(", "s", ")"}]}], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"s", " ", "-", " ", "a"}], ")"}], "n"], "Q", 
     RowBox[{"(", "s", ")"}]}]]}]]],
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "1"}], "n"], 
      FractionBox[
       SubscriptBox["A", "k"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", " ", "-", " ", "a"}], ")"}], "k"]]}], " ", "+", " ", 
     RowBox[{"R", 
      RowBox[{"(", "s", ")"}]}]}]}]}]]],
 ",  \n\nwhere  ",
 Cell[BoxData[
  RowBox[{"R", 
   RowBox[{"(", "s", ")"}]}]]],
 "  is the sum of all partial fractions that do not involve factors of the \
form  ",
 Cell[BoxData[
  StyleBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"s", " ", "-", 
      StyleBox[" ",
       FontSize->12], "a"}], ")"}], "j"],
   FontSize->12]]],
 ".  Furthermore, the coefficients  ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["A",
    FontSize->14], "k"]]],
 "  can be computed with the formula  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["A", "k"], "=", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "-", "k"}], ")"}], "!"}]], 
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"s", " ", "\[Rule]", " ", "a"}]], "  ", 
       RowBox[{
        FractionBox[
         SuperscriptBox["d", 
          RowBox[{"n", "-", "k"}]], 
         RowBox[{"d", " ", 
          SuperscriptBox["s", 
           RowBox[{"n", "-", "k"}]]}]], " ", 
        FractionBox[
         RowBox[{"P", 
          RowBox[{"(", "s", ")"}]}], 
         RowBox[{"Q", 
          RowBox[{"(", "s", ")"}]}]], "  ", "for", "  ", "k"}]}]}], "=", 
     "1"}]}], ",", "2", ",", "...", ",", "n"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.20 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 12.24.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "s", ")"}]}], "=", 
   FractionBox[
    RowBox[{
     SuperscriptBox["s", "3"], " ", "-", " ", 
     RowBox[{"4", "s"}], " ", "+", "  ", "1"}], 
    RowBox[{"s", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"s", " ", "-", " ", "1"}], ")"}], "3"]}]]}]],
  AspectRatioFixed->True],
 ".  Find  ",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    SuperscriptBox["\[ScriptCapitalL]", 
     RowBox[{"-", "1"}]],
    FontSize->16], 
   RowBox[{"(", 
    RowBox[{"Y", 
     RowBox[{"(", "s", ")"}]}], ")"}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Solution.", "Text"],

Cell[TextData[{
 "From Equations ",
 StyleBox["(12-37)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(12-37)",
  FontColor->RGBColor[0, 0, 1]],
 " we write \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["s", "3"], " ", "-", " ", 
     RowBox[{"4", "s"}], " ", "+", "  ", "1"}], 
    RowBox[{"s", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"s", " ", "-", " ", "1"}], ")"}], "3"]}]], " ", "=", " ", 
   RowBox[{
    FractionBox[
     SubscriptBox["A", "3"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"s", " ", "-", " ", "1"}], ")"}], "3"]], "+", 
    FractionBox[
     SubscriptBox["A", "2"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"s", " ", "-", " ", "1"}], ")"}], "2"]], "+", 
    FractionBox[
     SubscriptBox["A", "1"], 
     RowBox[{"s", " ", "-", " ", "1"}]], "+", 
    FractionBox[
     SubscriptBox["B", "1"], "s"]}]}]]]
}], "Text",
 CellChangeTimes->{{3.399636893234375*^9, 3.39963689490625*^9}}],

Cell[TextData[{
 "We calculate the coefficient ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["B", "1"], "=", 
   RowBox[{"-", "1"}]}]]],
 " by  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["B", "1"], " ", "=", " ", 
    RowBox[{
     RowBox[{"Res", "[", 
      RowBox[{"Y", ",", "0"}], "]"}], " ", "=", " ", 
     RowBox[{
      UnderscriptBox[
       RowBox[{" ", "lim", " "}], 
       RowBox[{"s", "\[Rule]", "0"}]], " ", "s", 
      FractionBox[
       RowBox[{
        SuperscriptBox["s", "3"], " ", "-", " ", 
        RowBox[{"4", "s"}], " ", "+", "  ", "1"}], 
       RowBox[{"s", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"s", " ", "-", " ", "1"}], ")"}], "3"]}]]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox[
       RowBox[{" ", "lim", " "}], 
       RowBox[{"s", "\[Rule]", "0"}]], " ", 
      FractionBox[
       RowBox[{
        SuperscriptBox["s", "3"], " ", "-", " ", 
        RowBox[{"4", "s"}], " ", "+", "  ", "1"}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", " ", "-", " ", "1"}], ")"}], "3"]]}], "  ", "=", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"0", " ", "-", "0", " ", "+", "  ", "1"}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", " ", "1"}], ")"}], "3"]], " ", "=", " ", 
      RowBox[{"-", "1"}]}]}]}]}]}]],
 "   "
}], "Text"],

Cell[TextData[{
 "We find the coefficients ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["A", "1"], "=", "2"}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["A", "2"], "=", "1"}]]],
 ", and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["A", "3"], "=", 
   RowBox[{"-", "2"}]}]]],
 " by using Theorem 12.20.  \n\nIn this case ",
 Cell[BoxData[
  RowBox[{"a", "=", "1"}]]],
 " and   ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"P", 
     RowBox[{"(", "s", ")"}]}], 
    RowBox[{"Q", 
     RowBox[{"(", "s", ")"}]}]], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SuperscriptBox["s", "3"], " ", "-", " ", 
     RowBox[{"4", "s"}], " ", "+", "  ", "1"}], "s"]}]]],
 ", and we get \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["A", "1"], " ", "=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox[
       RowBox[{" ", "lim", " "}], 
       RowBox[{"s", "\[Rule]", "1"}]], " ", 
      FractionBox[
       RowBox[{"P", 
        RowBox[{"(", "s", ")"}]}], 
       RowBox[{"Q", 
        RowBox[{"(", "s", ")"}]}]]}], " ", "=", " ", 
     RowBox[{
      UnderscriptBox[
       RowBox[{" ", "lim", " "}], 
       RowBox[{"s", "\[Rule]", "1"}]], " ", 
      FractionBox[
       RowBox[{
        SuperscriptBox["s", "3"], " ", "-", " ", 
        RowBox[{"4", "s"}], " ", "+", "  ", "1"}], "s"]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"1", " ", "-", " ", "4", " ", "+", "  ", "1"}], "1"], " ", "=", 
     " ", 
     RowBox[{"-", "2"}]}]}]}]}]],
 " \n\t\t\t\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["A", "2"], " ", "=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"1", "!"}]], 
      UnderscriptBox[
       RowBox[{" ", "lim", " "}], 
       RowBox[{"s", "\[Rule]", "1"}]], " ", 
      FractionBox["d", "ds"], 
      FractionBox[
       RowBox[{"P", 
        RowBox[{"(", "s", ")"}]}], 
       RowBox[{"Q", 
        RowBox[{"(", "s", ")"}]}]]}], " ", "=", " ", 
     RowBox[{
      UnderscriptBox[
       RowBox[{" ", "lim", " "}], 
       RowBox[{"s", "\[Rule]", "1"}]], " ", 
      FractionBox["d", "ds"], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         SuperscriptBox["s", "3"], " ", "-", " ", 
         RowBox[{"4", "s"}], " ", "+", "  ", "1"}], "s"], ")"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox[
       RowBox[{" ", "lim", " "}], 
       RowBox[{"s", "\[Rule]", "1"}]], " ", 
      FractionBox["d", "ds"], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], "-", "4", "+", 
        FractionBox["1", "s"]}], ")"}]}], "=", " ", 
     RowBox[{
      UnderscriptBox[
       RowBox[{" ", "lim", " "}], 
       RowBox[{"s", "\[Rule]", "1"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "s"}], " ", "-", 
        FractionBox["1", 
         SuperscriptBox["s", "2"]]}], ")"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", " ", "-", "1"}], ")"}], " ", "=", " ", "1"}]}]}]}]],
 " \n\t\t\t\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["A", "3"], " ", "=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "!"}]], 
      UnderscriptBox[
       RowBox[{" ", "lim", " "}], 
       RowBox[{"s", "\[Rule]", "1"}]], " ", 
      FractionBox[
       SuperscriptBox["d", "2"], 
       SuperscriptBox["ds", "2"]], 
      FractionBox[
       RowBox[{"P", 
        RowBox[{"(", "s", ")"}]}], 
       RowBox[{"Q", 
        RowBox[{"(", "s", ")"}]}]]}], " ", "=", " ", 
     RowBox[{
      FractionBox["1", "2"], 
      UnderscriptBox[
       RowBox[{" ", "lim", " "}], 
       RowBox[{"s", "\[Rule]", "1"}]], " ", 
      FractionBox[
       SuperscriptBox["d", "2"], 
       SuperscriptBox["ds", "2"]], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         SuperscriptBox["s", "3"], " ", "-", " ", 
         RowBox[{"4", "s"}], " ", "+", "  ", "1"}], "s"], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"     ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], 
      UnderscriptBox[
       RowBox[{" ", "lim", " "}], 
       RowBox[{"s", "\[Rule]", "1"}]], " ", 
      FractionBox[
       SuperscriptBox["d", "2"], 
       SuperscriptBox["ds", "2"]], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], "-", "4", "+", 
        FractionBox["1", "s"]}], ")"}]}], "=", " ", 
     RowBox[{
      FractionBox["1", "2"], 
      UnderscriptBox[
       RowBox[{" ", "lim", " "}], 
       RowBox[{"s", "\[Rule]", "1"}]], " ", 
      FractionBox["d", "ds"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "s"}], " ", "-", 
        FractionBox["1", 
         SuperscriptBox["s", "2"]]}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"     ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], 
      UnderscriptBox[
       RowBox[{" ", "lim", " "}], 
       RowBox[{"s", "\[Rule]", "1"}]], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        FractionBox["2", 
         SuperscriptBox["s", "3"]]}], ")"}]}], "  ", "=", " ", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"(", 
        RowBox[{"2", "+", "2"}], ")"}]}], " ", "=", " ", "2"}]}]}]}]}]],
 " "
}], "Text"],

Cell[TextData[{
 "Now substitute these values into the formula  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "s", ")"}]}], " ", "=", "  ", 
   RowBox[{
    FractionBox[
     SubscriptBox["A", "3"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"s", " ", "-", " ", "1"}], ")"}], "3"]], "+", 
    FractionBox[
     SubscriptBox["A", "2"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"s", " ", "-", " ", "1"}], ")"}], "2"]], "+", 
    FractionBox[
     SubscriptBox["A", "1"], 
     RowBox[{"s", " ", "-", " ", "1"}]], "+", 
    FractionBox[
     SubscriptBox["B", "1"], "s"]}]}]]],
 ", and get the partial fraction representation for ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "s", ")"}]}]]],
 ":  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "s", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["s", "3"], " ", "-", " ", 
      RowBox[{"4", "s"}], " ", "+", "  ", "1"}], 
     RowBox[{"s", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", " ", "-", " ", "1"}], ")"}], "3"]}]], " ", "=", " ", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["2", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", " ", "-", " ", "1"}], ")"}], "3"]]}], "+", 
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", " ", "-", " ", "1"}], ")"}], "2"]], "+", 
     FractionBox["2", 
      RowBox[{"s", " ", "-", " ", "1"}]], "-", 
     FractionBox["1", "s"]}]}]}]]],
 ","
}], "Text"],

Cell[TextData[{
 "\nThe solution ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    StyleBox[
     SuperscriptBox["\[ScriptCapitalL]", 
      RowBox[{"-", "1"}]],
     FontSize->16], 
    RowBox[{"(", 
     RowBox[{"Y", 
      RowBox[{"(", "s", ")"}]}], ")"}]}]}]]],
 " is found with the computation \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"y", 
     RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
    RowBox[{
     StyleBox[
      SuperscriptBox["\[ScriptCapitalL]", 
       RowBox[{"-", "1"}]],
      FontSize->16], 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        SuperscriptBox["s", "3"], " ", "-", " ", 
        RowBox[{"4", "s"}], " ", "+", "  ", "1"}], 
       RowBox[{"s", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"s", " ", "-", " ", "1"}], ")"}], "3"]}]], ")"}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", " ", 
    RowBox[{
     StyleBox[
      SuperscriptBox["\[ScriptCapitalL]", 
       RowBox[{"-", "1"}]],
      FontSize->16], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["2", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"s", " ", "-", " ", "1"}], ")"}], "3"]]}], "+", 
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"s", " ", "-", " ", "1"}], ")"}], "2"]], "+", 
       FractionBox["2", 
        RowBox[{"s", " ", "-", " ", "1"}]], "-", 
       FractionBox["1", "s"]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       StyleBox[
        SuperscriptBox["\[ScriptCapitalL]", 
         RowBox[{"-", "1"}]],
        FontSize->16]}], 
      RowBox[{"(", 
       FractionBox["2", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"s", " ", "-", " ", "1"}], ")"}], "3"]], ")"}]}], "+", 
     RowBox[{
      StyleBox[
       SuperscriptBox["\[ScriptCapitalL]", 
        RowBox[{"-", "1"}]],
       FontSize->16], 
      RowBox[{"(", 
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"s", " ", "-", " ", "1"}], ")"}], "2"]], ")"}]}], "+", 
     RowBox[{
      StyleBox[
       SuperscriptBox["\[ScriptCapitalL]", 
        RowBox[{"-", "1"}]],
       FontSize->16], 
      RowBox[{"(", 
       FractionBox["2", 
        RowBox[{"s", " ", "-", " ", "1"}]], ")"}]}], "-", 
     RowBox[{
      StyleBox[
       SuperscriptBox["\[ScriptCapitalL]", 
        RowBox[{"-", "1"}]],
       FontSize->16], 
      RowBox[{"(", 
       FractionBox["1", "s"], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", " ", 
       SuperscriptBox["t", "2"]}], 
      SuperscriptBox["\[ExponentialE]", "t"]}], " ", "+", " ", 
     RowBox[{"t", " ", 
      SuperscriptBox["\[ExponentialE]", "t"]}], " ", "+", " ", 
     RowBox[{"2", 
      SuperscriptBox["\[ExponentialE]", "t"]}], " ", "-", " ", "1"}]}]}]}]],
 " "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"12.24", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670752065625*^9, 3.50670752065625*^9}}],

Cell["Enter Y[s] and find its partial fraction expansion.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "a", ",", "b", ",", "s", ",", "t", ",", "Y", ",", "PQ", ",", "PR"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "s_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["s", "3"], " ", "-", " ", 
       RowBox[{"4", "s"}], " ", "+", " ", "1"}], 
      RowBox[{"s", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", "-", "1"}], ")"}], "3"]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{"Y", "[", "s", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{"Apart", "[", 
       RowBox[{"Y", "[", "s", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39964833475*^9, 3.399648335578125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Traditionally.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The partial fraction expansion can be obtained with the residue calculus. \
\n",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", "[", "s", "]"}], " ", "=", 
   RowBox[{
    FractionBox[
     RowBox[{" ", 
      SubscriptBox["a", "3"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"s", " ", "-", " ", "1"}], ")"}], "3"]], " ", "+", 
    FractionBox[
     RowBox[{" ", 
      SubscriptBox["a", "2"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"s", " ", "-", " ", "1"}], ")"}], "2"]], "+", " ", 
    FractionBox[
     SubscriptBox["a", "1"], 
     RowBox[{"s", " ", "-", " ", "1"}]], " ", "+", 
    FractionBox[
     RowBox[{" ", 
      SubscriptBox["b", "1"]}], "s"]}]}]]],
 "  \nAt  s = 1, we compute  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "1"], ",", 
   SubscriptBox["a", "2"], ",", " ", 
   RowBox[{"and", "  ", 
    SubscriptBox["a", "3"]}]}]]],
 "  as follows."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"PQ", " ", "=", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["s", "3"], " ", "-", " ", 
       RowBox[{"4", "s"}], " ", "+", " ", "1"}], "s"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "3"], " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{"PQ", ",", 
       RowBox[{"s", "\[Rule]", "1"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "2"], " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "s"], " ", "PQ"}], ",", 
       RowBox[{"s", "\[Rule]", "1"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "1"], " ", "=", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "!"}]], " ", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"s", ",", "s"}]], "PQ"}], ",", 
        RowBox[{"s", "\[Rule]", "1"}]}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(a\), \(3\)]\) = \!\(\*UnderscriptBox[\(lim\), \
\(s \[Rule] 1\)]\) \>\"", ",", "PQ", ",", "\"\< = \>\"", ",", 
      SubscriptBox["a", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(a\), \(2\)]\) = \!\(\*UnderscriptBox[\(lim\), \
\(s \[Rule] 1\)]\) \>\"", ",", 
      RowBox[{"Together", "[", 
       RowBox[{
        SubscriptBox["\[PartialD]", "s"], " ", "PQ"}], "]"}], ",", 
      "\"\< = \>\"", ",", 
      SubscriptBox["a", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(a\), \(1\)]\) = \!\(\*UnderscriptBox[\(lim\), \
\(s \[Rule] 1\)]\) \>\"", ",", 
      RowBox[{"Together", "[", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"s", ",", "s"}]], "PQ"}], "]"}], ",", "\"\< = \>\"", ",", 
      SubscriptBox["a", "1"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399648337046875*^9, 3.399648338078125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "At  s = 0, we compute  ",
 Cell[BoxData[
  SubscriptBox["b", "1"]]],
 "  as follows."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"PR", " ", "=", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["s", "3"], " ", "-", " ", 
       RowBox[{"4", "s"}], " ", "+", " ", "1"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", "-", "1"}], ")"}], "3"]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["b", "1"], " ", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{"PR", ",", 
       RowBox[{"s", "\[Rule]", "0"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(b\), \(1\)]\) = \!\(\*UnderscriptBox[\(lim\), \
\(s \[Rule] 0\)]\)\>\"", ",", "PR", ",", "\"\< = \>\"", ",", 
      SubscriptBox["b", "1"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39964833990625*^9, 3.3996483408125*^9}},
 AspectRatioFixed->True],

Cell["\<\
Using the residue calculus, we construct the partial fraction expansion.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "s_", "]"}], " ", "=", 
     RowBox[{
      FractionBox[
       RowBox[{" ", 
        SubscriptBox["a", "3"]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", " ", "-", " ", "1"}], ")"}], "3"]], " ", "+", 
      FractionBox[
       RowBox[{" ", 
        SubscriptBox["a", "2"]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", " ", "-", " ", "1"}], ")"}], "2"]], "+", " ", 
      FractionBox[
       SubscriptBox["a", "1"], 
       RowBox[{"s", " ", "-", " ", "1"}]], " ", "+", 
      FractionBox[
       RowBox[{" ", 
        SubscriptBox["b", "1"]}], "s"]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{"Y", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399648405984375*^9, 3.399648406953125*^9}}],

Cell[TextData[{
 "Use a table of Laplace transforms to solve for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "t", "]"}], "=", 
   RowBox[{
    StyleBox[
     SuperscriptBox["\[ScriptCapitalL]", 
      RowBox[{"-", "1"}]],
     FontSize->16], 
    RowBox[{"(", 
     RowBox[{"Y", "[", "s", "]"}], ")"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Ys", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"Y", "[", "s", "]"}], "]"}]}], "}"}]}], "]"}]}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"Length", "[", 
        RowBox[{"Y", "[", "s", "]"}], "]"}]}], ",", 
      RowBox[{"i", "++"}], ",", 
      RowBox[{
       SubscriptBox["Ys", 
        RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ", 
       "=", " ", 
       SubscriptBox[
        RowBox[{"Y", "[", "s", "]"}], 
        RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}]}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"yt", "=", 
     RowBox[{"InverseLaplaceTransform", "[", 
      RowBox[{"Ys", ",", " ", "s", ",", " ", "t"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"yt", ",", "Ys"}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"InverseLaplaceTransform", "[", 
      RowBox[{
       RowBox[{"Y", "[", "s", "]"}], ",", " ", "s", ",", " ", "t"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"TableForm", "[", 
      RowBox[{"table", ",", 
       RowBox[{"TableHeadings", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"None", ",", 
          RowBox[{"{", 
           RowBox[{"\"\<f[t]\>\"", ",", "\"\<\[ScriptCapitalL](f[t])\>\""}], 
           "}"}]}], "}"}]}]}], "]"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{"Y", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[t] = \>\"", ",", 
      RowBox[{"y", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399648342296875*^9, 3.399648343515625*^9}}],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can check this with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s  result using the LaplaceTransform package."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"InverseLaplaceTransform", "[", 
      RowBox[{
       RowBox[{"Y", "[", "s", "]"}], ",", " ", "s", ",", " ", "t"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{"Apart", "[", 
       RowBox[{"Y", "[", "s", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[t] = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{"y", "[", "t", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399648345078125*^9, 3.3996483461875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Alternately.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We could use the partial fraction expansion that was developed in ",
 StyleBox[ButtonBox["Section 8.1.",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/ResidueCalcMod.html"], None}],
  FontFamily->"Times New Roman",
  FontVariations->{"Underline"->True}],
 " \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["s", "3"], " ", "-", " ", 
     RowBox[{"4", "s"}], " ", "+", "  ", "1"}], 
    RowBox[{"s", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"s", " ", "-", " ", "1"}], ")"}], "3"]}]], " ", "=", " ", 
   RowBox[{
    FractionBox[
     SubscriptBox["A", "3"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"s", " ", "-", " ", "1"}], ")"}], "3"]], "+", 
    FractionBox[
     SubscriptBox["A", "2"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"s", " ", "-", " ", "1"}], ")"}], "2"]], "+", 
    FractionBox[
     SubscriptBox["A", "1"], 
     RowBox[{"s", " ", "-", " ", "1"}]], "+", 
    FractionBox[
     SubscriptBox["B", "1"], "s"]}]}]]],
 "\n\nWhere \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["B", "1"], " ", "=", " ", 
    RowBox[{
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "s", ")"}]}], ",", "0"}], "]"}], " ", "=", " ", 
     RowBox[{"-", "1"}]}]}], "\[IndentingNewLine]"}], "\n", 
  RowBox[{
   RowBox[{
    SubscriptBox["A", "1"], " ", "=", " ", 
    RowBox[{
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "s", ")"}]}], ",", "1"}], "]"}], " ", "=", " ", "2"}]}], 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{
   RowBox[{
    SubscriptBox["A", "2"], " ", "=", " ", 
    RowBox[{
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"s", "-", "1"}], ")"}], " ", "Y", 
        RowBox[{"(", "s", ")"}]}], ",", "1"}], "]"}], " ", "=", " ", "1"}]}], 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{
   SubscriptBox["A", "3"], " ", "=", " ", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", "-", "1"}], ")"}], "2"], " ", "Y", 
       RowBox[{"(", "s", ")"}]}], ",", "1"}], "]"}], " ", "=", " ", 
    RowBox[{"-", "2"}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "It is useful to notice that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can easily find these residues using the built in command  ",
 Cell[BoxData["Residue"]],
 ". "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Y", "[", "s_", "]"}], "=", 
    FractionBox[
     RowBox[{
      SuperscriptBox["s", "3"], " ", "-", " ", 
      RowBox[{"4", "s"}], " ", "+", "  ", "1"}], 
     RowBox[{"s", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", " ", "-", " ", "1"}], ")"}], "3"]}]]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399648348734375*^9, 3.399648349828125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["B", "1"], " ", "=", " ", 
   RowBox[{"Residue", "[", 
    RowBox[{
     RowBox[{"Y", "[", "s", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", "0"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.399648350671875*^9, 3.399648377484375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["A", "1"], " ", "=", " ", 
   RowBox[{"Residue", "[", 
    RowBox[{
     RowBox[{"Y", "[", "s", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", "1"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.399648352265625*^9, 3.399648378828125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["A", "2"], " ", "=", " ", 
   RowBox[{"Residue", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"s", "-", "1"}], ")"}], " ", 
      RowBox[{"Y", "[", "s", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", "1"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.39964835390625*^9, 3.399648380078125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["A", "3"], " ", "=", " ", 
   RowBox[{"Residue", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", "-", "1"}], ")"}], "2"], " ", 
      RowBox[{"Y", "[", "s", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", "1"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.399648355625*^9, 3.399648381203125*^9}}],

Cell["Then it is easy to form with the calculation", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{
      FractionBox[
       SubscriptBox["A", "3"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", " ", "-", " ", "1"}], ")"}], "3"]], "+", 
      FractionBox[
       SubscriptBox["A", "2"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", " ", "-", " ", "1"}], ")"}], "2"]], "+", 
      FractionBox[
       SubscriptBox["A", "1"], 
       RowBox[{"s", " ", "-", " ", "1"}]], "+", 
      FractionBox[
       SubscriptBox["B", "1"], "s"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{"Y", "[", "s", "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399648358390625*^9, 3.399648359234375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Theorem 12.21 (Irreducible Quadratic Factors).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 Cell[BoxData[
  RowBox[{"P", 
   RowBox[{"(", "s", ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "Q", 
   RowBox[{"(", "s", ")"}]}]]],
 " be polynomials with real coefficients such that the degree of ",
 Cell[BoxData[
  RowBox[{"P", 
   RowBox[{"(", "s", ")"}]}]]],
 " is at most 1 larger than the degree of ",
 Cell[BoxData[
  RowBox[{"Q", 
   RowBox[{"(", "s", ")"}]}]]],
 ".   If  ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", "s", ")"}]}]]],
 "  does not have a factor of the form  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"s", "-", "a"}], ")"}], "2"], "+", 
   SuperscriptBox["b", "2"]}]]],
 ",  then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "s", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"P", 
      RowBox[{"(", "s", ")"}]}], 
     RowBox[{"Q", 
      RowBox[{"(", "s", ")"}]}]], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"P", 
       RowBox[{"(", "s", ")"}]}], 
      RowBox[{
       RowBox[{"[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"s", " ", "-", " ", "a"}], ")"}], "2"], " ", "+", " ", 
         SuperscriptBox["b", "2"]}], "]"}], "T", 
       RowBox[{"(", "s", ")"}]}]], " ", "=", " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"2", "A", 
         RowBox[{"(", 
          RowBox[{"s", " ", "-", " ", "a"}], ")"}]}], " ", "-", " ", 
        RowBox[{"2", "B", " ", "b"}]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"s", " ", "-", " ", "a"}], ")"}], "2"], " ", "+", " ", 
        SuperscriptBox["b", "2"]}]], " ", "+", " ", 
      RowBox[{"R", 
       RowBox[{"(", "s", ")"}]}]}]}]}]}]]],
 ",  \nwhere  \n\n",
 StyleBox["(12.21)\t",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "B"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{"P", 
     RowBox[{"(", 
      RowBox[{"a", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}]}], 
    RowBox[{
     RowBox[{"Q", "'"}], 
     RowBox[{"(", 
      RowBox[{"a", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}]}]]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.21 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 12.25.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "s", ")"}]}], "=", 
   FractionBox[
    RowBox[{"5", "s"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", "+", " ", "4"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", "+", " ", "9"}], ")"}]}]]}]],
  AspectRatioFixed->True],
 ".  Find  ",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    SuperscriptBox["\[ScriptCapitalL]", 
     RowBox[{"-", "1"}]],
    FontSize->16], 
   RowBox[{"(", 
    RowBox[{"Y", 
     RowBox[{"(", "s", ")"}]}], ")"}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Solution.", "Text"],

Cell[TextData[{
 "\tThis solution is a little tedious and illustrates how Theorem 12.21 is \
applied to obtain the partial fraction expansion of ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "s", ")"}]}]]],
 " when two irreducible quadratic factors are involved."
}], "Text"],

Cell[TextData[{
 "Here we have ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", 
    RowBox[{"(", "s", ")"}]}], " ", "=", " ", 
   RowBox[{"5", "s"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Q", 
    RowBox[{"(", "s", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", "+", " ", "4"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", "+", " ", "9"}], ")"}]}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["s", "4"], "+", 
     RowBox[{"13", " ", 
      SuperscriptBox["s", "2"]}], "+", "36"}]}]}]]],
 ",  and the roots of ",
 Cell[BoxData[
  RowBox[{"Q", 
   RowBox[{"(", "s", ")"}]}]]],
 " occur at ",
 Cell[BoxData[
  RowBox[{"0", "\[PlusMinus]", 
   RowBox[{"2", "\[ImaginaryI]"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"0", "\[PlusMinus]", 
   RowBox[{"3", "\[ImaginaryI]"}]}]]],
 ".  The derivative of   ",
 Cell[BoxData[
  RowBox[{"Q", 
   RowBox[{"(", "s", ")"}]}]]],
 "  is ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"Q", "'"}], 
    RowBox[{"(", "s", ")"}]}], "=", 
   RowBox[{
    RowBox[{"4", " ", 
     SuperscriptBox["s", "3"]}], "+", 
    RowBox[{"26", " ", "s"}]}]}]]],
 ".  Computing the residues at  at ",
 Cell[BoxData[
  RowBox[{"2", "\[ImaginaryI]"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"3", "\[ImaginaryI]"}]]],
 " yields\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{"Y", ",", 
     RowBox[{"2", "i"}]}], "]"}], "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox[
      RowBox[{"P", 
       RowBox[{"(", 
        RowBox[{"2", "\[ImaginaryI]"}], ")"}]}], 
      RowBox[{
       RowBox[{"Q", "'"}], 
       RowBox[{"(", 
        RowBox[{"2", "\[ImaginaryI]"}], ")"}]}]], ")"}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"5", 
       RowBox[{"(", 
        RowBox[{"2", "\[ImaginaryI]"}], ")"}]}], 
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"2", "\[ImaginaryI]"}], ")"}], "3"]}], "+", 
       RowBox[{"26", " ", 
        RowBox[{"(", 
         RowBox[{"2", "\[ImaginaryI]"}], ")"}]}]}]], "=", 
     RowBox[{
      FractionBox[
       RowBox[{"10", "\[ImaginaryI]"}], 
       RowBox[{
        RowBox[{
         RowBox[{"-", "32"}], " ", "\[ImaginaryI]"}], "+", 
        RowBox[{"52", " ", "\[ImaginaryI]"}]}]], " ", "=", " ", 
      FractionBox["1", "2"]}]}]}]}]]],
 ",  \n\t\tand\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{"Y", ",", 
     RowBox[{"3", "i"}]}], "]"}], "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox[
      RowBox[{"P", 
       RowBox[{"(", 
        RowBox[{"3", "\[ImaginaryI]"}], ")"}]}], 
      RowBox[{
       RowBox[{"Q", "'"}], 
       RowBox[{"(", 
        RowBox[{"3", "\[ImaginaryI]"}], ")"}]}]], ")"}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"5", 
       RowBox[{"(", 
        RowBox[{"3", "\[ImaginaryI]"}], ")"}]}], 
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"3", "\[ImaginaryI]"}], ")"}], "3"]}], "+", 
       RowBox[{"26", " ", 
        RowBox[{"(", 
         RowBox[{"3", "\[ImaginaryI]"}], ")"}]}]}]], "=", 
     RowBox[{
      FractionBox[
       RowBox[{"15", "\[ImaginaryI]"}], 
       RowBox[{
        RowBox[{
         RowBox[{"-", "108"}], " ", "\[ImaginaryI]"}], "+", 
        RowBox[{"78", " ", "\[ImaginaryI]"}]}]], "=", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]}]}]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "The above residues are used to determine the values in Equation ",
 StyleBox["(12-21)",
  FontColor->RGBColor[0, 0, 1]],
 ", and we get \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["A", "1"], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["B", "1"]}]}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"P", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "1"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["b", "1"]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"Q", "'"}], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "1"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["b", "1"]}]}], ")"}]}]], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"P", 
       RowBox[{"(", 
        RowBox[{"2", "\[ImaginaryI]"}], ")"}]}], 
      RowBox[{
       RowBox[{"Q", "'"}], 
       RowBox[{"(", 
        RowBox[{"2", "\[ImaginaryI]"}], ")"}]}]], "=", "  ", 
     RowBox[{
      FractionBox["1", "2"], "+", 
      RowBox[{"0", " ", "\[ImaginaryI]"}]}]}]}]}]]],
 "  \n\t\tand\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["A", "2"], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["B", "2"]}]}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"P", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "2"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["b", "2"]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"Q", "'"}], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "2"], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["b", "2"]}]}], ")"}]}]], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"P", 
       RowBox[{"(", 
        RowBox[{"3", "\[ImaginaryI]"}], ")"}]}], 
      RowBox[{
       RowBox[{"Q", "'"}], 
       RowBox[{"(", 
        RowBox[{"3", "\[ImaginaryI]"}], ")"}]}]], "=", " ", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], "+", 
      RowBox[{"0", " ", "\[ImaginaryI]"}]}]}]}]}]]],
 " "
}], "Text",
 CellChangeTimes->{3.39963690084375*^9}],

Cell[TextData[{
 "We find that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["A", "1"], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["B", "1"]}]}], "=", 
   RowBox[{
    FractionBox["1", "2"], "+", 
    RowBox[{"0", " ", "\[ImaginaryI]"}]}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["A", "2"], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["B", "2"]}]}], "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], "+", 
    RowBox[{"0", " ", "\[ImaginaryI]"}]}]}]]],
 ", which correspond to ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["a", "1"], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["b", "1"]}]}], "=", 
   RowBox[{"0", "+", 
    RowBox[{"2", "\[ImaginaryI]"}]}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["a", "2"], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["b", "2"]}]}], "=", 
   RowBox[{"0", "+", 
    RowBox[{"3", "\[ImaginaryI]"}]}]}]]],
 ",  respectively.  Applying the formula in Theorem 12.21 we obtain \n\n\t\t\t\
",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "s", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"2", 
       RowBox[{"(", 
        SubscriptBox["A", "1"], ")"}], 
       RowBox[{"(", 
        RowBox[{"s", " ", "-", " ", 
         SubscriptBox["a", "1"]}], ")"}]}], " ", "-", " ", 
      RowBox[{"2", 
       RowBox[{"(", 
        SubscriptBox["B", "1"], " ", ")"}], 
       RowBox[{"(", 
        SubscriptBox["b", "1"], ")"}]}]}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", " ", "-", " ", 
         SubscriptBox["a", "1"]}], ")"}], "2"], " ", "+", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SubscriptBox["b", "1"], ")"}], "2"]}]], " ", "+", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"2", 
       SubscriptBox["A", "2"], 
       RowBox[{"(", 
        RowBox[{"s", " ", "-", " ", 
         SubscriptBox["a", "2"]}], ")"}]}], " ", "-", " ", 
      RowBox[{"2", 
       RowBox[{"(", 
        SubscriptBox["B", "2"], " ", ")"}], 
       RowBox[{"(", 
        SubscriptBox["b", "2"], ")"}]}]}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", " ", "-", " ", 
         SubscriptBox["a", "2"]}], ")"}], "2"], " ", "+", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SubscriptBox["b", "2"], ")"}], "2"]}]]}]}]]],
 "  \n\t\t\t\nwhich becomes\t\t\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "s", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"2", 
       RowBox[{"(", 
        FractionBox["1", "2"], ")"}], 
       RowBox[{"(", 
        RowBox[{"s", " ", "-", " ", "0"}], ")"}]}], " ", "-", " ", 
      RowBox[{"2", 
       RowBox[{"(", "0", " ", ")"}], 
       RowBox[{"(", "2", ")"}]}]}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", " ", "-", " ", "0"}], ")"}], "2"], " ", "+", " ", 
      SuperscriptBox[
       RowBox[{"(", "2", ")"}], "2"]}]], " ", "+", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"-", 
         FractionBox["1", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"s", " ", "-", " ", "0"}], ")"}]}], " ", "-", " ", 
      RowBox[{"2", 
       RowBox[{"(", "0", ")"}], 
       RowBox[{"(", "3", ")"}]}]}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", " ", "-", " ", "0"}], ")"}], "2"], " ", "+", " ", 
      SuperscriptBox[
       RowBox[{"(", "3", ")"}], "2"]}]]}]}]]],
 " \n\t\t\t\nand is simplified as\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "s", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["s", 
     RowBox[{
      SuperscriptBox["s", "2"], "+", "4"}]], " ", "-", 
    FractionBox["s", 
     RowBox[{
      SuperscriptBox["s", "2"], "+", "9"}]]}]}]]],
 ".\n\t\t\t\nFinally   ",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    SuperscriptBox["\[ScriptCapitalL]", 
     RowBox[{"-", "1"}]],
    FontSize->16], 
   RowBox[{"(", 
    RowBox[{"Y", 
     RowBox[{"(", "s", ")"}]}], ")"}]}]]],
 "is found with the calculation \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     StyleBox[
      SuperscriptBox["\[ScriptCapitalL]", 
       RowBox[{"-", "1"}]],
      FontSize->16], 
     RowBox[{"(", 
      RowBox[{"Y", 
       RowBox[{"(", "s", ")"}]}], ")"}]}], " ", "=", " ", 
    RowBox[{
     StyleBox[
      SuperscriptBox["\[ScriptCapitalL]", 
       RowBox[{"-", "1"}]],
      FontSize->16], 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"5", "s"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["s", "2"], " ", "+", " ", "4"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["s", "2"], " ", "+", " ", "9"}], ")"}]}]], ")"}]}]}],
    "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                          ", 
   RowBox[{"=", " ", 
    RowBox[{
     StyleBox[
      SuperscriptBox["\[ScriptCapitalL]", 
       RowBox[{"-", "1"}]],
      FontSize->16], 
     RowBox[{"(", 
      RowBox[{
       FractionBox["s", 
        RowBox[{
         SuperscriptBox["s", "2"], "+", "4"}]], " ", "-", 
       FractionBox["s", 
        RowBox[{
         SuperscriptBox["s", "2"], "+", "9"}]]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                          ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      StyleBox[
       SuperscriptBox["\[ScriptCapitalL]", 
        RowBox[{"-", "1"}]],
       FontSize->16], 
      RowBox[{"(", 
       FractionBox["s", 
        RowBox[{
         SuperscriptBox["s", "2"], "+", 
         SuperscriptBox["2", "2"]}]], ")"}]}], " ", "-", " ", 
     RowBox[{
      StyleBox[
       SuperscriptBox["\[ScriptCapitalL]", 
        RowBox[{"-", "1"}]],
       FontSize->16], 
      RowBox[{"(", 
       FractionBox["s", 
        RowBox[{
         SuperscriptBox["s", "2"], "+", 
         SuperscriptBox["3", "2"]}]], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                          ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"cos", 
      RowBox[{"(", 
       RowBox[{"2", "t"}], ")"}]}], "  ", "-", "  ", 
     RowBox[{"cos", 
      RowBox[{"(", 
       RowBox[{"3", "t"}], ")"}]}]}]}]}]}]],
 " "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"12.25", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.50670752865625*^9, 3.50670752865625*^9}}],

Cell["Enter Y[s] and find its partial fraction expansion.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "a", ",", "A", ",", "b", ",", "B", ",", "s", ",", "t", ",", "Y", ",", 
      "z", ",", "i", ",", "res1", ",", "res2", ",", "Yi"}], "]"}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "s_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"5", "s"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["s", "2"], "+", "4"}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["s", "2"], "+", "9"}], ")"}]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{"Y", "[", "s", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{"Apart", "[", 
       RowBox[{"Y", "[", "s", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399648433609375*^9, 3.399648434296875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Traditionally.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The partial fraction expansion can be obtained with the residue calculus. \
\nThe simple poles in the upper half plane occur at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{"2", "\[ImaginaryI]", " ", "and", "  ", 
     SubscriptBox["z", "2"]}], "=", 
    RowBox[{"3", "\[ImaginaryI]"}]}]}]]],
 ".  First determine their residues."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], " ", "=", " ", 
     RowBox[{"2", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], " ", "=", " ", 
     RowBox[{"3", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"res1", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"Y", "[", "s", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"s", ",", 
         SubscriptBox["z", "1"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"res2", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"Y", "[", "s", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"s", ",", 
         SubscriptBox["z", "2"]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{"Y", "[", "s", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[Y[s],\>\"", ",", 
      SubscriptBox["z", "1"], ",", "\"\<] = \>\"", ",", "res1"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[Y[s],\>\"", ",", 
      SubscriptBox["z", "2"], ",", "\"\<] = \>\"", ",", "res2"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399648435453125*^9, 3.39964843634375*^9}},
 AspectRatioFixed->True],

Cell["\<\
Using the residue calculus, we construct the partial fraction expansion.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["a", "1"], " ", "=", " ", 
     RowBox[{"Re", "[", 
      SubscriptBox["z", "1"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["b", "1"], " ", "=", " ", 
     RowBox[{"Im", "[", 
      SubscriptBox["z", "1"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["A", "1"], " ", "=", " ", 
     RowBox[{"Re", "[", "res1", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["B", "1"], " ", "=", " ", 
     RowBox[{"Im", "[", "res1", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "2"], " ", "=", " ", 
     RowBox[{"Re", "[", 
      SubscriptBox["z", "2"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["b", "2"], " ", "=", " ", 
     RowBox[{"Im", "[", 
      SubscriptBox["z", "2"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["A", "2"], "=", " ", 
     RowBox[{"Re", "[", "res2", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["B", "2"], " ", "=", " ", 
     RowBox[{"Im", "[", "res2", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Y1", "[", "s_", "]"}], " ", "=", 
     FractionBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubscriptBox["A", "1"], 
         RowBox[{"(", 
          RowBox[{"s", " ", "-", " ", 
           SubscriptBox["a", "1"]}], ")"}]}], " ", "-", " ", 
        RowBox[{"2", " ", 
         SubscriptBox["B", "1"], " ", 
         SubscriptBox["b", "1"]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"s", " ", "-", " ", 
           SubscriptBox["a", "1"]}], ")"}], "2"], " ", "+", " ", 
        SuperscriptBox[
         SubscriptBox["b", "1"], "2"]}], ")"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Y2", "[", "s_", "]"}], " ", "=", 
     FractionBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubscriptBox["A", "2"], 
         RowBox[{"(", 
          RowBox[{"s", " ", "-", " ", 
           SubscriptBox["a", "2"]}], ")"}]}], " ", "-", " ", 
        RowBox[{"2", " ", 
         SubscriptBox["B", "2"], " ", 
         SubscriptBox["b", "2"]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"s", " ", "-", " ", 
           SubscriptBox["a", "2"]}], ")"}], "2"], " ", "+", " ", 
        SuperscriptBox[
         SubscriptBox["b", "2"], "2"]}], ")"}]]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "s_", "]"}], "=", 
     RowBox[{
      RowBox[{"Y1", "[", "s", "]"}], " ", "+", " ", 
      RowBox[{"Y2", "[", "s", "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(Y\), \(1\)]\)[s] = \>\"", ",", 
      RowBox[{"Y1", "[", "s", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(Y\), \(2\)]\)[s] = \>\"", ",", 
      RowBox[{"Y2", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< Y[s] = \>\"", ",", 
      RowBox[{"Y", "[", "s", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3996484380625*^9, 3.399648439921875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use a table of Laplace transforms to solve for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "t", "]"}], "=", 
   RowBox[{
    StyleBox[
     SuperscriptBox["\[ScriptCapitalL]", 
      RowBox[{"-", "1"}]],
     FontSize->16], 
    RowBox[{"(", 
     RowBox[{"Y", "[", "s", "]"}], ")"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Ys", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"Y", "[", "s", "]"}], "]"}]}], "}"}]}], "]"}]}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"Length", "[", 
        RowBox[{"Y", "[", "s", "]"}], "]"}]}], ",", 
      RowBox[{"i", "++"}], ",", 
      RowBox[{
       SubscriptBox["Ys", 
        RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ", 
       "=", " ", 
       SubscriptBox[
        RowBox[{"Y", "[", "s", "]"}], 
        RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}]}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"yt", "=", 
     RowBox[{"InverseLaplaceTransform", "[", 
      RowBox[{"Ys", ",", " ", "s", ",", " ", "t"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"yt", ",", "Ys"}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"InverseLaplaceTransform", "[", 
      RowBox[{
       RowBox[{"Y", "[", "s", "]"}], ",", " ", "s", ",", " ", "t"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"TableForm", "[", 
      RowBox[{"table", ",", 
       RowBox[{"TableHeadings", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"None", ",", 
          RowBox[{"{", 
           RowBox[{"\"\<f[t]\>\"", ",", "\"\<\[ScriptCapitalL](f[t])\>\""}], 
           "}"}]}], "}"}]}]}], "]"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{"Y", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[t] = \>\"", ",", 
      RowBox[{"y", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3996484415*^9, 3.39964844259375*^9}}],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can check this with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s  result using the LaplaceTransform package."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"InverseLaplaceTransform", "[", 
      RowBox[{
       RowBox[{"Y", "[", "s", "]"}], ",", " ", "s", ",", " ", "t"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{"Apart", "[", 
       RowBox[{"Y", "[", "s", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[t] = \>\"", ",", 
      RowBox[{"y", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39964844428125*^9, 3.399648445*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Alternately.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We could the methods of partial fraction expansion that were developed in \
",
 StyleBox[ButtonBox["Section 8.1.",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/ResidueCalcMod.html"], None}],
  FontFamily->"Times New Roman",
  FontVariations->{"Underline"->True}],
 "  \nAll we would need to do is consider complex terms in the denominator. \n\
\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"5", "s"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], " ", "+", " ", "4"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], " ", "+", " ", "9"}], ")"}]}]], " ", "=", 
    " ", 
    FractionBox[
     RowBox[{"5", "s"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"s", " ", "-", " ", 
        RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"s", " ", "+", " ", 
        RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"s", " ", "-", " ", 
        RowBox[{"3", "\[ImaginaryI]"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"s", " ", "+", " ", 
        RowBox[{"3", "\[ImaginaryI]"}]}], ")"}]}]]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                           ", 
   RowBox[{"=", 
    RowBox[{
     FractionBox[
      SubscriptBox["A", "1"], 
      RowBox[{"s", " ", "-", " ", 
       RowBox[{"2", "\[ImaginaryI]"}]}]], "+", 
     FractionBox[
      SubscriptBox["A", "2"], 
      RowBox[{"s", " ", "+", " ", 
       RowBox[{"2", "\[ImaginaryI]"}]}]], "+", 
     FractionBox[
      SubscriptBox["A", "3"], 
      RowBox[{"s", " ", "-", " ", 
       RowBox[{"3", "\[ImaginaryI]"}]}]], "+", 
     FractionBox[
      SubscriptBox["A", "4"], 
      RowBox[{"s", " ", "+", " ", 
       RowBox[{"3", "\[ImaginaryI]"}]}]]}]}]}]}]],
 " \n\nWhere \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["A", "1"], " ", "=", " ", 
    RowBox[{
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "s", ")"}]}], ",", 
       RowBox[{"2", "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
     FractionBox["1", "2"]}]}], "\[IndentingNewLine]"}], "\n", 
  RowBox[{
   RowBox[{
    SubscriptBox["A", "2"], " ", "=", " ", 
    RowBox[{
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "s", ")"}]}], ",", 
       RowBox[{
        RowBox[{"-", "2"}], "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
     FractionBox["1", "2"]}]}], "\[IndentingNewLine]"}], "\n", 
  RowBox[{
   RowBox[{
    SubscriptBox["A", "3"], " ", "=", " ", 
    RowBox[{
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "s", ")"}]}], ",", 
       RowBox[{"3", "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
     RowBox[{"-", 
      FractionBox["1", "2"]}]}]}], "\[IndentingNewLine]"}], "\n", 
  RowBox[{
   SubscriptBox["A", "4"], " ", "=", " ", 
   RowBox[{
    RowBox[{"Res", "[", " ", 
     RowBox[{
      RowBox[{"Y", 
       RowBox[{"(", "s", ")"}]}], ",", 
      RowBox[{
       RowBox[{"-", "3"}], "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
    RowBox[{"-", 
     FractionBox["1", "2"]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "It is useful to notice that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can easily find these residues using the built in command  ",
 Cell[BoxData["Residue"]],
 ". "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Y", "[", "s_", "]"}], "=", 
    FractionBox[
     RowBox[{"5", "s"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], " ", "+", " ", "4"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], " ", "+", " ", "9"}], ")"}]}]]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399648447921875*^9, 3.399648448703125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["A", "1"], " ", "=", " ", 
   RowBox[{"Residue", "[", 
    RowBox[{
     RowBox[{"Y", "[", "s", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", 
       RowBox[{"2", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{3.39964845071875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["A", "2"], " ", "=", " ", 
   RowBox[{"Residue", "[", 
    RowBox[{
     RowBox[{"Y", "[", "s", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", 
       RowBox[{
        RowBox[{"-", "2"}], "\[ImaginaryI]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{3.39964845178125*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["A", "3"], " ", "=", " ", 
   RowBox[{"Residue", "[", 
    RowBox[{
     RowBox[{"Y", "[", "s", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", 
       RowBox[{"3", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{3.399648452671875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["A", "4"], " ", "=", " ", 
   RowBox[{"Residue", "[", 
    RowBox[{
     RowBox[{"Y", "[", "s", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", 
       RowBox[{
        RowBox[{"-", "3"}], "\[ImaginaryI]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.399648453625*^9, 3.39964846184375*^9}, 
   3.399648500265625*^9}],

Cell["Then it is easy to form with the calculation", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{
      FractionBox[
       SubscriptBox["A", "1"], 
       RowBox[{"s", " ", "-", " ", 
        RowBox[{"2", "\[ImaginaryI]"}]}]], "+", 
      FractionBox[
       SubscriptBox["A", "2"], 
       RowBox[{"s", " ", "+", " ", 
        RowBox[{"2", "\[ImaginaryI]"}]}]], "+", 
      FractionBox[
       SubscriptBox["A", "3"], 
       RowBox[{"s", " ", "-", " ", 
        RowBox[{"3", "\[ImaginaryI]"}]}]], "+", 
      FractionBox[
       SubscriptBox["A", "4"], 
       RowBox[{"s", " ", "+", " ", 
        RowBox[{"3", "\[ImaginaryI]"}]}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{"Y", "[", "s", "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39964845596875*^9, 3.399648456890625*^9}}],

Cell["\<\
It takes a bit of work to collect the two fractions involving the irreducible \
quadratics.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"t1", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Together", "[", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "\[ImaginaryI]"}], "+", "s"}], ")"}]}]],
         "+", 
        FractionBox["1", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "\[ImaginaryI]"}], "+", "s"}], ")"}]}]]}], 
       "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y1", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"Numerator", "[", "t1", "]"}], "/", 
      RowBox[{"Factor", "[", 
       RowBox[{"Denominator", "[", "t1", "]"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"t2", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Together", "[", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], "+", "s"}], ")"}]}]],
         "+", 
        FractionBox["1", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "\[ImaginaryI]"}], "+", "s"}], ")"}]}]]}], 
       "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y2", "[", "s_", "]"}], "=", " ", 
     RowBox[{
      RowBox[{"Numerator", "[", "t2", "]"}], "/", 
      RowBox[{"Factor", "[", 
       RowBox[{"Denominator", "[", "t2", "]"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{
       RowBox[{"Y1", "[", "s", "]"}], "+", 
       RowBox[{"Y2", "[", "s", "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3996484584375*^9, 3.39964845971875*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 12.26.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "s", ")"}]}], "=", 
   FractionBox[
    RowBox[{
     SuperscriptBox["s", "3"], " ", "+", " ", 
     RowBox[{"3", 
      SuperscriptBox["s", "2"]}], " ", "-", " ", "s", " ", "+", " ", "1"}], 
    RowBox[{"s", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"s", " ", "+", " ", "1"}], ")"}], "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", "+", " ", "1"}], ")"}]}]]}]]],
 ".  Find  ",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    SuperscriptBox["\[ScriptCapitalL]", 
     RowBox[{"-", "1"}]],
    FontSize->16], 
   RowBox[{"(", 
    RowBox[{"Y", 
     RowBox[{"(", "s", ")"}]}], ")"}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Solution.", "Text"],

Cell[TextData[{
 "\tThis solution is a little tedious and illustrates how Theorems 12.20 and \
12.21 are applied to obtain the partial fraction expansion of ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "s", ")"}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "The partial fraction expression for ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "s", ")"}]}]]],
 " has the form \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "s", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["D", "s"], " ", "+", " ", 
    FractionBox[
     SubscriptBox["C", "1"], 
     RowBox[{"s", "+", "1"}]], " ", "+", " ", 
    FractionBox[
     SubscriptBox["C", "2"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"s", "+", "1"}], ")"}], "2"]], " ", "+", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"2", " ", "A", " ", 
       RowBox[{"(", 
        RowBox[{"s", "-", "0"}], ")"}]}], "-", 
      RowBox[{"2", " ", "B"}]}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", "-", "0"}], ")"}], "2"], "+", 
      SuperscriptBox["1", "2"]}]]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "First, we calculate the coefficient ",
 Cell[BoxData[
  RowBox[{"D", "=", "1"}]]],
 ".  In the denominator of ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "s", ")"}]}]]],
 " the linear factor ",
 Cell[BoxData[
  RowBox[{"(", "s", ")"}]]],
 " is nonrepeated, so we have \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"D", "=", 
    RowBox[{
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "s", ")"}]}], ",", "0"}], "]"}], "=", " ", 
     RowBox[{
      UnderscriptBox[
       RowBox[{" ", "lim", " "}], 
       RowBox[{"s", "\[Rule]", "0"}]], " ", 
      RowBox[{"(", 
       RowBox[{"s", 
        FractionBox[
         RowBox[{
          SuperscriptBox["s", "3"], "+", 
          RowBox[{"3", 
           SuperscriptBox["s", "2"]}], "-", "s", "+", "1"}], 
         RowBox[{"s", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"s", "+", "1"}], ")"}], "2"], 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["s", "2"], "+", "1"}], ")"}]}]]}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox[
      RowBox[{" ", "lim", " "}], 
      RowBox[{"s", "\[Rule]", "0"}]], " ", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        SuperscriptBox["s", "3"], "+", 
        RowBox[{"3", 
         SuperscriptBox["s", "2"]}], "-", "s", "+", "1"}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"s", "+", "1"}], ")"}], "2"], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["s", "2"], "+", "1"}], ")"}]}]], ")"}]}], " ", "=", 
    " ", 
    RowBox[{
     FractionBox[
      RowBox[{"0", " ", "+", " ", 
       RowBox[{"3", "*", "0"}], " ", "-", " ", "0", " ", "+", " ", "1"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"0", "+", "1"}], ")"}], "2"], 
       RowBox[{"(", 
        RowBox[{"0", "+", "1"}], ")"}]}]], " ", "=", " ", "1"}]}]}]}]],
 " \n"
}], "Text"],

Cell[TextData[{
 "Second, we calculate the coefficients ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["C", "1"], "=", 
   RowBox[{"-", "2"}]}]]],
 ", and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["C", "2"], "=", 
   RowBox[{"-", "2"}]}]]],
 " by using Theorem 12.20.  In this case ",
 Cell[BoxData[
  RowBox[{"a", "=", 
   RowBox[{"-", "1"}]}]]],
 " and   ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"P", 
     RowBox[{"(", "s", ")"}]}], 
    RowBox[{"Q", 
     RowBox[{"(", "s", ")"}]}]], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SuperscriptBox["s", "3"], " ", "+", " ", 
     RowBox[{"3", 
      SuperscriptBox["s", "2"]}], " ", "-", " ", "s", " ", "+", " ", "1"}], 
    RowBox[{"s", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", "+", " ", "1"}], ")"}]}]]}]]],
 ".   In the denominator of ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "s", ")"}]}]]],
 " the term ",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"s", "+", "1"}], ")"}], "2"]]],
 " is a repeated factor, so we have  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["C", "1"], "  ", "=", " ", 
    RowBox[{
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "s", ")"}]}], ",", 
       RowBox[{"-", "1"}]}], "]"}], " ", "=", "  ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"1", "!"}]], 
      UnderscriptBox[
       RowBox[{" ", "lim", " "}], 
       RowBox[{"s", "\[Rule]", 
        RowBox[{"-", "1"}]}]], " ", 
      FractionBox["d", "ds"], 
      FractionBox[
       RowBox[{"P", 
        RowBox[{"(", "s", ")"}]}], 
       RowBox[{"Q", 
        RowBox[{"(", "s", ")"}]}]]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"=", " ", 
    RowBox[{
     UnderscriptBox[
      RowBox[{" ", "lim", " "}], 
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "1"}]}]], " ", 
     FractionBox["d", "ds"], 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        SuperscriptBox["s", "3"], " ", "+", " ", 
        RowBox[{"3", 
         SuperscriptBox["s", "2"]}], " ", "-", " ", "s", " ", "+", " ", "1"}], 
       RowBox[{"s", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["s", "2"], " ", "+", " ", "1"}], ")"}]}]], ")"}]}]}],
    "  ", "\n"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"=", " ", 
    RowBox[{
     UnderscriptBox[
      RowBox[{" ", "lim", " "}], 
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "1"}]}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", " ", "3"}], " ", 
        SuperscriptBox["s", "4"]}], " ", "+", " ", 
       RowBox[{"4", " ", 
        SuperscriptBox["s", "3"]}], " ", "-", " ", "1"}], 
      RowBox[{
       SuperscriptBox["s", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["s", "2"], " ", "+", " ", "1"}], ")"}], "2"]}]]}]}], 
   "  ", "\[IndentingNewLine]"}], "\n", 
  RowBox[{"      ", 
   RowBox[{
    RowBox[{"=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "3"}], " ", "-", "4", "-", "1"}], 
      RowBox[{"1", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "1"}], ")"}], "2"]}]]}], " ", "=", "  ", 
    RowBox[{"-", "2"}], " "}]}]}]],
 " \n\n\t\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["C", "2"], " ", "=", " ", 
    RowBox[{
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"s", "+", "1"}], ")"}], "Y", 
        RowBox[{"(", "s", ")"}]}], ",", 
       RowBox[{"-", "1"}]}], "]"}], " ", "=", " ", 
     RowBox[{
      UnderscriptBox[
       RowBox[{" ", "lim", " "}], 
       RowBox[{"s", "\[Rule]", 
        RowBox[{"-", "1"}]}]], " ", 
      FractionBox[
       RowBox[{"P", 
        RowBox[{"(", "s", ")"}]}], 
       RowBox[{"Q", 
        RowBox[{"(", "s", ")"}]}]]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"=", " ", 
    RowBox[{
     UnderscriptBox[
      RowBox[{" ", "lim", " "}], 
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "1"}]}]], " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["s", "3"], " ", "+", " ", 
       RowBox[{"3", 
        SuperscriptBox["s", "2"]}], " ", "-", " ", "s", " ", "+", " ", "1"}], 
      RowBox[{"s", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["s", "2"], " ", "+", " ", "1"}], ")"}]}]]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], " ", "+", " ", "3", " ", "+", " ", "1", " ", "+", 
       " ", "1"}], 
      RowBox[{
       RowBox[{"-", "1"}], 
       RowBox[{"(", 
        RowBox[{"1", " ", "+", " ", "1"}], ")"}]}]], " ", "=", " ", 
     RowBox[{"-", "2"}]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "Third, we calculate the coefficients ",
 Cell[BoxData[
  RowBox[{"A", "=", 
   FractionBox["1", "2"]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"B", "=", 
   RowBox[{"-", 
    FractionBox["1", "2"]}]}]]],
 "  by using Theorem 12.21.  Here we have ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", 
    RowBox[{"(", "s", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["s", "3"], "+", 
    RowBox[{"3", 
     SuperscriptBox["s", "2"]}], "-", "s", "+", "1"}]}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Q", 
    RowBox[{"(", "s", ")"}]}], "=", 
   RowBox[{"s", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"s", "+", "1"}], ")"}], "2"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["s", "2"], "+", "1"}], ")"}]}]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"Q", "'"}], 
    RowBox[{"(", "s", ")"}]}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"s", "+", "1"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"5", " ", 
       SuperscriptBox["s", "3"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["s", "2"]}], "+", 
      RowBox[{"3", " ", "s"}], "+", "1"}], ")"}]}]}]]],
 ".  In the denominator of ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "s", ")"}]}]]],
 " the factor ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["s", "2"], "+", "1"}], ")"}]]],
 " is an irreducible quadratic, with roots ",
 Cell[BoxData[
  RowBox[{"0", "\[PlusMinus]", "\[ImaginaryI]"}]]],
 ", so that \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"Y", ",", "\[ImaginaryI]"}], "]"}], "=", 
    RowBox[{"(", 
     FractionBox[
      RowBox[{"P", 
       RowBox[{"(", "\[ImaginaryI]", ")"}]}], 
      RowBox[{
       RowBox[{"Q", "'"}], 
       RowBox[{"(", "\[ImaginaryI]", ")"}]}]], ")"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                    ", 
   RowBox[{"=", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ImaginaryI]", "3"], " ", "+", " ", 
      RowBox[{"3", 
       SuperscriptBox["\[ImaginaryI]", "2"]}], " ", "-", " ", "\[ImaginaryI]",
       " ", "+", " ", "1"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[ImaginaryI]", "+", "1"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", " ", 
         SuperscriptBox["\[ImaginaryI]", "3"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["\[ImaginaryI]", "2"]}], "+", 
        RowBox[{"3", " ", "\[ImaginaryI]"}], "+", "1"}], ")"}], " "}]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                    ", 
   RowBox[{"=", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "-", " ", 
      RowBox[{"3", "\[ImaginaryI]"}], " ", "-", " ", "\[ImaginaryI]", " ", 
      "+", " ", "1"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[ImaginaryI]", "+", "1"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "5"}], " ", "\[ImaginaryI]"}], "-", 
        RowBox[{"3", " ", "\[ImaginaryI]"}], "+", 
        RowBox[{"3", " ", "\[ImaginaryI]"}], "+", "1"}], ")"}], " "}]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                    ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"1", "-", 
       RowBox[{"5", " ", "\[ImaginaryI]"}]}], 
      RowBox[{"6", "-", 
       RowBox[{"4", " ", "\[ImaginaryI]", " "}]}]], " ", "=", " ", 
     FractionBox[
      RowBox[{"1", "-", "\[ImaginaryI]"}], "2"]}]}]}]}]],
 "   \n\nHence we have ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"A", "+", 
    RowBox[{"\[ImaginaryI]", " ", "B"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{"1", "-", "\[ImaginaryI]"}], "2"]}]]],
 ".  Or if you prefer taking limits then we can use the calculation \n\n\t\t\t\
",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"A", "+", 
     RowBox[{"\[ImaginaryI]", " ", "B"}]}], " ", "=", 
    RowBox[{
     RowBox[{"Res", "[", 
      RowBox[{"Y", ",", "\[ImaginaryI]"}], "]"}], "=", " ", 
     RowBox[{
      UnderscriptBox[
       RowBox[{" ", "lim", " "}], 
       RowBox[{"s", "\[Rule]", "\[ImaginaryI]"}]], 
      FractionBox[
       RowBox[{
        SuperscriptBox["s", "3"], " ", "+", " ", 
        RowBox[{"3", 
         SuperscriptBox["s", "2"]}], " ", "-", " ", "s", " ", "+", " ", "1"}], 
       RowBox[{"s", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"s", " ", "+", " ", "1"}], ")"}], "2"], 
        RowBox[{"(", 
         RowBox[{"s", " ", "+", " ", "\[ImaginaryI]"}], ")"}]}]]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ImaginaryI]", "3"], " ", "+", " ", 
       RowBox[{"3", 
        SuperscriptBox["\[ImaginaryI]", "2"]}], " ", "-", " ", 
       "\[ImaginaryI]", " ", "+", " ", "1"}], 
      RowBox[{"\[ImaginaryI]", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"\[ImaginaryI]", " ", "+", " ", "1"}], ")"}], "2"], 
       RowBox[{"(", 
        RowBox[{"\[ImaginaryI]", " ", "+", " ", "\[ImaginaryI]"}], ")"}]}]], 
     " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "-", " ", "3", " ", "-", " ", 
       "\[ImaginaryI]", " ", "+", " ", "1"}], 
      RowBox[{"\[ImaginaryI]", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"\[ImaginaryI]", " ", "+", " ", "1"}], ")"}], "2"], 
       RowBox[{"(", 
        RowBox[{"\[ImaginaryI]", " ", "+", " ", "\[ImaginaryI]"}], 
        ")"}]}]]}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "2"}], "-", 
       RowBox[{"2", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "4"}], " ", "\[ImaginaryI]"}]], " ", "=", " ", 
     FractionBox[
      RowBox[{"1", "-", "\[ImaginaryI]"}], "2"]}]}]}]}]],
 "\n\nEither way, we obtain ",
 Cell[BoxData[
  RowBox[{"A", "=", 
   FractionBox["1", "2"]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"B", "=", 
   RowBox[{"-", 
    FractionBox["1", "2"]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Now substitute these values into the formula  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "s", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["D", "s"], " ", "+", " ", 
    FractionBox[
     SubscriptBox["C", "1"], 
     RowBox[{"s", "+", "1"}]], " ", "+", " ", 
    FractionBox[
     SubscriptBox["C", "2"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"s", "+", "1"}], ")"}], "2"]], " ", "+", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"2", " ", "A", " ", 
       RowBox[{"(", 
        RowBox[{"s", "-", "0"}], ")"}]}], "-", 
      RowBox[{"2", " ", "B"}]}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", "-", "0"}], ")"}], "2"], "+", 
      SuperscriptBox["1", "2"]}]]}]}]]],
 ", and get the partial fraction representation for ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "s", ")"}]}]]],
 ":  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Y", 
     RowBox[{"(", "s", ")"}]}], " ", "=", " ", 
    RowBox[{
     FractionBox["1", "s"], " ", "+", " ", 
     FractionBox[
      RowBox[{"-", "2"}], 
      RowBox[{"s", "+", "1"}]], " ", "+", " ", 
     FractionBox[
      RowBox[{"-", "2"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", "+", "1"}], ")"}], "2"]], " ", "+", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         FractionBox["1", "2"], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"s", "-", "0"}], ")"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"-", 
          FractionBox["1", "2"]}], ")"}]}]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", "-", "0"}], ")"}], "2"], "+", 
       SuperscriptBox["1", "2"]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox["1", "s"], " ", "-", " ", 
     FractionBox["2", 
      RowBox[{"s", "+", "1"}]], " ", "-", " ", 
     FractionBox["2", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", "+", "1"}], ")"}], "2"]], " ", "+", " ", 
     FractionBox["s", 
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       SuperscriptBox["1", "2"]}]], " ", "+", " ", 
     FractionBox["1", 
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       SuperscriptBox["1", "2"]}]], " "}]}]}]}]],
 " "
}], "Text"],

Cell[TextData[{
 "Now we use Table 12.2 to get  \n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     StyleBox[
      SuperscriptBox["\[ScriptCapitalL]", 
       RowBox[{"-", "1"}]],
      FontSize->16], 
     RowBox[{"(", 
      RowBox[{"Y", 
       RowBox[{"(", "s", ")"}]}], ")"}]}], " ", "=", " ", 
    RowBox[{
     StyleBox[
      SuperscriptBox["\[ScriptCapitalL]", 
       RowBox[{"-", "1"}]],
      FontSize->16], 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "s"], " ", "-", " ", 
       FractionBox["2", 
        RowBox[{"s", "+", "1"}]], " ", "-", " ", 
       FractionBox["2", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"s", "+", "1"}], ")"}], "2"]], " ", "+", " ", 
       FractionBox["s", 
        RowBox[{
         SuperscriptBox["s", "2"], "+", 
         SuperscriptBox["1", "2"]}]], " ", "+", " ", 
       FractionBox["1", 
        RowBox[{
         SuperscriptBox["s", "2"], "+", 
         SuperscriptBox["1", "2"]}]]}], ")"}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{" ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      StyleBox[
       SuperscriptBox["\[ScriptCapitalL]", 
        RowBox[{"-", "1"}]],
       FontSize->16], 
      RowBox[{"(", 
       FractionBox["1", "s"], ")"}]}], "-", 
     RowBox[{
      StyleBox[
       SuperscriptBox["\[ScriptCapitalL]", 
        RowBox[{"-", "1"}]],
       FontSize->16], 
      RowBox[{"(", 
       FractionBox["2", 
        RowBox[{"s", "+", "1"}]], ")"}]}], "-", 
     RowBox[{
      StyleBox[
       SuperscriptBox["\[ScriptCapitalL]", 
        RowBox[{"-", "1"}]],
       FontSize->16], 
      RowBox[{"(", 
       FractionBox["2", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"s", "+", "1"}], ")"}], "2"]], ")"}]}], "+", 
     RowBox[{
      StyleBox[
       SuperscriptBox["\[ScriptCapitalL]", 
        RowBox[{"-", "1"}]],
       FontSize->16], 
      RowBox[{"(", 
       FractionBox["s", 
        RowBox[{
         SuperscriptBox["s", "2"], "+", 
         SuperscriptBox["1", "2"]}]], ")"}]}], "+", 
     RowBox[{
      StyleBox[
       SuperscriptBox["\[ScriptCapitalL]", 
        RowBox[{"-", "1"}]],
       FontSize->16], 
      RowBox[{"(", 
       FractionBox["1", 
        RowBox[{
         SuperscriptBox["s", "2"], "+", 
         SuperscriptBox["1", "2"]}]], ")"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{" ", 
   RowBox[{"=", "  ", 
    RowBox[{"1", " ", "-", " ", 
     RowBox[{"2", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "t"}]]}], " ", "-", " ", 
     RowBox[{"2", "t", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "t"}]]}], " ", "+", " ", 
     RowBox[{"cos", 
      RowBox[{"(", "t", ")"}]}], "+", " ", 
     RowBox[{"sin", 
      RowBox[{"(", "t", ")"}]}]}]}]}]}]],
 " "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"12.26", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506707533546875*^9, 3.506707533546875*^9}}],

Cell["Enter Y[s] and find its partial fraction expansion.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"i", ",", "s", ",", "t", ",", "y", ",", "Y", ",", "Yi"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "s_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["s", "3"], "+", 
       RowBox[{"3", 
        SuperscriptBox["s", "2"]}], "-", "s", "+", "1"}], 
      RowBox[{"s", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", "+", "1"}], ")"}], "2"], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["s", "2"], "+", "1"}], ")"}]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{"Y", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "s_", "]"}], " ", "=", 
     RowBox[{"Apart", "[", 
      RowBox[{"Y", "[", "s", "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{"Y", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "s_", "]"}], " ", "=", 
     RowBox[{"Map", "[", 
      RowBox[{"Simplify", ",", 
       RowBox[{"ExpandAll", "[", 
        RowBox[{"Y", "[", "s", "]"}], "]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{"Y", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399648509109375*^9, 3.3996485110625*^9}}],

Cell[TextData[{
 "Use a table of Laplace transforms to solve for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "t", "]"}], "=", 
   RowBox[{
    StyleBox[
     SuperscriptBox["\[ScriptCapitalL]", 
      RowBox[{"-", "1"}]],
     FontSize->16], 
    RowBox[{"(", 
     RowBox[{"Y", "[", "s", "]"}], ")"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Ys", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"Y", "[", "s", "]"}], "]"}]}], "}"}]}], "]"}]}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"Length", "[", 
        RowBox[{"Y", "[", "s", "]"}], "]"}]}], ",", 
      RowBox[{"i", "++"}], ",", 
      RowBox[{
       SubscriptBox["Ys", 
        RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]], " ", 
       "=", " ", 
       SubscriptBox[
        RowBox[{"Y", "[", "s", "]"}], 
        RowBox[{"\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]]}]}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"yt", "=", 
     RowBox[{"InverseLaplaceTransform", "[", 
      RowBox[{"Ys", ",", " ", "s", ",", " ", "t"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"table", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"yt", ",", "Ys"}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"InverseLaplaceTransform", "[", 
      RowBox[{
       RowBox[{"Y", "[", "s", "]"}], ",", " ", "s", ",", " ", "t"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"TableForm", "[", 
      RowBox[{"table", ",", 
       RowBox[{"TableHeadings", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"None", ",", 
          RowBox[{"{", 
           RowBox[{"\"\<f[t]\>\"", ",", "\"\<\[ScriptCapitalL](f[t])\>\""}], 
           "}"}]}], "}"}]}]}], "]"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{"Y", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[t] = \>\"", ",", 
      RowBox[{"y", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399648513859375*^9, 3.39964851515625*^9}}],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can check this with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s  result using the LaplaceTransform package."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"InverseLaplaceTransform", "[", 
      RowBox[{
       RowBox[{"Y", "[", "s", "]"}], ",", " ", "s", ",", " ", "t"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{"Y", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[t] = \>\"", ",", 
      RowBox[{"y", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399648517*^9, 3.39964851796875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Alternately.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We could the methods of partial fraction expansion that were developed in \
",
 StyleBox[ButtonBox["Section 8.1.",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/ResidueCalcMod.html"], None}],
  FontFamily->"Times New Roman",
  FontVariations->{"Underline"->True}],
 "  \nAll we would need to do is consider complex terms in the denominator. \n\
\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["s", "3"], " ", "+", " ", 
      RowBox[{"3", 
       SuperscriptBox["s", "2"]}], " ", "-", " ", "s", " ", "+", " ", "1"}], 
     RowBox[{"s", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", " ", "+", " ", "1"}], ")"}], "2"], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], " ", "+", " ", "1"}], ")"}]}]], " ", "=", 
    FractionBox[
     RowBox[{
      SuperscriptBox["s", "3"], " ", "+", " ", 
      RowBox[{"3", 
       SuperscriptBox["s", "2"]}], " ", "-", " ", "s", " ", "+", " ", "1"}], 
     RowBox[{"s", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", " ", "+", " ", "1"}], ")"}], "2"], 
      RowBox[{"(", 
       RowBox[{"s", " ", "-", " ", "\[ImaginaryI]"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"s", " ", "+", " ", "\[ImaginaryI]"}], ")"}]}]]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                           ", 
   RowBox[{"=", 
    RowBox[{
     FractionBox["A", "s"], " ", "+", " ", 
     FractionBox[
      SubscriptBox["B", "1"], 
      RowBox[{"s", "+", "1"}]], " ", "+", " ", 
     FractionBox[
      SubscriptBox["B", "2"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", "+", "1"}], ")"}], "2"]], "+", 
     FractionBox[
      SubscriptBox["C", "1"], 
      RowBox[{"s", " ", "-", " ", "\[ImaginaryI]"}]], "+", 
     FractionBox[
      SubscriptBox["C", "2"], 
      RowBox[{"s", " ", "+", " ", "\[ImaginaryI]"}]]}]}]}]}]],
 " \n\nWhere \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"A", "=", 
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "s", ")"}]}], ",", "0"}], "]"}]}], "\[IndentingNewLine]",
     "\[IndentingNewLine]", 
    RowBox[{
     SubscriptBox["B", "1"], "  ", "=", " ", 
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "s", ")"}]}], ",", 
       RowBox[{"-", "1"}]}], "]"}]}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubscriptBox["B", "2"], " ", "=", " ", 
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"s", "+", "1"}], ")"}], "Y", 
        RowBox[{"(", "s", ")"}]}], ",", 
       RowBox[{"-", "1"}]}], "]"}]}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubscriptBox["C", "1"], " ", "=", " ", 
     RowBox[{
      RowBox[{"Res", "[", 
       RowBox[{
        RowBox[{"Y", 
         RowBox[{"(", "s", ")"}]}], ",", "\[ImaginaryI]"}], "]"}], " ", "=", 
      " ", 
      FractionBox["1", "2"]}]}], "\n", "\[IndentingNewLine]", 
    RowBox[{
     SubscriptBox["C", "2"], " ", "=", " ", 
     RowBox[{
      RowBox[{"Res", "[", 
       RowBox[{
        RowBox[{"Y", 
         RowBox[{"(", "s", ")"}]}], ",", 
        RowBox[{"-", "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
      FractionBox["1", "2"]}]}]}]}]]],
 "  "
}], "Text"],

Cell[TextData[{
 "It is useful to notice that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can easily find these residues using the built in command  ",
 Cell[BoxData["Residue"]],
 ". "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Y", "[", "s_", "]"}], "=", 
    FractionBox[
     RowBox[{
      SuperscriptBox["s", "3"], " ", "+", " ", 
      RowBox[{"3", 
       SuperscriptBox["s", "2"]}], " ", "-", " ", "s", " ", "+", " ", "1"}], 
     RowBox[{"s", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"s", " ", "+", " ", "1"}], ")"}], "2"], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], " ", "+", " ", "1"}], ")"}]}]]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399648520890625*^9, 3.399648521671875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "   ", 
  RowBox[{"A", " ", "=", " ", 
   RowBox[{"Residue", "[", 
    RowBox[{
     RowBox[{"Y", "[", "s", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", "0"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{3.39964852353125*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["B", "1"], "  ", "=", " ", 
   RowBox[{"Residue", "[", 
    RowBox[{
     RowBox[{"Y", "[", "s", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", 
       RowBox[{"-", "1"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{3.399648524234375*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["B", "2"], " ", "=", " ", 
   RowBox[{"Residue", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"s", "+", "1"}], ")"}], 
      RowBox[{"Y", "[", "s", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", 
       RowBox[{"-", "1"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{3.39964852521875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["C", "1"], " ", "=", " ", 
   RowBox[{"Residue", "[", 
    RowBox[{
     RowBox[{"Y", "[", "s", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", "\[ImaginaryI]"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{3.3996485261875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["C", "2"], " ", "=", " ", 
   RowBox[{"Residue", "[", 
    RowBox[{
     RowBox[{"Y", "[", "s", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", 
       RowBox[{"-", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{3.399648527359375*^9}],

Cell["Then it is easy to form with the calculation", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{
      FractionBox["A", "s"], " ", "+", " ", 
      FractionBox[
       SubscriptBox["B", "1"], 
       RowBox[{"s", "+", "1"}]], " ", "+", " ", 
      FractionBox[
       SubscriptBox["B", "2"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", "+", "1"}], ")"}], "2"]], "+", 
      FractionBox[
       SubscriptBox["C", "1"], 
       RowBox[{"s", " ", "-", " ", "\[ImaginaryI]"}]], "+", 
      FractionBox[
       SubscriptBox["C", "2"], 
       RowBox[{"s", " ", "+", " ", "\[ImaginaryI]"}]]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{"Y", "[", "s", "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399648532171875*^9, 3.399648533140625*^9}}],

Cell["\<\
It takes a bit of work to collect the two fractions involving the irreducible \
quadratics.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"t1", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Together", "[", 
       RowBox[{
        FractionBox[
         RowBox[{
          FractionBox["1", "2"], "-", 
          FractionBox["\[ImaginaryI]", "2"]}], 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], "+", "s"}]], "+", 
        FractionBox[
         RowBox[{
          FractionBox["1", "2"], "+", 
          FractionBox["\[ImaginaryI]", "2"]}], 
         RowBox[{"\[ImaginaryI]", "+", "s"}]]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y1", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"Numerator", "[", "t1", "]"}], "/", 
      RowBox[{"Factor", "[", 
       RowBox[{"Denominator", "[", "t1", "]"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{
       FractionBox["A", "s"], " ", "+", " ", 
       FractionBox[
        SubscriptBox["B", "1"], 
        RowBox[{"s", "+", "1"}]], " ", "+", " ", 
       FractionBox[
        SubscriptBox["B", "2"], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"s", "+", "1"}], ")"}], "2"]], "+", 
       RowBox[{"Y1", "[", "s", "]"}]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{
       FractionBox["A", "s"], " ", "+", " ", 
       FractionBox[
        SubscriptBox["B", "1"], 
        RowBox[{"s", "+", "1"}]], " ", "+", " ", 
       FractionBox[
        SubscriptBox["B", "2"], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"s", "+", "1"}], ")"}], "2"]], "+", 
       RowBox[{"Expand", "[", 
        RowBox[{"Y1", "[", "s", "]"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399648535078125*^9, 3.399648536171875*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 12.27.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use Laplace transforms to solve the system \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "'"}], 
      RowBox[{"(", "t", ")"}]}], "=", "   ", 
     RowBox[{
      RowBox[{
       RowBox[{"y", 
        RowBox[{"(", "t", ")"}]}], " ", "-", "  ", 
       RowBox[{"x", 
        RowBox[{"(", "t", ")"}], "      ", 
        StyleBox["with",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "    ", "y", 
        RowBox[{"(", "0", ")"}]}]}], "=", "1"}]}], 
    StyleBox[";",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "'"}], 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"5", "y", 
      RowBox[{"(", "t", ")"}]}], "-", 
     RowBox[{"3", "x", 
      RowBox[{"(", "t", ")"}], "       ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "    ", "x", 
      RowBox[{"(", "0", ")"}]}]}], "=", 
    StyleBox[
     RowBox[{"2", 
      StyleBox[".",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]]}]}]}]],
 "   "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.047619 0.47619 0.0561849 0.561849 [
[.28571 .04368 -9 -9 ]
[.28571 .04368 9 0 ]
[.52381 .04368 -3 -9 ]
[.52381 .04368 3 0 ]
[.7619 .04368 -9 -9 ]
[.7619 .04368 9 0 ]
[1 .04368 -3 -9 ]
[1 .04368 3 0 ]
[1.025 .05618 0 -6.28125 ]
[1.025 .05618 10 6.28125 ]
[.03512 .19665 -24 -4.5 ]
[.03512 .19665 0 4.5 ]
[.03512 .33711 -18 -4.5 ]
[.03512 .33711 0 4.5 ]
[.03512 .47757 -24 -4.5 ]
[.03512 .47757 0 4.5 ]
[.03512 .61803 -6 -4.5 ]
[.03512 .61803 0 4.5 ]
[.04762 .64303 -5 0 ]
[.04762 .64303 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.28571 .05618 m
.28571 .06243 L
s
[(0.5)] .28571 .04368 0 1 Mshowa
.52381 .05618 m
.52381 .06243 L
s
[(1)] .52381 .04368 0 1 Mshowa
.7619 .05618 m
.7619 .06243 L
s
[(1.5)] .7619 .04368 0 1 Mshowa
1 .05618 m
1 .06243 L
s
[(2)] 1 .04368 0 1 Mshowa
0 .05618 m
1 .05618 L
s
gsave
1.025 .05618 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.04762 .19665 m
.05387 .19665 L
s
[(0.25)] .03512 .19665 1 0 Mshowa
.04762 .33711 m
.05387 .33711 L
s
[(0.5)] .03512 .33711 1 0 Mshowa
.04762 .47757 m
.05387 .47757 L
s
[(0.75)] .03512 .47757 1 0 Mshowa
.04762 .61803 m
.05387 .61803 L
s
[(1)] .03512 .61803 1 0 Mshowa
.04762 0 m
.04762 .61803 L
s
gsave
.04762 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
1 .61803 m
.88753 .50548 L
.74387 .39129 L
.60572 .29723 L
.48016 .22097 L
.36096 .15556 L
.26357 .10715 L
.17975 .06967 L
.11747 .04513 L
.07301 .03022 L
.05562 .02532 L
.04001 .02164 L
.034 .02048 L
.02826 .01956 L
.02575 .01923 L
.02351 .01897 L
.02147 .01879 L
.01968 .01866 L
.01874 .01861 L
.01826 .01859 L
.01776 .01857 L
.01735 .01855 L
.01691 .01854 L
.01651 .01854 L
.01615 .01853 L
.01593 .01853 L
.0157 .01853 L
.01528 .01853 L
.01488 .01854 L
.01452 .01854 L
.01414 .01855 L
.01373 .01857 L
.01292 .01861 L
.01225 .01866 L
.01165 .01871 L
.0104 .01886 L
.00938 .01902 L
.0084 .01923 L
.00743 .0195 L
.00664 .01977 L
.00588 .02009 L
.00516 .02047 L
.00459 .02086 L
.00413 .02124 L
.00374 .02165 L
.00344 .02204 L
.00317 .02249 L
.00306 .02273 L
.00296 .023 L
.00288 .02324 L
Mistroke
.00283 .02348 L
.00279 .02371 L
.00277 .02384 L
.00275 .02395 L
.00274 .02409 L
.00274 .02417 L
.00274 .02425 L
.00273 .02439 L
.00273 .02452 L
.00274 .0246 L
.00274 .02467 L
.00275 .02482 L
.00276 .0249 L
.00276 .02497 L
.00278 .02514 L
.00283 .02541 L
.00289 .02571 L
.00305 .02631 L
.00326 .02691 L
.00353 .02754 L
.00414 .02869 L
.00599 .03133 L
.01063 .03615 L
.01654 .04098 L
.02246 .0451 L
.02845 .04879 L
.03361 .05164 L
.03784 .05377 L
.04152 .05544 L
.04428 .05654 L
.04627 .05723 L
.04636 .05726 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{374, 231.063},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 373}, {230.063, 0}} -> {0, 0, 0, 0}}],
 " \n\t\t\t\tA graph of the solution."
}], "Text"],

Cell["Solution.", "Text"],

Cell[TextData[{
 "We let ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "s", ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"X", 
   RowBox[{"(", "s", ")"}]}]]],
 " denote the Laplace transforms of ",
 Cell[BoxData[
  RowBox[{"y", 
   RowBox[{"(", "t", ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"x", 
   RowBox[{"(", "t", ")"}]}]]],
 ", respectively.  Taking the transforms of the two differential equations \
gives  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"s", " ", "Y", 
      RowBox[{"(", "s", ")"}]}], "-", "1"}], " ", "=", "    ", 
    RowBox[{
     RowBox[{"Y", 
      RowBox[{"(", "s", ")"}]}], "  ", "-", "  ", 
     RowBox[{"X", 
      RowBox[{"(", "s", ")"}]}]}]}], 
   StyleBox[";",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}], "\[IndentingNewLine]", 
  StyleBox["and",
   FontFamily->"Times New Roman",
   FontSize->12,
   FontWeight->"Plain",
   FontSlant->"Plain",
   FontVariations->{"StrikeThrough"->False,
   "Underline"->False},
   FontColor->GrayLevel[0]], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"s", " ", "X", 
     RowBox[{"(", "s", ")"}]}], "-", "2"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"5", "Y", 
     RowBox[{"(", "s", ")"}]}], " ", "-", 
    RowBox[{"3", "X", 
     RowBox[{
      RowBox[{"(", "s", ")"}], 
      StyleBox[".",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}]}]}]],
 "\n\nwhich can be written as  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"s", "-", "1"}], ")"}], "Y", 
       RowBox[{"(", "s", ")"}]}], "      ", "+", "        ", 
      RowBox[{"X", 
       RowBox[{"(", "s", ")"}]}]}], " ", "=", " ", "1"}], 
    StyleBox[";",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}], " "}], "\[IndentingNewLine]", 
  StyleBox["and",
   FontFamily->"Times New Roman",
   FontSize->12,
   FontWeight->"Plain",
   FontSlant->"Plain",
   FontVariations->{"StrikeThrough"->False,
   "Underline"->False},
   FontColor->GrayLevel[0]], "\n", 
  RowBox[{"           ", 
   RowBox[{
    RowBox[{
     RowBox[{"5", "Y", 
      RowBox[{"(", "s", ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"s", "+", "3"}], ")"}], "X", 
      RowBox[{"(", "s", ")"}]}]}], " ", "=", " ", 
    RowBox[{"-", 
     StyleBox[
      RowBox[{"2", 
       StyleBox[".",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "We use Cramer's rule to solve for ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "s", ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"X", 
   RowBox[{"(", "s", ")"}]}]]],
 " : \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "s", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"|", GridBox[{
        {"1", "1"},
        {
         RowBox[{"-", "2"}], 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"s", "+", "3"}], ")"}]}]}
       }], "|"}], 
     RowBox[{"|", GridBox[{
        {
         RowBox[{"(", 
          RowBox[{"s", "-", "1"}], ")"}], "1"},
        {"5", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"s", "+", "3"}], ")"}]}]}
       }], "|"}]], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"s", "+", "3"}], ")"}]}], " ", "-", " ", 
       RowBox[{"(", 
        RowBox[{"-", "2"}], ")"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"s", "-", "1"}], ")"}]}], 
        RowBox[{"(", 
         RowBox[{"s", "+", "3"}], ")"}]}], " ", "-", " ", "5"}]], " ", "=", 
     " ", 
     FractionBox[
      RowBox[{"s", "+", "1"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", "+", "1"}], ")"}], "2"], "+", "1"}]]}]}]}]]],
 " \n\t\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "s", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"|", GridBox[{
        {
         RowBox[{"(", 
          RowBox[{"s", "-", "1"}], ")"}], "1"},
        {"5", 
         RowBox[{"-", "2"}]}
       }], "|"}], 
     RowBox[{"|", GridBox[{
        {
         RowBox[{"(", 
          RowBox[{"s", "-", "1"}], ")"}], "1"},
        {"5", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"s", "+", "3"}], ")"}]}]}
       }], "|"}]], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], 
        RowBox[{"(", 
         RowBox[{"s", "-", "1"}], ")"}]}], " ", "-", " ", "5"}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"s", "-", "1"}], ")"}]}], 
        RowBox[{"(", 
         RowBox[{"s", "+", "3"}], ")"}]}], " ", "-", " ", "5"}]], " ", "=", 
     " ", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", "s"}], "+", "3"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", "+", "1"}], ")"}], "2"], "+", "1"}]]}]}]}]]]
}], "Text"],

Cell[TextData[{
 "We obtain the desired solution by computing the inverse transforms:\n\n\t\t\
\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"y", 
     RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
    RowBox[{
     StyleBox[
      SuperscriptBox["\[ScriptCapitalL]", 
       RowBox[{"-", "1"}]],
      FontSize->16], 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"(", 
        RowBox[{"s", "+", "1"}], ")"}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"s", "+", "1"}], ")"}], "2"], " ", "+", " ", 
        SuperscriptBox["1", "2"]}]], ")"}]}]}], " "}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "t"}]], "cos", 
     RowBox[{"(", "t", ")"}]}]}]}]}]],
 " \n\t\t\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"x", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    StyleBox[
     SuperscriptBox["\[ScriptCapitalL]", 
      RowBox[{"-", "1"}]],
     FontSize->16], 
    RowBox[{"(", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"s", "+", "1"}], ")"}]}], "+", "1"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"s", "+", "1"}], ")"}], "2"], "+", 
       SuperscriptBox["1", "2"]}]], ")"}]}]}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"2", 
      StyleBox[
       SuperscriptBox["\[ScriptCapitalL]", 
        RowBox[{"-", "1"}]],
       FontSize->16], 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"(", 
         RowBox[{"s", "+", "1"}], ")"}], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"s", "+", "1"}], ")"}], "2"], "+", 
         SuperscriptBox["1", "2"]}]], ")"}]}], " ", "+", " ", 
     RowBox[{
      StyleBox[
       SuperscriptBox["\[ScriptCapitalL]", 
        RowBox[{"-", "1"}]],
       FontSize->16], 
      RowBox[{"(", 
       FractionBox["1", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"s", "+", "1"}], ")"}], "2"], "+", 
         SuperscriptBox["1", "2"]}]], ")"}]}]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"2", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "t"}]], "cos", 
      RowBox[{"(", "t", ")"}]}], " ", "+", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "t"}]], "sin", 
      RowBox[{"(", "t", ")"}], " "}]}]}]}]}]],
 " \n"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Explore", " ", "Solution", " ", 
   RowBox[{"12.27", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.5067075375625*^9, 3.5067075375625*^9}}],

Cell["\<\
Enter the initial conditions and the system of  D.E.s.  Then Laplace \
transform the D.E.s and solve for the transforms Y[s] any X[s] and the \
functions y[t] and x[t].\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "eqn1", ",", "eqn2", ",", "solset", ",", "s", ",", "t", ",", "x", ",", 
      "X", ",", "y", ",", "Y", ",", "x0", ",", "y0"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"de1", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "'"}], "[", "t", "]"}], " ", "\[Equal]", "   ", 
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "  ", "-", "  ", 
       RowBox[{"x", "[", "t", "]"}]}]}]}], " ", ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"de2", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
      RowBox[{
       RowBox[{"5", 
        RowBox[{"y", "[", "t", "]"}]}], " ", "-", " ", 
       RowBox[{"3", 
        RowBox[{"x", "[", "t", "]"}]}]}]}]}], " ", ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"y0", " ", "=", " ", "1"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"x0", " ", "=", " ", "2"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqn1", "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"de1", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "t", "]"}], "\[Rule]", 
          RowBox[{"X", "[", "s", "]"}]}], ",", 
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "\[Rule]", 
          RowBox[{"Y", "[", "s", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "'"}], "[", "t", "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"s", " ", 
            RowBox[{"Y", "[", "s", "]"}]}], "-", "y0"}]}]}], "}"}]}], "]"}]}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqn2", "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"de2", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "t", "]"}], "\[Rule]", 
          RowBox[{"X", "[", "s", "]"}]}], ",", 
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "\[Rule]", 
          RowBox[{"Y", "[", "s", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "'"}], "[", "t", "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"s", " ", 
            RowBox[{"X", "[", "s", "]"}]}], "-", "x0"}]}]}], "}"}]}], "]"}]}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "de1", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "de2", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", "y0"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[0] = \>\"", ",", "x0"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "eqn1", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "eqn2", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"eqn1", ",", "eqn2"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"X", "[", "s", "]"}], ",", 
         RowBox[{"Y", "[", "s", "]"}]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "s_", "]"}], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "s_", "]"}], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "2", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"InverseLaplaceTransform", "[", 
      RowBox[{
       RowBox[{"Y", "[", "s", "]"}], ",", " ", "s", ",", " ", "t"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "t_", "]"}], " ", "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"y", "[", "t", "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"InverseLaplaceTransform", "[", 
      RowBox[{
       RowBox[{"X", "[", "s", "]"}], ",", " ", "s", ",", " ", "t"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "t_", "]"}], " ", "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"x", "[", "t", "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{"Y", "[", "s", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<X[s] = \>\"", ",", 
      RowBox[{"X", "[", "s", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[t] = \>\"", ",", 
      RowBox[{"y", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[t] = \>\"", ",", 
      RowBox[{"x", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399648555015625*^9, 3.399648557109375*^9}}],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can substitute y[t] and x[t] into the D.E.'s and verify that they are \
the solution."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<        y'[t] = \>\"", ",", 
      RowBox[{
       RowBox[{"y", "'"}], "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  y[t] - x[t] = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "-", 
        RowBox[{"x", "[", "t", "]"}]}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  Does  y'[t] = y[t] - x[t] ? \>\"", ",", 
      RowBox[{"ExpandAll", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "-", 
         RowBox[{"x", "[", "t", "]"}]}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<        x'[t] = \>\"", ",", 
      RowBox[{
       RowBox[{"x", "'"}], "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<        x'[t] = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"x", "'"}], "[", "t", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<5y[t] - 3x[t] = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"5", 
         RowBox[{"y", "[", "t", "]"}]}], " ", "-", " ", 
        RowBox[{"3", 
         RowBox[{"x", "[", "t", "]"}]}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Does    x'[t] = 5y[t] - 3x[t] ? \>\"", ",", 
      RowBox[{"ExpandAll", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"5", 
          RowBox[{"y", "[", "t", "]"}]}], " ", "-", " ", 
         RowBox[{"3", 
          RowBox[{"x", "[", "t", "]"}]}]}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399648559078125*^9, 3.399648560046875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "/s DSolve package to solve the system of D.E.'s and plot the solution."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "eqn1", ",", "eqn2", ",", "solset", ",", "t", ",", "x", ",", "y"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqn1", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "'"}], "[", "t", "]"}], " ", "\[Equal]", "  ", 
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], " ", "-", " ", 
       RowBox[{"x", "[", "t", "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqn2", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
      RowBox[{
       RowBox[{"5", 
        RowBox[{"y", "[", "t", "]"}]}], " ", "-", " ", 
       RowBox[{"3", 
        RowBox[{"x", "[", "t", "]"}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eqn1", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eqn2", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"DSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"eqn1", ",", "eqn2", ",", " ", 
         RowBox[{
          RowBox[{"x", "[", "0", "]"}], "\[Equal]", "2"}], ",", " ", 
         RowBox[{
          RowBox[{"y", "[", "0", "]"}], "\[Equal]", "1"}]}], "}"}], ",", " ", 
       "\n", "                ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], ",", " ", 
         RowBox[{"x", "[", "t", "]"}]}], "}"}], ",", " ", "t"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"FullSimplify", "[", 
      SubscriptBox["solset", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"FullSimplify", "[", 
      SubscriptBox["solset", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "2", ",", "2"}], "\[RightDoubleBracket]"}]], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "t", "]"}], ",", 
       RowBox[{"y", "[", "t", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "5"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Magenta"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "0.25"}], "]"}]}], "}"}]}]}], "]"}], 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[t] = \>\"", ",", 
      RowBox[{"y", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[t] = \>\"", ",", 
      RowBox[{"x", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", "y0"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[0] = \>\"", ",", "x0"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399648561765625*^9, 3.399648565625*^9}, {
  3.4002237740625*^9, 3.400223774375*^9}}]
}, Closed]],

Cell[TextData[{
 "\tAccording to Equation ",
 StyleBox["(12-29)",
  FontColor->RGBColor[0, 0, 1]],
 ", the inverse Laplace transform is given by the integral formula  \n\n\t\t\t\
",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     StyleBox[
      SuperscriptBox["\[ScriptCapitalL]", 
       RowBox[{"-", "1"}]],
      FontSize->16], 
     RowBox[{"(", 
      RowBox[{"F", 
       RowBox[{"(", "s", ")"}]}], ")"}]}], " ", "=", " ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{
        SubscriptBox["\[Sigma]", "0"], "-", "\[ImaginaryI]\[Infinity]"}], 
       RowBox[{
        SubscriptBox["\[Sigma]", "0"], "+", "\[ImaginaryI]\[Infinity]"}]], 
      " ", 
      RowBox[{"F", 
       RowBox[{"(", "s", ")"}], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"s", " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "s"}]}]}]}]}]}]]],
 ",  \n\nwhere ",
 Cell[BoxData[
  SubscriptBox["\[Sigma]", "0"]]],
 " is any suitably chosen large positive constant.  This improper integral is \
a contour integral taken along the vertical line ",
 Cell[BoxData[
  RowBox[{"s", "=", 
   RowBox[{
    SubscriptBox["\[Sigma]", "0"], "+", 
    RowBox[{"\[ImaginaryI]", " ", "\[Tau]"}]}]}]]],
 " in the complex ",
 Cell[BoxData[
  RowBox[{"s", "=", 
   RowBox[{"\[Sigma]", "+", 
    RowBox[{"\[ImaginaryI]", " ", "\[Tau]"}]}]}]]],
 " plane.  We use the residue theory in Chapter 8 to evaluate it.  We leave \
the cases in which the integrand has either infinitely many poles or branch \
points for you to research in advanced texts.  We state the following more \
elementary theorem."
}], "Text",
 CellChangeTimes->{3.399636909265625*^9}],

Cell[TextData[{
 StyleBox["Theorem 12.22 (Inverse Laplace Transform).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "s", ")"}]}], "=", 
   FractionBox[
    RowBox[{"P", 
     RowBox[{"(", "s", ")"}]}], 
    RowBox[{"Q", 
     RowBox[{"(", "s", ")"}]}]]}]]],
 ", where ",
 Cell[BoxData[
  RowBox[{"P", 
   RowBox[{"(", "s", ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "Q", 
   RowBox[{"(", "s", ")"}]}]]],
 " are polynomials of degree ",
 StyleBox["m",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ", respectively, and  ",
 Cell[BoxData[
  RowBox[{"n", ">", "m"}]]],
 ".  The inverse Laplace transform of  ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "s", ")"}]}]]],
 "  is given by  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    StyleBox[
     SuperscriptBox["\[ScriptCapitalL]", 
      RowBox[{"-", "1"}]],
     FontSize->16], 
    RowBox[{"(", 
     RowBox[{"F", 
      RowBox[{"(", "s", ")"}]}], ")"}]}]}]]],
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"=", " ", 
    RowBox[{"\[Sum]", " ", 
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"F", 
        RowBox[{"(", "s", ")"}], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"s", " ", "t"}]]}], ",", 
       SubscriptBox["s", "k"]}], "]"}]}]}]}]]],
 ",  \n\nwhere the sum is taken over all the residues of the complex function \
 ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "s", ")"}], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"s", " ", "t"}]]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.22 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tUsing the residue calculus, the English mathematician ",
 ButtonBox["Oliver Heaviside",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Heaviside.\
html"], None}],
 " discovered a method for inverting the Laplace transform."
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 12.23 (Heaviside Expansion Theorem).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 Cell[BoxData[
  RowBox[{"P", 
   RowBox[{"(", "s", ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"Q", 
   RowBox[{"(", "s", ")"}]}]]],
 " be polynomials of degree ",
 StyleBox["m",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ", respectively, where ",
 Cell[BoxData[
  RowBox[{"n", ">", "m"}]]],
 ". If ",
 Cell[BoxData[
  RowBox[{"Q", 
   RowBox[{"(", "s", ")"}]}]]],
 " has ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " distinct simple zeros at the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    StyleBox["s",
     FontSize->14], "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14], 
   SubscriptBox[
    StyleBox["s",
     FontSize->14], "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14], 
   StyleBox["...",
    FontFamily->"Times New Roman",
    FontSize->14], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->14], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14], 
   SubscriptBox[
    StyleBox["s",
     FontSize->14], "n"]}]]],
 ",  then  ",
 Cell[BoxData[
  FractionBox[
   StyleBox[
    RowBox[{"P", 
     RowBox[{"(", "s", ")"}]}],
    FontSize->12], 
   StyleBox[
    RowBox[{"Q", 
     RowBox[{"(", "s", ")"}]}],
    FontSize->12]]]],
 "  is the Laplace transform of the function  ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "t", ")"}]}]]],
 "  given by\n\n",
 StyleBox["(12.44)\t",
  FontColor->RGBColor[0, 0, 1]],
 "\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    RowBox[{
     StyleBox[
      SuperscriptBox["\[ScriptCapitalL]", 
       RowBox[{"-", "1"}]],
      FontSize->16], 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"P", 
        RowBox[{"(", "s", ")"}]}], 
       RowBox[{"Q", 
        RowBox[{"(", "s", ")"}]}]], ")"}]}], "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "1"}], "n"], 
     RowBox[{
      FractionBox[
       RowBox[{"P", 
        RowBox[{"(", 
         SubscriptBox["s", "k"], ")"}]}], 
       RowBox[{
        RowBox[{"Q", "'"}], 
        RowBox[{"(", 
         SubscriptBox["s", "k"], ")"}]}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SubscriptBox["s", "k"], " ", "t"}]]}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.23 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 12.28.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Let  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "s", ")"}]}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{"4", "s"}], " ", "+", " ", "3"}], 
    RowBox[{" ", 
     RowBox[{
      SuperscriptBox["s", "3"], " ", "+", " ", 
      RowBox[{"2", 
       SuperscriptBox["s", "2"]}], " ", "+", " ", "s", " ", "+", " ", 
      "2"}]}]]}]]],
 ".  Find  ",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    SuperscriptBox["\[ScriptCapitalL]", 
     RowBox[{"-", "1"}]],
    FontSize->16], 
   RowBox[{"(", 
    RowBox[{"Y", 
     RowBox[{"(", "s", ")"}]}], ")"}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Solution.", "Text"],

Cell[TextData[{
 "Here we have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", 
    RowBox[{"(", "s", ")"}]}], "=", 
   RowBox[{
    RowBox[{"4", "s"}], "+", "3"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Q", 
    RowBox[{"(", "s", ")"}]}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["s", "3"], "+", 
     RowBox[{"2", 
      SuperscriptBox["s", "2"]}], "+", "s", "+", "2"}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s", "+", "2"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s", "2"], "+", "1"}], ")"}]}]}]}]]],
 "  so that ",
 Cell[BoxData[
  RowBox[{"Q", 
   RowBox[{"(", "s", ")"}]}]]],
 " has simple zeros located at the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["s", "1"], "=", 
   RowBox[{"-", "2"}]}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["s", "2"], "=", "\[ImaginaryI]"}]]],
 ", and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["s", "3"], "=", 
   RowBox[{"-", "\[ImaginaryI]"}]}]]],
 ".  When we use  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"Q", "'"}], 
    RowBox[{"(", "s", ")"}]}], "=", 
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["s", "2"]}], "+", 
    RowBox[{"4", " ", "s"}], "+", "1"}]}]]],
 ",  calculation reveals that \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"P", 
     RowBox[{"(", 
      SubscriptBox["s", "1"], ")"}]}], 
    RowBox[{
     RowBox[{"Q", "'"}], 
     RowBox[{"(", 
      SubscriptBox["s", "1"], ")"}]}]], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"P", 
      RowBox[{"(", 
       RowBox[{"-", "2"}], ")"}]}], 
     RowBox[{
      RowBox[{"Q", "'"}], 
      RowBox[{"(", 
       RowBox[{"-", "2"}], ")"}]}]], "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"4", 
        RowBox[{"(", 
         RowBox[{"-", "2"}], ")"}]}], " ", "+", " ", "3"}], 
      RowBox[{
       RowBox[{"3", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "2"}], ")"}], "2"]}], " ", "+", " ", 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"-", "2"}], ")"}]}], " ", "+", " ", "1"}]], "  ", "=", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"-", "5"}], "5"], " ", "=", " ", 
      RowBox[{"-", "1"}]}]}]}]}]]],
 "\n\n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"P", 
      RowBox[{"(", 
       SubscriptBox["s", "2"], ")"}]}], 
     RowBox[{
      RowBox[{"Q", "'"}], 
      RowBox[{"(", 
       SubscriptBox["s", "2"], ")"}]}]], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"P", 
       RowBox[{"(", "\[ImaginaryI]", ")"}]}], 
      RowBox[{
       RowBox[{"Q", "'"}], 
       RowBox[{"(", "\[ImaginaryI]", ")"}]}]], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"4", 
        RowBox[{"(", "\[ImaginaryI]", ")"}]}], " ", "+", " ", "3"}], 
      RowBox[{
       RowBox[{"3", 
        SuperscriptBox[
         RowBox[{"(", "\[ImaginaryI]", ")"}], "2"]}], " ", "+", " ", 
       RowBox[{"4", " ", 
        RowBox[{"(", "\[ImaginaryI]", ")"}]}], " ", "+", " ", "1"}]]}]}], " ",
    "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"3", "+", 
       RowBox[{"4", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"4", " ", "\[ImaginaryI]"}]}]], " ", "=", " ", 
     RowBox[{
      FractionBox["1", "2"], "-", "\[ImaginaryI]"}]}]}]}]}]],
 " \n\n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"P", 
      RowBox[{"(", 
       SubscriptBox["s", "3"], ")"}]}], 
     RowBox[{
      RowBox[{"Q", "'"}], 
      RowBox[{"(", 
       SubscriptBox["s", "3"], ")"}]}]], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"P", 
       RowBox[{"(", 
        RowBox[{"-", "\[ImaginaryI]"}], ")"}]}], 
      RowBox[{
       RowBox[{"Q", "'"}], 
       RowBox[{"(", 
        RowBox[{"-", "\[ImaginaryI]"}], ")"}]}]], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"4", 
        RowBox[{"(", 
         RowBox[{"-", "\[ImaginaryI]"}], ")"}]}], " ", "+", " ", "3"}], 
      RowBox[{
       RowBox[{"3", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "\[ImaginaryI]"}], ")"}], "2"]}], " ", "+", " ", 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"-", "\[ImaginaryI]"}], ")"}]}], " ", "+", " ", "1"}]]}]}], 
   " ", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"3", "-", 
       RowBox[{"4", " ", "\[ImaginaryI]"}]}], 
      RowBox[{
       RowBox[{"-", "2"}], "-", 
       RowBox[{"4", " ", "\[ImaginaryI]"}]}]], " ", "=", "  ", 
     RowBox[{
      FractionBox["1", "2"], "+", "\[ImaginaryI]"}]}]}]}]}]],
 " "
}], "Text"],

Cell[TextData[{
 "Applying Equation ",
 StyleBox["(12-44)",
  FontColor->RGBColor[0, 0, 1]],
 " in Theorem 12.23 gives ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "1"}], "n"], 
    RowBox[{
     FractionBox[
      RowBox[{"P", 
       RowBox[{"(", 
        SubscriptBox["s", "k"], ")"}]}], 
      RowBox[{
       RowBox[{"Q", "'"}], 
       RowBox[{"(", 
        SubscriptBox["s", "k"], ")"}]}]], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       SubscriptBox["s", "k"], " ", "t"}]]}]}]}]]],
 " as \n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"P", 
        RowBox[{"(", 
         SubscriptBox["s", "1"], ")"}]}], 
       RowBox[{
        RowBox[{"Q", "'"}], 
        RowBox[{"(", 
         SubscriptBox["s", "1"], ")"}]}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SubscriptBox["s", "1"], " ", "t"}]]}], " ", "+", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"P", 
        RowBox[{"(", 
         SubscriptBox["s", "2"], ")"}]}], 
       RowBox[{
        RowBox[{"Q", "'"}], 
        RowBox[{"(", 
         SubscriptBox["s", "2"], ")"}]}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SubscriptBox["s", "2"], " ", "t"}]]}], " ", "+", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"P", 
        RowBox[{"(", 
         SubscriptBox["s", "3"], ")"}]}], 
       RowBox[{
        RowBox[{"Q", "'"}], 
        RowBox[{"(", 
         SubscriptBox["s", "3"], ")"}]}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SubscriptBox["s", "3"], " ", "t"}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"          ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "t"}]]}], " ", "+", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", "2"], "-", "\[ImaginaryI]"}], ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "t"}]]}], " ", "+", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", "2"], "+", "\[ImaginaryI]"}], ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "t"}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"-", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "t"}]]}], " ", "+", " ", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "t"}]], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t"}]]}], "2"], ")"}], " ", 
     "+", " ", 
     RowBox[{"2", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "t"}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t"}]]}], 
       RowBox[{"2", "\[ImaginaryI]"}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"-", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "t"}]]}], " ", "+", " ", 
     RowBox[{"cos", 
      RowBox[{"(", "t", ")"}]}], " ", "+", " ", 
     RowBox[{"2", "sin", 
      RowBox[{"(", "t", ")"}]}]}]}]}]}]],
 "  "
}], "Text",
 CellChangeTimes->{3.399636915546875*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"Solution", " ", 
   RowBox[{"12.28", "."}]}],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Subsection",
 CellChangeTimes->{{3.506707542375*^9, 3.506707542390625*^9}}],

Cell["\<\
Enter Y[s] and use the Heaviside Expansion Theorem to find y[t].\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "P", ",", "Q", ",", "solset", ",", "s", ",", "t", ",", "y", ",", "Y"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"P", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"4", "s"}], " ", "+", " ", "3"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Q", "[", "s_", "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["s", "3"], " ", "+", " ", 
      RowBox[{"2", 
       SuperscriptBox["s", "2"]}], " ", "+", " ", "s", " ", "+", " ", "2"}]}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "s_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"P", "[", "s", "]"}], 
      RowBox[{"Q", "[", "s", "]"}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Q", "[", "s", "]"}], "\[Equal]", "0"}], ",", "s"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["s", "1"], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["s", "2"], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"2", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["s", "3"], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"3", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<P[s] = \>\"", ",", 
      RowBox[{"P", "[", "s", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Q[s] = \>\"", ",", 
      RowBox[{"Q", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[s] = \>\"", ",", 
      RowBox[{"Y", "[", "s", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve the equation Q[s] = 0\>\"", "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Q", "[", "s", "]"}], " ", "\[Equal]", "0"}], " ", "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Factor", "[", 
       RowBox[{"Q", "[", "s", "]"}], "]"}], "\[Equal]", "0"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(s\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["s", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(s\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["s", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(s\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["s", "3"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399648586890625*^9, 3.3996485884375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Q[s] has simple zeros at the points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["s", "1"], " ", "=", 
    RowBox[{"-", "2"}]}], ",", " ", 
   RowBox[{
    SubscriptBox["s", "2"], " ", "=", 
    RowBox[{"-", "\[ImaginaryI]"}]}], ",", " ", 
   RowBox[{
    RowBox[{"and", "  ", 
     SubscriptBox["s", "3"]}], " ", "=", "\[ImaginaryI]"}]}]]],
 ".  Construct the three terms  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"P", "[", 
       SubscriptBox["s", "k"], "]"}], 
      RowBox[{
       RowBox[{"Q", "'"}], "[", 
       SubscriptBox["s", "k"], "]"}]], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       SubscriptBox["s", "k"], "t"}]], "  ", "for", "  ", "k"}], " ", "=", 
    " ", "1"}], ",", "2", ",", "3"}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<P[\>\"", ",", 
      SubscriptBox["s", "1"], ",", "\"\<]/Q'[\>\"", ",", 
      SubscriptBox["s", "1"], ",", "\"\<] = (\>\"", ",", 
      RowBox[{"P", "[", 
       SubscriptBox["s", "1"], "]"}], ",", "\"\<)/(\>\"", ",", 
      RowBox[{
       RowBox[{"Q", "'"}], "[", 
       SubscriptBox["s", "1"], "]"}], ",", "\"\<) = \>\"", ",", 
      FractionBox[
       RowBox[{"P", "[", 
        SubscriptBox["s", "1"], "]"}], 
       RowBox[{
        RowBox[{"Q", "'"}], "[", 
        SubscriptBox["s", "1"], "]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<P[\>\"", ",", 
      SubscriptBox["s", "2"], ",", "\"\<]/Q'[\>\"", ",", 
      SubscriptBox["s", "2"], ",", "\"\<] = (\>\"", ",", 
      RowBox[{"P", "[", 
       SubscriptBox["s", "2"], "]"}], ",", "\"\<)/(\>\"", ",", 
      RowBox[{
       RowBox[{"Q", "'"}], "[", 
       SubscriptBox["s", "2"], "]"}], ",", "\"\<) = \>\"", ",", 
      FractionBox[
       RowBox[{"P", "[", 
        SubscriptBox["s", "2"], "]"}], 
       RowBox[{
        RowBox[{"Q", "'"}], "[", 
        SubscriptBox["s", "2"], "]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<P[\>\"", ",", 
      SubscriptBox["s", "3"], ",", "\"\<]/Q'[\>\"", ",", 
      SubscriptBox["s", "3"], ",", "\"\<] = (\>\"", ",", 
      RowBox[{"P", "[", 
       SubscriptBox["s", "3"], "]"}], ",", "\"\<)/(\>\"", ",", 
      RowBox[{
       RowBox[{"Q", "'"}], "[", 
       SubscriptBox["s", "3"], "]"}], ",", "\"\<) = \>\"", ",", 
      FractionBox[
       RowBox[{"P", "[", 
        SubscriptBox["s", "3"], "]"}], 
       RowBox[{
        RowBox[{"Q", "'"}], "[", 
        SubscriptBox["s", "3"], "]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<P[\>\"", ",", 
      SubscriptBox["s", "1"], ",", "\"\<]/Q'[\>\"", ",", 
      SubscriptBox["s", "1"], ",", "\"\<] \>\"", ",", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SubscriptBox["s", "1"], "t"}]], ",", "\"\< = \>\"", ",", 
      RowBox[{
       FractionBox[
        RowBox[{"P", "[", 
         SubscriptBox["s", "1"], "]"}], 
        RowBox[{
         RowBox[{"Q", "'"}], "[", 
         SubscriptBox["s", "1"], "]"}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SubscriptBox["s", "1"], "t"}]]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<P[\>\"", ",", 
      SubscriptBox["s", "2"], ",", "\"\<]/Q'[\>\"", ",", 
      SubscriptBox["s", "2"], ",", "\"\<] \>\"", ",", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SubscriptBox["s", "2"], "t"}]], ",", "\"\< = \>\"", ",", 
      RowBox[{
       FractionBox[
        RowBox[{"P", "[", 
         SubscriptBox["s", "2"], "]"}], 
        RowBox[{
         RowBox[{"Q", "'"}], "[", 
         SubscriptBox["s", "2"], "]"}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SubscriptBox["s", "2"], "t"}]]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<P[\>\"", ",", 
      SubscriptBox["s", "2"], ",", "\"\<]/Q'[\>\"", ",", 
      SubscriptBox["s", "2"], ",", "\"\<] \>\"", ",", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SubscriptBox["s", "2"], "t"}]], ",", "\"\< = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"P", "[", 
          SubscriptBox["s", "2"], "]"}], 
         RowBox[{
          RowBox[{"Q", "'"}], "[", 
          SubscriptBox["s", "2"], "]"}]], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SubscriptBox["s", "2"], "t"}]]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<P[\>\"", ",", 
      SubscriptBox["s", "3"], ",", "\"\<]/Q'[\>\"", ",", 
      SubscriptBox["s", "3"], ",", "\"\<] \>\"", ",", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SubscriptBox["s", "3"], "t"}]], ",", "\"\< = \>\"", ",", 
      RowBox[{
       FractionBox[
        RowBox[{"P", "[", 
         SubscriptBox["s", "3"], "]"}], 
        RowBox[{
         RowBox[{"Q", "'"}], "[", 
         SubscriptBox["s", "3"], "]"}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SubscriptBox["s", "3"], "t"}]]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<P[\>\"", ",", 
      SubscriptBox["s", "3"], ",", "\"\<]/Q'[\>\"", ",", 
      SubscriptBox["s", "3"], ",", "\"\<] \>\"", ",", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SubscriptBox["s", "3"], "t"}]], ",", "\"\< = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"P", "[", 
          SubscriptBox["s", "3"], "]"}], 
         RowBox[{
          RowBox[{"Q", "'"}], "[", 
          SubscriptBox["s", "3"], "]"}]], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SubscriptBox["s", "3"], "t"}]]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39964859171875*^9, 3.399648593421875*^9}}],

Cell["Use the Heaviside Expansion Theorem to construct y[t].", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "t_", "]"}], " ", "=", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"P", "[", 
         SubscriptBox["s", "1"], "]"}], 
        RowBox[{
         RowBox[{"Q", "'"}], "[", 
         SubscriptBox["s", "1"], "]"}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SubscriptBox["s", "1"], "t"}]]}], "+", 
      RowBox[{
       FractionBox[
        RowBox[{"P", "[", 
         SubscriptBox["s", "2"], "]"}], 
        RowBox[{
         RowBox[{"Q", "'"}], "[", 
         SubscriptBox["s", "2"], "]"}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SubscriptBox["s", "2"], "t"}]]}], "+", 
      RowBox[{
       FractionBox[
        RowBox[{"P", "[", 
         SubscriptBox["s", "3"], "]"}], 
        RowBox[{
         RowBox[{"Q", "'"}], "[", 
         SubscriptBox["s", "3"], "]"}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SubscriptBox["s", "3"], "t"}]]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[t] = P[\>\"", ",", 
      SubscriptBox["s", "1"], ",", "\"\<]/Q'[\>\"", ",", 
      SubscriptBox["s", "1"], ",", "\"\<] \>\"", ",", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SubscriptBox["s", "1"], "t"}]], ",", "\"\< + \>\"", ",", "\"\<P[\>\"",
       ",", 
      SubscriptBox["s", "2"], ",", "\"\<]/Q'[\>\"", ",", 
      SubscriptBox["s", "2"], ",", "\"\<] \>\"", ",", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SubscriptBox["s", "2"], "t"}]], ",", "\"\< + \>\"", ",", "\"\<P[\>\"",
       ",", 
      SubscriptBox["s", "3"], ",", "\"\<]/Q'[\>\"", ",", 
      SubscriptBox["s", "3"], ",", "\"\<] \>\"", ",", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        SubscriptBox["s", "3"], "t"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[t] = (\>\"", ",", 
      RowBox[{
       FractionBox[
        RowBox[{"P", "[", 
         SubscriptBox["s", "1"], "]"}], 
        RowBox[{
         RowBox[{"Q", "'"}], "[", 
         SubscriptBox["s", "1"], "]"}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SubscriptBox["s", "1"], "t"}]]}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{
       FractionBox[
        RowBox[{"P", "[", 
         SubscriptBox["s", "2"], "]"}], 
        RowBox[{
         RowBox[{"Q", "'"}], "[", 
         SubscriptBox["s", "2"], "]"}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SubscriptBox["s", "2"], "t"}]]}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{
       FractionBox[
        RowBox[{"P", "[", 
         SubscriptBox["s", "3"], "]"}], 
        RowBox[{
         RowBox[{"Q", "'"}], "[", 
         SubscriptBox["s", "3"], "]"}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         SubscriptBox["s", "3"], "t"}]]}], ",", "\"\<)\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[t] = (\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"P", "[", 
          SubscriptBox["s", "1"], "]"}], 
         RowBox[{
          RowBox[{"Q", "'"}], "[", 
          SubscriptBox["s", "1"], "]"}]], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SubscriptBox["s", "1"], "t"}]]}], "]"}], ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     + (\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"P", "[", 
          SubscriptBox["s", "2"], "]"}], 
         RowBox[{
          RowBox[{"Q", "'"}], "[", 
          SubscriptBox["s", "2"], "]"}]], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SubscriptBox["s", "2"], "t"}]]}], "]"}], ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     + (\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"P", "[", 
          SubscriptBox["s", "3"], "]"}], 
         RowBox[{
          RowBox[{"Q", "'"}], "[", 
          SubscriptBox["s", "3"], "]"}]], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SubscriptBox["s", "3"], "t"}]]}], "]"}], ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "t_", "]"}], " ", "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"y", "[", "t", "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[t] = \>\"", ",", 
      RowBox[{"y", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3996485951875*^9, 3.39964859746875*^9}}],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can check this with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s  result using the LaplaceTransform package."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"InverseLaplaceTransform", "[", 
      RowBox[{
       RowBox[{"Y", "[", "s", "]"}], ",", " ", "s", ",", " ", "t"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[s] = \>\"", ",", 
      RowBox[{"Map", "[", 
       RowBox[{"Expand", ",", 
        RowBox[{"Apart", "[", 
         RowBox[{"Y", "[", "s", "]"}], "]"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[t] = \>\"", ",", 
      RowBox[{"y", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39964859909375*^9, 3.399648599796875*^9}},
 AspectRatioFixed->True]
}, Closed]]
},
CellGrouping->Manual,
WindowSize->{910, 626},
WindowMargins->{{25, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1000, 24, 341, "Text"],
Cell[1548, 46, 125, 2, 29, "Text"],
Cell[1676, 50, 190, 4, 29, "Text"],
Cell[1869, 56, 1082, 34, 145, "Text"],
Cell[2954, 92, 2105, 82, 94, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[5084, 178, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[5228, 184, 194, 5, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[5437, 192, 3095, 116, 159, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[8557, 312, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[8701, 318, 172, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[8888, 325, 744, 31, 41, "Text",
 Evaluatable->False],
Cell[9635, 358, 25, 0, 29, "Text"],
Cell[9663, 360, 1002, 35, 80, "Text"],
Cell[10668, 397, 1470, 49, 135, "Text"],
Cell[12141, 448, 5587, 195, 510, "Text"],
Cell[17731, 645, 1545, 54, 91, "Text"],
Cell[19279, 701, 3163, 109, 247, "Text"],
Cell[CellGroupData[{
Cell[22467, 814, 231, 6, 37, "Subsection"],
Cell[22701, 822, 67, 0, 29, "Text"],
Cell[22771, 824, 1001, 30, 156, "Input"],
Cell[23775, 856, 1060, 38, 76, "Text",
 Evaluatable->False],
Cell[24838, 896, 2195, 63, 257, "Input"],
Cell[27036, 961, 161, 7, 29, "Text",
 Evaluatable->False],
Cell[27200, 970, 912, 26, 146, "Input"],
Cell[28115, 998, 142, 4, 29, "Text",
 Evaluatable->False],
Cell[28260, 1004, 987, 30, 111, "Input"],
Cell[29250, 1036, 380, 15, 31, "Text",
 Evaluatable->False],
Cell[29633, 1053, 2502, 73, 255, "Input"],
Cell[32138, 1128, 276, 10, 29, "Text",
 Evaluatable->False],
Cell[32417, 1140, 874, 25, 132, "Input"],
Cell[33294, 1167, 2400, 81, 267, "Text"],
Cell[35697, 1250, 207, 7, 29, "Text"],
Cell[35907, 1259, 469, 14, 94, "Input"],
Cell[36379, 1275, 328, 9, 52, "Input"],
Cell[36710, 1286, 328, 9, 52, "Input"],
Cell[37041, 1297, 409, 12, 52, "Input"],
Cell[37453, 1311, 437, 13, 54, "Input"],
Cell[37893, 1326, 60, 0, 29, "Text"],
Cell[37956, 1328, 895, 27, 111, "Input"]
}, Closed]],
Cell[38866, 1358, 2631, 94, 159, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[41522, 1456, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[41666, 1462, 172, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[41853, 1469, 752, 32, 40, "Text",
 Evaluatable->False],
Cell[42608, 1503, 25, 0, 29, "Text"],
Cell[42636, 1505, 279, 7, 47, "Text"],
Cell[42918, 1514, 3500, 132, 152, "Text"],
Cell[46421, 1648, 2132, 75, 127, "Text"],
Cell[48556, 1725, 6388, 227, 512, "Text"],
Cell[CellGroupData[{
Cell[54969, 1956, 231, 6, 37, "Subsection"],
Cell[55203, 1964, 67, 0, 29, "Text"],
Cell[55273, 1966, 1066, 32, 156, "Input"],
Cell[56342, 2000, 532, 16, 47, "Text",
 Evaluatable->False],
Cell[56877, 2018, 1459, 43, 192, "Input"],
Cell[58339, 2063, 142, 4, 29, "Text",
 Evaluatable->False],
Cell[58484, 2069, 3526, 107, 399, "Input"],
Cell[62013, 2178, 380, 15, 31, "Text",
 Evaluatable->False],
Cell[62396, 2195, 2496, 73, 255, "Input"],
Cell[64895, 2270, 276, 10, 29, "Text",
 Evaluatable->False],
Cell[65174, 2282, 831, 24, 132, "Input"],
Cell[66008, 2308, 3316, 108, 353, "Text"],
Cell[69327, 2418, 207, 7, 29, "Text"],
Cell[69537, 2427, 478, 15, 94, "Input"],
Cell[70018, 2444, 338, 10, 52, "Input"],
Cell[70359, 2456, 362, 11, 52, "Input"],
Cell[70724, 2469, 339, 10, 52, "Input"],
Cell[71066, 2481, 409, 12, 52, "Input"],
Cell[71478, 2495, 60, 0, 29, "Text"],
Cell[71541, 2497, 956, 28, 108, "Input"],
Cell[72500, 2527, 115, 3, 29, "Text"],
Cell[72618, 2532, 1990, 62, 188, "Input"]
}, Closed]],
Cell[74623, 2597, 862, 34, 44, "Text",
 Evaluatable->False],
Cell[75488, 2633, 25, 0, 29, "Text"],
Cell[75516, 2635, 239, 7, 29, "Text"],
Cell[75758, 2644, 875, 32, 76, "Text"],
Cell[76636, 2678, 2036, 70, 161, "Text"],
Cell[78675, 2750, 4886, 171, 444, "Text"],
Cell[83564, 2923, 6167, 200, 502, "Text"],
Cell[89734, 3125, 2416, 83, 145, "Text"],
Cell[92153, 3210, 2861, 99, 173, "Text"],
Cell[CellGroupData[{
Cell[95039, 3313, 233, 6, 37, "Subsection"],
Cell[95275, 3321, 67, 0, 29, "Text"],
Cell[95345, 3323, 1643, 50, 219, "Input"],
Cell[96991, 3375, 380, 15, 31, "Text",
 Evaluatable->False],
Cell[97374, 3392, 2501, 73, 255, "Input"],
Cell[99878, 3467, 276, 10, 29, "Text",
 Evaluatable->False],
Cell[100157, 3479, 794, 23, 132, "Input"],
Cell[100954, 3504, 3470, 108, 389, "Text"],
Cell[104427, 3614, 207, 7, 29, "Text"],
Cell[104637, 3623, 617, 18, 99, "Input"],
Cell[105257, 3643, 287, 8, 52, "Input"],
Cell[105547, 3653, 328, 10, 52, "Input"],
Cell[105878, 3665, 403, 13, 52, "Input"],
Cell[106284, 3680, 314, 9, 52, "Input"],
Cell[106601, 3691, 339, 10, 52, "Input"],
Cell[106943, 3703, 60, 0, 29, "Text"],
Cell[107006, 3705, 936, 28, 111, "Input"],
Cell[107945, 3735, 115, 3, 29, "Text"],
Cell[108063, 3740, 1944, 58, 194, "Input"]
}, Closed]],
Cell[110022, 3801, 1965, 68, 101, "Text",
 Evaluatable->False],
Cell[111990, 3871, 6952, 286, 267, "Text"],
Cell[118945, 4159, 25, 0, 29, "Text"],
Cell[118973, 4161, 3105, 113, 215, "Text"],
Cell[122081, 4276, 2582, 100, 161, "Text"],
Cell[124666, 4378, 2584, 90, 223, "Text"],
Cell[CellGroupData[{
Cell[127275, 4472, 229, 6, 37, "Subsection"],
Cell[127507, 4480, 192, 4, 29, "Text"],
Cell[127702, 4486, 5726, 164, 612, "Input"],
Cell[133431, 4652, 241, 8, 29, "Text",
 Evaluatable->False],
Cell[133675, 4662, 2318, 66, 232, "Input"],
Cell[135996, 4730, 284, 10, 29, "Text",
 Evaluatable->False],
Cell[136283, 4742, 3858, 111, 372, "Input"]
}, Closed]],
Cell[140156, 4856, 1812, 54, 145, "Text"],
Cell[141971, 4912, 1897, 74, 134, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[143893, 4990, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[144037, 4996, 172, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[144224, 5003, 318, 8, 26, "Text"],
Cell[144545, 5013, 2504, 108, 107, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[147074, 5125, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[147218, 5131, 172, 4, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[147405, 5138, 740, 31, 36, "Text",
 Evaluatable->False],
Cell[148148, 5171, 25, 0, 29, "Text"],
Cell[148176, 5173, 4835, 178, 329, "Text"],
Cell[153014, 5353, 3853, 130, 224, "Text"],
Cell[CellGroupData[{
Cell[156892, 5487, 214, 6, 37, "Subsection"],
Cell[157109, 5495, 88, 2, 29, "Text"],
Cell[157200, 5499, 3515, 103, 470, "Input"],
Cell[160718, 5604, 863, 31, 40, "Text",
 Evaluatable->False],
Cell[161584, 5637, 5656, 160, 416, "Input"],
Cell[167243, 5799, 116, 2, 29, "Text",
 Evaluatable->False],
Cell[167362, 5803, 5081, 152, 345, "Input"],
Cell[172446, 5957, 276, 10, 29, "Text",
 Evaluatable->False],
Cell[172725, 5969, 908, 26, 132, "Input"]
}, Closed]]
}
]
*)

(* End of internal cache information *)
